package main

import (
	"regexp"
	"strconv"
)

type emojiData struct {
	Name        string
	Description string
	Unicode     string
	Alias       []string
}

func emojiUnicodeConvert(s string) string {
	re := regexp.MustCompile(`:(\w+|([+-]\d)):`)
	return re.ReplaceAllStringFunc(s, renderUnicodeEmoji)
}

func resolveRootEmojis(s string) string {
	re := regexp.MustCompile(`:(\w+|([+-]\d)):`)
	return re.ReplaceAllStringFunc(s, emojiRootLookup)
}

func emojiRootLookup(s string) string {
	if temp, ok := emojiMap[s]; ok {
		return temp.Name
	} else {
		return s
	}
}

func renderUnicodeEmoji(source string) string {
	if data, ok := emojiMap[source]; ok {
		emj, err := strconv.ParseInt(data.Unicode, 16, 32)
		if err != nil {
			// because not all of them are parseable (like keycaps \u0031-FE0F-20E3)
			return source
		} else {
			return string(emj)
		}
	} else {
		return source
	}
}

var emojiMap = map[string]emojiData{":+1:": emojiData{Name: ":+1:", Description: "Thumbs Up Sign", Unicode: "1F44D", Alias: []string{"thumbsup", "yes", "awesome", "good", "agree", "accept", "cool", "hand", "like"}}, ":-1:": emojiData{Name: ":-1:", Description: "Thumbs Down Sign", Unicode: "1F44E", Alias: []string{"thumbsdown", "no", "dislike", "hand"}}, ":-_-:": emojiData{Name: ":expressionless:", Description: "Expressionless Face", Unicode: "1F611", Alias: []string{"face", "indifferent", "-_-", "meh", "deadpan"}}, ":0:": emojiData{Name: ":zero:", Description: "Keycap 0", Unicode: "0030-FE0F-20E3", Alias: []string{"0", "numbers", "blue-square", "null"}}, ":100:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":101:": emojiData{Name: ":poodle:", Description: "Poodle", Unicode: "1F429", Alias: []string{"dog", "animal", "101", "nature", "pet"}}, ":10:": emojiData{Name: ":keycap_ten:", Description: "Keycap Ten", Unicode: "1F51F", Alias: []string{"numbers", "10", "blue-square"}}, ":1234:": emojiData{Name: ":1234:", Description: "Input Symbol for Numbers", Unicode: "1F522", Alias: []string{"numbers", "blue-square"}}, ":18:": emojiData{Name: ":underage:", Description: "No One Under Eighteen Symbol", Unicode: "1F51E", Alias: []string{"18", "drink", "pub", "night", "minor", "circle"}}, ":1:": emojiData{Name: ":one:", Description: "Keycap 1", Unicode: "0031-FE0F-20E3", Alias: []string{"blue-square", "numbers", "1"}}, ":2:": emojiData{Name: ":two:", Description: "Keycap 2", Unicode: "0032-FE0F-20E3", Alias: []string{"numbers", "2", "prime", "blue-square"}}, ":3:": emojiData{Name: ":three:", Description: "Keycap 3", Unicode: "0033-FE0F-20E3", Alias: []string{"3", "numbers", "prime", "blue-square"}}, ":4:": emojiData{Name: ":four:", Description: "Keycap 4", Unicode: "0034-FE0F-20E3", Alias: []string{"4", "numbers", "blue-square"}}, ":5:": emojiData{Name: ":five:", Description: "Keycap 5", Unicode: "0035-FE0F-20E3", Alias: []string{"5", "numbers", "blue-square", "prime"}}, ":6:": emojiData{Name: ":six:", Description: "Keycap 6", Unicode: "0036-FE0F-20E3", Alias: []string{"6", "numbers", "blue-square"}}, ":7:": emojiData{Name: ":seven:", Description: "Keycap 7", Unicode: "0037-FE0F-20E3", Alias: []string{"7", "numbers", "blue-square", "prime"}}, ":80s:": emojiData{Name: ":floppy_disk:", Description: "Floppy Disk", Unicode: "1F4BE", Alias: []string{"oldschool", "technology", "save", "90s", "80s"}}, ":8:": emojiData{Name: ":eight:", Description: "Keycap 8", Unicode: "0038-FE0F-20E3", Alias: []string{"8", "blue-square", "numbers"}}, ":8ball:": emojiData{Name: ":8ball:", Description: "Billiards", Unicode: "1F3B1", Alias: []string{"pool", "hobby", "game", "luck", "magic"}}, ":90s:": emojiData{Name: ":cd:", Description: "Optical Disc", Unicode: "1F4BF", Alias: []string{"technology", "dvd", "disk", "disc", "90s"}}, ":911:": emojiData{Name: ":ambulance:", Description: "Ambulance", Unicode: "1F691", Alias: []string{"health", "911", "hospital"}}, ":9:": emojiData{Name: ":nine:", Description: "Keycap 9", Unicode: "0039-FE0F-20E3", Alias: []string{"blue-square", "numbers", "9"}}, "::'(:": emojiData{Name: ":cry:", Description: "Crying Face", Unicode: "1F622", Alias: []string{"face", "tears", "sad", "depressed", "upset", ":'("}}, "::(:": emojiData{Name: ":worried:", Description: "Worried Face", Unicode: "1F61F", Alias: []string{"face", "concern", "nervous", ":("}}, "::):": emojiData{Name: ":smile:", Description: "Smiling Face with Open Mouth and Smiling Eyes", Unicode: "1F604", Alias: []string{"face", "happy", "joy", "funny", "haha", "laugh", "like", ":D", ":)"}}, "::/:": emojiData{Name: ":confused:", Description: "Confused Face", Unicode: "1F615", Alias: []string{"face", "indifference", "huh", "weird", "hmmm", ":/"}}, "::D:": emojiData{Name: ":smile:", Description: "Smiling Face with Open Mouth and Smiling Eyes", Unicode: "1F604", Alias: []string{"face", "happy", "joy", "funny", "haha", "laugh", "like", ":D", ":)"}}, "::O:": emojiData{Name: ":open_mouth:", Description: "Face with Open Mouth", Unicode: "1F62E", Alias: []string{"face", "surprise", "impressed", "wow", "whoa", ":O"}}, "::S:": emojiData{Name: ":confounded:", Description: "Confounded Face", Unicode: "1F616", Alias: []string{"face", "confused", "sick", "unwell", "oops", ":S"}}, "::|:": emojiData{Name: ":neutral_face:", Description: "Neutral Face", Unicode: "1F610", Alias: []string{"indifference", "meh", ":|", "neutral"}}, ":;):": emojiData{Name: ":wink:", Description: "Winking Face", Unicode: "1F609", Alias: []string{"face", "happy", "mischievous", "secret", ";)", "smile", "eye"}}, ":NASA:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":NBA:": emojiData{Name: ":basketball:", Description: "Basketball and Hoop", Unicode: "1F3C0", Alias: []string{"sports", "balls", "NBA"}}, ":NFL:": emojiData{Name: ":football:", Description: "American Football", Unicode: "1F3C8", Alias: []string{"sports", "balls", "NFL"}}, ":PA:": emojiData{Name: ":microphone:", Description: "Microphone", Unicode: "1F3A4", Alias: []string{"sound", "music", "PA", "sing", "talkshow"}}, ":PS4:": emojiData{Name: ":video_game:", Description: "Video Game", Unicode: "1F3AE", Alias: []string{"play", "console", "PS4", "controller"}}, ":UFO:": emojiData{Name: ":alien:", Description: "Extraterrestrial Alien", Unicode: "1F47D", Alias: []string{"UFO", "paul", "weird", "outer_space"}}, ":USA:": emojiData{Name: ":earth_americas:", Description: "Earth Globe Americas", Unicode: "1F30E", Alias: []string{"globe", "world", "USA", "international"}}, ":XD:": emojiData{Name: ":laughing:", Description: "Smiling Face with Open Mouth and Tightly-Closed Eyes", Unicode: "1F606", Alias: []string{"happy", "joy", "lol", "satisfied", "haha", "face", "glad", "XD", "laugh"}}, ":a11y:": emojiData{Name: ":wheelchair:", Description: "Wheelchair Symbol", Unicode: "267F", Alias: []string{"blue-square", "disabled", "a11y", "accessibility"}}, ":a:": emojiData{Name: ":a:", Description: "Negative Squared Latin Capital Letter a", Unicode: "1F170-FE0F", Alias: []string{"red-square", "alphabet", "letter"}}, ":ab:": emojiData{Name: ":ab:", Description: "Negative Squared Ab", Unicode: "1F18E", Alias: []string{"red-square", "alphabet"}}, ":abc:": emojiData{Name: ":abc:", Description: "Input Symbol for Latin Letters", Unicode: "1F524", Alias: []string{"blue-square", "alphabet"}}, ":abcd:": emojiData{Name: ":abcd:", Description: "Input Symbol for Latin Small Letters", Unicode: "1F521", Alias: []string{"blue-square", "alphabet"}}, ":above:": emojiData{Name: ":up:", Description: "Squared Up with Exclamation Mark", Unicode: "1F199", Alias: []string{"blue-square", "above", "high"}}, ":accept:": emojiData{Name: ":+1:", Description: "Thumbs Up Sign", Unicode: "1F44D", Alias: []string{"thumbsup", "yes", "awesome", "good", "agree", "accept", "cool", "hand", "like"}}, ":accessibility:": emojiData{Name: ":wheelchair:", Description: "Wheelchair Symbol", Unicode: "267F", Alias: []string{"blue-square", "disabled", "a11y", "accessibility"}}, ":accessories:": emojiData{Name: ":handbag:", Description: "Handbag", Unicode: "1F45C", Alias: []string{"fashion", "accessory", "accessories", "shopping"}}, ":accessory:": emojiData{Name: ":handbag:", Description: "Handbag", Unicode: "1F45C", Alias: []string{"fashion", "accessory", "accessories", "shopping"}}, ":accomodation:": emojiData{Name: ":hotel:", Description: "Hotel", Unicode: "1F3E8", Alias: []string{"building", "accomodation", "checkin"}}, ":acting:": emojiData{Name: ":performing_arts:", Description: "Performing Arts", Unicode: "1F3AD", Alias: []string{"acting", "theater", "drama"}}, ":addition:": emojiData{Name: ":heavy_plus_sign:", Description: "Heavy Plus Sign", Unicode: "2795", Alias: []string{"math", "calculation", "addition", "more", "increase"}}, ":admission_tickets:": emojiData{Name: ":admission_tickets:", Description: "Admission Tickets", Unicode: "1F39F-FE0F", Alias: []string(nil)}, ":adult:": emojiData{Name: ":adult:", Description: "Adult", Unicode: "1F9D1", Alias: []string(nil)}, ":aerial_tramway:": emojiData{Name: ":aerial_tramway:", Description: "Aerial Tramway", Unicode: "1F6A1", Alias: []string{"transportation", "vehicle", "ski"}}, ":affection:": emojiData{Name: ":kiss:", Description: "Kiss Mark", Unicode: "1F48B", Alias: []string{"face", "lips", "love", "like", "affection", "valentines"}}, ":afternoon:": emojiData{Name: ":low_brightness:", Description: "Low Brightness Symbol", Unicode: "1F505", Alias: []string{"sun", "afternoon", "warm", "summer"}}, ":agree:": emojiData{Name: ":+1:", Description: "Thumbs Up Sign", Unicode: "1F44D", Alias: []string{"thumbsup", "yes", "awesome", "good", "agree", "accept", "cool", "hand", "like"}}, ":agreement:": emojiData{Name: ":handshake:", Description: "Handshake", Unicode: "1F91D", Alias: []string{"agreement", "shake"}}, ":agriculture:": emojiData{Name: ":tractor:", Description: "Tractor", Unicode: "1F69C", Alias: []string{"vehicle", "car", "farming", "agriculture"}}, ":air:": emojiData{Name: ":dash:", Description: "Dash Symbol", Unicode: "1F4A8", Alias: []string{"wind", "air", "fast", "shoo", "fart", "smoke", "puff"}}, ":airplane:": emojiData{Name: ":seat:", Description: "Seat", Unicode: "1F4BA", Alias: []string{"sit", "airplane", "transport", "bus", "flight", "fly"}}, ":airplane_arriving:": emojiData{Name: ":airplane_arriving:", Description: "Airplane Arriving", Unicode: "1F6EC", Alias: []string(nil)}, ":airplane_departure:": emojiData{Name: ":airplane_departure:", Description: "Airplane Departure", Unicode: "1F6EB", Alias: []string(nil)}, ":airport:": emojiData{Name: ":baggage_claim:", Description: "Baggage Claim", Unicode: "1F6C4", Alias: []string{"blue-square", "airport", "transport"}}, ":alarm:": emojiData{Name: ":timer_clock:", Description: "Timer Clock", Unicode: "23F2-FE0F", Alias: []string{"alarm"}}, ":alarm_clock:": emojiData{Name: ":alarm_clock:", Description: "Alarm Clock", Unicode: "23F0", Alias: []string{"time", "wake"}}, ":alcohol:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":alembic:": emojiData{Name: ":alembic:", Description: "Alembic", Unicode: "2697-FE0F", Alias: []string{"distilling", "science", "experiment", "chemistry"}}, ":alert:": emojiData{Name: ":warning:", Description: "Warning Sign", Unicode: "26A0-FE0F", Alias: []string{"exclamation", "wip", "alert", "error", "problem", "issue"}}, ":alien:": emojiData{Name: ":alien:", Description: "Extraterrestrial Alien", Unicode: "1F47D", Alias: []string{"UFO", "paul", "weird", "outer_space"}}, ":allergy:": emojiData{Name: ":sneezing_face:", Description: "Sneezing Face", Unicode: "1F927", Alias: []string{"face", "gesundheit", "sneeze", "sick", "allergy"}}, ":alligator:": emojiData{Name: ":crocodile:", Description: "Crocodile", Unicode: "1F40A", Alias: []string{"animal", "nature", "reptile", "lizard", "alligator"}}, ":alphabet:": emojiData{Name: ":cl:", Description: "Squared Cl", Unicode: "1F191", Alias: []string{"alphabet", "words", "red-square"}}, ":ambulance:": emojiData{Name: ":ambulance:", Description: "Ambulance", Unicode: "1F691", Alias: []string{"health", "911", "hospital"}}, ":america:": emojiData{Name: ":us:", Description: "United States Flag", Unicode: "1F1FA-1F1F8", Alias: []string{"united", "states", "america", "flag", "nation", "country", "banner"}}, ":american:": emojiData{Name: ":statue_of_liberty:", Description: "Statue of Liberty", Unicode: "1F5FD", Alias: []string{"american", "newyork"}}, ":ampersand:": emojiData{Name: ":symbols:", Description: "Input Symbol for Symbols", Unicode: "1F523", Alias: []string{"blue-square", "music", "note", "ampersand", "percent", "glyphs", "characters"}}, ":amphora:": emojiData{Name: ":amphora:", Description: "Amphora", Unicode: "1F3FA", Alias: []string{"vase", "jar"}}, ":anchor:": emojiData{Name: ":anchor:", Description: "Anchor", Unicode: "2693", Alias: []string{"ship", "ferry", "sea", "boat"}}, ":ancient:": emojiData{Name: ":scroll:", Description: "Scroll", Unicode: "1F4DC", Alias: []string{"documents", "ancient", "history", "paper"}}, ":angel:": emojiData{Name: ":innocent:", Description: "Smiling Face with Halo", Unicode: "1F607", Alias: []string{"face", "angel", "heaven", "halo"}}, ":anger:": emojiData{Name: ":anger:", Description: "Anger Symbol", Unicode: "1F4A2", Alias: []string{"angry", "mad"}}, ":angry:": emojiData{Name: ":anger:", Description: "Anger Symbol", Unicode: "1F4A2", Alias: []string{"angry", "mad"}}, ":anguished:": emojiData{Name: ":anguished:", Description: "Anguished Face", Unicode: "1F627", Alias: []string{"face", "stunned", "nervous"}}, ":animal:": emojiData{Name: ":cow:", Description: "Cow Face", Unicode: "1F42E", Alias: []string{"beef", "ox", "animal", "nature", "moo", "milk"}}, ":annoyed:": emojiData{Name: ":angry:", Description: "Angry Face", Unicode: "1F620", Alias: []string{"mad", "face", "annoyed", "frustrated"}}, ":answer:": emojiData{Name: ":heavy_check_mark:", Description: "Heavy Check Mark", Unicode: "2714-FE0F", Alias: []string{"ok", "nike", "answer", "yes", "tick"}}, ":ant:": emojiData{Name: ":ant:", Description: "Ant", Unicode: "1F41C", Alias: []string{"animal", "insect", "nature", "bug"}}, ":appetizer:": emojiData{Name: ":fried_shrimp:", Description: "Fried Shrimp", Unicode: "1F364", Alias: []string{"food", "animal", "appetizer", "summer"}}, ":applause:": emojiData{Name: ":clap:", Description: "Clapping Hands Sign", Unicode: "1F44F", Alias: []string{"hands", "praise", "applause", "congrats", "yay"}}, ":apple:": emojiData{Name: ":iphone:", Description: "Mobile Phone", Unicode: "1F4F1", Alias: []string{"technology", "apple", "gadgets", "dial"}}, ":aquarius:": emojiData{Name: ":aquarius:", Description: "Aquarius", Unicode: "2652", Alias: []string{"sign", "purple-square", "zodiac", "astrology"}}, ":arabs:": emojiData{Name: ":man_with_turban:", Description: "Man with Turban", Unicode: "1F473", Alias: []string{"male", "indian", "hinduism", "arabs"}}, ":arachnid:": emojiData{Name: ":scorpion:", Description: "Scorpion", Unicode: "1F982", Alias: []string{"animal", "arachnid"}}, ":arcade:": emojiData{Name: ":space_invader:", Description: "Alien Monster", Unicode: "1F47E", Alias: []string{"game", "arcade", "play"}}, ":architect:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":aries:": emojiData{Name: ":aries:", Description: "Aries", Unicode: "2648", Alias: []string{"sign", "purple-square", "zodiac", "astrology"}}, ":arm:": emojiData{Name: ":muscle:", Description: "Flexed Biceps", Unicode: "1F4AA", Alias: []string{"arm", "flex", "hand", "summer", "strong", "biceps"}}, ":arrest:": emojiData{Name: ":chains:", Description: "Chains", Unicode: "26D3-FE0F", Alias: []string{"lock", "arrest"}}, ":arrow:": emojiData{Name: ":on:", Description: "On with Exclamation Mark with Left Right Arrow Above", Unicode: "1F51B", Alias: []string{"arrow", "words"}}, ":arrow_backward:": emojiData{Name: ":arrow_backward:", Description: "Black Left-Pointing Triangle", Unicode: "25C0-FE0F", Alias: []string{"blue-square", "left", "direction"}}, ":arrow_double_down:": emojiData{Name: ":arrow_double_down:", Description: "Black Down-Pointing Double Triangle", Unicode: "23EC", Alias: []string{"blue-square", "direction", "bottom"}}, ":arrow_double_up:": emojiData{Name: ":arrow_double_up:", Description: "Black Up-Pointing Double Triangle", Unicode: "23EB", Alias: []string{"blue-square", "direction", "top"}}, ":arrow_down:": emojiData{Name: ":arrow_down:", Description: "Downwards Black Arrow", Unicode: "2B07-FE0F", Alias: []string{"blue-square", "direction", "bottom"}}, ":arrow_down_small:": emojiData{Name: ":arrow_down_small:", Description: "Down-Pointing Small Red Triangle", Unicode: "1F53D", Alias: []string{"blue-square", "direction", "bottom"}}, ":arrow_forward:": emojiData{Name: ":arrow_forward:", Description: "Black Right-Pointing Triangle", Unicode: "25B6-FE0F", Alias: []string{"blue-square", "right", "direction", "play"}}, ":arrow_heading_down:": emojiData{Name: ":arrow_heading_down:", Description: "Arrow Pointing Rightwards Then Curving Downwards", Unicode: "2935-FE0F", Alias: []string{"blue-square", "direction", "bottom"}}, ":arrow_heading_up:": emojiData{Name: ":arrow_heading_up:", Description: "Arrow Pointing Rightwards Then Curving Upwards", Unicode: "2934-FE0F", Alias: []string{"blue-square", "direction", "top"}}, ":arrow_left:": emojiData{Name: ":arrow_left:", Description: "Leftwards Black Arrow", Unicode: "2B05-FE0F", Alias: []string{"blue-square", "previous", "back"}}, ":arrow_lower_left:": emojiData{Name: ":arrow_lower_left:", Description: "South West Arrow", Unicode: "2199-FE0F", Alias: []string{"blue-square", "direction", "diagonal", "southwest"}}, ":arrow_lower_right:": emojiData{Name: ":arrow_lower_right:", Description: "South East Arrow", Unicode: "2198-FE0F", Alias: []string{"blue-square", "direction", "diagonal", "southeast"}}, ":arrow_right:": emojiData{Name: ":arrow_right:", Description: "Black Rightwards Arrow", Unicode: "27A1-FE0F", Alias: []string{"blue-square", "next"}}, ":arrow_right_hook:": emojiData{Name: ":arrow_right_hook:", Description: "Rightwards Arrow with Hook", Unicode: "21AA-FE0F", Alias: []string{"blue-square", "return", "rotate", "direction"}}, ":arrow_up:": emojiData{Name: ":arrow_up:", Description: "Upwards Black Arrow", Unicode: "2B06-FE0F", Alias: []string{"blue-square", "continue", "top", "direction"}}, ":arrow_up_down:": emojiData{Name: ":arrow_up_down:", Description: "Up Down Arrow", Unicode: "2195-FE0F", Alias: []string{"blue-square", "direction", "way", "vertical"}}, ":arrow_up_small:": emojiData{Name: ":arrow_up_small:", Description: "Up-Pointing Small Red Triangle", Unicode: "1F53C", Alias: []string{"blue-square", "triangle", "direction", "point", "forward", "top"}}, ":arrow_upper_left:": emojiData{Name: ":arrow_upper_left:", Description: "North West Arrow", Unicode: "2196-FE0F", Alias: []string{"blue-square", "point", "direction", "diagonal", "northwest"}}, ":arrow_upper_right:": emojiData{Name: ":arrow_upper_right:", Description: "North East Arrow", Unicode: "2197-FE0F", Alias: []string{"blue-square", "point", "direction", "diagonal", "northeast"}}, ":arrows_clockwise:": emojiData{Name: ":arrows_clockwise:", Description: "Clockwise Downwards and Upwards Open Circle Arrows", Unicode: "1F503", Alias: []string{"sync", "cycle", "round", "repeat"}}, ":arrows_counterclockwise:": emojiData{Name: ":arrows_counterclockwise:", Description: "Anticlockwise Downwards and Upwards Open Circle Arrows", Unicode: "1F504", Alias: []string{"blue-square", "sync", "cycle"}}, ":art:": emojiData{Name: ":art:", Description: "Artist Palette", Unicode: "1F3A8", Alias: []string{"design", "paint", "draw", "colors"}}, ":articulated_lorry:": emojiData{Name: ":articulated_lorry:", Description: "Articulated Lorry", Unicode: "1F69B", Alias: []string{"vehicle", "cars", "transportation", "express"}}, ":artist:": emojiData{Name: ":studio_microphone:", Description: "Studio Microphone", Unicode: "1F399-FE0F", Alias: []string{"sing", "recording", "artist", "talkshow"}}, ":ashes:": emojiData{Name: ":funeral_urn:", Description: "Funeral Urn", Unicode: "26B1-FE0F", Alias: []string{"dead", "die", "death", "rip", "ashes"}}, ":asia:": emojiData{Name: ":rice_scene:", Description: "Moon Viewing Ceremony", Unicode: "1F391", Alias: []string{"photo", "japan", "asia", "tsukimi"}}, ":asian:": emojiData{Name: ":rice:", Description: "Cooked Rice", Unicode: "1F35A", Alias: []string{"food", "china", "asian"}}, ":astonished:": emojiData{Name: ":astonished:", Description: "Astonished Face", Unicode: "1F632", Alias: []string{"face", "xox", "surprised", "poisoned"}}, ":astrology:": emojiData{Name: ":ophiuchus:", Description: "Ophiuchus", Unicode: "26CE", Alias: []string{"sign", "purple-square", "constellation", "astrology"}}, ":astronomy:": emojiData{Name: ":telescope:", Description: "Telescope", Unicode: "1F52D", Alias: []string{"stars", "space", "zoom", "science", "astronomy"}}, ":athletic_shoe:": emojiData{Name: ":athletic_shoe:", Description: "Athletic Shoe", Unicode: "1F45F", Alias: []string{"shoes", "sports", "sneakers"}}, ":atm:": emojiData{Name: ":atm:", Description: "Automated Teller Machine", Unicode: "1F3E7", Alias: []string{"money", "sales", "cash", "blue-square", "payment", "bank"}}, ":atom_symbol:": emojiData{Name: ":atom_symbol:", Description: "Atom Symbol", Unicode: "269B-FE0F", Alias: []string{"science", "physics", "chemistry"}}, ":attack:": emojiData{Name: ":facepunch:", Description: "Fisted Hand Sign", Unicode: "1F44A", Alias: []string{"angry", "violence", "fist", "hit", "attack", "hand"}}, ":aubergine:": emojiData{Name: ":eggplant:", Description: "Aubergine", Unicode: "1F346", Alias: []string{"vegetable", "nature", "food", "aubergine"}}, ":avocado:": emojiData{Name: ":avocado:", Description: "Avocado", Unicode: "1F951", Alias: []string{"fruit", "food"}}, ":aw:": emojiData{Name: ":frowning:", Description: "Frowning Face with Open Mouth", Unicode: "1F626", Alias: []string{"face", "aw", "what"}}, ":award:": emojiData{Name: ":trophy:", Description: "Trophy", Unicode: "1F3C6", Alias: []string{"win", "award", "contest", "place", "ftw", "ceremony"}}, ":awareness:": emojiData{Name: ":reminder_ribbon:", Description: "Reminder Ribbon", Unicode: "1F397-FE0F", Alias: []string{"sports", "cause", "support", "awareness"}}, ":awesome:": emojiData{Name: ":+1:", Description: "Thumbs Up Sign", Unicode: "1F44D", Alias: []string{"thumbsup", "yes", "awesome", "good", "agree", "accept", "cool", "hand", "like"}}, ":b:": emojiData{Name: ":b:", Description: "Negative Squared Latin Capital Letter B", Unicode: "1F171-FE0F", Alias: []string{"red-square", "alphabet", "letter"}}, ":baby:": emojiData{Name: ":hatching_chick:", Description: "Hatching Chick", Unicode: "1F423", Alias: []string{"animal", "chicken", "egg", "born", "baby", "bird"}}, ":baby_bottle:": emojiData{Name: ":baby_bottle:", Description: "Baby Bottle", Unicode: "1F37C", Alias: []string{"food", "container", "milk"}}, ":baby_chick:": emojiData{Name: ":baby_chick:", Description: "Baby Chick", Unicode: "1F424", Alias: []string{"animal", "chicken", "bird"}}, ":baby_symbol:": emojiData{Name: ":baby_symbol:", Description: "Baby Symbol", Unicode: "1F6BC", Alias: []string{"orange-square", "child"}}, ":back:": emojiData{Name: ":leftwards_arrow_with_hook:", Description: "Leftwards Arrow with Hook", Unicode: "21A9-FE0F", Alias: []string{"back", "return", "blue-square", "undo", "enter"}}, ":backhand:": emojiData{Name: ":raised_back_of_hand:", Description: "Raised Back of Hand", Unicode: "1F91A", Alias: []string{"fingers", "raised", "backhand"}}, ":backpack:": emojiData{Name: ":school_satchel:", Description: "School Satchel", Unicode: "1F392", Alias: []string{"student", "education", "bag", "backpack"}}, ":bacon:": emojiData{Name: ":bacon:", Description: "Bacon", Unicode: "1F953", Alias: []string{"food", "breakfast", "pork", "pig", "meat"}}, ":bad:": emojiData{Name: ":part_alternation_mark:", Description: "Part Alternation Mark", Unicode: "303D-FE0F", Alias: []string{"graph", "presentation", "stats", "business", "economics", "bad"}}, ":badge:": emojiData{Name: ":beginner:", Description: "Japanese Symbol for Beginner", Unicode: "1F530", Alias: []string{"badge", "shield"}}, ":badminton_racquet_and_shuttlecock:": emojiData{Name: ":badminton_racquet_and_shuttlecock:", Description: "Badminton Racquet and Shuttlecock", Unicode: "1F3F8", Alias: []string(nil)}, ":bag:": emojiData{Name: ":school_satchel:", Description: "School Satchel", Unicode: "1F392", Alias: []string{"student", "education", "bag", "backpack"}}, ":baggage_claim:": emojiData{Name: ":baggage_claim:", Description: "Baggage Claim", Unicode: "1F6C4", Alias: []string{"blue-square", "airport", "transport"}}, ":baguette_bread:": emojiData{Name: ":baguette_bread:", Description: "Baguette Bread", Unicode: "1F956", Alias: []string{"food", "bread", "french"}}, ":balance:": emojiData{Name: ":yin_yang:", Description: "Yin Yang", Unicode: "262F-FE0F", Alias: []string{"balance"}}, ":balloon:": emojiData{Name: ":balloon:", Description: "Balloon", Unicode: "1F388", Alias: []string{"party", "celebration", "birthday", "circus"}}, ":ballot_box_with_ballot:": emojiData{Name: ":ballot_box_with_ballot:", Description: "Ballot Box with Ballot", Unicode: "1F5F3-FE0F", Alias: []string(nil)}, ":ballot_box_with_check:": emojiData{Name: ":ballot_box_with_check:", Description: "Ballot Box with Check", Unicode: "2611-FE0F", Alias: []string{"ok", "agree", "confirm", "black-square", "vote", "election", "yes", "tick"}}, ":balls:": emojiData{Name: ":volleyball:", Description: "Volleyball", Unicode: "1F3D0", Alias: []string{"sports", "balls"}}, ":bamboo:": emojiData{Name: ":bamboo:", Description: "Pine Decoration", Unicode: "1F38D", Alias: []string{"plant", "nature", "vegetable", "panda", "pine_decoration"}}, ":banana:": emojiData{Name: ":monkey:", Description: "Monkey", Unicode: "1F412", Alias: []string{"animal", "nature", "banana", "circus"}}, ":bandage:": emojiData{Name: ":face_with_head_bandage:", Description: "Face with Head-Bandage", Unicode: "1F915", Alias: []string{"injured", "clumsy", "bandage", "hurt"}}, ":bangbang:": emojiData{Name: ":bangbang:", Description: "Double Exclamation Mark", Unicode: "203C-FE0F", Alias: []string{"exclamation", "surprise"}}, ":bank:": emojiData{Name: ":bank:", Description: "Bank", Unicode: "1F3E6", Alias: []string{"building", "money", "sales", "cash", "business", "enterprise"}}, ":banner:": emojiData{Name: ":us:", Description: "United States Flag", Unicode: "1F1FA-1F1F8", Alias: []string{"united", "states", "america", "flag", "nation", "country", "banner"}}, ":bar:": emojiData{Name: ":dart:", Description: "Direct Hit", Unicode: "1F3AF", Alias: []string{"game", "play", "bar"}}, ":bar_chart:": emojiData{Name: ":bar_chart:", Description: "Bar Chart", Unicode: "1F4CA", Alias: []string{"graph", "presentation", "stats"}}, ":barbecue:": emojiData{Name: ":dango:", Description: "Dango", Unicode: "1F361", Alias: []string{"food", "dessert", "sweet", "japanese", "barbecue", "meat"}}, ":barber:": emojiData{Name: ":barber:", Description: "Barber Pole", Unicode: "1F488", Alias: []string{"hair", "salon", "style"}}, ":barely_sunny:": emojiData{Name: ":barely_sunny:", Description: "Barely Sunny", Unicode: "1F325-FE0F", Alias: []string(nil)}, ":barrell:": emojiData{Name: ":oil_drum:", Description: "Oil Drum", Unicode: "1F6E2-FE0F", Alias: []string{"barrell"}}, ":bars:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":bart:": emojiData{Name: ":trolleybus:", Description: "Trolleybus", Unicode: "1F68E", Alias: []string{"bart", "transportation", "vehicle"}}, ":baseball:": emojiData{Name: ":baseball:", Description: "Baseball", Unicode: "26BE", Alias: []string{"sports", "balls"}}, ":basketball:": emojiData{Name: ":basketball:", Description: "Basketball and Hoop", Unicode: "1F3C0", Alias: []string{"sports", "balls", "NBA"}}, ":bat:": emojiData{Name: ":bat:", Description: "Bat", Unicode: "1F987", Alias: []string{"animal", "nature", "blind", "vampire"}}, ":bath:": emojiData{Name: ":hotsprings:", Description: "Hot Springs", Unicode: "2668-FE0F", Alias: []string{"bath", "warm", "relax"}}, ":bathroom:": emojiData{Name: ":toilet:", Description: "Toilet", Unicode: "1F6BD", Alias: []string{"restroom", "wc", "washroom", "bathroom", "potty"}}, ":bathtub:": emojiData{Name: ":bathtub:", Description: "Bathtub", Unicode: "1F6C1", Alias: []string{"clean", "shower", "bathroom"}}, ":battery:": emojiData{Name: ":battery:", Description: "Battery", Unicode: "1F50B", Alias: []string{"power", "energy", "sustain"}}, ":bbcall:": emojiData{Name: ":pager:", Description: "Pager", Unicode: "1F4DF", Alias: []string{"bbcall", "oldschool", "90s"}}, ":beach:": emojiData{Name: ":sunglasses:", Description: "Smiling Face with Sunglasses", Unicode: "1F60E", Alias: []string{"face", "cool", "smile", "summer", "beach", "sunglass"}}, ":beach_with_umbrella:": emojiData{Name: ":beach_with_umbrella:", Description: "Beach with Umbrella", Unicode: "1F3D6-FE0F", Alias: []string(nil)}, ":bear:": emojiData{Name: ":bear:", Description: "Bear Face", Unicode: "1F43B", Alias: []string{"animal", "nature", "wild"}}, ":bearded_person:": emojiData{Name: ":bearded_person:", Description: "Bearded Person", Unicode: "1F9D4", Alias: []string(nil)}, ":beauty:": emojiData{Name: ":nail_care:", Description: "Nail Polish", Unicode: "1F485", Alias: []string{"beauty", "manicure", "finger", "fashion", "nail"}}, ":bed:": emojiData{Name: ":bed:", Description: "Bed", Unicode: "1F6CF-FE0F", Alias: []string{"sleep", "rest"}}, ":bee:": emojiData{Name: ":bee:", Description: "Honeybee", Unicode: "1F41D", Alias: []string(nil)}, ":beef:": emojiData{Name: ":cow:", Description: "Cow Face", Unicode: "1F42E", Alias: []string{"beef", "ox", "animal", "nature", "moo", "milk"}}, ":beer:": emojiData{Name: ":beer:", Description: "Beer Mug", Unicode: "1F37A", Alias: []string{"relax", "beverage", "drink", "drunk", "party", "pub", "summer", "alcohol", "booze"}}, ":beers:": emojiData{Name: ":beers:", Description: "Clinking Beer Mugs", Unicode: "1F37B", Alias: []string{"relax", "beverage", "drink", "drunk", "party", "pub", "summer", "alcohol", "booze"}}, ":bees:": emojiData{Name: ":honey_pot:", Description: "Honey Pot", Unicode: "1F36F", Alias: []string{"bees", "sweet", "kitchen"}}, ":beetle:": emojiData{Name: ":beetle:", Description: "Lady Beetle", Unicode: "1F41E", Alias: []string{"animal", "insect", "nature", "ladybug"}}, ":beginner:": emojiData{Name: ":beginner:", Description: "Japanese Symbol for Beginner", Unicode: "1F530", Alias: []string{"badge", "shield"}}, ":bell:": emojiData{Name: ":wind_chime:", Description: "Wind Chime", Unicode: "1F390", Alias: []string{"nature", "ding", "spring", "bell"}}, ":bellhop_bell:": emojiData{Name: ":bellhop_bell:", Description: "Bellhop Bell", Unicode: "1F6CE-FE0F", Alias: []string{"service"}}, ":bento:": emojiData{Name: ":bento:", Description: "Bento Box", Unicode: "1F371", Alias: []string{"food", "japanese", "box"}}, ":bet:": emojiData{Name: ":slot_machine:", Description: "Slot Machine", Unicode: "1F3B0", Alias: []string{"bet", "gamble", "vegas", "fruit machine", "luck", "casino"}}, ":betting:": emojiData{Name: ":horse_racing:", Description: "Horse Racing", Unicode: "1F3C7", Alias: []string{"animal", "betting", "competition", "gambling", "luck"}}, ":beverage:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":biceps:": emojiData{Name: ":muscle:", Description: "Flexed Biceps", Unicode: "1F4AA", Alias: []string{"arm", "flex", "hand", "summer", "strong", "biceps"}}, ":bicycle:": emojiData{Name: ":bike:", Description: "Bicycle", Unicode: "1F6B2", Alias: []string{"sports", "bicycle", "exercise", "hipster"}}, ":bicyclist:": emojiData{Name: ":bicyclist:", Description: "Bicyclist", Unicode: "1F6B4", Alias: []string(nil)}, ":bike:": emojiData{Name: ":bike:", Description: "Bicycle", Unicode: "1F6B2", Alias: []string{"sports", "bicycle", "exercise", "hipster"}}, ":bikini:": emojiData{Name: ":bikini:", Description: "Bikini", Unicode: "1F459", Alias: []string{"swimming", "female", "woman", "girl", "fashion", "beach", "summer"}}, ":bill:": emojiData{Name: ":credit_card:", Description: "Credit Card", Unicode: "1F4B3", Alias: []string{"money", "sales", "dollar", "bill", "payment", "shopping"}}, ":billed_cap:": emojiData{Name: ":billed_cap:", Description: "Billed Cap", Unicode: "1F9E2", Alias: []string(nil)}, ":bills:": emojiData{Name: ":money_with_wings:", Description: "Money with Wings", Unicode: "1F4B8", Alias: []string{"dollar", "bills", "payment", "sale"}}, ":bin:": emojiData{Name: ":wastebasket:", Description: "Wastebasket", Unicode: "1F5D1-FE0F", Alias: []string{"bin", "trash", "rubbish", "garbage", "toss"}}, ":biohazard_sign:": emojiData{Name: ":biohazard_sign:", Description: "Biohazard Sign", Unicode: "2623-FE0F", Alias: []string(nil)}, ":bird:": emojiData{Name: ":hatching_chick:", Description: "Hatching Chick", Unicode: "1F423", Alias: []string{"animal", "chicken", "egg", "born", "baby", "bird"}}, ":birthday:": emojiData{Name: ":balloon:", Description: "Balloon", Unicode: "1F388", Alias: []string{"party", "celebration", "birthday", "circus"}}, ":black-square:": emojiData{Name: ":ballot_box_with_check:", Description: "Ballot Box with Check", Unicode: "2611-FE0F", Alias: []string{"ok", "agree", "confirm", "black-square", "vote", "election", "yes", "tick"}}, ":black_circle:": emojiData{Name: ":black_circle:", Description: "Medium Black Circle", Unicode: "26AB", Alias: []string{"shape", "button", "round"}}, ":black_circle_for_record:": emojiData{Name: ":black_circle_for_record:", Description: "Black Circle for Record", Unicode: "23FA-FE0F", Alias: []string(nil)}, ":black_heart:": emojiData{Name: ":black_heart:", Description: "Black Heart", Unicode: "1F5A4", Alias: []string{"evil"}}, ":black_joker:": emojiData{Name: ":black_joker:", Description: "Playing Card Black Joker", Unicode: "1F0CF", Alias: []string{"poker", "cards", "game", "play", "magic"}}, ":black_large_square:": emojiData{Name: ":black_large_square:", Description: "Black Large Square", Unicode: "2B1B", Alias: []string{"shape", "icon", "button"}}, ":black_left_pointing_double_triangle_with_vertical_bar:": emojiData{Name: ":black_left_pointing_double_triangle_with_vertical_bar:", Description: "Black Left Pointing Double Triangle with Vertical Bar", Unicode: "23EE-FE0F", Alias: []string(nil)}, ":black_medium_small_square:": emojiData{Name: ":black_medium_small_square:", Description: "Black Medium Small Square", Unicode: "25FE", Alias: []string{"icon", "shape", "button"}}, ":black_medium_square:": emojiData{Name: ":black_medium_square:", Description: "Black Medium Square", Unicode: "25FC-FE0F", Alias: []string{"shape", "button", "icon"}}, ":black_nib:": emojiData{Name: ":black_nib:", Description: "Black Nib", Unicode: "2712-FE0F", Alias: []string{"pen", "stationery", "writing", "write"}}, ":black_right_pointing_double_triangle_with_vertical_bar:": emojiData{Name: ":black_right_pointing_double_triangle_with_vertical_bar:", Description: "Black Right Pointing Double Triangle with Vertical Bar", Unicode: "23ED-FE0F", Alias: []string(nil)}, ":black_right_pointing_triangle_with_double_vertical_bar:": emojiData{Name: ":black_right_pointing_triangle_with_double_vertical_bar:", Description: "Black Right Pointing Triangle with Double Vertical Bar", Unicode: "23EF-FE0F", Alias: []string(nil)}, ":black_small_square:": emojiData{Name: ":black_small_square:", Description: "Black Small Square", Unicode: "25AA-FE0F", Alias: []string{"shape", "icon"}}, ":black_square_button:": emojiData{Name: ":black_square_button:", Description: "Black Square Button", Unicode: "1F532", Alias: []string{"shape", "input", "frame"}}, ":black_square_for_stop:": emojiData{Name: ":black_square_for_stop:", Description: "Black Square for Stop", Unicode: "23F9-FE0F", Alias: []string(nil)}, ":blade:": emojiData{Name: ":hocho:", Description: "Hocho", Unicode: "1F52A", Alias: []string{"knife", "blade", "cutlery", "kitchen", "weapon"}}, ":blind:": emojiData{Name: ":bat:", Description: "Bat", Unicode: "1F987", Alias: []string{"animal", "nature", "blind", "vampire"}}, ":blond-haired-man:": emojiData{Name: ":blond-haired-man:", Description: "Blond Haired Man", Unicode: "1F471-200D-2642-FE0F", Alias: []string(nil)}, ":blond-haired-woman:": emojiData{Name: ":blond-haired-woman:", Description: "Blond Haired Woman", Unicode: "1F471-200D-2640-FE0F", Alias: []string(nil)}, ":blond:": emojiData{Name: ":princess:", Description: "Princess", Unicode: "1F478", Alias: []string{"girl", "woman", "female", "blond", "crown", "royal", "queen"}}, ":blood:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":blossom:": emojiData{Name: ":blossom:", Description: "Blossom", Unicode: "1F33C", Alias: []string{"nature", "flowers", "yellow"}}, ":blowfish:": emojiData{Name: ":blowfish:", Description: "Blowfish", Unicode: "1F421", Alias: []string{"animal", "nature", "food", "sea", "ocean"}}, ":blown:": emojiData{Name: ":boom:", Description: "Collision Symbol", Unicode: "1F4A5", Alias: []string{"bomb", "explode", "explosion", "collision", "blown"}}, ":blue-circle:": emojiData{Name: ":m:", Description: "Circled Latin Capital Letter M", Unicode: "24C2-FE0F", Alias: []string{"alphabet", "blue-circle", "letter"}}, ":blue-square:": emojiData{Name: ":three:", Description: "Keycap 3", Unicode: "0033-FE0F-20E3", Alias: []string{"3", "numbers", "prime", "blue-square"}}, ":blue:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":blue_book:": emojiData{Name: ":blue_book:", Description: "Blue Book", Unicode: "1F4D8", Alias: []string{"read", "library", "knowledge", "learn", "study"}}, ":blue_car:": emojiData{Name: ":blue_car:", Description: "Recreational Vehicle", Unicode: "1F699", Alias: []string{"transportation", "vehicle"}}, ":blue_heart:": emojiData{Name: ":blue_heart:", Description: "Blue Heart", Unicode: "1F499", Alias: []string{"love", "like", "affection", "valentines"}}, ":blues:": emojiData{Name: ":saxophone:", Description: "Saxophone", Unicode: "1F3B7", Alias: []string{"music", "instrument", "jazz", "blues"}}, ":bluetooth:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":blush:": emojiData{Name: ":relaxed:", Description: "White Smiling Face", Unicode: "263A-FE0F", Alias: []string{"face", "blush", "massage", "happiness"}}, ":boar:": emojiData{Name: ":boar:", Description: "Boar", Unicode: "1F417", Alias: []string{"animal", "nature"}}, ":boat:": emojiData{Name: ":anchor:", Description: "Anchor", Unicode: "2693", Alias: []string{"ship", "ferry", "sea", "boat"}}, ":bomb:": emojiData{Name: ":bomb:", Description: "Bomb", Unicode: "1F4A3", Alias: []string{"boom", "explode", "explosion", "terrorism"}}, ":book:": emojiData{Name: ":book:", Description: "Open Book", Unicode: "1F4D6", Alias: []string(nil)}, ":bookmark:": emojiData{Name: ":bookmark:", Description: "Bookmark", Unicode: "1F516", Alias: []string{"favorite", "label", "save"}}, ":bookmark_tabs:": emojiData{Name: ":bookmark_tabs:", Description: "Bookmark Tabs", Unicode: "1F4D1", Alias: []string{"favorite", "save", "order", "tidy"}}, ":books:": emojiData{Name: ":books:", Description: "Books", Unicode: "1F4DA", Alias: []string{"literature", "library", "study"}}, ":boom:": emojiData{Name: ":bomb:", Description: "Bomb", Unicode: "1F4A3", Alias: []string{"boom", "explode", "explosion", "terrorism"}}, ":boot:": emojiData{Name: ":boot:", Description: "Womans Boots", Unicode: "1F462", Alias: []string{"shoes", "fashion"}}, ":booze:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":border:": emojiData{Name: ":customs:", Description: "Customs", Unicode: "1F6C3", Alias: []string{"passport", "border", "blue-square"}}, ":bored:": emojiData{Name: ":unamused:", Description: "Unamused Face", Unicode: "1F612", Alias: []string{"indifference", "bored", "straight face", "serious", "sarcasm"}}, ":born:": emojiData{Name: ":hatching_chick:", Description: "Hatching Chick", Unicode: "1F423", Alias: []string{"animal", "chicken", "egg", "born", "baby", "bird"}}, ":bottle:": emojiData{Name: ":champagne:", Description: "Bottle with Popping Cork", Unicode: "1F37E", Alias: []string{"drink", "wine", "bottle", "celebration"}}, ":bottom:": emojiData{Name: ":arrow_down:", Description: "Downwards Black Arrow", Unicode: "2B07-FE0F", Alias: []string{"blue-square", "direction", "bottom"}}, ":bouquet:": emojiData{Name: ":bouquet:", Description: "Bouquet", Unicode: "1F490", Alias: []string{"flowers", "nature", "spring"}}, ":bourbon:": emojiData{Name: ":tumbler_glass:", Description: "Tumbler Glass", Unicode: "1F943", Alias: []string{"drink", "beverage", "drunk", "alcohol", "liquor", "booze", "bourbon", "scotch", "whisky", "glass", "shot"}}, ":bow:": emojiData{Name: ":bow:", Description: "Person Bowing Deeply", Unicode: "1F647", Alias: []string(nil)}, ":bow_and_arrow:": emojiData{Name: ":bow_and_arrow:", Description: "Bow and Arrow", Unicode: "1F3F9", Alias: []string{"sports"}}, ":bowl:": emojiData{Name: ":tea:", Description: "Teacup Without Handle", Unicode: "1F375", Alias: []string{"drink", "bowl", "breakfast", "green", "british"}}, ":bowl_with_spoon:": emojiData{Name: ":bowl_with_spoon:", Description: "Bowl with Spoon", Unicode: "1F963", Alias: []string(nil)}, ":bowling:": emojiData{Name: ":bowling:", Description: "Bowling", Unicode: "1F3B3", Alias: []string{"sports", "fun", "play"}}, ":bowtie:": emojiData{Name: ":ribbon:", Description: "Ribbon", Unicode: "1F380", Alias: []string{"decoration", "pink", "girl", "bowtie"}}, ":box:": emojiData{Name: ":bento:", Description: "Bento Box", Unicode: "1F371", Alias: []string{"food", "japanese", "box"}}, ":boxing_glove:": emojiData{Name: ":boxing_glove:", Description: "Boxing Glove", Unicode: "1F94A", Alias: []string{"sports", "fighting"}}, ":boy:": emojiData{Name: ":man_dancing:", Description: "Man Dancing", Unicode: "1F57A", Alias: []string{"male", "boy", "fun", "dancer"}}, ":brain:": emojiData{Name: ":brain:", Description: "Brain", Unicode: "1F9E0", Alias: []string(nil)}, ":branch:": emojiData{Name: ":tanabata_tree:", Description: "Tanabata Tree", Unicode: "1F38B", Alias: []string{"plant", "nature", "branch", "summer"}}, ":brand:": emojiData{Name: ":tm:", Description: "Trade Mark Sign", Unicode: "2122-FE0F", Alias: []string{"trademark", "brand", "law", "legal"}}, ":brass:": emojiData{Name: ":trumpet:", Description: "Trumpet", Unicode: "1F3BA", Alias: []string{"music", "brass"}}, ":bread:": emojiData{Name: ":bread:", Description: "Bread", Unicode: "1F35E", Alias: []string{"food", "wheat", "breakfast", "toast"}}, ":break:": emojiData{Name: ":broken_heart:", Description: "Broken Heart", Unicode: "1F494", Alias: []string{"sad", "sorry", "break", "heart", "heartbreak"}}, ":breakfast:": emojiData{Name: ":bread:", Description: "Bread", Unicode: "1F35E", Alias: []string{"food", "wheat", "breakfast", "toast"}}, ":breast-feeding:": emojiData{Name: ":breast-feeding:", Description: "Breast-Feeding", Unicode: "1F931", Alias: []string(nil)}, ":bride:": emojiData{Name: ":wedding:", Description: "Wedding", Unicode: "1F492", Alias: []string{"love", "like", "affection", "couple", "marriage", "bride", "groom"}}, ":bride_with_veil:": emojiData{Name: ":bride_with_veil:", Description: "Bride with Veil", Unicode: "1F470", Alias: []string{"couple", "marriage", "wedding", "woman", "bride"}}, ":bridge_at_night:": emojiData{Name: ":bridge_at_night:", Description: "Bridge at Night", Unicode: "1F309", Alias: []string{"photo", "sanfrancisco"}}, ":briefcase:": emojiData{Name: ":briefcase:", Description: "Briefcase", Unicode: "1F4BC", Alias: []string{"business", "documents", "work", "law", "legal", "job", "career"}}, ":brightness:": emojiData{Name: ":sunny:", Description: "Black Sun with Rays", Unicode: "2600-FE0F", Alias: []string{"weather", "nature", "brightness", "summer", "beach", "spring"}}, ":british:": emojiData{Name: ":guardsman:", Description: "Guardsman", Unicode: "1F482", Alias: []string{"uk", "gb", "british", "male", "guy", "royal"}}, ":broadcast:": emojiData{Name: ":loud_sound:", Description: "Speaker with Three Sound Waves", Unicode: "1F50A", Alias: []string{"volume", "noise", "noisy", "speaker", "broadcast"}}, ":broccoli:": emojiData{Name: ":broccoli:", Description: "Broccoli", Unicode: "1F966", Alias: []string(nil)}, ":broken_heart:": emojiData{Name: ":broken_heart:", Description: "Broken Heart", Unicode: "1F494", Alias: []string{"sad", "sorry", "break", "heart", "heartbreak"}}, ":bromance:": emojiData{Name: ":two_men_holding_hands:", Description: "Two Men Holding Hands", Unicode: "1F46C", Alias: []string{"pair", "couple", "love", "like", "bromance", "friendship", "people", "human"}}, ":brown:": emojiData{Name: ":horse:", Description: "Horse Face", Unicode: "1F434", Alias: []string{"animal", "brown", "nature"}}, ":bubble:": emojiData{Name: ":thought_balloon:", Description: "Thought Balloon", Unicode: "1F4AD", Alias: []string{"bubble", "cloud", "speech", "thinking", "dream"}}, ":buck:": emojiData{Name: ":heavy_dollar_sign:", Description: "Heavy Dollar Sign", Unicode: "1F4B2", Alias: []string{"money", "sales", "payment", "currency", "buck"}}, ":buddhism:": emojiData{Name: ":wheel_of_dharma:", Description: "Wheel of Dharma", Unicode: "2638-FE0F", Alias: []string{"hinduism", "buddhism", "sikhism", "jainism"}}, ":bug:": emojiData{Name: ":bug:", Description: "Bug", Unicode: "1F41B", Alias: []string{"animal", "insect", "nature", "worm"}}, ":build:": emojiData{Name: ":hammer:", Description: "Hammer", Unicode: "1F528", Alias: []string{"tools", "build", "create"}}, ":building:": emojiData{Name: ":bank:", Description: "Bank", Unicode: "1F3E6", Alias: []string{"building", "money", "sales", "cash", "business", "enterprise"}}, ":building_construction:": emojiData{Name: ":building_construction:", Description: "Building Construction", Unicode: "1F3D7-FE0F", Alias: []string{"wip", "working", "progress"}}, ":buildings:": emojiData{Name: ":city_sunset:", Description: "Cityscape at Dusk", Unicode: "1F306", Alias: []string{"photo", "evening", "sky", "buildings"}}, ":bulb:": emojiData{Name: ":bulb:", Description: "Electric Light Bulb", Unicode: "1F4A1", Alias: []string{"light", "electricity", "idea"}}, ":bullettrain_front:": emojiData{Name: ":bullettrain_front:", Description: "High-Speed Train with Bullet Nose", Unicode: "1F685", Alias: []string{"transportation", "vehicle", "speed", "fast", "public", "travel"}}, ":bullettrain_side:": emojiData{Name: ":bullettrain_side:", Description: "High-Speed Train", Unicode: "1F684", Alias: []string{"transportation", "vehicle"}}, ":bunny:": emojiData{Name: ":rabbit:", Description: "Rabbit Face", Unicode: "1F430", Alias: []string{"animal", "nature", "pet", "spring", "magic", "bunny"}}, ":bureau:": emojiData{Name: ":office:", Description: "Office Building", Unicode: "1F3E2", Alias: []string{"building", "bureau", "work"}}, ":burger king:": emojiData{Name: ":hamburger:", Description: "Hamburger", Unicode: "1F354", Alias: []string{"meat", "fast food", "beef", "cheeseburger", "mcdonalds", "burger king"}}, ":burrito:": emojiData{Name: ":burrito:", Description: "Burrito", Unicode: "1F32F", Alias: []string{"food", "mexican"}}, ":bus:": emojiData{Name: ":seat:", Description: "Seat", Unicode: "1F4BA", Alias: []string{"sit", "airplane", "transport", "bus", "flight", "fly"}}, ":business:": emojiData{Name: ":bank:", Description: "Bank", Unicode: "1F3E6", Alias: []string{"building", "money", "sales", "cash", "business", "enterprise"}}, ":busstop:": emojiData{Name: ":busstop:", Description: "Bus Stop", Unicode: "1F68F", Alias: []string{"transportation", "wait"}}, ":bust_in_silhouette:": emojiData{Name: ":bust_in_silhouette:", Description: "Bust in Silhouette", Unicode: "1F464", Alias: []string{"user", "person", "human"}}, ":busts_in_silhouette:": emojiData{Name: ":busts_in_silhouette:", Description: "Busts in Silhouette", Unicode: "1F465", Alias: []string{"user", "person", "human", "group", "team"}}, ":butterfly:": emojiData{Name: ":open_hands:", Description: "Open Hands Sign", Unicode: "1F450", Alias: []string{"fingers", "butterfly", "hands", "open"}}, ":button:": emojiData{Name: ":large_blue_circle:", Description: "Large Blue Circle", Unicode: "1F535", Alias: []string{"shape", "icon", "button"}}, ":ca:": emojiData{Name: ":maple_leaf:", Description: "Maple Leaf", Unicode: "1F341", Alias: []string{"nature", "plant", "vegetable", "ca", "fall"}}, ":cactus:": emojiData{Name: ":cactus:", Description: "Cactus", Unicode: "1F335", Alias: []string{"vegetable", "plant", "nature"}}, ":caffeine:": emojiData{Name: ":coffee:", Description: "Hot Beverage", Unicode: "2615", Alias: []string{"beverage", "caffeine", "latte", "espresso"}}, ":cake:": emojiData{Name: ":birthday:", Description: "Birthday Cake", Unicode: "1F382", Alias: []string{"food", "dessert", "cake"}}, ":calculate:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":calculation:": emojiData{Name: ":heavy_multiplication_x:", Description: "Heavy Multiplication X", Unicode: "2716-FE0F", Alias: []string{"math", "calculation"}}, ":calendar:": emojiData{Name: ":calendar:", Description: "Tear-off Calendar", Unicode: "1F4C6", Alias: []string{"schedule", "date", "planning"}}, ":call_me_hand:": emojiData{Name: ":call_me_hand:", Description: "Call Me Hand", Unicode: "1F919", Alias: []string{"hands", "gesture"}}, ":calling:": emojiData{Name: ":calling:", Description: "Mobile Phone with Rightwards Arrow at Left", Unicode: "1F4F2", Alias: []string{"iphone", "incoming"}}, ":camel:": emojiData{Name: ":camel:", Description: "Bactrian Camel", Unicode: "1F42B", Alias: []string{"animal", "nature", "hot", "desert", "hump"}}, ":camera:": emojiData{Name: ":selfie:", Description: "Selfie", Unicode: "1F933", Alias: []string{"camera", "phone"}}, ":camera_with_flash:": emojiData{Name: ":camera_with_flash:", Description: "Camera with Flash", Unicode: "1F4F8", Alias: []string(nil)}, ":camping:": emojiData{Name: ":flashlight:", Description: "Electric Torch", Unicode: "1F526", Alias: []string{"dark", "camping", "sight", "night"}}, ":cancel:": emojiData{Name: ":x:", Description: "Cross Mark", Unicode: "274C", Alias: []string{"no", "delete", "remove", "cancel"}}, ":cancer:": emojiData{Name: ":cancer:", Description: "Cancer", Unicode: "264B", Alias: []string{"sign", "zodiac", "purple-square", "astrology"}}, ":candle:": emojiData{Name: ":candle:", Description: "Candle", Unicode: "1F56F-FE0F", Alias: []string{"fire", "wax"}}, ":candy:": emojiData{Name: ":lollipop:", Description: "Lollipop", Unicode: "1F36D", Alias: []string{"food", "snack", "candy", "sweet"}}, ":canned_food:": emojiData{Name: ":canned_food:", Description: "Canned Food", Unicode: "1F96B", Alias: []string(nil)}, ":canoe:": emojiData{Name: ":canoe:", Description: "Canoe", Unicode: "1F6F6", Alias: []string{"boat", "paddle", "water", "ship"}}, ":cap:": emojiData{Name: ":mortar_board:", Description: "Graduation Cap", Unicode: "1F393", Alias: []string{"school", "college", "degree", "university", "graduation", "cap", "hat", "legal", "learn", "education"}}, ":capital_abcd:": emojiData{Name: ":capital_abcd:", Description: "Input Symbol for Latin Capital Letters", Unicode: "1F520", Alias: []string{"alphabet", "words", "blue-square"}}, ":capricorn:": emojiData{Name: ":capricorn:", Description: "Capricorn", Unicode: "2651", Alias: []string{"sign", "zodiac", "purple-square", "astrology"}}, ":caption:": emojiData{Name: ":right_anger_bubble:", Description: "Right Anger Bubble", Unicode: "1F5EF-FE0F", Alias: []string{"caption", "speech", "thinking", "mad"}}, ":car:": emojiData{Name: ":bus:", Description: "Bus", Unicode: "1F68C", Alias: []string{"car", "vehicle", "transportation"}}, ":card_file_box:": emojiData{Name: ":card_file_box:", Description: "Card File Box", Unicode: "1F5C3-FE0F", Alias: []string{"business", "stationery"}}, ":card_index:": emojiData{Name: ":card_index:", Description: "Card Index", Unicode: "1F4C7", Alias: []string{"business", "stationery"}}, ":card_index_dividers:": emojiData{Name: ":card_index_dividers:", Description: "Card Index Dividers", Unicode: "1F5C2-FE0F", Alias: []string{"organizing", "business", "stationery"}}, ":cardboard:": emojiData{Name: ":package:", Description: "Package", Unicode: "1F4E6", Alias: []string{"mail", "gift", "cardboard", "box", "moving"}}, ":cards:": emojiData{Name: ":spades:", Description: "Black Spade Suit", Unicode: "2660-FE0F", Alias: []string{"poker", "cards", "suits", "magic"}}, ":career:": emojiData{Name: ":briefcase:", Description: "Briefcase", Unicode: "1F4BC", Alias: []string{"business", "documents", "work", "law", "legal", "job", "career"}}, ":carnival:": emojiData{Name: ":fireworks:", Description: "Fireworks", Unicode: "1F386", Alias: []string{"photo", "festival", "carnival", "congratulations"}}, ":carousel_horse:": emojiData{Name: ":carousel_horse:", Description: "Carousel Horse", Unicode: "1F3A0", Alias: []string{"photo", "carnival"}}, ":carp:": emojiData{Name: ":flags:", Description: "Carp Streamer", Unicode: "1F38F", Alias: []string{"fish", "japanese", "koinobori", "carp", "banner"}}, ":carriage:": emojiData{Name: ":train:", Description: "Tram Car", Unicode: "1F68B", Alias: []string{"transportation", "vehicle", "carriage", "public", "travel"}}, ":carrot:": emojiData{Name: ":carrot:", Description: "Carrot", Unicode: "1F955", Alias: []string{"vegetable", "food", "orange"}}, ":cars:": emojiData{Name: ":fire_engine:", Description: "Fire Engine", Unicode: "1F692", Alias: []string{"transportation", "cars", "vehicle"}}, ":cash:": emojiData{Name: ":bank:", Description: "Bank", Unicode: "1F3E6", Alias: []string{"building", "money", "sales", "cash", "business", "enterprise"}}, ":casino:": emojiData{Name: ":slot_machine:", Description: "Slot Machine", Unicode: "1F3B0", Alias: []string{"bet", "gamble", "vegas", "fruit machine", "luck", "casino"}}, ":casket:": emojiData{Name: ":coffin:", Description: "Coffin", Unicode: "26B0-FE0F", Alias: []string{"vampire", "dead", "die", "death", "rip", "graveyard", "cemetery", "casket", "funeral", "box"}}, ":casserole:": emojiData{Name: ":shallow_pan_of_food:", Description: "Shallow Pan of Food", Unicode: "1F958", Alias: []string{"food", "cooking", "casserole", "paella"}}, ":cassette:": emojiData{Name: ":loop:", Description: "Double Curly Loop", Unicode: "27BF", Alias: []string{"tape", "cassette"}}, ":cat2:": emojiData{Name: ":cat2:", Description: "Cat", Unicode: "1F408", Alias: []string{"animal", "meow", "pet", "cats"}}, ":cat:": emojiData{Name: ":cat:", Description: "Cat Face", Unicode: "1F431", Alias: []string{"animal", "meow", "nature", "pet", "kitten"}}, ":caterpillar:": emojiData{Name: ":butterfly:", Description: "Butterfly", Unicode: "1F98B", Alias: []string{"animal", "insect", "nature", "caterpillar"}}, ":cats:": emojiData{Name: ":pouting_cat:", Description: "Pouting Cat Face", Unicode: "1F63E", Alias: []string{"animal", "cats"}}, ":cause:": emojiData{Name: ":reminder_ribbon:", Description: "Reminder Ribbon", Unicode: "1F397-FE0F", Alias: []string{"sports", "cause", "support", "awareness"}}, ":caution:": emojiData{Name: ":construction:", Description: "Construction Sign", Unicode: "1F6A7", Alias: []string{"wip", "progress", "caution", "warning"}}, ":cd:": emojiData{Name: ":dvd:", Description: "Dvd", Unicode: "1F4C0", Alias: []string{"cd", "disk", "disc"}}, ":celebrate:": emojiData{Name: ":clinking_glasses:", Description: "Clinking Glasses", Unicode: "1F942", Alias: []string{"beverage", "drink", "party", "alcohol", "celebrate", "cheers"}}, ":celebration:": emojiData{Name: ":balloon:", Description: "Balloon", Unicode: "1F388", Alias: []string{"party", "celebration", "birthday", "circus"}}, ":cemetery:": emojiData{Name: ":coffin:", Description: "Coffin", Unicode: "26B0-FE0F", Alias: []string{"vampire", "dead", "die", "death", "rip", "graveyard", "cemetery", "casket", "funeral", "box"}}, ":century:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":ceremony:": emojiData{Name: ":trophy:", Description: "Trophy", Unicode: "1F3C6", Alias: []string{"win", "award", "contest", "place", "ftw", "ceremony"}}, ":chains:": emojiData{Name: ":chains:", Description: "Chains", Unicode: "26D3-FE0F", Alias: []string{"lock", "arrest"}}, ":champagne:": emojiData{Name: ":champagne:", Description: "Bottle with Popping Cork", Unicode: "1F37E", Alias: []string{"drink", "wine", "bottle", "celebration"}}, ":characters:": emojiData{Name: ":symbols:", Description: "Input Symbol for Symbols", Unicode: "1F523", Alias: []string{"blue-square", "music", "note", "ampersand", "percent", "glyphs", "characters"}}, ":charger:": emojiData{Name: ":electric_plug:", Description: "Electric Plug", Unicode: "1F50C", Alias: []string{"charger", "power"}}, ":chart:": emojiData{Name: ":chart:", Description: "Chart with Upwards Trend and Yen Sign", Unicode: "1F4B9", Alias: []string{"green-square", "graph", "presentation", "stats"}}, ":chart_with_downwards_trend:": emojiData{Name: ":chart_with_downwards_trend:", Description: "Chart with Downwards Trend", Unicode: "1F4C9", Alias: []string{"graph", "presentation", "stats", "recession", "business", "economics", "money", "sales", "bad", "failure"}}, ":chart_with_upwards_trend:": emojiData{Name: ":chart_with_upwards_trend:", Description: "Chart with Upwards Trend", Unicode: "1F4C8", Alias: []string{"graph", "presentation", "stats", "recovery", "business", "economics", "money", "sales", "good", "success"}}, ":chatting:": emojiData{Name: ":speech_balloon:", Description: "Speech Balloon", Unicode: "1F4AC", Alias: []string{"bubble", "words", "message", "talk", "chatting"}}, ":checkered_flag:": emojiData{Name: ":checkered_flag:", Description: "Chequered Flag", Unicode: "1F3C1", Alias: []string{"contest", "finishline", "race", "gokart"}}, ":checkin:": emojiData{Name: ":hotel:", Description: "Hotel", Unicode: "1F3E8", Alias: []string{"building", "accomodation", "checkin"}}, ":cheers:": emojiData{Name: ":clinking_glasses:", Description: "Clinking Glasses", Unicode: "1F942", Alias: []string{"beverage", "drink", "party", "alcohol", "celebrate", "cheers"}}, ":cheese_wedge:": emojiData{Name: ":mouse:", Description: "Mouse Face", Unicode: "1F42D", Alias: []string{"animal", "nature", "cheese_wedge", "rodent"}}, ":cheeseburger:": emojiData{Name: ":hamburger:", Description: "Hamburger", Unicode: "1F354", Alias: []string{"meat", "fast food", "beef", "cheeseburger", "mcdonalds", "burger king"}}, ":chemistry:": emojiData{Name: ":alembic:", Description: "Alembic", Unicode: "2697-FE0F", Alias: []string{"distilling", "science", "experiment", "chemistry"}}, ":cherries:": emojiData{Name: ":cherries:", Description: "Cherries", Unicode: "1F352", Alias: []string{"food", "fruit"}}, ":cherry_blossom:": emojiData{Name: ":cherry_blossom:", Description: "Cherry Blossom", Unicode: "1F338", Alias: []string{"nature", "plant", "spring", "flower"}}, ":chestnut:": emojiData{Name: ":chestnut:", Description: "Chestnut", Unicode: "1F330", Alias: []string{"food", "squirrel"}}, ":chicken:": emojiData{Name: ":hatching_chick:", Description: "Hatching Chick", Unicode: "1F423", Alias: []string{"animal", "chicken", "egg", "born", "baby", "bird"}}, ":child:": emojiData{Name: ":baby_symbol:", Description: "Baby Symbol", Unicode: "1F6BC", Alias: []string{"orange-square", "child"}}, ":childish:": emojiData{Name: ":stuck_out_tongue_winking_eye:", Description: "Face with Stuck-out Tongue and Winking Eye", Unicode: "1F61C", Alias: []string{"face", "prank", "childish", "playful", "mischievous", "smile", "wink", "tongue"}}, ":children_crossing:": emojiData{Name: ":children_crossing:", Description: "Children Crossing", Unicode: "1F6B8", Alias: []string{"school", "warning", "danger", "sign", "driving", "yellow-diamond"}}, ":chili:": emojiData{Name: ":hot_pepper:", Description: "Hot Pepper", Unicode: "1F336-FE0F", Alias: []string{"food", "spicy", "chilli", "chili"}}, ":chill:": emojiData{Name: ":couch_and_lamp:", Description: "Couch and Lamp", Unicode: "1F6CB-FE0F", Alias: []string{"read", "chill"}}, ":chilli:": emojiData{Name: ":hot_pepper:", Description: "Hot Pepper", Unicode: "1F336-FE0F", Alias: []string{"food", "spicy", "chilli", "chili"}}, ":chime:": emojiData{Name: ":bell:", Description: "Bell", Unicode: "1F514", Alias: []string{"sound", "notification", "christmas", "xmas", "chime"}}, ":china:": emojiData{Name: ":rice:", Description: "Cooked Rice", Unicode: "1F35A", Alias: []string{"food", "china", "asian"}}, ":chinese:": emojiData{Name: ":dragon:", Description: "Dragon", Unicode: "1F409", Alias: []string{"animal", "myth", "nature", "chinese", "green"}}, ":chipmunk:": emojiData{Name: ":chipmunk:", Description: "Chipmunk", Unicode: "1F43F-FE0F", Alias: []string{"animal", "nature", "rodent", "squirrel"}}, ":chips:": emojiData{Name: ":fries:", Description: "French Fries", Unicode: "1F35F", Alias: []string{"chips", "snack", "fast food"}}, ":chocolate:": emojiData{Name: ":cookie:", Description: "Cookie", Unicode: "1F36A", Alias: []string{"food", "snack", "oreo", "chocolate", "sweet", "dessert"}}, ":chocolate_bar:": emojiData{Name: ":chocolate_bar:", Description: "Chocolate Bar", Unicode: "1F36B", Alias: []string{"food", "snack", "dessert", "sweet"}}, ":chopsticks:": emojiData{Name: ":chopsticks:", Description: "Chopsticks", Unicode: "1F962", Alias: []string(nil)}, ":christ:": emojiData{Name: ":church:", Description: "Church", Unicode: "26EA", Alias: []string{"building", "religion", "christ"}}, ":christianity:": emojiData{Name: ":latin_cross:", Description: "Latin Cross", Unicode: "271D-FE0F", Alias: []string{"christianity"}}, ":christmas:": emojiData{Name: ":snowflake:", Description: "Snowflake", Unicode: "2744-FE0F", Alias: []string{"winter", "season", "cold", "weather", "christmas", "xmas"}}, ":christmas_tree:": emojiData{Name: ":christmas_tree:", Description: "Christmas Tree", Unicode: "1F384", Alias: []string{"festival", "vacation", "december", "xmas", "celebration"}}, ":church:": emojiData{Name: ":place_of_worship:", Description: "Place of Worship", Unicode: "1F6D0", Alias: []string{"religion", "church", "temple", "prayer"}}, ":cigarette:": emojiData{Name: ":no_smoking:", Description: "No Smoking Symbol", Unicode: "1F6AD", Alias: []string{"cigarette", "blue-square", "smell", "smoke"}}, ":cinema:": emojiData{Name: ":cinema:", Description: "Cinema", Unicode: "1F3A6", Alias: []string{"blue-square", "record", "film", "movie", "curtain", "stage", "theater"}}, ":circle:": emojiData{Name: ":no_bicycles:", Description: "No Bicycles", Unicode: "1F6B3", Alias: []string{"cyclist", "prohibited", "circle"}}, ":circus:": emojiData{Name: ":monkey:", Description: "Monkey", Unicode: "1F412", Alias: []string{"animal", "nature", "banana", "circus"}}, ":circus_tent:": emojiData{Name: ":circus_tent:", Description: "Circus Tent", Unicode: "1F3AA", Alias: []string{"festival", "carnival", "party"}}, ":city:": emojiData{Name: ":night_with_stars:", Description: "Night with Stars", Unicode: "1F303", Alias: []string{"evening", "city", "downtown"}}, ":city_sunrise:": emojiData{Name: ":city_sunrise:", Description: "Sunset over Buildings", Unicode: "1F307", Alias: []string{"photo", "good morning", "dawn"}}, ":city_sunset:": emojiData{Name: ":city_sunset:", Description: "Cityscape at Dusk", Unicode: "1F306", Alias: []string{"photo", "evening", "sky", "buildings"}}, ":cityscape:": emojiData{Name: ":cityscape:", Description: "Cityscape", Unicode: "1F3D9-FE0F", Alias: []string{"photo", "night life", "urban"}}, ":cl:": emojiData{Name: ":cl:", Description: "Squared Cl", Unicode: "1F191", Alias: []string{"alphabet", "words", "red-square"}}, ":clap:": emojiData{Name: ":clap:", Description: "Clapping Hands Sign", Unicode: "1F44F", Alias: []string{"hands", "praise", "applause", "congrats", "yay"}}, ":clapper:": emojiData{Name: ":clapper:", Description: "Clapper Board", Unicode: "1F3AC", Alias: []string{"movie", "film", "record"}}, ":classical_building:": emojiData{Name: ":classical_building:", Description: "Classical Building", Unicode: "1F3DB-FE0F", Alias: []string{"art", "culture", "history"}}, ":classroom:": emojiData{Name: ":notebook_with_decorative_cover:", Description: "Notebook with Decorative Cover", Unicode: "1F4D4", Alias: []string{"classroom", "notes", "record", "paper", "study"}}, ":classy:": emojiData{Name: ":tophat:", Description: "Top Hat", Unicode: "1F3A9", Alias: []string{"magic", "gentleman", "classy", "circus"}}, ":clean:": emojiData{Name: ":bathtub:", Description: "Bathtub", Unicode: "1F6C1", Alias: []string{"clean", "shower", "bathroom"}}, ":cleaning:": emojiData{Name: ":potable_water:", Description: "Potable Water Symbol", Unicode: "1F6B0", Alias: []string{"blue-square", "liquid", "restroom", "cleaning", "faucet"}}, ":clef:": emojiData{Name: ":musical_score:", Description: "Musical Score", Unicode: "1F3BC", Alias: []string{"treble", "clef", "compose"}}, ":clinking_glasses:": emojiData{Name: ":clinking_glasses:", Description: "Clinking Glasses", Unicode: "1F942", Alias: []string{"beverage", "drink", "party", "alcohol", "celebrate", "cheers"}}, ":clipboard:": emojiData{Name: ":clipboard:", Description: "Clipboard", Unicode: "1F4CB", Alias: []string{"stationery", "documents"}}, ":clock1030:": emojiData{Name: ":clock1030:", Description: "Clock Face Ten-Thirty", Unicode: "1F565", Alias: []string{"time", "late", "early", "schedule"}}, ":clock10:": emojiData{Name: ":clock10:", Description: "Clock Face Ten Oclock", Unicode: "1F559", Alias: []string{"time", "late", "early", "schedule"}}, ":clock1130:": emojiData{Name: ":clock1130:", Description: "Clock Face Eleven-Thirty", Unicode: "1F566", Alias: []string{"time", "late", "early", "schedule"}}, ":clock11:": emojiData{Name: ":clock11:", Description: "Clock Face Eleven Oclock", Unicode: "1F55A", Alias: []string{"time", "late", "early", "schedule"}}, ":clock1230:": emojiData{Name: ":clock1230:", Description: "Clock Face Twelve-Thirty", Unicode: "1F567", Alias: []string{"time", "late", "early", "schedule"}}, ":clock12:": emojiData{Name: ":clock12:", Description: "Clock Face Twelve Oclock", Unicode: "1F55B", Alias: []string{"time", "noon", "midnight", "midday", "late", "early", "schedule"}}, ":clock130:": emojiData{Name: ":clock130:", Description: "Clock Face One-Thirty", Unicode: "1F55C", Alias: []string{"time", "late", "early", "schedule"}}, ":clock1:": emojiData{Name: ":clock1:", Description: "Clock Face One Oclock", Unicode: "1F550", Alias: []string{"time", "late", "early", "schedule"}}, ":clock230:": emojiData{Name: ":clock230:", Description: "Clock Face Two-Thirty", Unicode: "1F55D", Alias: []string{"time", "late", "early", "schedule"}}, ":clock2:": emojiData{Name: ":clock2:", Description: "Clock Face Two Oclock", Unicode: "1F551", Alias: []string{"time", "late", "early", "schedule"}}, ":clock330:": emojiData{Name: ":clock330:", Description: "Clock Face Three-Thirty", Unicode: "1F55E", Alias: []string{"time", "late", "early", "schedule"}}, ":clock3:": emojiData{Name: ":clock3:", Description: "Clock Face Three Oclock", Unicode: "1F552", Alias: []string{"time", "late", "early", "schedule"}}, ":clock430:": emojiData{Name: ":clock430:", Description: "Clock Face Four-Thirty", Unicode: "1F55F", Alias: []string{"time", "late", "early", "schedule"}}, ":clock4:": emojiData{Name: ":clock4:", Description: "Clock Face Four Oclock", Unicode: "1F553", Alias: []string{"time", "late", "early", "schedule"}}, ":clock530:": emojiData{Name: ":clock530:", Description: "Clock Face Five-Thirty", Unicode: "1F560", Alias: []string{"time", "late", "early", "schedule"}}, ":clock5:": emojiData{Name: ":clock5:", Description: "Clock Face Five Oclock", Unicode: "1F554", Alias: []string{"time", "late", "early", "schedule"}}, ":clock630:": emojiData{Name: ":clock630:", Description: "Clock Face Six-Thirty", Unicode: "1F561", Alias: []string{"time", "late", "early", "schedule"}}, ":clock6:": emojiData{Name: ":clock6:", Description: "Clock Face Six Oclock", Unicode: "1F555", Alias: []string{"time", "late", "early", "schedule", "dawn", "dusk"}}, ":clock730:": emojiData{Name: ":clock730:", Description: "Clock Face Seven-Thirty", Unicode: "1F562", Alias: []string{"time", "late", "early", "schedule"}}, ":clock7:": emojiData{Name: ":clock7:", Description: "Clock Face Seven Oclock", Unicode: "1F556", Alias: []string{"time", "late", "early", "schedule"}}, ":clock830:": emojiData{Name: ":clock830:", Description: "Clock Face Eight-Thirty", Unicode: "1F563", Alias: []string{"time", "late", "early", "schedule"}}, ":clock8:": emojiData{Name: ":clock8:", Description: "Clock Face Eight Oclock", Unicode: "1F557", Alias: []string{"time", "late", "early", "schedule"}}, ":clock930:": emojiData{Name: ":clock930:", Description: "Clock Face Nine-Thirty", Unicode: "1F564", Alias: []string{"time", "late", "early", "schedule"}}, ":clock9:": emojiData{Name: ":clock9:", Description: "Clock Face Nine Oclock", Unicode: "1F558", Alias: []string{"time", "late", "early", "schedule"}}, ":clock:": emojiData{Name: ":hourglass:", Description: "Hourglass", Unicode: "231B", Alias: []string{"time", "clock", "oldschool", "limit", "exam", "quiz", "test"}}, ":closed_book:": emojiData{Name: ":closed_book:", Description: "Closed Book", Unicode: "1F4D5", Alias: []string{"read", "library", "knowledge", "textbook", "learn"}}, ":closed_lock_with_key:": emojiData{Name: ":closed_lock_with_key:", Description: "Closed Lock with Key", Unicode: "1F510", Alias: []string{"security", "privacy"}}, ":closed_umbrella:": emojiData{Name: ":closed_umbrella:", Description: "Closed Umbrella", Unicode: "1F302", Alias: []string{"weather", "rain", "drizzle"}}, ":cloth:": emojiData{Name: ":necktie:", Description: "Necktie", Unicode: "1F454", Alias: []string{"shirt", "suitup", "formal", "fashion", "cloth", "business"}}, ":clothes:": emojiData{Name: ":dress:", Description: "Dress", Unicode: "1F457", Alias: []string{"clothes", "fashion", "shopping"}}, ":cloud:": emojiData{Name: ":cloud:", Description: "Cloud", Unicode: "2601-FE0F", Alias: []string{"weather", "sky"}}, ":cloudy:": emojiData{Name: ":partly_sunny:", Description: "Sun Behind Cloud", Unicode: "26C5", Alias: []string{"weather", "nature", "cloudy", "morning", "fall", "spring"}}, ":clover:": emojiData{Name: ":shamrock:", Description: "Shamrock", Unicode: "2618-FE0F", Alias: []string{"vegetable", "plant", "nature", "irish", "clover"}}, ":clown_face:": emojiData{Name: ":clown_face:", Description: "Clown Face", Unicode: "1F921", Alias: []string{"face"}}, ":clubs:": emojiData{Name: ":clubs:", Description: "Black Club Suit", Unicode: "2663-FE0F", Alias: []string{"poker", "cards", "magic", "suits"}}, ":cluck:": emojiData{Name: ":chicken:", Description: "Chicken", Unicode: "1F414", Alias: []string{"animal", "cluck", "nature", "bird"}}, ":clumsy:": emojiData{Name: ":face_with_head_bandage:", Description: "Face with Head-Bandage", Unicode: "1F915", Alias: []string{"injured", "clumsy", "bandage", "hurt"}}, ":cn:": emojiData{Name: ":cn:", Description: "China Flag", Unicode: "1F1E8-1F1F3", Alias: []string{"china", "chinese", "prc", "flag", "country", "nation", "banner"}}, ":coat:": emojiData{Name: ":coat:", Description: "Coat", Unicode: "1F9E5", Alias: []string(nil)}, ":cocktail:": emojiData{Name: ":tropical_drink:", Description: "Tropical Drink", Unicode: "1F379", Alias: []string{"beverage", "cocktail", "summer", "beach", "alcohol", "booze", "mojito"}}, ":coconut:": emojiData{Name: ":coconut:", Description: "Coconut", Unicode: "1F965", Alias: []string(nil)}, ":coffee:": emojiData{Name: ":coffee:", Description: "Hot Beverage", Unicode: "2615", Alias: []string{"beverage", "caffeine", "latte", "espresso"}}, ":coffin:": emojiData{Name: ":coffin:", Description: "Coffin", Unicode: "26B0-FE0F", Alias: []string{"vampire", "dead", "die", "death", "rip", "graveyard", "cemetery", "casket", "funeral", "box"}}, ":cog:": emojiData{Name: ":gear:", Description: "Gear", Unicode: "2699-FE0F", Alias: []string{"cog"}}, ":coins:": emojiData{Name: ":moneybag:", Description: "Money Bag", Unicode: "1F4B0", Alias: []string{"dollar", "payment", "coins", "sale"}}, ":cold:": emojiData{Name: ":ski:", Description: "Ski and Ski Boot", Unicode: "1F3BF", Alias: []string{"sports", "winter", "cold", "snow"}}, ":cold_sweat:": emojiData{Name: ":cold_sweat:", Description: "Face with Open Mouth and Cold Sweat", Unicode: "1F630", Alias: []string{"face", "nervous", "sweat"}}, ":college:": emojiData{Name: ":mortar_board:", Description: "Graduation Cap", Unicode: "1F393", Alias: []string{"school", "college", "degree", "university", "graduation", "cap", "hat", "legal", "learn", "education"}}, ":collision:": emojiData{Name: ":boom:", Description: "Collision Symbol", Unicode: "1F4A5", Alias: []string{"bomb", "explode", "explosion", "collision", "blown"}}, ":colors:": emojiData{Name: ":art:", Description: "Artist Palette", Unicode: "1F3A8", Alias: []string{"design", "paint", "draw", "colors"}}, ":comet:": emojiData{Name: ":comet:", Description: "Comet", Unicode: "2604-FE0F", Alias: []string{"space"}}, ":communication:": emojiData{Name: ":mailbox_with_mail:", Description: "Open Mailbox with Raised Flag", Unicode: "1F4EC", Alias: []string{"email", "inbox", "communication"}}, ":competition:": emojiData{Name: ":horse_racing:", Description: "Horse Racing", Unicode: "1F3C7", Alias: []string{"animal", "betting", "competition", "gambling", "luck"}}, ":compose:": emojiData{Name: ":writing_hand:", Description: "Writing Hand", Unicode: "270D-FE0F", Alias: []string{"lower_left_ballpoint_pen", "stationery", "write", "compose"}}, ":compression:": emojiData{Name: ":compression:", Description: "Compression", Unicode: "1F5DC-FE0F", Alias: []string(nil)}, ":computer:": emojiData{Name: ":keyboard:", Description: "Keyboard", Unicode: "2328-FE0F", Alias: []string{"technology", "computer", "type", "input", "text"}}, ":computing:": emojiData{Name: ":desktop_computer:", Description: "Desktop Computer", Unicode: "1F5A5-FE0F", Alias: []string{"technology", "computing", "screen"}}, ":concern:": emojiData{Name: ":worried:", Description: "Worried Face", Unicode: "1F61F", Alias: []string{"face", "concern", "nervous", ":("}}, ":concert:": emojiData{Name: ":ticket:", Description: "Ticket", Unicode: "1F3AB", Alias: []string{"event", "concert", "pass"}}, ":confetti_ball:": emojiData{Name: ":confetti_ball:", Description: "Confetti Ball", Unicode: "1F38A", Alias: []string{"festival", "party", "birthday", "circus"}}, ":confirm:": emojiData{Name: ":ballot_box_with_check:", Description: "Ballot Box with Check", Unicode: "2611-FE0F", Alias: []string{"ok", "agree", "confirm", "black-square", "vote", "election", "yes", "tick"}}, ":confounded:": emojiData{Name: ":confounded:", Description: "Confounded Face", Unicode: "1F616", Alias: []string{"face", "confused", "sick", "unwell", "oops", ":S"}}, ":confused:": emojiData{Name: ":question:", Description: "Black Question Mark Ornament", Unicode: "2753", Alias: []string{"doubt", "confused"}}, ":congrats:": emojiData{Name: ":clap:", Description: "Clapping Hands Sign", Unicode: "1F44F", Alias: []string{"hands", "praise", "applause", "congrats", "yay"}}, ":congratulations:": emojiData{Name: ":fireworks:", Description: "Fireworks", Unicode: "1F386", Alias: []string{"photo", "festival", "carnival", "congratulations"}}, ":connection:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":console:": emojiData{Name: ":video_game:", Description: "Video Game", Unicode: "1F3AE", Alias: []string{"play", "console", "PS4", "controller"}}, ":constellation:": emojiData{Name: ":ophiuchus:", Description: "Ophiuchus", Unicode: "26CE", Alias: []string{"sign", "purple-square", "constellation", "astrology"}}, ":construction:": emojiData{Name: ":construction:", Description: "Construction Sign", Unicode: "1F6A7", Alias: []string{"wip", "progress", "caution", "warning"}}, ":construction_worker:": emojiData{Name: ":construction_worker:", Description: "Construction Worker", Unicode: "1F477", Alias: []string(nil)}, ":container:": emojiData{Name: ":baby_bottle:", Description: "Baby Bottle", Unicode: "1F37C", Alias: []string{"food", "container", "milk"}}, ":contest:": emojiData{Name: ":checkered_flag:", Description: "Chequered Flag", Unicode: "1F3C1", Alias: []string{"contest", "finishline", "race", "gokart"}}, ":continue:": emojiData{Name: ":fast_forward:", Description: "Black Right-Pointing Double Triangle", Unicode: "23E9", Alias: []string{"blue-square", "play", "speed", "continue"}}, ":control_knobs:": emojiData{Name: ":control_knobs:", Description: "Control Knobs", Unicode: "1F39B-FE0F", Alias: []string{"dial"}}, ":controller:": emojiData{Name: ":video_game:", Description: "Video Game", Unicode: "1F3AE", Alias: []string{"play", "console", "PS4", "controller"}}, ":convenience_store:": emojiData{Name: ":convenience_store:", Description: "Convenience Store", Unicode: "1F3EA", Alias: []string{"building", "shopping", "groceries"}}, ":cook:": emojiData{Name: ":fire:", Description: "Fire", Unicode: "1F525", Alias: []string{"hot", "cook", "flame"}}, ":cookie:": emojiData{Name: ":cookie:", Description: "Cookie", Unicode: "1F36A", Alias: []string{"food", "snack", "oreo", "chocolate", "sweet", "dessert"}}, ":cooking:": emojiData{Name: ":shallow_pan_of_food:", Description: "Shallow Pan of Food", Unicode: "1F958", Alias: []string{"food", "cooking", "casserole", "paella"}}, ":cool:": emojiData{Name: ":sunglasses:", Description: "Smiling Face with Sunglasses", Unicode: "1F60E", Alias: []string{"face", "cool", "smile", "summer", "beach", "sunglass"}}, ":cop:": emojiData{Name: ":cop:", Description: "Police Officer", Unicode: "1F46E", Alias: []string(nil)}, ":copyright:": emojiData{Name: ":copyright:", Description: "Copyright Sign", Unicode: "00A9-FE0F", Alias: []string{"ip", "license", "circle", "law", "legal"}}, ":corn:": emojiData{Name: ":corn:", Description: "Ear of Maize", Unicode: "1F33D", Alias: []string{"food", "vegetable", "plant"}}, ":couch_and_lamp:": emojiData{Name: ":couch_and_lamp:", Description: "Couch and Lamp", Unicode: "1F6CB-FE0F", Alias: []string{"read", "chill"}}, ":countdown:": emojiData{Name: ":hourglass_flowing_sand:", Description: "Hourglass with Flowing Sand", Unicode: "23F3", Alias: []string{"oldschool", "time", "countdown"}}, ":country:": emojiData{Name: ":us:", Description: "United States Flag", Unicode: "1F1FA-1F1F8", Alias: []string{"united", "states", "america", "flag", "nation", "country", "banner"}}, ":couple:": emojiData{Name: ":wedding:", Description: "Wedding", Unicode: "1F492", Alias: []string{"love", "like", "affection", "couple", "marriage", "bride", "groom"}}, ":couple_with_heart:": emojiData{Name: ":couple_with_heart:", Description: "Couple with Heart", Unicode: "1F491", Alias: []string(nil)}, ":couplekiss:": emojiData{Name: ":couplekiss:", Description: "Kiss", Unicode: "1F48F", Alias: []string(nil)}, ":cow2:": emojiData{Name: ":cow2:", Description: "Cow", Unicode: "1F404", Alias: []string{"beef", "ox", "animal", "nature", "moo", "milk"}}, ":cow:": emojiData{Name: ":cow:", Description: "Cow Face", Unicode: "1F42E", Alias: []string{"beef", "ox", "animal", "nature", "moo", "milk"}}, ":crab:": emojiData{Name: ":crab:", Description: "Crab", Unicode: "1F980", Alias: []string{"animal", "crustacean"}}, ":create:": emojiData{Name: ":hammer:", Description: "Hammer", Unicode: "1F528", Alias: []string{"tools", "build", "create"}}, ":creature:": emojiData{Name: ":octopus:", Description: "Octopus", Unicode: "1F419", Alias: []string{"animal", "creature", "ocean", "sea", "nature", "beach"}}, ":credit_card:": emojiData{Name: ":credit_card:", Description: "Credit Card", Unicode: "1F4B3", Alias: []string{"money", "sales", "dollar", "bill", "payment", "shopping"}}, ":creepy:": emojiData{Name: ":japanese_ogre:", Description: "Japanese Ogre", Unicode: "1F479", Alias: []string{"monster", "red", "mask", "halloween", "scary", "creepy", "devil", "demon", "japanese", "ogre"}}, ":crescent_moon:": emojiData{Name: ":crescent_moon:", Description: "Crescent Moon", Unicode: "1F319", Alias: []string{"night", "sleep", "sky", "evening", "magic"}}, ":cricket:": emojiData{Name: ":cricket:", Description: "Cricket", Unicode: "1F997", Alias: []string{"sports"}}, ":cricket_bat_and_ball:": emojiData{Name: ":cricket_bat_and_ball:", Description: "Cricket Bat and Ball", Unicode: "1F3CF", Alias: []string(nil)}, ":croak:": emojiData{Name: ":frog:", Description: "Frog Face", Unicode: "1F438", Alias: []string{"animal", "nature", "croak", "toad"}}, ":crocodile:": emojiData{Name: ":crocodile:", Description: "Crocodile", Unicode: "1F40A", Alias: []string{"animal", "nature", "reptile", "lizard", "alligator"}}, ":croissant:": emojiData{Name: ":croissant:", Description: "Croissant", Unicode: "1F950", Alias: []string{"food", "bread", "french"}}, ":crossed_fingers:": emojiData{Name: ":crossed_fingers:", Description: "Hand with Index and Middle Fingers Crossed", Unicode: "1F91E", Alias: []string{"good", "lucky"}}, ":crossed_flags:": emojiData{Name: ":crossed_flags:", Description: "Crossed Flags", Unicode: "1F38C", Alias: []string{"japanese", "nation", "country", "border"}}, ":crossed_swords:": emojiData{Name: ":crossed_swords:", Description: "Crossed Swords", Unicode: "2694-FE0F", Alias: []string{"weapon"}}, ":crossing:": emojiData{Name: ":no_pedestrians:", Description: "No Pedestrians", Unicode: "1F6B7", Alias: []string{"rules", "crossing", "walking", "circle"}}, ":crown:": emojiData{Name: ":prince:", Description: "Prince", Unicode: "1F934", Alias: []string{"boy", "man", "male", "crown", "royal", "king"}}, ":cruise:": emojiData{Name: ":passenger_ship:", Description: "Passenger Ship", Unicode: "1F6F3-FE0F", Alias: []string{"yacht", "cruise", "ferry"}}, ":crush:": emojiData{Name: ":blush:", Description: "Smiling Face with Smiling Eyes", Unicode: "1F60A", Alias: []string{"face", "smile", "happy", "flushed", "crush", "embarrassed", "shy", "joy"}}, ":crustacean:": emojiData{Name: ":crab:", Description: "Crab", Unicode: "1F980", Alias: []string{"animal", "crustacean"}}, ":cry:": emojiData{Name: ":sob:", Description: "Loudly Crying Face", Unicode: "1F62D", Alias: []string{"face", "cry", "tears", "sad", "upset", "depressed"}}, ":crying_cat_face:": emojiData{Name: ":crying_cat_face:", Description: "Crying Cat Face", Unicode: "1F63F", Alias: []string{"animal", "tears", "weep", "sad", "cats", "upset", "cry"}}, ":crystal:": emojiData{Name: ":diamond_shape_with_a_dot_inside:", Description: "Diamond Shape with a Dot Inside", Unicode: "1F4A0", Alias: []string{"jewel", "blue", "gem", "crystal", "fancy"}}, ":crystal_ball:": emojiData{Name: ":crystal_ball:", Description: "Crystal Ball", Unicode: "1F52E", Alias: []string{"disco", "party", "magic", "circus", "fortune_teller"}}, ":cucumber:": emojiData{Name: ":cucumber:", Description: "Cucumber", Unicode: "1F952", Alias: []string{"fruit", "food", "pickle"}}, ":culture:": emojiData{Name: ":classical_building:", Description: "Classical Building", Unicode: "1F3DB-FE0F", Alias: []string{"art", "culture", "history"}}, ":cup_with_straw:": emojiData{Name: ":cup_with_straw:", Description: "Cup with Straw", Unicode: "1F964", Alias: []string(nil)}, ":cupertino:": emojiData{Name: ":motorway:", Description: "Motorway", Unicode: "1F6E3-FE0F", Alias: []string{"road", "cupertino", "interstate", "highway"}}, ":cupid:": emojiData{Name: ":cupid:", Description: "Heart with Arrow", Unicode: "1F498", Alias: []string{"love", "like", "heart", "affection", "valentines"}}, ":curling_stone:": emojiData{Name: ":curling_stone:", Description: "Curling Stone", Unicode: "1F94C", Alias: []string(nil)}, ":curly_loop:": emojiData{Name: ":curly_loop:", Description: "Curly Loop", Unicode: "27B0", Alias: []string{"scribble", "draw", "shape", "squiggle"}}, ":currency:": emojiData{Name: ":euro:", Description: "Banknote with Euro Sign", Unicode: "1F4B6", Alias: []string{"money", "sales", "dollar", "currency"}}, ":currency_exchange:": emojiData{Name: ":currency_exchange:", Description: "Currency Exchange", Unicode: "1F4B1", Alias: []string{"money", "sales", "dollar", "travel"}}, ":curry:": emojiData{Name: ":curry:", Description: "Curry and Rice", Unicode: "1F35B", Alias: []string{"food", "spicy", "hot", "indian"}}, ":curtain:": emojiData{Name: ":cinema:", Description: "Cinema", Unicode: "1F3A6", Alias: []string{"blue-square", "record", "film", "movie", "curtain", "stage", "theater"}}, ":custard:": emojiData{Name: ":custard:", Description: "Custard", Unicode: "1F36E", Alias: []string{"dessert", "food"}}, ":custom:": emojiData{Name: ":passport_control:", Description: "Passport Control", Unicode: "1F6C2", Alias: []string{"custom", "blue-square"}}, ":customs:": emojiData{Name: ":customs:", Description: "Customs", Unicode: "1F6C3", Alias: []string{"passport", "border", "blue-square"}}, ":cut:": emojiData{Name: ":scissors:", Description: "Black Scissors", Unicode: "2702-FE0F", Alias: []string{"stationery", "cut"}}, ":cut_of_meat:": emojiData{Name: ":cut_of_meat:", Description: "Cut of Meat", Unicode: "1F969", Alias: []string(nil)}, ":cutlery:": emojiData{Name: ":hocho:", Description: "Hocho", Unicode: "1F52A", Alias: []string{"knife", "blade", "cutlery", "kitchen", "weapon"}}, ":cycle:": emojiData{Name: ":arrows_clockwise:", Description: "Clockwise Downwards and Upwards Open Circle Arrows", Unicode: "1F503", Alias: []string{"sync", "cycle", "round", "repeat"}}, ":cyclist:": emojiData{Name: ":no_bicycles:", Description: "No Bicycles", Unicode: "1F6B3", Alias: []string{"cyclist", "prohibited", "circle"}}, ":cyclone:": emojiData{Name: ":tornado:", Description: "Tornado", Unicode: "1F32A-FE0F", Alias: []string{"weather", "cyclone", "twister"}}, ":dad:": emojiData{Name: ":man:", Description: "Man", Unicode: "1F468", Alias: []string{"mustache", "father", "dad", "guy", "classy", "sir", "moustache"}}, ":dagger_knife:": emojiData{Name: ":dagger_knife:", Description: "Dagger Knife", Unicode: "1F5E1-FE0F", Alias: []string(nil)}, ":dancer:": emojiData{Name: ":man_dancing:", Description: "Man Dancing", Unicode: "1F57A", Alias: []string{"male", "boy", "fun", "dancer"}}, ":dancers:": emojiData{Name: ":dancers:", Description: "Woman with Bunny Ears", Unicode: "1F46F", Alias: []string(nil)}, ":danger:": emojiData{Name: ":skull_and_crossbones:", Description: "Skull and Crossbones", Unicode: "2620-FE0F", Alias: []string{"poison", "danger", "deadly", "scary", "death", "pirate", "evil"}}, ":dango:": emojiData{Name: ":dango:", Description: "Dango", Unicode: "1F361", Alias: []string{"food", "dessert", "sweet", "japanese", "barbecue", "meat"}}, ":dark:": emojiData{Name: ":flashlight:", Description: "Electric Torch", Unicode: "1F526", Alias: []string{"dark", "camping", "sight", "night"}}, ":dark_sunglasses:": emojiData{Name: ":dark_sunglasses:", Description: "Dark Sunglasses", Unicode: "1F576-FE0F", Alias: []string{"face", "cool", "accessories"}}, ":dart:": emojiData{Name: ":dart:", Description: "Direct Hit", Unicode: "1F3AF", Alias: []string{"game", "play", "bar"}}, ":dash:": emojiData{Name: ":dash:", Description: "Dash Symbol", Unicode: "1F4A8", Alias: []string{"wind", "air", "fast", "shoo", "fart", "smoke", "puff"}}, ":data:": emojiData{Name: ":minidisc:", Description: "Minidisc", Unicode: "1F4BD", Alias: []string{"technology", "record", "data", "disk", "90s"}}, ":date:": emojiData{Name: ":calendar:", Description: "Tear-off Calendar", Unicode: "1F4C6", Alias: []string{"schedule", "date", "planning"}}, ":dating:": emojiData{Name: ":love_hotel:", Description: "Love Hotel", Unicode: "1F3E9", Alias: []string{"like", "affection", "dating"}}, ":dawn:": emojiData{Name: ":clock6:", Description: "Clock Face Six Oclock", Unicode: "1F555", Alias: []string{"time", "late", "early", "schedule", "dawn", "dusk"}}, ":de:": emojiData{Name: ":de:", Description: "Germany Flag", Unicode: "1F1E9-1F1EA", Alias: []string{"german", "nation", "flag", "country", "banner"}}, ":dead:": emojiData{Name: ":funeral_urn:", Description: "Funeral Urn", Unicode: "26B1-FE0F", Alias: []string{"dead", "die", "death", "rip", "ashes"}}, ":deadline:": emojiData{Name: ":stopwatch:", Description: "Stopwatch", Unicode: "23F1-FE0F", Alias: []string{"time", "deadline"}}, ":deadly:": emojiData{Name: ":skull_and_crossbones:", Description: "Skull and Crossbones", Unicode: "2620-FE0F", Alias: []string{"poison", "danger", "deadly", "scary", "death", "pirate", "evil"}}, ":deadpan:": emojiData{Name: ":expressionless:", Description: "Expressionless Face", Unicode: "1F611", Alias: []string{"face", "indifferent", "-_-", "meh", "deadpan"}}, ":death:": emojiData{Name: ":funeral_urn:", Description: "Funeral Urn", Unicode: "26B1-FE0F", Alias: []string{"dead", "die", "death", "rip", "ashes"}}, ":december:": emojiData{Name: ":christmas_tree:", Description: "Christmas Tree", Unicode: "1F384", Alias: []string{"festival", "vacation", "december", "xmas", "celebration"}}, ":deciduous_tree:": emojiData{Name: ":deciduous_tree:", Description: "Deciduous Tree", Unicode: "1F333", Alias: []string{"plant", "nature"}}, ":decoration:": emojiData{Name: ":rosette:", Description: "Rosette", Unicode: "1F3F5-FE0F", Alias: []string{"flower", "decoration", "military"}}, ":decorative:": emojiData{Name: ":fleur_de_lis:", Description: "Fleur De Lis", Unicode: "269C-FE0F", Alias: []string{"decorative", "scout"}}, ":deer:": emojiData{Name: ":deer:", Description: "Deer", Unicode: "1F98C", Alias: []string{"animal", "nature", "horns", "venison"}}, ":degree:": emojiData{Name: ":mortar_board:", Description: "Graduation Cap", Unicode: "1F393", Alias: []string{"school", "college", "degree", "university", "graduation", "cap", "hat", "legal", "learn", "education"}}, ":delete:": emojiData{Name: ":x:", Description: "Cross Mark", Unicode: "274C", Alias: []string{"no", "delete", "remove", "cancel"}}, ":delicious:": emojiData{Name: ":yum:", Description: "Face Savouring Delicious Food", Unicode: "1F60B", Alias: []string{"happy", "joy", "tongue", "smile", "face", "silly", "yummy", "nom", "delicious", "savouring"}}, ":demon:": emojiData{Name: ":japanese_ogre:", Description: "Japanese Ogre", Unicode: "1F479", Alias: []string{"monster", "red", "mask", "halloween", "scary", "creepy", "devil", "demon", "japanese", "ogre"}}, ":denied:": emojiData{Name: ":no_entry_sign:", Description: "No Entry Sign", Unicode: "1F6AB", Alias: []string{"forbid", "stop", "limit", "denied", "disallow", "circle"}}, ":deny:": emojiData{Name: ":negative_squared_cross_mark:", Description: "Negative Squared Cross Mark", Unicode: "274E", Alias: []string{"x", "green-square", "no", "deny"}}, ":department_store:": emojiData{Name: ":department_store:", Description: "Department Store", Unicode: "1F3EC", Alias: []string{"building", "shopping", "mall"}}, ":deploy:": emojiData{Name: ":ship:", Description: "Ship", Unicode: "1F6A2", Alias: []string{"transportation", "titanic", "deploy"}}, ":depressed:": emojiData{Name: ":sob:", Description: "Loudly Crying Face", Unicode: "1F62D", Alias: []string{"face", "cry", "tears", "sad", "upset", "depressed"}}, ":derelict_house_building:": emojiData{Name: ":derelict_house_building:", Description: "Derelict House Building", Unicode: "1F3DA-FE0F", Alias: []string(nil)}, ":desert:": emojiData{Name: ":desert:", Description: "Desert", Unicode: "1F3DC-FE0F", Alias: []string{"photo", "warm", "saharah"}}, ":desert_island:": emojiData{Name: ":desert_island:", Description: "Desert Island", Unicode: "1F3DD-FE0F", Alias: []string{"photo", "tropical", "mojito"}}, ":design:": emojiData{Name: ":art:", Description: "Artist Palette", Unicode: "1F3A8", Alias: []string{"design", "paint", "draw", "colors"}}, ":desktop_computer:": emojiData{Name: ":desktop_computer:", Description: "Desktop Computer", Unicode: "1F5A5-FE0F", Alias: []string{"technology", "computing", "screen"}}, ":despise:": emojiData{Name: ":rage:", Description: "Pouting Face", Unicode: "1F621", Alias: []string{"angry", "mad", "hate", "despise"}}, ":dessert:": emojiData{Name: ":icecream:", Description: "Soft Ice Cream", Unicode: "1F366", Alias: []string{"food", "hot", "dessert", "summer"}}, ":destination:": emojiData{Name: ":koko:", Description: "Squared Katakana Koko", Unicode: "1F201", Alias: []string{"blue-square", "here", "katakana", "japanese", "destination"}}, ":detective:": emojiData{Name: ":mag:", Description: "Left-Pointing Magnifying Glass", Unicode: "1F50D", Alias: []string{"search", "zoom", "find", "detective"}}, ":devil:": emojiData{Name: ":japanese_ogre:", Description: "Japanese Ogre", Unicode: "1F479", Alias: []string{"monster", "red", "mask", "halloween", "scary", "creepy", "devil", "demon", "japanese", "ogre"}}, ":dhikr:": emojiData{Name: ":prayer_beads:", Description: "Prayer Beads", Unicode: "1F4FF", Alias: []string{"dhikr", "religious"}}, ":diagonal:": emojiData{Name: ":arrow_lower_right:", Description: "South East Arrow", Unicode: "2198-FE0F", Alias: []string{"blue-square", "direction", "diagonal", "southeast"}}, ":dial:": emojiData{Name: ":telephone_receiver:", Description: "Telephone Receiver", Unicode: "1F4DE", Alias: []string{"technology", "communication", "dial"}}, ":diamond:": emojiData{Name: ":ring:", Description: "Ring", Unicode: "1F48D", Alias: []string{"wedding", "propose", "marriage", "valentines", "diamond", "fashion", "jewelry", "gem", "engagement"}}, ":diamond_shape_with_a_dot_inside:": emojiData{Name: ":diamond_shape_with_a_dot_inside:", Description: "Diamond Shape with a Dot Inside", Unicode: "1F4A0", Alias: []string{"jewel", "blue", "gem", "crystal", "fancy"}}, ":diamonds:": emojiData{Name: ":diamonds:", Description: "Black Diamond Suit", Unicode: "2666-FE0F", Alias: []string{"poker", "cards", "magic", "suits"}}, ":dice:": emojiData{Name: ":game_die:", Description: "Game Die", Unicode: "1F3B2", Alias: []string{"dice", "random", "tabletop", "play", "luck"}}, ":die:": emojiData{Name: ":funeral_urn:", Description: "Funeral Urn", Unicode: "26B1-FE0F", Alias: []string{"dead", "die", "death", "rip", "ashes"}}, ":dig:": emojiData{Name: ":pick:", Description: "Pick", Unicode: "26CF-FE0F", Alias: []string{"tools", "dig"}}, ":ding:": emojiData{Name: ":wind_chime:", Description: "Wind Chime", Unicode: "1F390", Alias: []string{"nature", "ding", "spring", "bell"}}, ":direction:": emojiData{Name: ":arrow_up_small:", Description: "Up-Pointing Small Red Triangle", Unicode: "1F53C", Alias: []string{"blue-square", "triangle", "direction", "point", "forward", "top"}}, ":disabled:": emojiData{Name: ":wheelchair:", Description: "Wheelchair Symbol", Unicode: "267F", Alias: []string{"blue-square", "disabled", "a11y", "accessibility"}}, ":disallow:": emojiData{Name: ":no_entry_sign:", Description: "No Entry Sign", Unicode: "1F6AB", Alias: []string{"forbid", "stop", "limit", "denied", "disallow", "circle"}}, ":disappointed:": emojiData{Name: ":disappointed:", Description: "Disappointed Face", Unicode: "1F61E", Alias: []string{"face", "sad", "upset", "depressed", ":("}}, ":disappointed_relieved:": emojiData{Name: ":disappointed_relieved:", Description: "Disappointed but Relieved Face", Unicode: "1F625", Alias: []string{"face", "phew", "sweat", "nervous"}}, ":disaster:": emojiData{Name: ":ocean:", Description: "Water Wave", Unicode: "1F30A", Alias: []string{"sea", "water", "wave", "nature", "tsunami", "disaster"}}, ":disc:": emojiData{Name: ":dvd:", Description: "Dvd", Unicode: "1F4C0", Alias: []string{"cd", "disk", "disc"}}, ":disco:": emojiData{Name: ":crystal_ball:", Description: "Crystal Ball", Unicode: "1F52E", Alias: []string{"disco", "party", "magic", "circus", "fortune_teller"}}, ":disease:": emojiData{Name: ":mask:", Description: "Face with Medical Mask", Unicode: "1F637", Alias: []string{"face", "sick", "ill", "disease"}}, ":disk:": emojiData{Name: ":dvd:", Description: "Dvd", Unicode: "1F4C0", Alias: []string{"cd", "disk", "disc"}}, ":dislike:": emojiData{Name: ":-1:", Description: "Thumbs Down Sign", Unicode: "1F44E", Alias: []string{"thumbsdown", "no", "dislike", "hand"}}, ":display:": emojiData{Name: ":computer:", Description: "Personal Computer", Unicode: "1F4BB", Alias: []string{"technology", "laptop", "screen", "display", "monitor"}}, ":distilling:": emojiData{Name: ":alembic:", Description: "Alembic", Unicode: "2697-FE0F", Alias: []string{"distilling", "science", "experiment", "chemistry"}}, ":divide:": emojiData{Name: ":u5272:", Description: "Squared Cjk Unified Ideograph-5272", Unicode: "1F239", Alias: []string{"cut", "divide", "chinese", "kanji", "pink-square"}}, ":diy:": emojiData{Name: ":wrench:", Description: "Wrench", Unicode: "1F527", Alias: []string{"tools", "diy", "ikea", "fix", "ainer"}}, ":dizzy:": emojiData{Name: ":dizzy_face:", Description: "Dizzy Face", Unicode: "1F635", Alias: []string{"spent", "unconscious", "xox", "dizzy"}}, ":dizzy_face:": emojiData{Name: ":dizzy_face:", Description: "Dizzy Face", Unicode: "1F635", Alias: []string{"spent", "unconscious", "xox", "dizzy"}}, ":do_not_litter:": emojiData{Name: ":do_not_litter:", Description: "Do Not Litter Symbol", Unicode: "1F6AF", Alias: []string{"trash", "bin", "garbage", "circle"}}, ":doctor:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":documents:": emojiData{Name: ":open_file_folder:", Description: "Open File Folder", Unicode: "1F4C2", Alias: []string{"documents", "load"}}, ":dog2:": emojiData{Name: ":dog2:", Description: "Dog", Unicode: "1F415", Alias: []string{"animal", "nature", "friend", "doge", "pet", "faithful"}}, ":dog:": emojiData{Name: ":dog:", Description: "Dog Face", Unicode: "1F436", Alias: []string{"animal", "friend", "nature", "woof", "puppy", "pet", "faithful"}}, ":doge:": emojiData{Name: ":dog2:", Description: "Dog", Unicode: "1F415", Alias: []string{"animal", "nature", "friend", "doge", "pet", "faithful"}}, ":dollar:": emojiData{Name: ":euro:", Description: "Banknote with Euro Sign", Unicode: "1F4B6", Alias: []string{"money", "sales", "dollar", "currency"}}, ":dolls:": emojiData{Name: ":dolls:", Description: "Japanese Dolls", Unicode: "1F38E", Alias: []string{"japanese", "toy", "kimono"}}, ":dolphin:": emojiData{Name: ":dolphin:", Description: "Dolphin", Unicode: "1F42C", Alias: []string{"animal", "nature", "fish", "sea", "ocean", "flipper", "fins", "beach"}}, ":donut:": emojiData{Name: ":doughnut:", Description: "Doughnut", Unicode: "1F369", Alias: []string{"food", "dessert", "snack", "sweet", "donut"}}, ":door:": emojiData{Name: ":door:", Description: "Door", Unicode: "1F6AA", Alias: []string{"house", "entry", "exit"}}, ":dork:": emojiData{Name: ":nerd_face:", Description: "Nerd Face", Unicode: "1F913", Alias: []string{"face", "nerdy", "geek", "dork"}}, ":double_vertical_bar:": emojiData{Name: ":double_vertical_bar:", Description: "Double Vertical Bar", Unicode: "23F8-FE0F", Alias: []string(nil)}, ":doubt:": emojiData{Name: ":question:", Description: "Black Question Mark Ornament", Unicode: "2753", Alias: []string{"doubt", "confused"}}, ":doubts:": emojiData{Name: ":grey_question:", Description: "White Question Mark Ornament", Unicode: "2754", Alias: []string{"doubts", "gray", "huh", "confused"}}, ":doughnut:": emojiData{Name: ":doughnut:", Description: "Doughnut", Unicode: "1F369", Alias: []string{"food", "dessert", "snack", "sweet", "donut"}}, ":dove_of_peace:": emojiData{Name: ":dove_of_peace:", Description: "Dove of Peace", Unicode: "1F54A-FE0F", Alias: []string(nil)}, ":down:": emojiData{Name: ":point_down:", Description: "White Down Pointing Backhand Index", Unicode: "1F447", Alias: []string{"fingers", "hand", "direction", "down"}}, ":downtown:": emojiData{Name: ":night_with_stars:", Description: "Night with Stars", Unicode: "1F303", Alias: []string{"evening", "city", "downtown"}}, ":dragon:": emojiData{Name: ":dragon:", Description: "Dragon", Unicode: "1F409", Alias: []string{"animal", "myth", "nature", "chinese", "green"}}, ":dragon_face:": emojiData{Name: ":dragon_face:", Description: "Dragon Face", Unicode: "1F432", Alias: []string{"animal", "myth", "nature", "chinese", "green"}}, ":drama:": emojiData{Name: ":performing_arts:", Description: "Performing Arts", Unicode: "1F3AD", Alias: []string{"acting", "theater", "drama"}}, ":draw:": emojiData{Name: ":art:", Description: "Artist Palette", Unicode: "1F3A8", Alias: []string{"design", "paint", "draw", "colors"}}, ":drawing:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":dream:": emojiData{Name: ":thought_balloon:", Description: "Thought Balloon", Unicode: "1F4AD", Alias: []string{"bubble", "cloud", "speech", "thinking", "dream"}}, ":dress:": emojiData{Name: ":dress:", Description: "Dress", Unicode: "1F457", Alias: []string{"clothes", "fashion", "shopping"}}, ":drink:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":drip:": emojiData{Name: ":sweat_drops:", Description: "Splashing Sweat Symbol", Unicode: "1F4A6", Alias: []string{"water", "drip", "oops"}}, ":driving:": emojiData{Name: ":vertical_traffic_light:", Description: "Vertical Traffic Light", Unicode: "1F6A6", Alias: []string{"transportation", "driving"}}, ":drizzle:": emojiData{Name: ":closed_umbrella:", Description: "Closed Umbrella", Unicode: "1F302", Alias: []string{"weather", "rain", "drizzle"}}, ":dromedary_camel:": emojiData{Name: ":dromedary_camel:", Description: "Dromedary Camel", Unicode: "1F42A", Alias: []string{"animal", "hot", "desert", "hump"}}, ":drooling_face:": emojiData{Name: ":drooling_face:", Description: "Drooling Face", Unicode: "1F924", Alias: []string{"face"}}, ":droplet:": emojiData{Name: ":droplet:", Description: "Droplet", Unicode: "1F4A7", Alias: []string{"water", "drip", "faucet", "spring"}}, ":drug:": emojiData{Name: ":pill:", Description: "Pill", Unicode: "1F48A", Alias: []string{"health", "medicine", "doctor", "pharmacy", "drug"}}, ":drugs:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":drum_with_drumsticks:": emojiData{Name: ":drum_with_drumsticks:", Description: "Drum with Drumsticks", Unicode: "1F941", Alias: []string(nil)}, ":drumstick:": emojiData{Name: ":meat_on_bone:", Description: "Meat on Bone", Unicode: "1F356", Alias: []string{"good", "food", "drumstick"}}, ":drunk:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":duck:": emojiData{Name: ":duck:", Description: "Duck", Unicode: "1F986", Alias: []string{"animal", "nature", "bird", "mallard"}}, ":dumpling:": emojiData{Name: ":dumpling:", Description: "Dumpling", Unicode: "1F95F", Alias: []string(nil)}, ":dusk:": emojiData{Name: ":clock6:", Description: "Clock Face Six Oclock", Unicode: "1F555", Alias: []string{"time", "late", "early", "schedule", "dawn", "dusk"}}, ":dvd:": emojiData{Name: ":dvd:", Description: "Dvd", Unicode: "1F4C0", Alias: []string{"cd", "disk", "disc"}}, ":e-mail:": emojiData{Name: ":e-mail:", Description: "E-Mail Symbol", Unicode: "1F4E7", Alias: []string{"communication", "inbox"}}, ":eagle:": emojiData{Name: ":eagle:", Description: "Eagle", Unicode: "1F985", Alias: []string{"animal", "nature", "bird"}}, ":ear:": emojiData{Name: ":ear:", Description: "Ear", Unicode: "1F442", Alias: []string{"face", "hear", "sound", "listen"}}, ":ear_of_rice:": emojiData{Name: ":ear_of_rice:", Description: "Ear of Rice", Unicode: "1F33E", Alias: []string{"nature", "plant"}}, ":early:": emojiData{Name: ":clock12:", Description: "Clock Face Twelve Oclock", Unicode: "1F55B", Alias: []string{"time", "noon", "midnight", "midday", "late", "early", "schedule"}}, ":earth:": emojiData{Name: ":globe_with_meridians:", Description: "Globe with Meridians", Unicode: "1F310", Alias: []string{"earth", "international", "world", "internet", "interweb", "i18n"}}, ":earth_africa:": emojiData{Name: ":earth_africa:", Description: "Earth Globe Europe-Africa", Unicode: "1F30D", Alias: []string{"globe", "world", "international"}}, ":earth_americas:": emojiData{Name: ":earth_americas:", Description: "Earth Globe Americas", Unicode: "1F30E", Alias: []string{"globe", "world", "USA", "international"}}, ":earth_asia:": emojiData{Name: ":earth_asia:", Description: "Earth Globe Asia-Australia", Unicode: "1F30F", Alias: []string{"globe", "world", "east", "international"}}, ":east:": emojiData{Name: ":earth_asia:", Description: "Earth Globe Asia-Australia", Unicode: "1F30F", Alias: []string{"globe", "world", "east", "international"}}, ":easter island:": emojiData{Name: ":moyai:", Description: "Moyai", Unicode: "1F5FF", Alias: []string{"rock", "easter island", "moai"}}, ":economics:": emojiData{Name: ":part_alternation_mark:", Description: "Part Alternation Mark", Unicode: "303D-FE0F", Alias: []string{"graph", "presentation", "stats", "business", "economics", "bad"}}, ":education:": emojiData{Name: ":school_satchel:", Description: "School Satchel", Unicode: "1F392", Alias: []string{"student", "education", "bag", "backpack"}}, ":egg:": emojiData{Name: ":hatching_chick:", Description: "Hatching Chick", Unicode: "1F423", Alias: []string{"animal", "chicken", "egg", "born", "baby", "bird"}}, ":eggplant:": emojiData{Name: ":eggplant:", Description: "Aubergine", Unicode: "1F346", Alias: []string{"vegetable", "nature", "food", "aubergine"}}, ":eight:": emojiData{Name: ":eight:", Description: "Keycap 8", Unicode: "0038-FE0F-20E3", Alias: []string{"8", "blue-square", "numbers"}}, ":eight_pointed_black_star:": emojiData{Name: ":eight_pointed_black_star:", Description: "Eight Pointed Black Star", Unicode: "2734-FE0F", Alias: []string{"orange-square", "shape", "polygon"}}, ":eight_spoked_asterisk:": emojiData{Name: ":eight_spoked_asterisk:", Description: "Eight Spoked Asterisk", Unicode: "2733-FE0F", Alias: []string{"star", "sparkle", "green-square"}}, ":eject:": emojiData{Name: ":eject:", Description: "Eject", Unicode: "23CF-FE0F", Alias: []string(nil)}, ":elder:": emojiData{Name: ":older_man:", Description: "Older Man", Unicode: "1F474", Alias: []string{"human", "male", "men", "old", "elder", "senior"}}, ":election:": emojiData{Name: ":white_check_mark:", Description: "White Heavy Check Mark", Unicode: "2705", Alias: []string{"green-square", "ok", "agree", "vote", "election", "answer", "tick"}}, ":electric_plug:": emojiData{Name: ":electric_plug:", Description: "Electric Plug", Unicode: "1F50C", Alias: []string{"charger", "power"}}, ":electricity:": emojiData{Name: ":bulb:", Description: "Electric Light Bulb", Unicode: "1F4A1", Alias: []string{"light", "electricity", "idea"}}, ":elephant:": emojiData{Name: ":elephant:", Description: "Elephant", Unicode: "1F418", Alias: []string{"animal", "nature", "nose", "th", "circus"}}, ":elf:": emojiData{Name: ":elf:", Description: "Elf", Unicode: "1F9DD", Alias: []string(nil)}, ":email:": emojiData{Name: ":love_letter:", Description: "Love Letter", Unicode: "1F48C", Alias: []string{"email", "like", "affection", "envelope", "valentines"}}, ":embarrassed:": emojiData{Name: ":blush:", Description: "Smiling Face with Smiling Eyes", Unicode: "1F60A", Alias: []string{"face", "smile", "happy", "flushed", "crush", "embarrassed", "shy", "joy"}}, ":embarrassing:": emojiData{Name: ":hole:", Description: "Hole", Unicode: "1F573-FE0F", Alias: []string{"embarrassing"}}, ":emergency:": emojiData{Name: ":rotating_light:", Description: "Police Cars Revolving Light", Unicode: "1F6A8", Alias: []string{"police", "ambulance", "911", "emergency", "alert", "error", "pinged", "law", "legal"}}, ":empty:": emojiData{Name: ":u7a7a:", Description: "Squared Cjk Unified Ideograph-7a7a", Unicode: "1F233", Alias: []string{"kanji", "japanese", "chinese", "empty", "sky", "blue-square"}}, ":end:": emojiData{Name: ":end:", Description: "End with Leftwards Arrow Above", Unicode: "1F51A", Alias: []string{"words", "arrow"}}, ":energy:": emojiData{Name: ":battery:", Description: "Battery", Unicode: "1F50B", Alias: []string{"power", "energy", "sustain"}}, ":enforcement:": emojiData{Name: ":police_car:", Description: "Police Car", Unicode: "1F693", Alias: []string{"vehicle", "cars", "transportation", "law", "legal", "enforcement"}}, ":engagement:": emojiData{Name: ":ring:", Description: "Ring", Unicode: "1F48D", Alias: []string{"wedding", "propose", "marriage", "valentines", "diamond", "fashion", "jewelry", "gem", "engagement"}}, ":england:": emojiData{Name: ":pound:", Description: "Banknote with Pound Sign", Unicode: "1F4B7", Alias: []string{"british", "sterling", "money", "sales", "bills", "uk", "england", "currency"}}, ":enter:": emojiData{Name: ":leftwards_arrow_with_hook:", Description: "Leftwards Arrow with Hook", Unicode: "21A9-FE0F", Alias: []string{"back", "return", "blue-square", "undo", "enter"}}, ":enterprise:": emojiData{Name: ":bank:", Description: "Bank", Unicode: "1F3E6", Alias: []string{"building", "money", "sales", "cash", "business", "enterprise"}}, ":entry:": emojiData{Name: ":door:", Description: "Door", Unicode: "1F6AA", Alias: []string{"house", "entry", "exit"}}, ":envelope:": emojiData{Name: ":love_letter:", Description: "Love Letter", Unicode: "1F48C", Alias: []string{"email", "like", "affection", "envelope", "valentines"}}, ":envelope_with_arrow:": emojiData{Name: ":envelope_with_arrow:", Description: "Envelope with Downwards Arrow Above", Unicode: "1F4E9", Alias: []string{"email", "communication"}}, ":environment:": emojiData{Name: ":national_park:", Description: "National Park", Unicode: "1F3DE-FE0F", Alias: []string{"photo", "environment", "nature"}}, ":error:": emojiData{Name: ":warning:", Description: "Warning Sign", Unicode: "26A0-FE0F", Alias: []string{"exclamation", "wip", "alert", "error", "problem", "issue"}}, ":es:": emojiData{Name: ":es:", Description: "Spain Flag", Unicode: "1F1EA-1F1F8", Alias: []string{"spain", "flag", "nation", "country", "banner"}}, ":espresso:": emojiData{Name: ":coffee:", Description: "Hot Beverage", Unicode: "2615", Alias: []string{"beverage", "caffeine", "latte", "espresso"}}, ":euro:": emojiData{Name: ":euro:", Description: "Banknote with Euro Sign", Unicode: "1F4B6", Alias: []string{"money", "sales", "dollar", "currency"}}, ":european_castle:": emojiData{Name: ":european_castle:", Description: "European Castle", Unicode: "1F3F0", Alias: []string{"building", "royalty", "history"}}, ":european_post_office:": emojiData{Name: ":european_post_office:", Description: "European Post Office", Unicode: "1F3E4", Alias: []string{"building", "email"}}, ":evening:": emojiData{Name: ":night_with_stars:", Description: "Night with Stars", Unicode: "1F303", Alias: []string{"evening", "city", "downtown"}}, ":event:": emojiData{Name: ":ticket:", Description: "Ticket", Unicode: "1F3AB", Alias: []string{"event", "concert", "pass"}}, ":evergreen_tree:": emojiData{Name: ":evergreen_tree:", Description: "Evergreen Tree", Unicode: "1F332", Alias: []string{"plant", "nature"}}, ":evil:": emojiData{Name: ":skull_and_crossbones:", Description: "Skull and Crossbones", Unicode: "2620-FE0F", Alias: []string{"poison", "danger", "deadly", "scary", "death", "pirate", "evil"}}, ":exam:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":exclamation:": emojiData{Name: ":warning:", Description: "Warning Sign", Unicode: "26A0-FE0F", Alias: []string{"exclamation", "wip", "alert", "error", "problem", "issue"}}, ":exercise:": emojiData{Name: ":bike:", Description: "Bicycle", Unicode: "1F6B2", Alias: []string{"sports", "bicycle", "exercise", "hipster"}}, ":exit:": emojiData{Name: ":door:", Description: "Door", Unicode: "1F6AA", Alias: []string{"house", "entry", "exit"}}, ":experiment:": emojiData{Name: ":alembic:", Description: "Alembic", Unicode: "2697-FE0F", Alias: []string{"distilling", "science", "experiment", "chemistry"}}, ":explode:": emojiData{Name: ":bomb:", Description: "Bomb", Unicode: "1F4A3", Alias: []string{"boom", "explode", "explosion", "terrorism"}}, ":exploding_head:": emojiData{Name: ":exploding_head:", Description: "Shocked Face with Exploding Head", Unicode: "1F92F", Alias: []string(nil)}, ":explosion:": emojiData{Name: ":bomb:", Description: "Bomb", Unicode: "1F4A3", Alias: []string{"boom", "explode", "explosion", "terrorism"}}, ":express:": emojiData{Name: ":articulated_lorry:", Description: "Articulated Lorry", Unicode: "1F69B", Alias: []string{"vehicle", "cars", "transportation", "express"}}, ":expressionless:": emojiData{Name: ":expressionless:", Description: "Expressionless Face", Unicode: "1F611", Alias: []string{"face", "indifferent", "-_-", "meh", "deadpan"}}, ":eye-in-speech-bubble:": emojiData{Name: ":eye-in-speech-bubble:", Description: "Eye in Speech Bubble", Unicode: "1F441-FE0F-200D-1F5E8-FE0F", Alias: []string(nil)}, ":eye:": emojiData{Name: ":wink:", Description: "Winking Face", Unicode: "1F609", Alias: []string{"face", "happy", "mischievous", "secret", ";)", "smile", "eye"}}, ":eyeglasses:": emojiData{Name: ":eyeglasses:", Description: "Eyeglasses", Unicode: "1F453", Alias: []string{"fashion", "accessories", "eyesight", "nerdy", "dork", "geek"}}, ":eyes:": emojiData{Name: ":eyes:", Description: "Eyes", Unicode: "1F440", Alias: []string{"look", "watch", "stalk", "peek", "see"}}, ":eyesight:": emojiData{Name: ":eyeglasses:", Description: "Eyeglasses", Unicode: "1F453", Alias: []string{"fashion", "accessories", "eyesight", "nerdy", "dork", "geek"}}, ":f1:": emojiData{Name: ":racing_car:", Description: "Racing Car", Unicode: "1F3CE-FE0F", Alias: []string{"sports", "race", "fast", "formula", "f1"}}, ":face:": emojiData{Name: ":scream:", Description: "Face Screaming in Fear", Unicode: "1F631", Alias: []string{"face", "munch", "scared", "omg"}}, ":face_palm:": emojiData{Name: ":face_palm:", Description: "Face Palm", Unicode: "1F926", Alias: []string(nil)}, ":face_vomiting:": emojiData{Name: ":face_vomiting:", Description: "Face with Open Mouth Vomiting", Unicode: "1F92E", Alias: []string(nil)}, ":face_with_cowboy_hat:": emojiData{Name: ":face_with_cowboy_hat:", Description: "Face with Cowboy Hat", Unicode: "1F920", Alias: []string(nil)}, ":face_with_hand_over_mouth:": emojiData{Name: ":face_with_hand_over_mouth:", Description: "Smiling Face with Smiling Eyes and Hand Covering Mouth", Unicode: "1F92D", Alias: []string(nil)}, ":face_with_head_bandage:": emojiData{Name: ":face_with_head_bandage:", Description: "Face with Head-Bandage", Unicode: "1F915", Alias: []string{"injured", "clumsy", "bandage", "hurt"}}, ":face_with_monocle:": emojiData{Name: ":face_with_monocle:", Description: "Face with Monocle", Unicode: "1F9D0", Alias: []string(nil)}, ":face_with_raised_eyebrow:": emojiData{Name: ":face_with_raised_eyebrow:", Description: "Face with One Eyebrow Raised", Unicode: "1F928", Alias: []string(nil)}, ":face_with_rolling_eyes:": emojiData{Name: ":face_with_rolling_eyes:", Description: "Face with Rolling Eyes", Unicode: "1F644", Alias: []string(nil)}, ":face_with_symbols_on_mouth:": emojiData{Name: ":face_with_symbols_on_mouth:", Description: "Serious Face with Symbols Covering Mouth", Unicode: "1F92C", Alias: []string(nil)}, ":face_with_thermometer:": emojiData{Name: ":face_with_thermometer:", Description: "Face with Thermometer", Unicode: "1F912", Alias: []string{"sick", "temperature", "thermometer", "cold", "fever"}}, ":facepunch:": emojiData{Name: ":facepunch:", Description: "Fisted Hand Sign", Unicode: "1F44A", Alias: []string{"angry", "violence", "fist", "hit", "attack", "hand"}}, ":factory:": emojiData{Name: ":factory:", Description: "Factory", Unicode: "1F3ED", Alias: []string{"building", "industry", "pollution", "smoke"}}, ":failure:": emojiData{Name: ":chart_with_downwards_trend:", Description: "Chart with Downwards Trend", Unicode: "1F4C9", Alias: []string{"graph", "presentation", "stats", "recession", "business", "economics", "money", "sales", "bad", "failure"}}, ":fairy:": emojiData{Name: ":fairy:", Description: "Fairy", Unicode: "1F9DA", Alias: []string(nil)}, ":faithful:": emojiData{Name: ":dog:", Description: "Dog Face", Unicode: "1F436", Alias: []string{"animal", "friend", "nature", "woof", "puppy", "pet", "faithful"}}, ":fall:": emojiData{Name: ":sunflower:", Description: "Sunflower", Unicode: "1F33B", Alias: []string{"nature", "plant", "fall"}}, ":fallen_leaf:": emojiData{Name: ":fallen_leaf:", Description: "Fallen Leaf", Unicode: "1F342", Alias: []string{"nature", "plant", "vegetable", "leaves"}}, ":family:": emojiData{Name: ":family:", Description: "Family", Unicode: "1F46A", Alias: []string(nil)}, ":fancy:": emojiData{Name: ":diamond_shape_with_a_dot_inside:", Description: "Diamond Shape with a Dot Inside", Unicode: "1F4A0", Alias: []string{"jewel", "blue", "gem", "crystal", "fancy"}}, ":farewell:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":farming:": emojiData{Name: ":tractor:", Description: "Tractor", Unicode: "1F69C", Alias: []string{"vehicle", "car", "farming", "agriculture"}}, ":fart:": emojiData{Name: ":dash:", Description: "Dash Symbol", Unicode: "1F4A8", Alias: []string{"wind", "air", "fast", "shoo", "fart", "smoke", "puff"}}, ":fashion:": emojiData{Name: ":necktie:", Description: "Necktie", Unicode: "1F454", Alias: []string{"shirt", "suitup", "formal", "fashion", "cloth", "business"}}, ":fast food:": emojiData{Name: ":hamburger:", Description: "Hamburger", Unicode: "1F354", Alias: []string{"meat", "fast food", "beef", "cheeseburger", "mcdonalds", "burger king"}}, ":fast:": emojiData{Name: ":racing_car:", Description: "Racing Car", Unicode: "1F3CE-FE0F", Alias: []string{"sports", "race", "fast", "formula", "f1"}}, ":fast_forward:": emojiData{Name: ":fast_forward:", Description: "Black Right-Pointing Double Triangle", Unicode: "23E9", Alias: []string{"blue-square", "play", "speed", "continue"}}, ":father christmas:": emojiData{Name: ":santa:", Description: "Father Christmas", Unicode: "1F385", Alias: []string{"festival", "man", "male", "xmas", "father christmas"}}, ":father:": emojiData{Name: ":man:", Description: "Man", Unicode: "1F468", Alias: []string{"mustache", "father", "dad", "guy", "classy", "sir", "moustache"}}, ":faucet:": emojiData{Name: ":potable_water:", Description: "Potable Water Symbol", Unicode: "1F6B0", Alias: []string{"blue-square", "liquid", "restroom", "cleaning", "faucet"}}, ":favorite:": emojiData{Name: ":bookmark:", Description: "Bookmark", Unicode: "1F516", Alias: []string{"favorite", "label", "save"}}, ":fax:": emojiData{Name: ":fax:", Description: "Fax Machine", Unicode: "1F4E0", Alias: []string{"communication", "technology"}}, ":fearful:": emojiData{Name: ":fearful:", Description: "Fearful Face", Unicode: "1F628", Alias: []string{"face", "scared", "terrified", "nervous", "oops", "huh"}}, ":federation:": emojiData{Name: ":ru:", Description: "Russia Flag", Unicode: "1F1F7-1F1FA", Alias: []string{"russian", "federation", "flag", "nation", "country", "banner"}}, ":feet:": emojiData{Name: ":footprints:", Description: "Footprints", Unicode: "1F463", Alias: []string{"feet", "tracking", "walking", "beach"}}, ":female-artist:": emojiData{Name: ":female-artist:", Description: "Female Artist", Unicode: "1F469-200D-1F3A8", Alias: []string(nil)}, ":female-astronaut:": emojiData{Name: ":female-astronaut:", Description: "Female Astronaut", Unicode: "1F469-200D-1F680", Alias: []string(nil)}, ":female-construction-worker:": emojiData{Name: ":female-construction-worker:", Description: "Female Construction Worker", Unicode: "1F477-200D-2640-FE0F", Alias: []string(nil)}, ":female-cook:": emojiData{Name: ":female-cook:", Description: "Female Cook", Unicode: "1F469-200D-1F373", Alias: []string(nil)}, ":female-detective:": emojiData{Name: ":female-detective:", Description: "Female Detective", Unicode: "1F575-FE0F-200D-2640-FE0F", Alias: []string(nil)}, ":female-doctor:": emojiData{Name: ":female-doctor:", Description: "Female Doctor", Unicode: "1F469-200D-2695-FE0F", Alias: []string(nil)}, ":female-factory-worker:": emojiData{Name: ":female-factory-worker:", Description: "Female Factory Worker", Unicode: "1F469-200D-1F3ED", Alias: []string(nil)}, ":female-farmer:": emojiData{Name: ":female-farmer:", Description: "Female Farmer", Unicode: "1F469-200D-1F33E", Alias: []string(nil)}, ":female-firefighter:": emojiData{Name: ":female-firefighter:", Description: "Female Firefighter", Unicode: "1F469-200D-1F692", Alias: []string(nil)}, ":female-guard:": emojiData{Name: ":female-guard:", Description: "Female Guard", Unicode: "1F482-200D-2640-FE0F", Alias: []string(nil)}, ":female-judge:": emojiData{Name: ":female-judge:", Description: "Female Judge", Unicode: "1F469-200D-2696-FE0F", Alias: []string(nil)}, ":female-mechanic:": emojiData{Name: ":female-mechanic:", Description: "Female Mechanic", Unicode: "1F469-200D-1F527", Alias: []string(nil)}, ":female-office-worker:": emojiData{Name: ":female-office-worker:", Description: "Female Office Worker", Unicode: "1F469-200D-1F4BC", Alias: []string(nil)}, ":female-pilot:": emojiData{Name: ":female-pilot:", Description: "Female Pilot", Unicode: "1F469-200D-2708-FE0F", Alias: []string(nil)}, ":female-police-officer:": emojiData{Name: ":female-police-officer:", Description: "Female Police Officer", Unicode: "1F46E-200D-2640-FE0F", Alias: []string(nil)}, ":female-scientist:": emojiData{Name: ":female-scientist:", Description: "Female Scientist", Unicode: "1F469-200D-1F52C", Alias: []string(nil)}, ":female-singer:": emojiData{Name: ":female-singer:", Description: "Female Singer", Unicode: "1F469-200D-1F3A4", Alias: []string(nil)}, ":female-student:": emojiData{Name: ":female-student:", Description: "Female Student", Unicode: "1F469-200D-1F393", Alias: []string(nil)}, ":female-teacher:": emojiData{Name: ":female-teacher:", Description: "Female Teacher", Unicode: "1F469-200D-1F3EB", Alias: []string(nil)}, ":female-technologist:": emojiData{Name: ":female-technologist:", Description: "Female Technologist", Unicode: "1F469-200D-1F4BB", Alias: []string(nil)}, ":female:": emojiData{Name: ":girl:", Description: "Girl", Unicode: "1F467", Alias: []string{"female", "woman", "teenager"}}, ":female_elf:": emojiData{Name: ":female_elf:", Description: "Female Elf", Unicode: "1F9DD-200D-2640-FE0F", Alias: []string(nil)}, ":female_fairy:": emojiData{Name: ":female_fairy:", Description: "Female Fairy", Unicode: "1F9DA-200D-2640-FE0F", Alias: []string(nil)}, ":female_genie:": emojiData{Name: ":female_genie:", Description: "Female Genie", Unicode: "1F9DE-200D-2640-FE0F", Alias: []string(nil)}, ":female_mage:": emojiData{Name: ":female_mage:", Description: "Female Mage", Unicode: "1F9D9-200D-2640-FE0F", Alias: []string(nil)}, ":female_sign:": emojiData{Name: ":female_sign:", Description: "Female Sign", Unicode: "2640-FE0F", Alias: []string(nil)}, ":female_vampire:": emojiData{Name: ":female_vampire:", Description: "Female Vampire", Unicode: "1F9DB-200D-2640-FE0F", Alias: []string(nil)}, ":female_zombie:": emojiData{Name: ":female_zombie:", Description: "Female Zombie", Unicode: "1F9DF-200D-2640-FE0F", Alias: []string(nil)}, ":fencer:": emojiData{Name: ":fencer:", Description: "Fencer", Unicode: "1F93A", Alias: []string(nil)}, ":ferris_wheel:": emojiData{Name: ":ferris_wheel:", Description: "Ferris Wheel", Unicode: "1F3A1", Alias: []string{"photo", "carnival", "londoneye"}}, ":ferry:": emojiData{Name: ":passenger_ship:", Description: "Passenger Ship", Unicode: "1F6F3-FE0F", Alias: []string{"yacht", "cruise", "ferry"}}, ":festival:": emojiData{Name: ":fireworks:", Description: "Fireworks", Unicode: "1F386", Alias: []string{"photo", "festival", "carnival", "congratulations"}}, ":fever:": emojiData{Name: ":face_with_thermometer:", Description: "Face with Thermometer", Unicode: "1F912", Alias: []string{"sick", "temperature", "thermometer", "cold", "fever"}}, ":field_hockey_stick_and_ball:": emojiData{Name: ":field_hockey_stick_and_ball:", Description: "Field Hockey Stick and Ball", Unicode: "1F3D1", Alias: []string(nil)}, ":fighting:": emojiData{Name: ":boxing_glove:", Description: "Boxing Glove", Unicode: "1F94A", Alias: []string{"sports", "fighting"}}, ":file_cabinet:": emojiData{Name: ":file_cabinet:", Description: "File Cabinet", Unicode: "1F5C4-FE0F", Alias: []string{"filing", "organizing"}}, ":file_folder:": emojiData{Name: ":file_folder:", Description: "File Folder", Unicode: "1F4C1", Alias: []string{"documents", "business", "office"}}, ":filing:": emojiData{Name: ":file_cabinet:", Description: "File Cabinet", Unicode: "1F5C4-FE0F", Alias: []string{"filing", "organizing"}}, ":film:": emojiData{Name: ":clapper:", Description: "Clapper Board", Unicode: "1F3AC", Alias: []string{"movie", "film", "record"}}, ":film_frames:": emojiData{Name: ":film_frames:", Description: "Film Frames", Unicode: "1F39E-FE0F", Alias: []string(nil)}, ":film_projector:": emojiData{Name: ":film_projector:", Description: "Film Projector", Unicode: "1F4FD-FE0F", Alias: []string{"video", "tape", "record", "movie"}}, ":films:": emojiData{Name: ":popcorn:", Description: "Popcorn", Unicode: "1F37F", Alias: []string{"food", "movie theater", "films", "snack"}}, ":find:": emojiData{Name: ":mag:", Description: "Left-Pointing Magnifying Glass", Unicode: "1F50D", Alias: []string{"search", "zoom", "find", "detective"}}, ":finger:": emojiData{Name: ":nail_care:", Description: "Nail Polish", Unicode: "1F485", Alias: []string{"beauty", "manicure", "finger", "fashion", "nail"}}, ":fingers:": emojiData{Name: ":point_up_2:", Description: "White Up Pointing Backhand Index", Unicode: "1F446", Alias: []string{"fingers", "hand", "direction", "up"}}, ":finishline:": emojiData{Name: ":checkered_flag:", Description: "Chequered Flag", Unicode: "1F3C1", Alias: []string{"contest", "finishline", "race", "gokart"}}, ":fins:": emojiData{Name: ":dolphin:", Description: "Dolphin", Unicode: "1F42C", Alias: []string{"animal", "nature", "fish", "sea", "ocean", "flipper", "fins", "beach"}}, ":fire:": emojiData{Name: ":name_badge:", Description: "Name Badge", Unicode: "1F4DB", Alias: []string{"fire", "forbid"}}, ":fire_engine:": emojiData{Name: ":fire_engine:", Description: "Fire Engine", Unicode: "1F692", Alias: []string{"transportation", "cars", "vehicle"}}, ":fireworks:": emojiData{Name: ":fireworks:", Description: "Fireworks", Unicode: "1F386", Alias: []string{"photo", "festival", "carnival", "congratulations"}}, ":first_place_medal:": emojiData{Name: ":first_place_medal:", Description: "First Place Medal", Unicode: "1F947", Alias: []string(nil)}, ":first_quarter_moon:": emojiData{Name: ":first_quarter_moon:", Description: "First Quarter Moon Symbol", Unicode: "1F313", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":first_quarter_moon_with_face:": emojiData{Name: ":first_quarter_moon_with_face:", Description: "First Quarter Moon with Face", Unicode: "1F31B", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":fish:": emojiData{Name: ":fish:", Description: "Fish", Unicode: "1F41F", Alias: []string{"animal", "food", "nature"}}, ":fish_cake:": emojiData{Name: ":fish_cake:", Description: "Fish Cake with Swirl Design", Unicode: "1F365", Alias: []string{"food", "japan", "sea", "beach", "narutomaki", "pink", "swirl", "kamaboko", "surimi", "ramen"}}, ":fishing_pole_and_fish:": emojiData{Name: ":fishing_pole_and_fish:", Description: "Fishing Pole and Fish", Unicode: "1F3A3", Alias: []string{"food", "hobby", "summer"}}, ":fist:": emojiData{Name: ":fist:", Description: "Raised Fist", Unicode: "270A", Alias: []string{"fingers", "hand", "grasp"}}, ":five:": emojiData{Name: ":five:", Description: "Keycap 5", Unicode: "0035-FE0F-20E3", Alias: []string{"5", "numbers", "blue-square", "prime"}}, ":fix:": emojiData{Name: ":nut_and_bolt:", Description: "Nut and Bolt", Unicode: "1F529", Alias: []string{"handy", "tools", "fix"}}, ":flag-ac:": emojiData{Name: ":flag-ac:", Description: "Ascension Island Flag", Unicode: "1F1E6-1F1E8", Alias: []string(nil)}, ":flag-ad:": emojiData{Name: ":flag-ad:", Description: "Andorra Flag", Unicode: "1F1E6-1F1E9", Alias: []string(nil)}, ":flag-ae:": emojiData{Name: ":flag-ae:", Description: "United Arab Emirates Flag", Unicode: "1F1E6-1F1EA", Alias: []string(nil)}, ":flag-af:": emojiData{Name: ":flag-af:", Description: "Afghanistan Flag", Unicode: "1F1E6-1F1EB", Alias: []string(nil)}, ":flag-ag:": emojiData{Name: ":flag-ag:", Description: "Antigua & Barbuda Flag", Unicode: "1F1E6-1F1EC", Alias: []string(nil)}, ":flag-ai:": emojiData{Name: ":flag-ai:", Description: "Anguilla Flag", Unicode: "1F1E6-1F1EE", Alias: []string(nil)}, ":flag-al:": emojiData{Name: ":flag-al:", Description: "Albania Flag", Unicode: "1F1E6-1F1F1", Alias: []string(nil)}, ":flag-am:": emojiData{Name: ":flag-am:", Description: "Armenia Flag", Unicode: "1F1E6-1F1F2", Alias: []string(nil)}, ":flag-ao:": emojiData{Name: ":flag-ao:", Description: "Angola Flag", Unicode: "1F1E6-1F1F4", Alias: []string(nil)}, ":flag-aq:": emojiData{Name: ":flag-aq:", Description: "Antarctica Flag", Unicode: "1F1E6-1F1F6", Alias: []string(nil)}, ":flag-ar:": emojiData{Name: ":flag-ar:", Description: "Argentina Flag", Unicode: "1F1E6-1F1F7", Alias: []string(nil)}, ":flag-as:": emojiData{Name: ":flag-as:", Description: "American Samoa Flag", Unicode: "1F1E6-1F1F8", Alias: []string(nil)}, ":flag-at:": emojiData{Name: ":flag-at:", Description: "Austria Flag", Unicode: "1F1E6-1F1F9", Alias: []string(nil)}, ":flag-au:": emojiData{Name: ":flag-au:", Description: "Australia Flag", Unicode: "1F1E6-1F1FA", Alias: []string(nil)}, ":flag-aw:": emojiData{Name: ":flag-aw:", Description: "Aruba Flag", Unicode: "1F1E6-1F1FC", Alias: []string(nil)}, ":flag-ax:": emojiData{Name: ":flag-ax:", Description: "Åland Islands Flag", Unicode: "1F1E6-1F1FD", Alias: []string(nil)}, ":flag-az:": emojiData{Name: ":flag-az:", Description: "Azerbaijan Flag", Unicode: "1F1E6-1F1FF", Alias: []string(nil)}, ":flag-ba:": emojiData{Name: ":flag-ba:", Description: "Bosnia & Herzegovina Flag", Unicode: "1F1E7-1F1E6", Alias: []string(nil)}, ":flag-bb:": emojiData{Name: ":flag-bb:", Description: "Barbados Flag", Unicode: "1F1E7-1F1E7", Alias: []string(nil)}, ":flag-bd:": emojiData{Name: ":flag-bd:", Description: "Bangladesh Flag", Unicode: "1F1E7-1F1E9", Alias: []string(nil)}, ":flag-be:": emojiData{Name: ":flag-be:", Description: "Belgium Flag", Unicode: "1F1E7-1F1EA", Alias: []string(nil)}, ":flag-bf:": emojiData{Name: ":flag-bf:", Description: "Burkina Faso Flag", Unicode: "1F1E7-1F1EB", Alias: []string(nil)}, ":flag-bg:": emojiData{Name: ":flag-bg:", Description: "Bulgaria Flag", Unicode: "1F1E7-1F1EC", Alias: []string(nil)}, ":flag-bh:": emojiData{Name: ":flag-bh:", Description: "Bahrain Flag", Unicode: "1F1E7-1F1ED", Alias: []string(nil)}, ":flag-bi:": emojiData{Name: ":flag-bi:", Description: "Burundi Flag", Unicode: "1F1E7-1F1EE", Alias: []string(nil)}, ":flag-bj:": emojiData{Name: ":flag-bj:", Description: "Benin Flag", Unicode: "1F1E7-1F1EF", Alias: []string(nil)}, ":flag-bl:": emojiData{Name: ":flag-bl:", Description: "St. Barthélemy Flag", Unicode: "1F1E7-1F1F1", Alias: []string(nil)}, ":flag-bm:": emojiData{Name: ":flag-bm:", Description: "Bermuda Flag", Unicode: "1F1E7-1F1F2", Alias: []string(nil)}, ":flag-bn:": emojiData{Name: ":flag-bn:", Description: "Brunei Flag", Unicode: "1F1E7-1F1F3", Alias: []string(nil)}, ":flag-bo:": emojiData{Name: ":flag-bo:", Description: "Bolivia Flag", Unicode: "1F1E7-1F1F4", Alias: []string(nil)}, ":flag-bq:": emojiData{Name: ":flag-bq:", Description: "Caribbean Netherlands Flag", Unicode: "1F1E7-1F1F6", Alias: []string(nil)}, ":flag-br:": emojiData{Name: ":flag-br:", Description: "Brazil Flag", Unicode: "1F1E7-1F1F7", Alias: []string(nil)}, ":flag-bs:": emojiData{Name: ":flag-bs:", Description: "Bahamas Flag", Unicode: "1F1E7-1F1F8", Alias: []string(nil)}, ":flag-bt:": emojiData{Name: ":flag-bt:", Description: "Bhutan Flag", Unicode: "1F1E7-1F1F9", Alias: []string(nil)}, ":flag-bv:": emojiData{Name: ":flag-bv:", Description: "Bouvet Island Flag", Unicode: "1F1E7-1F1FB", Alias: []string(nil)}, ":flag-bw:": emojiData{Name: ":flag-bw:", Description: "Botswana Flag", Unicode: "1F1E7-1F1FC", Alias: []string(nil)}, ":flag-by:": emojiData{Name: ":flag-by:", Description: "Belarus Flag", Unicode: "1F1E7-1F1FE", Alias: []string(nil)}, ":flag-bz:": emojiData{Name: ":flag-bz:", Description: "Belize Flag", Unicode: "1F1E7-1F1FF", Alias: []string(nil)}, ":flag-ca:": emojiData{Name: ":flag-ca:", Description: "Canada Flag", Unicode: "1F1E8-1F1E6", Alias: []string(nil)}, ":flag-cc:": emojiData{Name: ":flag-cc:", Description: "Cocos (keeling) Islands Flag", Unicode: "1F1E8-1F1E8", Alias: []string(nil)}, ":flag-cd:": emojiData{Name: ":flag-cd:", Description: "Congo - Kinshasa Flag", Unicode: "1F1E8-1F1E9", Alias: []string(nil)}, ":flag-cf:": emojiData{Name: ":flag-cf:", Description: "Central African Republic Flag", Unicode: "1F1E8-1F1EB", Alias: []string(nil)}, ":flag-cg:": emojiData{Name: ":flag-cg:", Description: "Congo - Brazzaville Flag", Unicode: "1F1E8-1F1EC", Alias: []string(nil)}, ":flag-ch:": emojiData{Name: ":flag-ch:", Description: "Switzerland Flag", Unicode: "1F1E8-1F1ED", Alias: []string(nil)}, ":flag-ci:": emojiData{Name: ":flag-ci:", Description: "Côte D’ivoire Flag", Unicode: "1F1E8-1F1EE", Alias: []string(nil)}, ":flag-ck:": emojiData{Name: ":flag-ck:", Description: "Cook Islands Flag", Unicode: "1F1E8-1F1F0", Alias: []string(nil)}, ":flag-cl:": emojiData{Name: ":flag-cl:", Description: "Chile Flag", Unicode: "1F1E8-1F1F1", Alias: []string(nil)}, ":flag-cm:": emojiData{Name: ":flag-cm:", Description: "Cameroon Flag", Unicode: "1F1E8-1F1F2", Alias: []string(nil)}, ":flag-co:": emojiData{Name: ":flag-co:", Description: "Colombia Flag", Unicode: "1F1E8-1F1F4", Alias: []string(nil)}, ":flag-cp:": emojiData{Name: ":flag-cp:", Description: "Clipperton Island Flag", Unicode: "1F1E8-1F1F5", Alias: []string(nil)}, ":flag-cr:": emojiData{Name: ":flag-cr:", Description: "Costa Rica Flag", Unicode: "1F1E8-1F1F7", Alias: []string(nil)}, ":flag-cu:": emojiData{Name: ":flag-cu:", Description: "Cuba Flag", Unicode: "1F1E8-1F1FA", Alias: []string(nil)}, ":flag-cv:": emojiData{Name: ":flag-cv:", Description: "Cape Verde Flag", Unicode: "1F1E8-1F1FB", Alias: []string(nil)}, ":flag-cw:": emojiData{Name: ":flag-cw:", Description: "Curaçao Flag", Unicode: "1F1E8-1F1FC", Alias: []string(nil)}, ":flag-cx:": emojiData{Name: ":flag-cx:", Description: "Christmas Island Flag", Unicode: "1F1E8-1F1FD", Alias: []string(nil)}, ":flag-cy:": emojiData{Name: ":flag-cy:", Description: "Cyprus Flag", Unicode: "1F1E8-1F1FE", Alias: []string(nil)}, ":flag-cz:": emojiData{Name: ":flag-cz:", Description: "Czechia Flag", Unicode: "1F1E8-1F1FF", Alias: []string(nil)}, ":flag-dg:": emojiData{Name: ":flag-dg:", Description: "Diego Garcia Flag", Unicode: "1F1E9-1F1EC", Alias: []string(nil)}, ":flag-dj:": emojiData{Name: ":flag-dj:", Description: "Djibouti Flag", Unicode: "1F1E9-1F1EF", Alias: []string(nil)}, ":flag-dk:": emojiData{Name: ":flag-dk:", Description: "Denmark Flag", Unicode: "1F1E9-1F1F0", Alias: []string(nil)}, ":flag-dm:": emojiData{Name: ":flag-dm:", Description: "Dominica Flag", Unicode: "1F1E9-1F1F2", Alias: []string(nil)}, ":flag-do:": emojiData{Name: ":flag-do:", Description: "Dominican Republic Flag", Unicode: "1F1E9-1F1F4", Alias: []string(nil)}, ":flag-dz:": emojiData{Name: ":flag-dz:", Description: "Algeria Flag", Unicode: "1F1E9-1F1FF", Alias: []string(nil)}, ":flag-ea:": emojiData{Name: ":flag-ea:", Description: "Ceuta & Melilla Flag", Unicode: "1F1EA-1F1E6", Alias: []string(nil)}, ":flag-ec:": emojiData{Name: ":flag-ec:", Description: "Ecuador Flag", Unicode: "1F1EA-1F1E8", Alias: []string(nil)}, ":flag-ee:": emojiData{Name: ":flag-ee:", Description: "Estonia Flag", Unicode: "1F1EA-1F1EA", Alias: []string(nil)}, ":flag-eg:": emojiData{Name: ":flag-eg:", Description: "Egypt Flag", Unicode: "1F1EA-1F1EC", Alias: []string(nil)}, ":flag-eh:": emojiData{Name: ":flag-eh:", Description: "Western Sahara Flag", Unicode: "1F1EA-1F1ED", Alias: []string(nil)}, ":flag-england:": emojiData{Name: ":flag-england:", Description: "England Flag", Unicode: "1F3F4-E0067-E0062-E0065-E006E-E0067-E007F", Alias: []string(nil)}, ":flag-er:": emojiData{Name: ":flag-er:", Description: "Eritrea Flag", Unicode: "1F1EA-1F1F7", Alias: []string(nil)}, ":flag-et:": emojiData{Name: ":flag-et:", Description: "Ethiopia Flag", Unicode: "1F1EA-1F1F9", Alias: []string(nil)}, ":flag-eu:": emojiData{Name: ":flag-eu:", Description: "European Union Flag", Unicode: "1F1EA-1F1FA", Alias: []string(nil)}, ":flag-fi:": emojiData{Name: ":flag-fi:", Description: "Finland Flag", Unicode: "1F1EB-1F1EE", Alias: []string(nil)}, ":flag-fj:": emojiData{Name: ":flag-fj:", Description: "Fiji Flag", Unicode: "1F1EB-1F1EF", Alias: []string(nil)}, ":flag-fk:": emojiData{Name: ":flag-fk:", Description: "Falkland Islands Flag", Unicode: "1F1EB-1F1F0", Alias: []string(nil)}, ":flag-fm:": emojiData{Name: ":flag-fm:", Description: "Micronesia Flag", Unicode: "1F1EB-1F1F2", Alias: []string(nil)}, ":flag-fo:": emojiData{Name: ":flag-fo:", Description: "Faroe Islands Flag", Unicode: "1F1EB-1F1F4", Alias: []string(nil)}, ":flag-ga:": emojiData{Name: ":flag-ga:", Description: "Gabon Flag", Unicode: "1F1EC-1F1E6", Alias: []string(nil)}, ":flag-gd:": emojiData{Name: ":flag-gd:", Description: "Grenada Flag", Unicode: "1F1EC-1F1E9", Alias: []string(nil)}, ":flag-ge:": emojiData{Name: ":flag-ge:", Description: "Georgia Flag", Unicode: "1F1EC-1F1EA", Alias: []string(nil)}, ":flag-gf:": emojiData{Name: ":flag-gf:", Description: "French Guiana Flag", Unicode: "1F1EC-1F1EB", Alias: []string(nil)}, ":flag-gg:": emojiData{Name: ":flag-gg:", Description: "Guernsey Flag", Unicode: "1F1EC-1F1EC", Alias: []string(nil)}, ":flag-gh:": emojiData{Name: ":flag-gh:", Description: "Ghana Flag", Unicode: "1F1EC-1F1ED", Alias: []string(nil)}, ":flag-gi:": emojiData{Name: ":flag-gi:", Description: "Gibraltar Flag", Unicode: "1F1EC-1F1EE", Alias: []string(nil)}, ":flag-gl:": emojiData{Name: ":flag-gl:", Description: "Greenland Flag", Unicode: "1F1EC-1F1F1", Alias: []string(nil)}, ":flag-gm:": emojiData{Name: ":flag-gm:", Description: "Gambia Flag", Unicode: "1F1EC-1F1F2", Alias: []string(nil)}, ":flag-gn:": emojiData{Name: ":flag-gn:", Description: "Guinea Flag", Unicode: "1F1EC-1F1F3", Alias: []string(nil)}, ":flag-gp:": emojiData{Name: ":flag-gp:", Description: "Guadeloupe Flag", Unicode: "1F1EC-1F1F5", Alias: []string(nil)}, ":flag-gq:": emojiData{Name: ":flag-gq:", Description: "Equatorial Guinea Flag", Unicode: "1F1EC-1F1F6", Alias: []string(nil)}, ":flag-gr:": emojiData{Name: ":flag-gr:", Description: "Greece Flag", Unicode: "1F1EC-1F1F7", Alias: []string(nil)}, ":flag-gs:": emojiData{Name: ":flag-gs:", Description: "South Georgia & South Sandwich Islands Flag", Unicode: "1F1EC-1F1F8", Alias: []string(nil)}, ":flag-gt:": emojiData{Name: ":flag-gt:", Description: "Guatemala Flag", Unicode: "1F1EC-1F1F9", Alias: []string(nil)}, ":flag-gu:": emojiData{Name: ":flag-gu:", Description: "Guam Flag", Unicode: "1F1EC-1F1FA", Alias: []string(nil)}, ":flag-gw:": emojiData{Name: ":flag-gw:", Description: "Guinea-Bissau Flag", Unicode: "1F1EC-1F1FC", Alias: []string(nil)}, ":flag-gy:": emojiData{Name: ":flag-gy:", Description: "Guyana Flag", Unicode: "1F1EC-1F1FE", Alias: []string(nil)}, ":flag-hk:": emojiData{Name: ":flag-hk:", Description: "Hong Kong Sar China Flag", Unicode: "1F1ED-1F1F0", Alias: []string(nil)}, ":flag-hm:": emojiData{Name: ":flag-hm:", Description: "Heard & Mcdonald Islands Flag", Unicode: "1F1ED-1F1F2", Alias: []string(nil)}, ":flag-hn:": emojiData{Name: ":flag-hn:", Description: "Honduras Flag", Unicode: "1F1ED-1F1F3", Alias: []string(nil)}, ":flag-hr:": emojiData{Name: ":flag-hr:", Description: "Croatia Flag", Unicode: "1F1ED-1F1F7", Alias: []string(nil)}, ":flag-ht:": emojiData{Name: ":flag-ht:", Description: "Haiti Flag", Unicode: "1F1ED-1F1F9", Alias: []string(nil)}, ":flag-hu:": emojiData{Name: ":flag-hu:", Description: "Hungary Flag", Unicode: "1F1ED-1F1FA", Alias: []string(nil)}, ":flag-ic:": emojiData{Name: ":flag-ic:", Description: "Canary Islands Flag", Unicode: "1F1EE-1F1E8", Alias: []string(nil)}, ":flag-id:": emojiData{Name: ":flag-id:", Description: "Indonesia Flag", Unicode: "1F1EE-1F1E9", Alias: []string(nil)}, ":flag-ie:": emojiData{Name: ":flag-ie:", Description: "Ireland Flag", Unicode: "1F1EE-1F1EA", Alias: []string(nil)}, ":flag-il:": emojiData{Name: ":flag-il:", Description: "Israel Flag", Unicode: "1F1EE-1F1F1", Alias: []string(nil)}, ":flag-im:": emojiData{Name: ":flag-im:", Description: "Isle of Man Flag", Unicode: "1F1EE-1F1F2", Alias: []string(nil)}, ":flag-in:": emojiData{Name: ":flag-in:", Description: "India Flag", Unicode: "1F1EE-1F1F3", Alias: []string(nil)}, ":flag-io:": emojiData{Name: ":flag-io:", Description: "British Indian Ocean Territory Flag", Unicode: "1F1EE-1F1F4", Alias: []string(nil)}, ":flag-iq:": emojiData{Name: ":flag-iq:", Description: "Iraq Flag", Unicode: "1F1EE-1F1F6", Alias: []string(nil)}, ":flag-ir:": emojiData{Name: ":flag-ir:", Description: "Iran Flag", Unicode: "1F1EE-1F1F7", Alias: []string(nil)}, ":flag-is:": emojiData{Name: ":flag-is:", Description: "Iceland Flag", Unicode: "1F1EE-1F1F8", Alias: []string(nil)}, ":flag-je:": emojiData{Name: ":flag-je:", Description: "Jersey Flag", Unicode: "1F1EF-1F1EA", Alias: []string(nil)}, ":flag-jm:": emojiData{Name: ":flag-jm:", Description: "Jamaica Flag", Unicode: "1F1EF-1F1F2", Alias: []string(nil)}, ":flag-jo:": emojiData{Name: ":flag-jo:", Description: "Jordan Flag", Unicode: "1F1EF-1F1F4", Alias: []string(nil)}, ":flag-ke:": emojiData{Name: ":flag-ke:", Description: "Kenya Flag", Unicode: "1F1F0-1F1EA", Alias: []string(nil)}, ":flag-kg:": emojiData{Name: ":flag-kg:", Description: "Kyrgyzstan Flag", Unicode: "1F1F0-1F1EC", Alias: []string(nil)}, ":flag-kh:": emojiData{Name: ":flag-kh:", Description: "Cambodia Flag", Unicode: "1F1F0-1F1ED", Alias: []string(nil)}, ":flag-ki:": emojiData{Name: ":flag-ki:", Description: "Kiribati Flag", Unicode: "1F1F0-1F1EE", Alias: []string(nil)}, ":flag-km:": emojiData{Name: ":flag-km:", Description: "Comoros Flag", Unicode: "1F1F0-1F1F2", Alias: []string(nil)}, ":flag-kn:": emojiData{Name: ":flag-kn:", Description: "St. Kitts & Nevis Flag", Unicode: "1F1F0-1F1F3", Alias: []string(nil)}, ":flag-kp:": emojiData{Name: ":flag-kp:", Description: "North Korea Flag", Unicode: "1F1F0-1F1F5", Alias: []string(nil)}, ":flag-kw:": emojiData{Name: ":flag-kw:", Description: "Kuwait Flag", Unicode: "1F1F0-1F1FC", Alias: []string(nil)}, ":flag-ky:": emojiData{Name: ":flag-ky:", Description: "Cayman Islands Flag", Unicode: "1F1F0-1F1FE", Alias: []string(nil)}, ":flag-kz:": emojiData{Name: ":flag-kz:", Description: "Kazakhstan Flag", Unicode: "1F1F0-1F1FF", Alias: []string(nil)}, ":flag-la:": emojiData{Name: ":flag-la:", Description: "Laos Flag", Unicode: "1F1F1-1F1E6", Alias: []string(nil)}, ":flag-lb:": emojiData{Name: ":flag-lb:", Description: "Lebanon Flag", Unicode: "1F1F1-1F1E7", Alias: []string(nil)}, ":flag-lc:": emojiData{Name: ":flag-lc:", Description: "St. Lucia Flag", Unicode: "1F1F1-1F1E8", Alias: []string(nil)}, ":flag-li:": emojiData{Name: ":flag-li:", Description: "Liechtenstein Flag", Unicode: "1F1F1-1F1EE", Alias: []string(nil)}, ":flag-lk:": emojiData{Name: ":flag-lk:", Description: "Sri Lanka Flag", Unicode: "1F1F1-1F1F0", Alias: []string(nil)}, ":flag-lr:": emojiData{Name: ":flag-lr:", Description: "Liberia Flag", Unicode: "1F1F1-1F1F7", Alias: []string(nil)}, ":flag-ls:": emojiData{Name: ":flag-ls:", Description: "Lesotho Flag", Unicode: "1F1F1-1F1F8", Alias: []string(nil)}, ":flag-lt:": emojiData{Name: ":flag-lt:", Description: "Lithuania Flag", Unicode: "1F1F1-1F1F9", Alias: []string(nil)}, ":flag-lu:": emojiData{Name: ":flag-lu:", Description: "Luxembourg Flag", Unicode: "1F1F1-1F1FA", Alias: []string(nil)}, ":flag-lv:": emojiData{Name: ":flag-lv:", Description: "Latvia Flag", Unicode: "1F1F1-1F1FB", Alias: []string(nil)}, ":flag-ly:": emojiData{Name: ":flag-ly:", Description: "Libya Flag", Unicode: "1F1F1-1F1FE", Alias: []string(nil)}, ":flag-ma:": emojiData{Name: ":flag-ma:", Description: "Morocco Flag", Unicode: "1F1F2-1F1E6", Alias: []string(nil)}, ":flag-mc:": emojiData{Name: ":flag-mc:", Description: "Monaco Flag", Unicode: "1F1F2-1F1E8", Alias: []string(nil)}, ":flag-md:": emojiData{Name: ":flag-md:", Description: "Moldova Flag", Unicode: "1F1F2-1F1E9", Alias: []string(nil)}, ":flag-me:": emojiData{Name: ":flag-me:", Description: "Montenegro Flag", Unicode: "1F1F2-1F1EA", Alias: []string(nil)}, ":flag-mf:": emojiData{Name: ":flag-mf:", Description: "St. Martin Flag", Unicode: "1F1F2-1F1EB", Alias: []string(nil)}, ":flag-mg:": emojiData{Name: ":flag-mg:", Description: "Madagascar Flag", Unicode: "1F1F2-1F1EC", Alias: []string(nil)}, ":flag-mh:": emojiData{Name: ":flag-mh:", Description: "Marshall Islands Flag", Unicode: "1F1F2-1F1ED", Alias: []string(nil)}, ":flag-mk:": emojiData{Name: ":flag-mk:", Description: "Macedonia Flag", Unicode: "1F1F2-1F1F0", Alias: []string(nil)}, ":flag-ml:": emojiData{Name: ":flag-ml:", Description: "Mali Flag", Unicode: "1F1F2-1F1F1", Alias: []string(nil)}, ":flag-mm:": emojiData{Name: ":flag-mm:", Description: "Myanmar (burma) Flag", Unicode: "1F1F2-1F1F2", Alias: []string(nil)}, ":flag-mn:": emojiData{Name: ":flag-mn:", Description: "Mongolia Flag", Unicode: "1F1F2-1F1F3", Alias: []string(nil)}, ":flag-mo:": emojiData{Name: ":flag-mo:", Description: "Macau Sar China Flag", Unicode: "1F1F2-1F1F4", Alias: []string(nil)}, ":flag-mp:": emojiData{Name: ":flag-mp:", Description: "Northern Mariana Islands Flag", Unicode: "1F1F2-1F1F5", Alias: []string(nil)}, ":flag-mq:": emojiData{Name: ":flag-mq:", Description: "Martinique Flag", Unicode: "1F1F2-1F1F6", Alias: []string(nil)}, ":flag-mr:": emojiData{Name: ":flag-mr:", Description: "Mauritania Flag", Unicode: "1F1F2-1F1F7", Alias: []string(nil)}, ":flag-ms:": emojiData{Name: ":flag-ms:", Description: "Montserrat Flag", Unicode: "1F1F2-1F1F8", Alias: []string(nil)}, ":flag-mt:": emojiData{Name: ":flag-mt:", Description: "Malta Flag", Unicode: "1F1F2-1F1F9", Alias: []string(nil)}, ":flag-mu:": emojiData{Name: ":flag-mu:", Description: "Mauritius Flag", Unicode: "1F1F2-1F1FA", Alias: []string(nil)}, ":flag-mv:": emojiData{Name: ":flag-mv:", Description: "Maldives Flag", Unicode: "1F1F2-1F1FB", Alias: []string(nil)}, ":flag-mw:": emojiData{Name: ":flag-mw:", Description: "Malawi Flag", Unicode: "1F1F2-1F1FC", Alias: []string(nil)}, ":flag-mx:": emojiData{Name: ":flag-mx:", Description: "Mexico Flag", Unicode: "1F1F2-1F1FD", Alias: []string(nil)}, ":flag-my:": emojiData{Name: ":flag-my:", Description: "Malaysia Flag", Unicode: "1F1F2-1F1FE", Alias: []string(nil)}, ":flag-mz:": emojiData{Name: ":flag-mz:", Description: "Mozambique Flag", Unicode: "1F1F2-1F1FF", Alias: []string(nil)}, ":flag-na:": emojiData{Name: ":flag-na:", Description: "Namibia Flag", Unicode: "1F1F3-1F1E6", Alias: []string(nil)}, ":flag-nc:": emojiData{Name: ":flag-nc:", Description: "New Caledonia Flag", Unicode: "1F1F3-1F1E8", Alias: []string(nil)}, ":flag-ne:": emojiData{Name: ":flag-ne:", Description: "Niger Flag", Unicode: "1F1F3-1F1EA", Alias: []string(nil)}, ":flag-nf:": emojiData{Name: ":flag-nf:", Description: "Norfolk Island Flag", Unicode: "1F1F3-1F1EB", Alias: []string(nil)}, ":flag-ng:": emojiData{Name: ":flag-ng:", Description: "Nigeria Flag", Unicode: "1F1F3-1F1EC", Alias: []string(nil)}, ":flag-ni:": emojiData{Name: ":flag-ni:", Description: "Nicaragua Flag", Unicode: "1F1F3-1F1EE", Alias: []string(nil)}, ":flag-nl:": emojiData{Name: ":flag-nl:", Description: "Netherlands Flag", Unicode: "1F1F3-1F1F1", Alias: []string(nil)}, ":flag-no:": emojiData{Name: ":flag-no:", Description: "Norway Flag", Unicode: "1F1F3-1F1F4", Alias: []string(nil)}, ":flag-np:": emojiData{Name: ":flag-np:", Description: "Nepal Flag", Unicode: "1F1F3-1F1F5", Alias: []string(nil)}, ":flag-nr:": emojiData{Name: ":flag-nr:", Description: "Nauru Flag", Unicode: "1F1F3-1F1F7", Alias: []string(nil)}, ":flag-nu:": emojiData{Name: ":flag-nu:", Description: "Niue Flag", Unicode: "1F1F3-1F1FA", Alias: []string(nil)}, ":flag-nz:": emojiData{Name: ":flag-nz:", Description: "New Zealand Flag", Unicode: "1F1F3-1F1FF", Alias: []string(nil)}, ":flag-om:": emojiData{Name: ":flag-om:", Description: "Oman Flag", Unicode: "1F1F4-1F1F2", Alias: []string(nil)}, ":flag-pa:": emojiData{Name: ":flag-pa:", Description: "Panama Flag", Unicode: "1F1F5-1F1E6", Alias: []string(nil)}, ":flag-pe:": emojiData{Name: ":flag-pe:", Description: "Peru Flag", Unicode: "1F1F5-1F1EA", Alias: []string(nil)}, ":flag-pf:": emojiData{Name: ":flag-pf:", Description: "French Polynesia Flag", Unicode: "1F1F5-1F1EB", Alias: []string(nil)}, ":flag-pg:": emojiData{Name: ":flag-pg:", Description: "Papua New Guinea Flag", Unicode: "1F1F5-1F1EC", Alias: []string(nil)}, ":flag-ph:": emojiData{Name: ":flag-ph:", Description: "Philippines Flag", Unicode: "1F1F5-1F1ED", Alias: []string(nil)}, ":flag-pk:": emojiData{Name: ":flag-pk:", Description: "Pakistan Flag", Unicode: "1F1F5-1F1F0", Alias: []string(nil)}, ":flag-pl:": emojiData{Name: ":flag-pl:", Description: "Poland Flag", Unicode: "1F1F5-1F1F1", Alias: []string(nil)}, ":flag-pm:": emojiData{Name: ":flag-pm:", Description: "St. Pierre & Miquelon Flag", Unicode: "1F1F5-1F1F2", Alias: []string(nil)}, ":flag-pn:": emojiData{Name: ":flag-pn:", Description: "Pitcairn Islands Flag", Unicode: "1F1F5-1F1F3", Alias: []string(nil)}, ":flag-pr:": emojiData{Name: ":flag-pr:", Description: "Puerto Rico Flag", Unicode: "1F1F5-1F1F7", Alias: []string(nil)}, ":flag-ps:": emojiData{Name: ":flag-ps:", Description: "Palestinian Territories Flag", Unicode: "1F1F5-1F1F8", Alias: []string(nil)}, ":flag-pt:": emojiData{Name: ":flag-pt:", Description: "Portugal Flag", Unicode: "1F1F5-1F1F9", Alias: []string(nil)}, ":flag-pw:": emojiData{Name: ":flag-pw:", Description: "Palau Flag", Unicode: "1F1F5-1F1FC", Alias: []string(nil)}, ":flag-py:": emojiData{Name: ":flag-py:", Description: "Paraguay Flag", Unicode: "1F1F5-1F1FE", Alias: []string(nil)}, ":flag-qa:": emojiData{Name: ":flag-qa:", Description: "Qatar Flag", Unicode: "1F1F6-1F1E6", Alias: []string(nil)}, ":flag-re:": emojiData{Name: ":flag-re:", Description: "Réunion Flag", Unicode: "1F1F7-1F1EA", Alias: []string(nil)}, ":flag-ro:": emojiData{Name: ":flag-ro:", Description: "Romania Flag", Unicode: "1F1F7-1F1F4", Alias: []string(nil)}, ":flag-rs:": emojiData{Name: ":flag-rs:", Description: "Serbia Flag", Unicode: "1F1F7-1F1F8", Alias: []string(nil)}, ":flag-rw:": emojiData{Name: ":flag-rw:", Description: "Rwanda Flag", Unicode: "1F1F7-1F1FC", Alias: []string(nil)}, ":flag-sa:": emojiData{Name: ":flag-sa:", Description: "Saudi Arabia Flag", Unicode: "1F1F8-1F1E6", Alias: []string(nil)}, ":flag-sb:": emojiData{Name: ":flag-sb:", Description: "Solomon Islands Flag", Unicode: "1F1F8-1F1E7", Alias: []string(nil)}, ":flag-sc:": emojiData{Name: ":flag-sc:", Description: "Seychelles Flag", Unicode: "1F1F8-1F1E8", Alias: []string(nil)}, ":flag-scotland:": emojiData{Name: ":flag-scotland:", Description: "Scotland Flag", Unicode: "1F3F4-E0067-E0062-E0073-E0063-E0074-E007F", Alias: []string(nil)}, ":flag-sd:": emojiData{Name: ":flag-sd:", Description: "Sudan Flag", Unicode: "1F1F8-1F1E9", Alias: []string(nil)}, ":flag-se:": emojiData{Name: ":flag-se:", Description: "Sweden Flag", Unicode: "1F1F8-1F1EA", Alias: []string(nil)}, ":flag-sg:": emojiData{Name: ":flag-sg:", Description: "Singapore Flag", Unicode: "1F1F8-1F1EC", Alias: []string(nil)}, ":flag-sh:": emojiData{Name: ":flag-sh:", Description: "St. Helena Flag", Unicode: "1F1F8-1F1ED", Alias: []string(nil)}, ":flag-si:": emojiData{Name: ":flag-si:", Description: "Slovenia Flag", Unicode: "1F1F8-1F1EE", Alias: []string(nil)}, ":flag-sj:": emojiData{Name: ":flag-sj:", Description: "Svalbard & Jan Mayen Flag", Unicode: "1F1F8-1F1EF", Alias: []string(nil)}, ":flag-sk:": emojiData{Name: ":flag-sk:", Description: "Slovakia Flag", Unicode: "1F1F8-1F1F0", Alias: []string(nil)}, ":flag-sl:": emojiData{Name: ":flag-sl:", Description: "Sierra Leone Flag", Unicode: "1F1F8-1F1F1", Alias: []string(nil)}, ":flag-sm:": emojiData{Name: ":flag-sm:", Description: "San Marino Flag", Unicode: "1F1F8-1F1F2", Alias: []string(nil)}, ":flag-sn:": emojiData{Name: ":flag-sn:", Description: "Senegal Flag", Unicode: "1F1F8-1F1F3", Alias: []string(nil)}, ":flag-so:": emojiData{Name: ":flag-so:", Description: "Somalia Flag", Unicode: "1F1F8-1F1F4", Alias: []string(nil)}, ":flag-sr:": emojiData{Name: ":flag-sr:", Description: "Suriname Flag", Unicode: "1F1F8-1F1F7", Alias: []string(nil)}, ":flag-ss:": emojiData{Name: ":flag-ss:", Description: "South Sudan Flag", Unicode: "1F1F8-1F1F8", Alias: []string(nil)}, ":flag-st:": emojiData{Name: ":flag-st:", Description: "São Tomé & Príncipe Flag", Unicode: "1F1F8-1F1F9", Alias: []string(nil)}, ":flag-sv:": emojiData{Name: ":flag-sv:", Description: "El Salvador Flag", Unicode: "1F1F8-1F1FB", Alias: []string(nil)}, ":flag-sx:": emojiData{Name: ":flag-sx:", Description: "Sint Maarten Flag", Unicode: "1F1F8-1F1FD", Alias: []string(nil)}, ":flag-sy:": emojiData{Name: ":flag-sy:", Description: "Syria Flag", Unicode: "1F1F8-1F1FE", Alias: []string(nil)}, ":flag-sz:": emojiData{Name: ":flag-sz:", Description: "Swaziland Flag", Unicode: "1F1F8-1F1FF", Alias: []string(nil)}, ":flag-ta:": emojiData{Name: ":flag-ta:", Description: "Tristan Da Cunha Flag", Unicode: "1F1F9-1F1E6", Alias: []string(nil)}, ":flag-tc:": emojiData{Name: ":flag-tc:", Description: "Turks & Caicos Islands Flag", Unicode: "1F1F9-1F1E8", Alias: []string(nil)}, ":flag-td:": emojiData{Name: ":flag-td:", Description: "Chad Flag", Unicode: "1F1F9-1F1E9", Alias: []string(nil)}, ":flag-tf:": emojiData{Name: ":flag-tf:", Description: "French Southern Territories Flag", Unicode: "1F1F9-1F1EB", Alias: []string(nil)}, ":flag-tg:": emojiData{Name: ":flag-tg:", Description: "Togo Flag", Unicode: "1F1F9-1F1EC", Alias: []string(nil)}, ":flag-th:": emojiData{Name: ":flag-th:", Description: "Thailand Flag", Unicode: "1F1F9-1F1ED", Alias: []string(nil)}, ":flag-tj:": emojiData{Name: ":flag-tj:", Description: "Tajikistan Flag", Unicode: "1F1F9-1F1EF", Alias: []string(nil)}, ":flag-tk:": emojiData{Name: ":flag-tk:", Description: "Tokelau Flag", Unicode: "1F1F9-1F1F0", Alias: []string(nil)}, ":flag-tl:": emojiData{Name: ":flag-tl:", Description: "Timor-Leste Flag", Unicode: "1F1F9-1F1F1", Alias: []string(nil)}, ":flag-tm:": emojiData{Name: ":flag-tm:", Description: "Turkmenistan Flag", Unicode: "1F1F9-1F1F2", Alias: []string(nil)}, ":flag-tn:": emojiData{Name: ":flag-tn:", Description: "Tunisia Flag", Unicode: "1F1F9-1F1F3", Alias: []string(nil)}, ":flag-to:": emojiData{Name: ":flag-to:", Description: "Tonga Flag", Unicode: "1F1F9-1F1F4", Alias: []string(nil)}, ":flag-tr:": emojiData{Name: ":flag-tr:", Description: "Turkey Flag", Unicode: "1F1F9-1F1F7", Alias: []string(nil)}, ":flag-tt:": emojiData{Name: ":flag-tt:", Description: "Trinidad & Tobago Flag", Unicode: "1F1F9-1F1F9", Alias: []string(nil)}, ":flag-tv:": emojiData{Name: ":flag-tv:", Description: "Tuvalu Flag", Unicode: "1F1F9-1F1FB", Alias: []string(nil)}, ":flag-tw:": emojiData{Name: ":flag-tw:", Description: "Taiwan Flag", Unicode: "1F1F9-1F1FC", Alias: []string(nil)}, ":flag-tz:": emojiData{Name: ":flag-tz:", Description: "Tanzania Flag", Unicode: "1F1F9-1F1FF", Alias: []string(nil)}, ":flag-ua:": emojiData{Name: ":flag-ua:", Description: "Ukraine Flag", Unicode: "1F1FA-1F1E6", Alias: []string(nil)}, ":flag-ug:": emojiData{Name: ":flag-ug:", Description: "Uganda Flag", Unicode: "1F1FA-1F1EC", Alias: []string(nil)}, ":flag-um:": emojiData{Name: ":flag-um:", Description: "U.s. Outlying Islands Flag", Unicode: "1F1FA-1F1F2", Alias: []string(nil)}, ":flag-un:": emojiData{Name: ":flag-un:", Description: "United Nations Flag", Unicode: "1F1FA-1F1F3", Alias: []string(nil)}, ":flag-uy:": emojiData{Name: ":flag-uy:", Description: "Uruguay Flag", Unicode: "1F1FA-1F1FE", Alias: []string(nil)}, ":flag-uz:": emojiData{Name: ":flag-uz:", Description: "Uzbekistan Flag", Unicode: "1F1FA-1F1FF", Alias: []string(nil)}, ":flag-va:": emojiData{Name: ":flag-va:", Description: "Vatican City Flag", Unicode: "1F1FB-1F1E6", Alias: []string(nil)}, ":flag-vc:": emojiData{Name: ":flag-vc:", Description: "St. Vincent & Grenadines Flag", Unicode: "1F1FB-1F1E8", Alias: []string(nil)}, ":flag-ve:": emojiData{Name: ":flag-ve:", Description: "Venezuela Flag", Unicode: "1F1FB-1F1EA", Alias: []string(nil)}, ":flag-vg:": emojiData{Name: ":flag-vg:", Description: "British Virgin Islands Flag", Unicode: "1F1FB-1F1EC", Alias: []string(nil)}, ":flag-vi:": emojiData{Name: ":flag-vi:", Description: "U.s. Virgin Islands Flag", Unicode: "1F1FB-1F1EE", Alias: []string(nil)}, ":flag-vn:": emojiData{Name: ":flag-vn:", Description: "Vietnam Flag", Unicode: "1F1FB-1F1F3", Alias: []string(nil)}, ":flag-vu:": emojiData{Name: ":flag-vu:", Description: "Vanuatu Flag", Unicode: "1F1FB-1F1FA", Alias: []string(nil)}, ":flag-wales:": emojiData{Name: ":flag-wales:", Description: "Wales Flag", Unicode: "1F3F4-E0067-E0062-E0077-E006C-E0073-E007F", Alias: []string(nil)}, ":flag-wf:": emojiData{Name: ":flag-wf:", Description: "Wallis & Futuna Flag", Unicode: "1F1FC-1F1EB", Alias: []string(nil)}, ":flag-ws:": emojiData{Name: ":flag-ws:", Description: "Samoa Flag", Unicode: "1F1FC-1F1F8", Alias: []string(nil)}, ":flag-xk:": emojiData{Name: ":flag-xk:", Description: "Kosovo Flag", Unicode: "1F1FD-1F1F0", Alias: []string(nil)}, ":flag-ye:": emojiData{Name: ":flag-ye:", Description: "Yemen Flag", Unicode: "1F1FE-1F1EA", Alias: []string(nil)}, ":flag-yt:": emojiData{Name: ":flag-yt:", Description: "Mayotte Flag", Unicode: "1F1FE-1F1F9", Alias: []string(nil)}, ":flag-za:": emojiData{Name: ":flag-za:", Description: "South Africa Flag", Unicode: "1F1FF-1F1E6", Alias: []string(nil)}, ":flag-zm:": emojiData{Name: ":flag-zm:", Description: "Zambia Flag", Unicode: "1F1FF-1F1F2", Alias: []string(nil)}, ":flag-zw:": emojiData{Name: ":flag-zw:", Description: "Zimbabwe Flag", Unicode: "1F1FF-1F1FC", Alias: []string(nil)}, ":flag:": emojiData{Name: ":golf:", Description: "Flag in Hole", Unicode: "26F3", Alias: []string{"sports", "business", "flag", "hole", "summer"}}, ":flags:": emojiData{Name: ":flags:", Description: "Carp Streamer", Unicode: "1F38F", Alias: []string{"fish", "japanese", "koinobori", "carp", "banner"}}, ":flame:": emojiData{Name: ":fire:", Description: "Fire", Unicode: "1F525", Alias: []string{"hot", "cook", "flame"}}, ":flapjacks:": emojiData{Name: ":pancakes:", Description: "Pancakes", Unicode: "1F95E", Alias: []string{"food", "breakfast", "flapjacks", "hotcakes"}}, ":flashlight:": emojiData{Name: ":flashlight:", Description: "Electric Torch", Unicode: "1F526", Alias: []string{"dark", "camping", "sight", "night"}}, ":flatbread:": emojiData{Name: ":stuffed_flatbread:", Description: "Stuffed Flatbread", Unicode: "1F959", Alias: []string{"food", "flatbread", "stuffed", "gyro"}}, ":flattered:": emojiData{Name: ":flushed:", Description: "Flushed Face", Unicode: "1F633", Alias: []string{"face", "blush", "shy", "flattered"}}, ":fleur_de_lis:": emojiData{Name: ":fleur_de_lis:", Description: "Fleur De Lis", Unicode: "269C-FE0F", Alias: []string{"decorative", "scout"}}, ":flex:": emojiData{Name: ":muscle:", Description: "Flexed Biceps", Unicode: "1F4AA", Alias: []string{"arm", "flex", "hand", "summer", "strong", "biceps"}}, ":flight:": emojiData{Name: ":seat:", Description: "Seat", Unicode: "1F4BA", Alias: []string{"sit", "airplane", "transport", "bus", "flight", "fly"}}, ":flip flops:": emojiData{Name: ":sandal:", Description: "Womans Sandal", Unicode: "1F461", Alias: []string{"shoes", "fashion", "flip flops"}}, ":flipped:": emojiData{Name: ":upside_down_face:", Description: "Upside-Down Face", Unicode: "1F643", Alias: []string{"face", "flipped", "silly", "smile"}}, ":flipper:": emojiData{Name: ":dolphin:", Description: "Dolphin", Unicode: "1F42C", Alias: []string{"animal", "nature", "fish", "sea", "ocean", "flipper", "fins", "beach"}}, ":floppy_disk:": emojiData{Name: ":floppy_disk:", Description: "Floppy Disk", Unicode: "1F4BE", Alias: []string{"oldschool", "technology", "save", "90s", "80s"}}, ":flower:": emojiData{Name: ":rosette:", Description: "Rosette", Unicode: "1F3F5-FE0F", Alias: []string{"flower", "decoration", "military"}}, ":flower_playing_cards:": emojiData{Name: ":flower_playing_cards:", Description: "Flower Playing Cards", Unicode: "1F3B4", Alias: []string{"game", "sunset", "red"}}, ":flowers:": emojiData{Name: ":blossom:", Description: "Blossom", Unicode: "1F33C", Alias: []string{"nature", "flowers", "yellow"}}, ":flushed:": emojiData{Name: ":blush:", Description: "Smiling Face with Smiling Eyes", Unicode: "1F60A", Alias: []string{"face", "smile", "happy", "flushed", "crush", "embarrassed", "shy", "joy"}}, ":fly:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":flying_saucer:": emojiData{Name: ":flying_saucer:", Description: "Flying Saucer", Unicode: "1F6F8", Alias: []string(nil)}, ":fog:": emojiData{Name: ":fog:", Description: "Fog", Unicode: "1F32B-FE0F", Alias: []string{"weather"}}, ":foggy:": emojiData{Name: ":foggy:", Description: "Foggy", Unicode: "1F301", Alias: []string{"photo", "mountain"}}, ":food:": emojiData{Name: ":icecream:", Description: "Soft Ice Cream", Unicode: "1F366", Alias: []string{"food", "hot", "dessert", "summer"}}, ":football:": emojiData{Name: ":soccer:", Description: "Soccer Ball", Unicode: "26BD", Alias: []string{"sports", "football"}}, ":footprints:": emojiData{Name: ":footprints:", Description: "Footprints", Unicode: "1F463", Alias: []string{"feet", "tracking", "walking", "beach"}}, ":forbid:": emojiData{Name: ":name_badge:", Description: "Name Badge", Unicode: "1F4DB", Alias: []string{"fire", "forbid"}}, ":forbidden:": emojiData{Name: ":u7981:", Description: "Squared Cjk Unified Ideograph-7981", Unicode: "1F232", Alias: []string{"kanji", "japanese", "chinese", "forbidden", "limit", "restricted", "red-square"}}, ":fork_and_knife:": emojiData{Name: ":fork_and_knife:", Description: "Fork and Knife", Unicode: "1F374", Alias: []string{"cutlery", "kitchen"}}, ":formal:": emojiData{Name: ":necktie:", Description: "Necktie", Unicode: "1F454", Alias: []string{"shirt", "suitup", "formal", "fashion", "cloth", "business"}}, ":formula:": emojiData{Name: ":racing_car:", Description: "Racing Car", Unicode: "1F3CE-FE0F", Alias: []string{"sports", "race", "fast", "formula", "f1"}}, ":fortune_cookie:": emojiData{Name: ":fortune_cookie:", Description: "Fortune Cookie", Unicode: "1F960", Alias: []string(nil)}, ":fortune_teller:": emojiData{Name: ":crystal_ball:", Description: "Crystal Ball", Unicode: "1F52E", Alias: []string{"disco", "party", "magic", "circus", "fortune_teller"}}, ":forward:": emojiData{Name: ":arrow_up_small:", Description: "Up-Pointing Small Red Triangle", Unicode: "1F53C", Alias: []string{"blue-square", "triangle", "direction", "point", "forward", "top"}}, ":fountain:": emojiData{Name: ":fountain:", Description: "Fountain", Unicode: "26F2", Alias: []string{"photo", "summer", "water", "fresh"}}, ":four:": emojiData{Name: ":four:", Description: "Keycap 4", Unicode: "0034-FE0F-20E3", Alias: []string{"4", "numbers", "blue-square"}}, ":four_leaf_clover:": emojiData{Name: ":four_leaf_clover:", Description: "Four Leaf Clover", Unicode: "1F340", Alias: []string{"vegetable", "plant", "nature", "lucky", "irish"}}, ":fox_face:": emojiData{Name: ":fox_face:", Description: "Fox Face", Unicode: "1F98A", Alias: []string{"animal", "nature", "face"}}, ":fr:": emojiData{Name: ":fr:", Description: "France Flag", Unicode: "1F1EB-1F1F7", Alias: []string{"banner", "flag", "nation", "france", "french", "country"}}, ":frame:": emojiData{Name: ":black_square_button:", Description: "Black Square Button", Unicode: "1F532", Alias: []string{"shape", "input", "frame"}}, ":frame_with_picture:": emojiData{Name: ":frame_with_picture:", Description: "Frame with Picture", Unicode: "1F5BC-FE0F", Alias: []string(nil)}, ":france:": emojiData{Name: ":fr:", Description: "France Flag", Unicode: "1F1EB-1F1F7", Alias: []string{"banner", "flag", "nation", "france", "french", "country"}}, ":frankfurter:": emojiData{Name: ":hotdog:", Description: "Hot Dog", Unicode: "1F32D", Alias: []string{"food", "frankfurter"}}, ":free:": emojiData{Name: ":free:", Description: "Squared Free", Unicode: "1F193", Alias: []string{"blue-square", "words"}}, ":french:": emojiData{Name: ":croissant:", Description: "Croissant", Unicode: "1F950", Alias: []string{"food", "bread", "french"}}, ":fresh:": emojiData{Name: ":fountain:", Description: "Fountain", Unicode: "26F2", Alias: []string{"photo", "summer", "water", "fresh"}}, ":fried_egg:": emojiData{Name: ":fried_egg:", Description: "Cooking", Unicode: "1F373", Alias: []string{"food", "breakfast", "kitchen", "egg"}}, ":fried_shrimp:": emojiData{Name: ":fried_shrimp:", Description: "Fried Shrimp", Unicode: "1F364", Alias: []string{"food", "animal", "appetizer", "summer"}}, ":friend:": emojiData{Name: ":dog:", Description: "Dog Face", Unicode: "1F436", Alias: []string{"animal", "friend", "nature", "woof", "puppy", "pet", "faithful"}}, ":friendship:": emojiData{Name: ":two_men_holding_hands:", Description: "Two Men Holding Hands", Unicode: "1F46C", Alias: []string{"pair", "couple", "love", "like", "bromance", "friendship", "people", "human"}}, ":fries:": emojiData{Name: ":fries:", Description: "French Fries", Unicode: "1F35F", Alias: []string{"chips", "snack", "fast food"}}, ":frog:": emojiData{Name: ":frog:", Description: "Frog Face", Unicode: "1F438", Alias: []string{"animal", "nature", "croak", "toad"}}, ":frowning:": emojiData{Name: ":frowning:", Description: "Frowning Face with Open Mouth", Unicode: "1F626", Alias: []string{"face", "aw", "what"}}, ":frozen:": emojiData{Name: ":snowman:", Description: "Snowman", Unicode: "2603-FE0F", Alias: []string{"winter", "season", "cold", "weather", "christmas", "xmas", "frozen", "without_snow"}}, ":fruit machine:": emojiData{Name: ":slot_machine:", Description: "Slot Machine", Unicode: "1F3B0", Alias: []string{"bet", "gamble", "vegas", "fruit machine", "luck", "casino"}}, ":fruit:": emojiData{Name: ":grapes:", Description: "Grapes", Unicode: "1F347", Alias: []string{"fruit", "food", "wine"}}, ":frustrated:": emojiData{Name: ":weary:", Description: "Weary Face", Unicode: "1F629", Alias: []string{"face", "tired", "sleepy", "sad", "frustrated", "upset"}}, ":ftw:": emojiData{Name: ":trophy:", Description: "Trophy", Unicode: "1F3C6", Alias: []string{"win", "award", "contest", "place", "ftw", "ceremony"}}, ":fuelpump:": emojiData{Name: ":fuelpump:", Description: "Fuel Pump", Unicode: "26FD", Alias: []string{"gas station", "petroleum"}}, ":full:": emojiData{Name: ":u6e80:", Description: "Squared Cjk Unified Ideograph-6e80", Unicode: "1F235", Alias: []string{"full", "chinese", "japanese", "red-square", "kanji"}}, ":full_moon:": emojiData{Name: ":full_moon:", Description: "Full Moon Symbol", Unicode: "1F315", Alias: []string{"nature", "yellow", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":full_moon_with_face:": emojiData{Name: ":full_moon_with_face:", Description: "Full Moon with Face", Unicode: "1F31D", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":fun:": emojiData{Name: ":man_dancing:", Description: "Man Dancing", Unicode: "1F57A", Alias: []string{"male", "boy", "fun", "dancer"}}, ":funeral:": emojiData{Name: ":coffin:", Description: "Coffin", Unicode: "26B0-FE0F", Alias: []string{"vampire", "dead", "die", "death", "rip", "graveyard", "cemetery", "casket", "funeral", "box"}}, ":funeral_urn:": emojiData{Name: ":funeral_urn:", Description: "Funeral Urn", Unicode: "26B1-FE0F", Alias: []string{"dead", "die", "death", "rip", "ashes"}}, ":funny:": emojiData{Name: ":smile:", Description: "Smiling Face with Open Mouth and Smiling Eyes", Unicode: "1F604", Alias: []string{"face", "happy", "joy", "funny", "haha", "laugh", "like", ":D", ":)"}}, ":future:": emojiData{Name: ":satellite:", Description: "Satellite", Unicode: "1F6F0-FE0F", Alias: []string{"communication", "future", "radio", "space"}}, ":gadgets:": emojiData{Name: ":headphones:", Description: "Headphone", Unicode: "1F3A7", Alias: []string{"music", "score", "gadgets"}}, ":gamble:": emojiData{Name: ":racehorse:", Description: "Horse", Unicode: "1F40E", Alias: []string{"animal", "gamble", "luck"}}, ":gambling:": emojiData{Name: ":horse_racing:", Description: "Horse Racing", Unicode: "1F3C7", Alias: []string{"animal", "betting", "competition", "gambling", "luck"}}, ":game:": emojiData{Name: ":dart:", Description: "Direct Hit", Unicode: "1F3AF", Alias: []string{"game", "play", "bar"}}, ":game_die:": emojiData{Name: ":game_die:", Description: "Game Die", Unicode: "1F3B2", Alias: []string{"dice", "random", "tabletop", "play", "luck"}}, ":garbage:": emojiData{Name: ":wastebasket:", Description: "Wastebasket", Unicode: "1F5D1-FE0F", Alias: []string{"bin", "trash", "rubbish", "garbage", "toss"}}, ":gas station:": emojiData{Name: ":fuelpump:", Description: "Fuel Pump", Unicode: "26FD", Alias: []string{"gas station", "petroleum"}}, ":gas:": emojiData{Name: ":triumph:", Description: "Face with Look of Triumph", Unicode: "1F624", Alias: []string{"face", "gas", "phew", "proud", "pride"}}, ":gb:": emojiData{Name: ":guardsman:", Description: "Guardsman", Unicode: "1F482", Alias: []string{"uk", "gb", "british", "male", "guy", "royal"}}, ":gear:": emojiData{Name: ":gear:", Description: "Gear", Unicode: "2699-FE0F", Alias: []string{"cog"}}, ":geek:": emojiData{Name: ":nerd_face:", Description: "Nerd Face", Unicode: "1F913", Alias: []string{"face", "nerdy", "geek", "dork"}}, ":gem:": emojiData{Name: ":large_orange_diamond:", Description: "Large Orange Diamond", Unicode: "1F536", Alias: []string{"shape", "jewel", "gem"}}, ":gemini:": emojiData{Name: ":gemini:", Description: "Gemini", Unicode: "264A", Alias: []string{"sign", "zodiac", "purple-square", "astrology"}}, ":gender:": emojiData{Name: ":womens:", Description: "Womens Symbol", Unicode: "1F6BA", Alias: []string{"purple-square", "woman", "female", "toilet", "loo", "restroom", "gender"}}, ":genie:": emojiData{Name: ":genie:", Description: "Genie", Unicode: "1F9DE", Alias: []string(nil)}, ":gentleman:": emojiData{Name: ":tophat:", Description: "Top Hat", Unicode: "1F3A9", Alias: []string{"magic", "gentleman", "classy", "circus"}}, ":german:": emojiData{Name: ":de:", Description: "Germany Flag", Unicode: "1F1E9-1F1EA", Alias: []string{"german", "nation", "flag", "country", "banner"}}, ":gesture:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":gesundheit:": emojiData{Name: ":sneezing_face:", Description: "Sneezing Face", Unicode: "1F927", Alias: []string{"face", "gesundheit", "sneeze", "sick", "allergy"}}, ":get:": emojiData{Name: ":ideograph_advantage:", Description: "Circled Ideograph Advantage", Unicode: "1F250", Alias: []string{"chinese", "kanji", "obtain", "get", "circle"}}, ":ghost:": emojiData{Name: ":ghost:", Description: "Ghost", Unicode: "1F47B", Alias: []string{"halloween", "spooky", "scary"}}, ":gift:": emojiData{Name: ":package:", Description: "Package", Unicode: "1F4E6", Alias: []string{"mail", "gift", "cardboard", "box", "moving"}}, ":gift_heart:": emojiData{Name: ":gift_heart:", Description: "Heart with Ribbon", Unicode: "1F49D", Alias: []string{"love", "valentines"}}, ":giraffe_face:": emojiData{Name: ":giraffe_face:", Description: "Giraffe Face", Unicode: "1F992", Alias: []string(nil)}, ":girl:": emojiData{Name: ":girl:", Description: "Girl", Unicode: "1F467", Alias: []string{"female", "woman", "teenager"}}, ":girls:": emojiData{Name: ":woman:", Description: "Woman", Unicode: "1F469", Alias: []string{"female", "girls", "lady"}}, ":glad:": emojiData{Name: ":laughing:", Description: "Smiling Face with Open Mouth and Tightly-Closed Eyes", Unicode: "1F606", Alias: []string{"happy", "joy", "lol", "satisfied", "haha", "face", "glad", "XD", "laugh"}}, ":glass:": emojiData{Name: ":tumbler_glass:", Description: "Tumbler Glass", Unicode: "1F943", Alias: []string{"drink", "beverage", "drunk", "alcohol", "liquor", "booze", "bourbon", "scotch", "whisky", "glass", "shot"}}, ":glass_of_milk:": emojiData{Name: ":glass_of_milk:", Description: "Glass of Milk", Unicode: "1F95B", Alias: []string(nil)}, ":globe:": emojiData{Name: ":earth_asia:", Description: "Earth Globe Asia-Australia", Unicode: "1F30F", Alias: []string{"globe", "world", "east", "international"}}, ":globe_with_meridians:": emojiData{Name: ":globe_with_meridians:", Description: "Globe with Meridians", Unicode: "1F310", Alias: []string{"earth", "international", "world", "internet", "interweb", "i18n"}}, ":gloves:": emojiData{Name: ":gloves:", Description: "Gloves", Unicode: "1F9E4", Alias: []string(nil)}, ":glyphs:": emojiData{Name: ":symbols:", Description: "Input Symbol for Symbols", Unicode: "1F523", Alias: []string{"blue-square", "music", "note", "ampersand", "percent", "glyphs", "characters"}}, ":goal_net:": emojiData{Name: ":goal_net:", Description: "Goal Net", Unicode: "1F945", Alias: []string{"sports"}}, ":goat:": emojiData{Name: ":goat:", Description: "Goat", Unicode: "1F410", Alias: []string{"animal", "nature"}}, ":goblin:": emojiData{Name: ":japanese_goblin:", Description: "Japanese Goblin", Unicode: "1F47A", Alias: []string{"red", "evil", "mask", "monster", "scary", "creepy", "japanese", "goblin"}}, ":gokart:": emojiData{Name: ":checkered_flag:", Description: "Chequered Flag", Unicode: "1F3C1", Alias: []string{"contest", "finishline", "race", "gokart"}}, ":golf:": emojiData{Name: ":golf:", Description: "Flag in Hole", Unicode: "26F3", Alias: []string{"sports", "business", "flag", "hole", "summer"}}, ":golfer:": emojiData{Name: ":golfer:", Description: "Golfer", Unicode: "1F3CC-FE0F", Alias: []string(nil)}, ":good morning:": emojiData{Name: ":city_sunrise:", Description: "Sunset over Buildings", Unicode: "1F307", Alias: []string{"photo", "good morning", "dawn"}}, ":good:": emojiData{Name: ":+1:", Description: "Thumbs Up Sign", Unicode: "1F44D", Alias: []string{"thumbsup", "yes", "awesome", "good", "agree", "accept", "cool", "hand", "like"}}, ":goodbye:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":gorilla:": emojiData{Name: ":gorilla:", Description: "Gorilla", Unicode: "1F98D", Alias: []string{"animal", "nature", "circus"}}, ":graduation:": emojiData{Name: ":mortar_board:", Description: "Graduation Cap", Unicode: "1F393", Alias: []string{"school", "college", "degree", "university", "graduation", "cap", "hat", "legal", "learn", "education"}}, ":grapes:": emojiData{Name: ":grapes:", Description: "Grapes", Unicode: "1F347", Alias: []string{"fruit", "food", "wine"}}, ":graph:": emojiData{Name: ":part_alternation_mark:", Description: "Part Alternation Mark", Unicode: "303D-FE0F", Alias: []string{"graph", "presentation", "stats", "business", "economics", "bad"}}, ":grasp:": emojiData{Name: ":fist:", Description: "Raised Fist", Unicode: "270A", Alias: []string{"fingers", "hand", "grasp"}}, ":grass:": emojiData{Name: ":leaves:", Description: "Leaf Fluttering in Wind", Unicode: "1F343", Alias: []string{"nature", "plant", "tree", "vegetable", "grass", "lawn", "spring"}}, ":graveyard:": emojiData{Name: ":coffin:", Description: "Coffin", Unicode: "26B0-FE0F", Alias: []string{"vampire", "dead", "die", "death", "rip", "graveyard", "cemetery", "casket", "funeral", "box"}}, ":gray:": emojiData{Name: ":grey_exclamation:", Description: "White Exclamation Mark Ornament", Unicode: "2755", Alias: []string{"surprise", "punctuation", "gray", "wow", "warning"}}, ":green-square:": emojiData{Name: ":white_check_mark:", Description: "White Heavy Check Mark", Unicode: "2705", Alias: []string{"green-square", "ok", "agree", "vote", "election", "answer", "tick"}}, ":green:": emojiData{Name: ":dragon:", Description: "Dragon", Unicode: "1F409", Alias: []string{"animal", "myth", "nature", "chinese", "green"}}, ":green_apple:": emojiData{Name: ":green_apple:", Description: "Green Apple", Unicode: "1F34F", Alias: []string{"fruit", "nature"}}, ":green_book:": emojiData{Name: ":green_book:", Description: "Green Book", Unicode: "1F4D7", Alias: []string{"read", "library", "knowledge", "study"}}, ":green_heart:": emojiData{Name: ":green_heart:", Description: "Green Heart", Unicode: "1F49A", Alias: []string{"love", "like", "affection", "valentines"}}, ":green_salad:": emojiData{Name: ":green_salad:", Description: "Green Salad", Unicode: "1F957", Alias: []string{"food", "healthy", "lettuce"}}, ":grey_exclamation:": emojiData{Name: ":grey_exclamation:", Description: "White Exclamation Mark Ornament", Unicode: "2755", Alias: []string{"surprise", "punctuation", "gray", "wow", "warning"}}, ":grey_question:": emojiData{Name: ":grey_question:", Description: "White Question Mark Ornament", Unicode: "2754", Alias: []string{"doubts", "gray", "huh", "confused"}}, ":grimace:": emojiData{Name: ":grimacing:", Description: "Grimacing Face", Unicode: "1F62C", Alias: []string{"face", "grimace", "teeth"}}, ":grimacing:": emojiData{Name: ":grimacing:", Description: "Grimacing Face", Unicode: "1F62C", Alias: []string{"face", "grimace", "teeth"}}, ":grin:": emojiData{Name: ":grin:", Description: "Grinning Face with Smiling Eyes", Unicode: "1F601", Alias: []string{"face", "happy", "smile", "joy", "kawaii"}}, ":grinning:": emojiData{Name: ":grinning:", Description: "Grinning Face", Unicode: "1F600", Alias: []string{"face", "smile", "happy", "joy", ":D", "grin"}}, ":groceries:": emojiData{Name: ":convenience_store:", Description: "Convenience Store", Unicode: "1F3EA", Alias: []string{"building", "shopping", "groceries"}}, ":groom:": emojiData{Name: ":wedding:", Description: "Wedding", Unicode: "1F492", Alias: []string{"love", "like", "affection", "couple", "marriage", "bride", "groom"}}, ":gross:": emojiData{Name: ":nauseated_face:", Description: "Nauseated Face", Unicode: "1F922", Alias: []string{"face", "vomit", "gross", "green", "sick", "throw up", "ill"}}, ":group:": emojiData{Name: ":busts_in_silhouette:", Description: "Busts in Silhouette", Unicode: "1F465", Alias: []string{"user", "person", "human", "group", "team"}}, ":guardsman:": emojiData{Name: ":guardsman:", Description: "Guardsman", Unicode: "1F482", Alias: []string{"uk", "gb", "british", "male", "guy", "royal"}}, ":guitar:": emojiData{Name: ":guitar:", Description: "Guitar", Unicode: "1F3B8", Alias: []string{"music", "instrument"}}, ":gun:": emojiData{Name: ":gun:", Description: "Pistol", Unicode: "1F52B", Alias: []string{"violence", "weapon", "pistol", "revolver"}}, ":guy:": emojiData{Name: ":guardsman:", Description: "Guardsman", Unicode: "1F482", Alias: []string{"uk", "gb", "british", "male", "guy", "royal"}}, ":gyro:": emojiData{Name: ":stuffed_flatbread:", Description: "Stuffed Flatbread", Unicode: "1F959", Alias: []string{"food", "flatbread", "stuffed", "gyro"}}, ":haha:": emojiData{Name: ":smile:", Description: "Smiling Face with Open Mouth and Smiling Eyes", Unicode: "1F604", Alias: []string{"face", "happy", "joy", "funny", "haha", "laugh", "like", ":D", ":)"}}, ":hair:": emojiData{Name: ":barber:", Description: "Barber Pole", Unicode: "1F488", Alias: []string{"hair", "salon", "style"}}, ":haircut:": emojiData{Name: ":haircut:", Description: "Haircut", Unicode: "1F487", Alias: []string(nil)}, ":halloween:": emojiData{Name: ":izakaya_lantern:", Description: "Izakaya Lantern", Unicode: "1F3EE", Alias: []string{"light", "paper", "halloween", "spooky"}}, ":halo:": emojiData{Name: ":innocent:", Description: "Smiling Face with Halo", Unicode: "1F607", Alias: []string{"face", "angel", "heaven", "halo"}}, ":hamburger:": emojiData{Name: ":hamburger:", Description: "Hamburger", Unicode: "1F354", Alias: []string{"meat", "fast food", "beef", "cheeseburger", "mcdonalds", "burger king"}}, ":hammer:": emojiData{Name: ":hammer:", Description: "Hammer", Unicode: "1F528", Alias: []string{"tools", "build", "create"}}, ":hammer_and_pick:": emojiData{Name: ":hammer_and_pick:", Description: "Hammer and Pick", Unicode: "2692-FE0F", Alias: []string{"tools", "build", "create"}}, ":hammer_and_wrench:": emojiData{Name: ":hammer_and_wrench:", Description: "Hammer and Wrench", Unicode: "1F6E0-FE0F", Alias: []string{"tools", "build", "create"}}, ":hamster:": emojiData{Name: ":hamster:", Description: "Hamster Face", Unicode: "1F439", Alias: []string{"animal", "nature"}}, ":hand:": emojiData{Name: ":point_up_2:", Description: "White Up Pointing Backhand Index", Unicode: "1F446", Alias: []string{"fingers", "hand", "direction", "up"}}, ":handbag:": emojiData{Name: ":handbag:", Description: "Handbag", Unicode: "1F45C", Alias: []string{"fashion", "accessory", "accessories", "shopping"}}, ":handball:": emojiData{Name: ":handball:", Description: "Handball", Unicode: "1F93E", Alias: []string(nil)}, ":hands:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":handshake:": emojiData{Name: ":handshake:", Description: "Handshake", Unicode: "1F91D", Alias: []string{"agreement", "shake"}}, ":handy:": emojiData{Name: ":nut_and_bolt:", Description: "Nut and Bolt", Unicode: "1F529", Alias: []string{"handy", "tools", "fix"}}, ":hankey:": emojiData{Name: ":hankey:", Description: "Pile of Poo", Unicode: "1F4A9", Alias: []string(nil)}, ":happiness:": emojiData{Name: ":relaxed:", Description: "White Smiling Face", Unicode: "263A-FE0F", Alias: []string{"face", "blush", "massage", "happiness"}}, ":happy:": emojiData{Name: ":blush:", Description: "Smiling Face with Smiling Eyes", Unicode: "1F60A", Alias: []string{"face", "smile", "happy", "flushed", "crush", "embarrassed", "shy", "joy"}}, ":happytears:": emojiData{Name: ":joy:", Description: "Face with Tears of Joy", Unicode: "1F602", Alias: []string{"face", "cry", "tears", "weep", "happy", "happytears", "haha"}}, ":hash:": emojiData{Name: ":hash:", Description: "Hash Key", Unicode: "0023-FE0F-20E3", Alias: []string{"symbol", "blue-square", "twitter"}}, ":hat:": emojiData{Name: ":mortar_board:", Description: "Graduation Cap", Unicode: "1F393", Alias: []string{"school", "college", "degree", "university", "graduation", "cap", "hat", "legal", "learn", "education"}}, ":hatched_chick:": emojiData{Name: ":hatched_chick:", Description: "Front-Facing Baby Chick", Unicode: "1F425", Alias: []string{"animal", "chicken", "baby", "bird"}}, ":hatching_chick:": emojiData{Name: ":hatching_chick:", Description: "Hatching Chick", Unicode: "1F423", Alias: []string{"animal", "chicken", "egg", "born", "baby", "bird"}}, ":hate:": emojiData{Name: ":rage:", Description: "Pouting Face", Unicode: "1F621", Alias: []string{"angry", "mad", "hate", "despise"}}, ":have:": emojiData{Name: ":u6709:", Description: "Squared Cjk Unified Ideograph-6709", Unicode: "1F236", Alias: []string{"orange-square", "chinese", "have", "kanji"}}, ":headline:": emojiData{Name: ":newspaper:", Description: "Newspaper", Unicode: "1F4F0", Alias: []string{"press", "headline"}}, ":headphones:": emojiData{Name: ":headphones:", Description: "Headphone", Unicode: "1F3A7", Alias: []string{"music", "score", "gadgets"}}, ":health:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":healthy:": emojiData{Name: ":green_salad:", Description: "Green Salad", Unicode: "1F957", Alias: []string{"food", "healthy", "lettuce"}}, ":hear:": emojiData{Name: ":ear:", Description: "Ear", Unicode: "1F442", Alias: []string{"face", "hear", "sound", "listen"}}, ":hear_no_evil:": emojiData{Name: ":hear_no_evil:", Description: "Hear-No-Evil Monkey", Unicode: "1F649", Alias: []string{"animal", "monkey", "nature"}}, ":heart:": emojiData{Name: ":heartbeat:", Description: "Beating Heart", Unicode: "1F493", Alias: []string{"love", "like", "affection", "valentines", "pink", "heart"}}, ":heart_decoration:": emojiData{Name: ":heart_decoration:", Description: "Heart Decoration", Unicode: "1F49F", Alias: []string{"purple-square", "love", "like"}}, ":heart_eyes:": emojiData{Name: ":heart_eyes:", Description: "Smiling Face with Heart-Shaped Eyes", Unicode: "1F60D", Alias: []string{"face", "love", "like", "affection", "valentines", "infatuation", "crush", "heart"}}, ":heart_eyes_cat:": emojiData{Name: ":heart_eyes_cat:", Description: "Smiling Cat Face with Heart-Shaped Eyes", Unicode: "1F63B", Alias: []string{"animal", "love", "like", "affection", "cats", "valentines", "heart"}}, ":heartbeat:": emojiData{Name: ":heartbeat:", Description: "Beating Heart", Unicode: "1F493", Alias: []string{"love", "like", "affection", "valentines", "pink", "heart"}}, ":heartbreak:": emojiData{Name: ":broken_heart:", Description: "Broken Heart", Unicode: "1F494", Alias: []string{"sad", "sorry", "break", "heart", "heartbreak"}}, ":heartpulse:": emojiData{Name: ":heartpulse:", Description: "Growing Heart", Unicode: "1F497", Alias: []string{"like", "love", "affection", "valentines", "pink"}}, ":hearts:": emojiData{Name: ":hearts:", Description: "Black Heart Suit", Unicode: "2665-FE0F", Alias: []string{"poker", "cards", "magic", "suits"}}, ":heaven:": emojiData{Name: ":innocent:", Description: "Smiling Face with Halo", Unicode: "1F607", Alias: []string{"face", "angel", "heaven", "halo"}}, ":heavy_check_mark:": emojiData{Name: ":heavy_check_mark:", Description: "Heavy Check Mark", Unicode: "2714-FE0F", Alias: []string{"ok", "nike", "answer", "yes", "tick"}}, ":heavy_division_sign:": emojiData{Name: ":heavy_division_sign:", Description: "Heavy Division Sign", Unicode: "2797", Alias: []string{"divide", "math", "calculation"}}, ":heavy_dollar_sign:": emojiData{Name: ":heavy_dollar_sign:", Description: "Heavy Dollar Sign", Unicode: "1F4B2", Alias: []string{"money", "sales", "payment", "currency", "buck"}}, ":heavy_exclamation_mark:": emojiData{Name: ":exclamation:", Description: "Heavy Exclamation Mark Symbol", Unicode: "2757", Alias: []string{"heavy_exclamation_mark", "danger", "surprise", "punctuation", "wow", "warning"}}, ":heavy_heart_exclamation_mark_ornament:": emojiData{Name: ":heavy_heart_exclamation_mark_ornament:", Description: "Heavy Heart Exclamation Mark Ornament", Unicode: "2763-FE0F", Alias: []string(nil)}, ":heavy_minus_sign:": emojiData{Name: ":heavy_minus_sign:", Description: "Heavy Minus Sign", Unicode: "2796", Alias: []string{"math", "calculation", "subtract", "less"}}, ":heavy_multiplication_x:": emojiData{Name: ":heavy_multiplication_x:", Description: "Heavy Multiplication X", Unicode: "2716-FE0F", Alias: []string{"math", "calculation"}}, ":heavy_plus_sign:": emojiData{Name: ":heavy_plus_sign:", Description: "Heavy Plus Sign", Unicode: "2795", Alias: []string{"math", "calculation", "addition", "more", "increase"}}, ":hedgehog:": emojiData{Name: ":hedgehog:", Description: "Hedgehog", Unicode: "1F994", Alias: []string(nil)}, ":helicopter:": emojiData{Name: ":helicopter:", Description: "Helicopter", Unicode: "1F681", Alias: []string{"transportation", "vehicle", "fly"}}, ":hello:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":hellokitty:": emojiData{Name: ":no_mouth:", Description: "Face Without Mouth", Unicode: "1F636", Alias: []string{"face", "hellokitty"}}, ":helmet_with_white_cross:": emojiData{Name: ":helmet_with_white_cross:", Description: "Helmet with White Cross", Unicode: "26D1-FE0F", Alias: []string(nil)}, ":help:": emojiData{Name: ":sos:", Description: "Squared Sos", Unicode: "1F198", Alias: []string{"help", "red-square", "words", "emergency", "911"}}, ":herb:": emojiData{Name: ":herb:", Description: "Herb", Unicode: "1F33F", Alias: []string{"vegetable", "plant", "medicine", "weed", "grass", "lawn"}}, ":here:": emojiData{Name: ":koko:", Description: "Squared Katakana Koko", Unicode: "1F201", Alias: []string{"blue-square", "here", "katakana", "japanese", "destination"}}, ":hexagram:": emojiData{Name: ":six_pointed_star:", Description: "Six Pointed Star with Middle Dot", Unicode: "1F52F", Alias: []string{"purple-square", "religion", "jewish", "hexagram"}}, ":hi:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":hibiscus:": emojiData{Name: ":hibiscus:", Description: "Hibiscus", Unicode: "1F33A", Alias: []string{"plant", "vegetable", "flowers", "beach"}}, ":high:": emojiData{Name: ":up:", Description: "Squared Up with Exclamation Mark", Unicode: "1F199", Alias: []string{"blue-square", "above", "high"}}, ":high_brightness:": emojiData{Name: ":high_brightness:", Description: "High Brightness Symbol", Unicode: "1F506", Alias: []string{"sun", "light"}}, ":high_heel:": emojiData{Name: ":high_heel:", Description: "High-Heeled Shoe", Unicode: "1F460", Alias: []string{"fashion", "shoes", "female", "pumps", "stiletto"}}, ":highfive:": emojiData{Name: ":pray:", Description: "Person with Folded Hands", Unicode: "1F64F", Alias: []string{"please", "hope", "wish", "namaste", "highfive"}}, ":highway:": emojiData{Name: ":motorway:", Description: "Motorway", Unicode: "1F6E3-FE0F", Alias: []string{"road", "cupertino", "interstate", "highway"}}, ":hinduism:": emojiData{Name: ":wheel_of_dharma:", Description: "Wheel of Dharma", Unicode: "2638-FE0F", Alias: []string{"hinduism", "buddhism", "sikhism", "jainism"}}, ":hippie:": emojiData{Name: ":peace_symbol:", Description: "Peace Symbol", Unicode: "262E-FE0F", Alias: []string{"hippie"}}, ":hipster:": emojiData{Name: ":bike:", Description: "Bicycle", Unicode: "1F6B2", Alias: []string{"sports", "bicycle", "exercise", "hipster"}}, ":hiss:": emojiData{Name: ":snake:", Description: "Snake", Unicode: "1F40D", Alias: []string{"animal", "evil", "nature", "hiss", "python"}}, ":history:": emojiData{Name: ":scroll:", Description: "Scroll", Unicode: "1F4DC", Alias: []string{"documents", "ancient", "history", "paper"}}, ":hit:": emojiData{Name: ":facepunch:", Description: "Fisted Hand Sign", Unicode: "1F44A", Alias: []string{"angry", "violence", "fist", "hit", "attack", "hand"}}, ":hmmm:": emojiData{Name: ":confused:", Description: "Confused Face", Unicode: "1F615", Alias: []string{"face", "indifference", "huh", "weird", "hmmm", ":/"}}, ":hobby:": emojiData{Name: ":fishing_pole_and_fish:", Description: "Fishing Pole and Fish", Unicode: "1F3A3", Alias: []string{"food", "hobby", "summer"}}, ":hocho:": emojiData{Name: ":hocho:", Description: "Hocho", Unicode: "1F52A", Alias: []string{"knife", "blade", "cutlery", "kitchen", "weapon"}}, ":hole:": emojiData{Name: ":hole:", Description: "Hole", Unicode: "1F573-FE0F", Alias: []string{"embarrassing"}}, ":home:": emojiData{Name: ":house:", Description: "House Building", Unicode: "1F3E0", Alias: []string{"building", "home"}}, ":honey_pot:": emojiData{Name: ":honey_pot:", Description: "Honey Pot", Unicode: "1F36F", Alias: []string{"bees", "sweet", "kitchen"}}, ":hooray:": emojiData{Name: ":raised_hands:", Description: "Person Raising Both Hands in Celebration", Unicode: "1F64C", Alias: []string{"gesture", "hooray", "yea", "celebration", "hands"}}, ":hoot:": emojiData{Name: ":owl:", Description: "Owl", Unicode: "1F989", Alias: []string{"animal", "nature", "bird", "hoot"}}, ":hope:": emojiData{Name: ":pray:", Description: "Person with Folded Hands", Unicode: "1F64F", Alias: []string{"please", "hope", "wish", "namaste", "highfive"}}, ":horizontal:": emojiData{Name: ":left_right_arrow:", Description: "Left Right Arrow", Unicode: "2194-FE0F", Alias: []string{"shape", "direction", "horizontal", "sideways"}}, ":horn:": emojiData{Name: ":rhinoceros:", Description: "Rhinoceros", Unicode: "1F98F", Alias: []string{"animal", "nature", "horn"}}, ":horns:": emojiData{Name: ":imp:", Description: "Imp", Unicode: "1F47F", Alias: []string{"devil", "angry", "horns"}}, ":horse:": emojiData{Name: ":horse:", Description: "Horse Face", Unicode: "1F434", Alias: []string{"animal", "brown", "nature"}}, ":horse_racing:": emojiData{Name: ":horse_racing:", Description: "Horse Racing", Unicode: "1F3C7", Alias: []string{"animal", "betting", "competition", "gambling", "luck"}}, ":hospital:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":hot:": emojiData{Name: ":icecream:", Description: "Soft Ice Cream", Unicode: "1F366", Alias: []string{"food", "hot", "dessert", "summer"}}, ":hot_pepper:": emojiData{Name: ":hot_pepper:", Description: "Hot Pepper", Unicode: "1F336-FE0F", Alias: []string{"food", "spicy", "chilli", "chili"}}, ":hotcakes:": emojiData{Name: ":pancakes:", Description: "Pancakes", Unicode: "1F95E", Alias: []string{"food", "breakfast", "flapjacks", "hotcakes"}}, ":hotdog:": emojiData{Name: ":hotdog:", Description: "Hot Dog", Unicode: "1F32D", Alias: []string{"food", "frankfurter"}}, ":hotel:": emojiData{Name: ":hotel:", Description: "Hotel", Unicode: "1F3E8", Alias: []string{"building", "accomodation", "checkin"}}, ":hotsprings:": emojiData{Name: ":hotsprings:", Description: "Hot Springs", Unicode: "2668-FE0F", Alias: []string{"bath", "warm", "relax"}}, ":hourglass:": emojiData{Name: ":hourglass:", Description: "Hourglass", Unicode: "231B", Alias: []string{"time", "clock", "oldschool", "limit", "exam", "quiz", "test"}}, ":hourglass_flowing_sand:": emojiData{Name: ":hourglass_flowing_sand:", Description: "Hourglass with Flowing Sand", Unicode: "23F3", Alias: []string{"oldschool", "time", "countdown"}}, ":house:": emojiData{Name: ":door:", Description: "Door", Unicode: "1F6AA", Alias: []string{"house", "entry", "exit"}}, ":house_buildings:": emojiData{Name: ":house_buildings:", Description: "House Buildings", Unicode: "1F3D8-FE0F", Alias: []string(nil)}, ":house_with_garden:": emojiData{Name: ":house_with_garden:", Description: "House with Garden", Unicode: "1F3E1", Alias: []string{"home", "plant", "nature"}}, ":hugging_face:": emojiData{Name: ":hugging_face:", Description: "Hugging Face", Unicode: "1F917", Alias: []string(nil)}, ":huh:": emojiData{Name: ":fearful:", Description: "Fearful Face", Unicode: "1F628", Alias: []string{"face", "scared", "terrified", "nervous", "oops", "huh"}}, ":human:": emojiData{Name: ":older_man:", Description: "Older Man", Unicode: "1F474", Alias: []string{"human", "male", "men", "old", "elder", "senior"}}, ":hump:": emojiData{Name: ":dromedary_camel:", Description: "Dromedary Camel", Unicode: "1F42A", Alias: []string{"animal", "hot", "desert", "hump"}}, ":hundred:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":hurricane:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":hurt:": emojiData{Name: ":face_with_head_bandage:", Description: "Face with Head-Bandage", Unicode: "1F915", Alias: []string{"injured", "clumsy", "bandage", "hurt"}}, ":hushed:": emojiData{Name: ":hushed:", Description: "Hushed Face", Unicode: "1F62F", Alias: []string{"face", "woo", "shh"}}, ":i18n:": emojiData{Name: ":globe_with_meridians:", Description: "Globe with Meridians", Unicode: "1F310", Alias: []string{"earth", "international", "world", "internet", "interweb", "i18n"}}, ":i_love_you_hand_sign:": emojiData{Name: ":i_love_you_hand_sign:", Description: "I Love You Hand Sign", Unicode: "1F91F", Alias: []string(nil)}, ":ice_cream:": emojiData{Name: ":ice_cream:", Description: "Ice Cream", Unicode: "1F368", Alias: []string{"food", "hot", "dessert"}}, ":ice_hockey_stick_and_puck:": emojiData{Name: ":ice_hockey_stick_and_puck:", Description: "Ice Hockey Stick and Puck", Unicode: "1F3D2", Alias: []string(nil)}, ":ice_skate:": emojiData{Name: ":ice_skate:", Description: "Ice Skate", Unicode: "26F8-FE0F", Alias: []string{"sports"}}, ":icecream:": emojiData{Name: ":icecream:", Description: "Soft Ice Cream", Unicode: "1F366", Alias: []string{"food", "hot", "dessert", "summer"}}, ":icon:": emojiData{Name: ":black_small_square:", Description: "Black Small Square", Unicode: "25AA-FE0F", Alias: []string{"shape", "icon"}}, ":id:": emojiData{Name: ":id:", Description: "Squared Id", Unicode: "1F194", Alias: []string{"purple-square", "words"}}, ":idea:": emojiData{Name: ":bulb:", Description: "Electric Light Bulb", Unicode: "1F4A1", Alias: []string{"light", "electricity", "idea"}}, ":ideograph_advantage:": emojiData{Name: ":ideograph_advantage:", Description: "Circled Ideograph Advantage", Unicode: "1F250", Alias: []string{"chinese", "kanji", "obtain", "get", "circle"}}, ":ikea:": emojiData{Name: ":wrench:", Description: "Wrench", Unicode: "1F527", Alias: []string{"tools", "diy", "ikea", "fix", "ainer"}}, ":ill:": emojiData{Name: ":mask:", Description: "Face with Medical Mask", Unicode: "1F637", Alias: []string{"face", "sick", "ill", "disease"}}, ":imp:": emojiData{Name: ":imp:", Description: "Imp", Unicode: "1F47F", Alias: []string{"devil", "angry", "horns"}}, ":impressed:": emojiData{Name: ":open_mouth:", Description: "Face with Open Mouth", Unicode: "1F62E", Alias: []string{"face", "surprise", "impressed", "wow", "whoa", ":O"}}, ":inbox:": emojiData{Name: ":mailbox_with_mail:", Description: "Open Mailbox with Raised Flag", Unicode: "1F4EC", Alias: []string{"email", "inbox", "communication"}}, ":inbox_tray:": emojiData{Name: ":inbox_tray:", Description: "Inbox Tray", Unicode: "1F4E5", Alias: []string{"email", "documents"}}, ":incoming:": emojiData{Name: ":calling:", Description: "Mobile Phone with Rightwards Arrow at Left", Unicode: "1F4F2", Alias: []string{"iphone", "incoming"}}, ":incoming_envelope:": emojiData{Name: ":incoming_envelope:", Description: "Incoming Envelope", Unicode: "1F4E8", Alias: []string{"email", "inbox"}}, ":increase:": emojiData{Name: ":heavy_plus_sign:", Description: "Heavy Plus Sign", Unicode: "2795", Alias: []string{"math", "calculation", "addition", "more", "increase"}}, ":indian:": emojiData{Name: ":curry:", Description: "Curry and Rice", Unicode: "1F35B", Alias: []string{"food", "spicy", "hot", "indian"}}, ":indifference:": emojiData{Name: ":unamused:", Description: "Unamused Face", Unicode: "1F612", Alias: []string{"indifference", "bored", "straight face", "serious", "sarcasm"}}, ":indifferent:": emojiData{Name: ":expressionless:", Description: "Expressionless Face", Unicode: "1F611", Alias: []string{"face", "indifferent", "-_-", "meh", "deadpan"}}, ":industry:": emojiData{Name: ":factory:", Description: "Factory", Unicode: "1F3ED", Alias: []string{"building", "industry", "pollution", "smoke"}}, ":infatuation:": emojiData{Name: ":kissing:", Description: "Kissing Face", Unicode: "1F617", Alias: []string{"love", "like", "face", "3", "valentines", "infatuation", "kiss"}}, ":info:": emojiData{Name: ":put_litter_in_its_place:", Description: "Put Litter in Its Place Symbol", Unicode: "1F6AE", Alias: []string{"blue-square", "sign", "human", "info"}}, ":information:": emojiData{Name: ":page_facing_up:", Description: "Page Facing Up", Unicode: "1F4C4", Alias: []string{"documents", "office", "paper", "information"}}, ":information_desk_person:": emojiData{Name: ":information_desk_person:", Description: "Information Desk Person", Unicode: "1F481", Alias: []string(nil)}, ":information_source:": emojiData{Name: ":information_source:", Description: "Information Source", Unicode: "2139-FE0F", Alias: []string{"blue-square", "alphabet", "letter"}}, ":injured:": emojiData{Name: ":face_with_head_bandage:", Description: "Face with Head-Bandage", Unicode: "1F915", Alias: []string{"injured", "clumsy", "bandage", "hurt"}}, ":ink:": emojiData{Name: ":printer:", Description: "Printer", Unicode: "1F5A8-FE0F", Alias: []string{"paper", "ink"}}, ":innocent:": emojiData{Name: ":innocent:", Description: "Smiling Face with Halo", Unicode: "1F607", Alias: []string{"face", "angel", "heaven", "halo"}}, ":input:": emojiData{Name: ":keyboard:", Description: "Keyboard", Unicode: "2328-FE0F", Alias: []string{"technology", "computer", "type", "input", "text"}}, ":insect:": emojiData{Name: ":beetle:", Description: "Lady Beetle", Unicode: "1F41E", Alias: []string{"animal", "insect", "nature", "ladybug"}}, ":instrument:": emojiData{Name: ":guitar:", Description: "Guitar", Unicode: "1F3B8", Alias: []string{"music", "instrument"}}, ":international:": emojiData{Name: ":earth_asia:", Description: "Earth Globe Asia-Australia", Unicode: "1F30F", Alias: []string{"globe", "world", "east", "international"}}, ":internet:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":interrobang:": emojiData{Name: ":interrobang:", Description: "Exclamation Question Mark", Unicode: "2049-FE0F", Alias: []string{"wat", "punctuation", "surprise"}}, ":interstate:": emojiData{Name: ":motorway:", Description: "Motorway", Unicode: "1F6E3-FE0F", Alias: []string{"road", "cupertino", "interstate", "highway"}}, ":interweb:": emojiData{Name: ":globe_with_meridians:", Description: "Globe with Meridians", Unicode: "1F310", Alias: []string{"earth", "international", "world", "internet", "interweb", "i18n"}}, ":ip:": emojiData{Name: ":copyright:", Description: "Copyright Sign", Unicode: "00A9-FE0F", Alias: []string{"ip", "license", "circle", "law", "legal"}}, ":iphone:": emojiData{Name: ":no_mobile_phones:", Description: "No Mobile Phones", Unicode: "1F4F5", Alias: []string{"iphone", "mute", "circle"}}, ":irish:": emojiData{Name: ":four_leaf_clover:", Description: "Four Leaf Clover", Unicode: "1F340", Alias: []string{"vegetable", "plant", "nature", "lucky", "irish"}}, ":islam:": emojiData{Name: ":mosque:", Description: "Mosque", Unicode: "1F54C", Alias: []string{"islam", "worship", "minaret"}}, ":issue:": emojiData{Name: ":warning:", Description: "Warning Sign", Unicode: "26A0-FE0F", Alias: []string{"exclamation", "wip", "alert", "error", "problem", "issue"}}, ":it:": emojiData{Name: ":it:", Description: "Italy Flag", Unicode: "1F1EE-1F1F9", Alias: []string{"italy", "flag", "nation", "country", "banner"}}, ":italian:": emojiData{Name: ":spaghetti:", Description: "Spaghetti", Unicode: "1F35D", Alias: []string{"food", "italian", "noodle"}}, ":italy:": emojiData{Name: ":it:", Description: "Italy Flag", Unicode: "1F1EE-1F1F9", Alias: []string{"italy", "flag", "nation", "country", "banner"}}, ":izakaya_lantern:": emojiData{Name: ":izakaya_lantern:", Description: "Izakaya Lantern", Unicode: "1F3EE", Alias: []string{"light", "paper", "halloween", "spooky"}}, ":jack_o_lantern:": emojiData{Name: ":jack_o_lantern:", Description: "Jack-O-Lantern", Unicode: "1F383", Alias: []string{"halloween", "light", "pumpkin", "creepy", "fall"}}, ":jainism:": emojiData{Name: ":wheel_of_dharma:", Description: "Wheel of Dharma", Unicode: "2638-FE0F", Alias: []string{"hinduism", "buddhism", "sikhism", "jainism"}}, ":japan:": emojiData{Name: ":rice_scene:", Description: "Moon Viewing Ceremony", Unicode: "1F391", Alias: []string{"photo", "japan", "asia", "tsukimi"}}, ":japanese:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":japanese_castle:": emojiData{Name: ":japanese_castle:", Description: "Japanese Castle", Unicode: "1F3EF", Alias: []string{"photo", "building"}}, ":japanese_goblin:": emojiData{Name: ":japanese_goblin:", Description: "Japanese Goblin", Unicode: "1F47A", Alias: []string{"red", "evil", "mask", "monster", "scary", "creepy", "japanese", "goblin"}}, ":japanese_ogre:": emojiData{Name: ":japanese_ogre:", Description: "Japanese Ogre", Unicode: "1F479", Alias: []string{"monster", "red", "mask", "halloween", "scary", "creepy", "devil", "demon", "japanese", "ogre"}}, ":jar:": emojiData{Name: ":amphora:", Description: "Amphora", Unicode: "1F3FA", Alias: []string{"vase", "jar"}}, ":jaws:": emojiData{Name: ":shark:", Description: "Shark", Unicode: "1F988", Alias: []string{"animal", "nature", "fish", "sea", "ocean", "jaws", "fins", "beach"}}, ":jazz:": emojiData{Name: ":saxophone:", Description: "Saxophone", Unicode: "1F3B7", Alias: []string{"music", "instrument", "jazz", "blues"}}, ":jeans:": emojiData{Name: ":jeans:", Description: "Jeans", Unicode: "1F456", Alias: []string{"fashion", "shopping"}}, ":jewel:": emojiData{Name: ":large_orange_diamond:", Description: "Large Orange Diamond", Unicode: "1F536", Alias: []string{"shape", "jewel", "gem"}}, ":jewelry:": emojiData{Name: ":ring:", Description: "Ring", Unicode: "1F48D", Alias: []string{"wedding", "propose", "marriage", "valentines", "diamond", "fashion", "jewelry", "gem", "engagement"}}, ":jewish:": emojiData{Name: ":synagogue:", Description: "Synagogue", Unicode: "1F54D", Alias: []string{"judaism", "worship", "temple", "jewish"}}, ":job:": emojiData{Name: ":briefcase:", Description: "Briefcase", Unicode: "1F4BC", Alias: []string{"business", "documents", "work", "law", "legal", "job", "career"}}, ":join:": emojiData{Name: ":u5408:", Description: "Squared Cjk Unified Ideograph-5408", Unicode: "1F234", Alias: []string{"japanese", "chinese", "join", "kanji", "red-square"}}, ":joint:": emojiData{Name: ":smoking:", Description: "Smoking Symbol", Unicode: "1F6AC", Alias: []string{"kills", "tobacco", "cigarette", "joint", "smoke"}}, ":joy:": emojiData{Name: ":blush:", Description: "Smiling Face with Smiling Eyes", Unicode: "1F60A", Alias: []string{"face", "smile", "happy", "flushed", "crush", "embarrassed", "shy", "joy"}}, ":joy_cat:": emojiData{Name: ":joy_cat:", Description: "Cat Face with Tears of Joy", Unicode: "1F639", Alias: []string{"animal", "cats", "haha", "happy", "tears"}}, ":joystick:": emojiData{Name: ":joystick:", Description: "Joystick", Unicode: "1F579-FE0F", Alias: []string{"game", "play"}}, ":jp:": emojiData{Name: ":jp:", Description: "Japan Flag", Unicode: "1F1EF-1F1F5", Alias: []string{"japanese", "nation", "flag", "country", "banner"}}, ":judaism:": emojiData{Name: ":synagogue:", Description: "Synagogue", Unicode: "1F54D", Alias: []string{"judaism", "worship", "temple", "jewish"}}, ":judo:": emojiData{Name: ":martial_arts_uniform:", Description: "Martial Arts Uniform", Unicode: "1F94B", Alias: []string{"judo", "karate", "taekwondo"}}, ":juggling:": emojiData{Name: ":juggling:", Description: "Juggling", Unicode: "1F939", Alias: []string(nil)}, ":kaaba:": emojiData{Name: ":kaaba:", Description: "Kaaba", Unicode: "1F54B", Alias: []string{"mecca", "mosque", "islam"}}, ":kamaboko:": emojiData{Name: ":fish_cake:", Description: "Fish Cake with Swirl Design", Unicode: "1F365", Alias: []string{"food", "japan", "sea", "beach", "narutomaki", "pink", "swirl", "kamaboko", "surimi", "ramen"}}, ":kanji:": emojiData{Name: ":ideograph_advantage:", Description: "Circled Ideograph Advantage", Unicode: "1F250", Alias: []string{"chinese", "kanji", "obtain", "get", "circle"}}, ":karate:": emojiData{Name: ":martial_arts_uniform:", Description: "Martial Arts Uniform", Unicode: "1F94B", Alias: []string{"judo", "karate", "taekwondo"}}, ":katakana:": emojiData{Name: ":koko:", Description: "Squared Katakana Koko", Unicode: "1F201", Alias: []string{"blue-square", "here", "katakana", "japanese", "destination"}}, ":kawaii:": emojiData{Name: ":grin:", Description: "Grinning Face with Smiling Eyes", Unicode: "1F601", Alias: []string{"face", "happy", "smile", "joy", "kawaii"}}, ":key:": emojiData{Name: ":key:", Description: "Key", Unicode: "1F511", Alias: []string{"lock", "door", "password"}}, ":keyboard:": emojiData{Name: ":keyboard:", Description: "Keyboard", Unicode: "2328-FE0F", Alias: []string{"technology", "computer", "type", "input", "text"}}, ":keycap_star:": emojiData{Name: ":keycap_star:", Description: "Keycap Star", Unicode: "002A-FE0F-20E3", Alias: []string(nil)}, ":keycap_ten:": emojiData{Name: ":keycap_ten:", Description: "Keycap Ten", Unicode: "1F51F", Alias: []string{"numbers", "10", "blue-square"}}, ":kills:": emojiData{Name: ":smoking:", Description: "Smoking Symbol", Unicode: "1F6AC", Alias: []string{"kills", "tobacco", "cigarette", "joint", "smoke"}}, ":kimono:": emojiData{Name: ":kimono:", Description: "Kimono", Unicode: "1F458", Alias: []string{"dress", "fashion", "women", "female", "japanese"}}, ":king:": emojiData{Name: ":prince:", Description: "Prince", Unicode: "1F934", Alias: []string{"boy", "man", "male", "crown", "royal", "king"}}, ":kiss:": emojiData{Name: ":kissing:", Description: "Kissing Face", Unicode: "1F617", Alias: []string{"love", "like", "face", "3", "valentines", "infatuation", "kiss"}}, ":kissing:": emojiData{Name: ":kissing:", Description: "Kissing Face", Unicode: "1F617", Alias: []string{"love", "like", "face", "3", "valentines", "infatuation", "kiss"}}, ":kissing_cat:": emojiData{Name: ":kissing_cat:", Description: "Kissing Cat Face with Closed Eyes", Unicode: "1F63D", Alias: []string{"animal", "cats", "kiss"}}, ":kissing_closed_eyes:": emojiData{Name: ":kissing_closed_eyes:", Description: "Kissing Face with Closed Eyes", Unicode: "1F61A", Alias: []string{"face", "love", "like", "affection", "valentines", "infatuation", "kiss"}}, ":kissing_heart:": emojiData{Name: ":kissing_heart:", Description: "Face Throwing a Kiss", Unicode: "1F618", Alias: []string{"face", "love", "like", "affection", "valentines", "infatuation", "kiss"}}, ":kissing_smiling_eyes:": emojiData{Name: ":kissing_smiling_eyes:", Description: "Kissing Face with Smiling Eyes", Unicode: "1F619", Alias: []string{"face", "affection", "valentines", "infatuation", "kiss"}}, ":kitchen:": emojiData{Name: ":honey_pot:", Description: "Honey Pot", Unicode: "1F36F", Alias: []string{"bees", "sweet", "kitchen"}}, ":kitten:": emojiData{Name: ":cat:", Description: "Cat Face", Unicode: "1F431", Alias: []string{"animal", "meow", "nature", "pet", "kitten"}}, ":kiwifruit:": emojiData{Name: ":kiwifruit:", Description: "Kiwifruit", Unicode: "1F95D", Alias: []string(nil)}, ":knife:": emojiData{Name: ":hocho:", Description: "Hocho", Unicode: "1F52A", Alias: []string{"knife", "blade", "cutlery", "kitchen", "weapon"}}, ":knife_fork_plate:": emojiData{Name: ":knife_fork_plate:", Description: "Knife Fork Plate", Unicode: "1F37D-FE0F", Alias: []string(nil)}, ":knowledge:": emojiData{Name: ":orange_book:", Description: "Orange Book", Unicode: "1F4D9", Alias: []string{"read", "library", "knowledge", "textbook", "study"}}, ":koala:": emojiData{Name: ":koala:", Description: "Koala", Unicode: "1F428", Alias: []string{"animal", "nature"}}, ":kod:": emojiData{Name: ":crown:", Description: "Crown", Unicode: "1F451", Alias: []string{"king", "kod", "leader", "royalty", "lord"}}, ":koinobori:": emojiData{Name: ":flags:", Description: "Carp Streamer", Unicode: "1F38F", Alias: []string{"fish", "japanese", "koinobori", "carp", "banner"}}, ":koko:": emojiData{Name: ":koko:", Description: "Squared Katakana Koko", Unicode: "1F201", Alias: []string{"blue-square", "here", "katakana", "japanese", "destination"}}, ":korea:": emojiData{Name: ":kr:", Description: "South Korea Flag", Unicode: "1F1F0-1F1F7", Alias: []string{"south", "korea", "nation", "flag", "country", "banner"}}, ":kr:": emojiData{Name: ":kr:", Description: "South Korea Flag", Unicode: "1F1F0-1F1F7", Alias: []string{"south", "korea", "nation", "flag", "country", "banner"}}, ":kyoto:": emojiData{Name: ":shinto_shrine:", Description: "Shinto Shrine", Unicode: "26E9-FE0F", Alias: []string{"temple", "japan", "kyoto"}}, ":label:": emojiData{Name: ":bookmark:", Description: "Bookmark", Unicode: "1F516", Alias: []string{"favorite", "label", "save"}}, ":laboratory:": emojiData{Name: ":microscope:", Description: "Microscope", Unicode: "1F52C", Alias: []string{"laboratory", "experiment", "zoomin", "science", "study"}}, ":lady:": emojiData{Name: ":older_woman:", Description: "Older Woman", Unicode: "1F475", Alias: []string{"human", "female", "women", "lady", "old", "elder", "senior"}}, ":ladybug:": emojiData{Name: ":beetle:", Description: "Lady Beetle", Unicode: "1F41E", Alias: []string{"animal", "insect", "nature", "ladybug"}}, ":laptop:": emojiData{Name: ":computer:", Description: "Personal Computer", Unicode: "1F4BB", Alias: []string{"technology", "laptop", "screen", "display", "monitor"}}, ":large_blue_circle:": emojiData{Name: ":large_blue_circle:", Description: "Large Blue Circle", Unicode: "1F535", Alias: []string{"shape", "icon", "button"}}, ":large_blue_diamond:": emojiData{Name: ":large_blue_diamond:", Description: "Large Blue Diamond", Unicode: "1F537", Alias: []string{"shape", "jewel", "gem"}}, ":large_orange_diamond:": emojiData{Name: ":large_orange_diamond:", Description: "Large Orange Diamond", Unicode: "1F536", Alias: []string{"shape", "jewel", "gem"}}, ":last_quarter_moon:": emojiData{Name: ":last_quarter_moon:", Description: "Last Quarter Moon Symbol", Unicode: "1F317", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":last_quarter_moon_with_face:": emojiData{Name: ":last_quarter_moon_with_face:", Description: "Last Quarter Moon with Face", Unicode: "1F31C", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":late:": emojiData{Name: ":clock12:", Description: "Clock Face Twelve Oclock", Unicode: "1F55B", Alias: []string{"time", "noon", "midnight", "midday", "late", "early", "schedule"}}, ":latin_cross:": emojiData{Name: ":latin_cross:", Description: "Latin Cross", Unicode: "271D-FE0F", Alias: []string{"christianity"}}, ":latte:": emojiData{Name: ":coffee:", Description: "Hot Beverage", Unicode: "2615", Alias: []string{"beverage", "caffeine", "latte", "espresso"}}, ":laugh:": emojiData{Name: ":smile:", Description: "Smiling Face with Open Mouth and Smiling Eyes", Unicode: "1F604", Alias: []string{"face", "happy", "joy", "funny", "haha", "laugh", "like", ":D", ":)"}}, ":laughing:": emojiData{Name: ":laughing:", Description: "Smiling Face with Open Mouth and Tightly-Closed Eyes", Unicode: "1F606", Alias: []string{"happy", "joy", "lol", "satisfied", "haha", "face", "glad", "XD", "laugh"}}, ":launch:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":law:": emojiData{Name: ":police_car:", Description: "Police Car", Unicode: "1F693", Alias: []string{"vehicle", "cars", "transportation", "law", "legal", "enforcement"}}, ":lawn:": emojiData{Name: ":leaves:", Description: "Leaf Fluttering in Wind", Unicode: "1F343", Alias: []string{"nature", "plant", "tree", "vegetable", "grass", "lawn", "spring"}}, ":leader:": emojiData{Name: ":crown:", Description: "Crown", Unicode: "1F451", Alias: []string{"king", "kod", "leader", "royalty", "lord"}}, ":learn:": emojiData{Name: ":closed_book:", Description: "Closed Book", Unicode: "1F4D5", Alias: []string{"read", "library", "knowledge", "textbook", "learn"}}, ":leaves:": emojiData{Name: ":fallen_leaf:", Description: "Fallen Leaf", Unicode: "1F342", Alias: []string{"nature", "plant", "vegetable", "leaves"}}, ":ledger:": emojiData{Name: ":ledger:", Description: "Ledger", Unicode: "1F4D2", Alias: []string{"notes", "paper"}}, ":left-facing_fist:": emojiData{Name: ":left-facing_fist:", Description: "Left-Facing Fist", Unicode: "1F91B", Alias: []string(nil)}, ":left:": emojiData{Name: ":arrow_backward:", Description: "Black Left-Pointing Triangle", Unicode: "25C0-FE0F", Alias: []string{"blue-square", "left", "direction"}}, ":left_luggage:": emojiData{Name: ":left_luggage:", Description: "Left Luggage", Unicode: "1F6C5", Alias: []string{"blue-square", "travel"}}, ":left_right_arrow:": emojiData{Name: ":left_right_arrow:", Description: "Left Right Arrow", Unicode: "2194-FE0F", Alias: []string{"shape", "direction", "horizontal", "sideways"}}, ":left_speech_bubble:": emojiData{Name: ":left_speech_bubble:", Description: "Left Speech Bubble", Unicode: "1F5E8-FE0F", Alias: []string{"words", "message", "talk", "chatting"}}, ":leftwards_arrow_with_hook:": emojiData{Name: ":leftwards_arrow_with_hook:", Description: "Leftwards Arrow with Hook", Unicode: "21A9-FE0F", Alias: []string{"back", "return", "blue-square", "undo", "enter"}}, ":legal:": emojiData{Name: ":police_car:", Description: "Police Car", Unicode: "1F693", Alias: []string{"vehicle", "cars", "transportation", "law", "legal", "enforcement"}}, ":lemon:": emojiData{Name: ":lemon:", Description: "Lemon", Unicode: "1F34B", Alias: []string{"fruit", "nature"}}, ":length:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":leo:": emojiData{Name: ":leo:", Description: "Leo", Unicode: "264C", Alias: []string{"sign", "purple-square", "zodiac", "astrology"}}, ":leopard:": emojiData{Name: ":leopard:", Description: "Leopard", Unicode: "1F406", Alias: []string{"animal", "nature"}}, ":less:": emojiData{Name: ":heavy_minus_sign:", Description: "Heavy Minus Sign", Unicode: "2796", Alias: []string{"math", "calculation", "subtract", "less"}}, ":letter:": emojiData{Name: ":information_source:", Description: "Information Source", Unicode: "2139-FE0F", Alias: []string{"blue-square", "alphabet", "letter"}}, ":lettuce:": emojiData{Name: ":green_salad:", Description: "Green Salad", Unicode: "1F957", Alias: []string{"food", "healthy", "lettuce"}}, ":level_slider:": emojiData{Name: ":level_slider:", Description: "Level Slider", Unicode: "1F39A-FE0F", Alias: []string{"scale"}}, ":libra:": emojiData{Name: ":libra:", Description: "Libra", Unicode: "264E", Alias: []string{"sign", "purple-square", "zodiac", "astrology"}}, ":library:": emojiData{Name: ":orange_book:", Description: "Orange Book", Unicode: "1F4D9", Alias: []string{"read", "library", "knowledge", "textbook", "study"}}, ":license:": emojiData{Name: ":copyright:", Description: "Copyright Sign", Unicode: "00A9-FE0F", Alias: []string{"ip", "license", "circle", "law", "legal"}}, ":lie:": emojiData{Name: ":lying_face:", Description: "Lying Face", Unicode: "1F925", Alias: []string{"face", "lie", "pinocchio"}}, ":light:": emojiData{Name: ":izakaya_lantern:", Description: "Izakaya Lantern", Unicode: "1F3EE", Alias: []string{"light", "paper", "halloween", "spooky"}}, ":light_rail:": emojiData{Name: ":light_rail:", Description: "Light Rail", Unicode: "1F688", Alias: []string{"transportation", "vehicle"}}, ":lightning bolt:": emojiData{Name: ":zap:", Description: "High Voltage Sign", Unicode: "26A1", Alias: []string{"thunder", "weather", "lightning bolt", "fast"}}, ":lightning:": emojiData{Name: ":lightning:", Description: "Lightning", Unicode: "1F329-FE0F", Alias: []string(nil)}, ":like:": emojiData{Name: ":kissing:", Description: "Kissing Face", Unicode: "1F617", Alias: []string{"love", "like", "face", "3", "valentines", "infatuation", "kiss"}}, ":limbs:": emojiData{Name: ":ok_hand:", Description: "Ok Hand Sign", Unicode: "1F44C", Alias: []string{"fingers", "limbs", "perfect", "ok", "okay"}}, ":limit:": emojiData{Name: ":no_entry_sign:", Description: "No Entry Sign", Unicode: "1F6AB", Alias: []string{"forbid", "stop", "limit", "denied", "disallow", "circle"}}, ":line:": emojiData{Name: ":wavy_dash:", Description: "Wavy Dash", Unicode: "3030-FE0F", Alias: []string{"draw", "line", "moustache", "mustache", "squiggle", "scribble"}}, ":link:": emojiData{Name: ":link:", Description: "Link Symbol", Unicode: "1F517", Alias: []string{"rings", "url"}}, ":linked_paperclips:": emojiData{Name: ":linked_paperclips:", Description: "Linked Paperclips", Unicode: "1F587-FE0F", Alias: []string(nil)}, ":lion_face:": emojiData{Name: ":lion_face:", Description: "Lion Face", Unicode: "1F981", Alias: []string(nil)}, ":lips:": emojiData{Name: ":kiss:", Description: "Kiss Mark", Unicode: "1F48B", Alias: []string{"face", "lips", "love", "like", "affection", "valentines"}}, ":lipstick:": emojiData{Name: ":lipstick:", Description: "Lipstick", Unicode: "1F484", Alias: []string{"female", "girl", "fashion", "woman"}}, ":liquid:": emojiData{Name: ":potable_water:", Description: "Potable Water Symbol", Unicode: "1F6B0", Alias: []string{"blue-square", "liquid", "restroom", "cleaning", "faucet"}}, ":liquor:": emojiData{Name: ":tumbler_glass:", Description: "Tumbler Glass", Unicode: "1F943", Alias: []string{"drink", "beverage", "drunk", "alcohol", "liquor", "booze", "bourbon", "scotch", "whisky", "glass", "shot"}}, ":listen:": emojiData{Name: ":ear:", Description: "Ear", Unicode: "1F442", Alias: []string{"face", "hear", "sound", "listen"}}, ":literature:": emojiData{Name: ":books:", Description: "Books", Unicode: "1F4DA", Alias: []string{"literature", "library", "study"}}, ":lizard:": emojiData{Name: ":crocodile:", Description: "Crocodile", Unicode: "1F40A", Alias: []string{"animal", "nature", "reptile", "lizard", "alligator"}}, ":load:": emojiData{Name: ":open_file_folder:", Description: "Open File Folder", Unicode: "1F4C2", Alias: []string{"documents", "load"}}, ":location:": emojiData{Name: ":world_map:", Description: "World Map", Unicode: "1F5FA-FE0F", Alias: []string{"location", "direction"}}, ":lock:": emojiData{Name: ":chains:", Description: "Chains", Unicode: "26D3-FE0F", Alias: []string{"lock", "arrest"}}, ":lock_with_ink_pen:": emojiData{Name: ":lock_with_ink_pen:", Description: "Lock with Ink Pen", Unicode: "1F50F", Alias: []string{"security", "secret"}}, ":lol:": emojiData{Name: ":laughing:", Description: "Smiling Face with Open Mouth and Tightly-Closed Eyes", Unicode: "1F606", Alias: []string{"happy", "joy", "lol", "satisfied", "haha", "face", "glad", "XD", "laugh"}}, ":lollipop:": emojiData{Name: ":lollipop:", Description: "Lollipop", Unicode: "1F36D", Alias: []string{"food", "snack", "candy", "sweet"}}, ":lolly:": emojiData{Name: ":candy:", Description: "Candy", Unicode: "1F36C", Alias: []string{"snack", "dessert", "sweet", "lolly"}}, ":londoneye:": emojiData{Name: ":ferris_wheel:", Description: "Ferris Wheel", Unicode: "1F3A1", Alias: []string{"photo", "carnival", "londoneye"}}, ":loo:": emojiData{Name: ":womens:", Description: "Womens Symbol", Unicode: "1F6BA", Alias: []string{"purple-square", "woman", "female", "toilet", "loo", "restroom", "gender"}}, ":look:": emojiData{Name: ":eyes:", Description: "Eyes", Unicode: "1F440", Alias: []string{"look", "watch", "stalk", "peek", "see"}}, ":loop:": emojiData{Name: ":loop:", Description: "Double Curly Loop", Unicode: "27BF", Alias: []string{"tape", "cassette"}}, ":lord:": emojiData{Name: ":crown:", Description: "Crown", Unicode: "1F451", Alias: []string{"king", "kod", "leader", "royalty", "lord"}}, ":loud_sound:": emojiData{Name: ":loud_sound:", Description: "Speaker with Three Sound Waves", Unicode: "1F50A", Alias: []string{"volume", "noise", "noisy", "speaker", "broadcast"}}, ":loudspeaker:": emojiData{Name: ":loudspeaker:", Description: "Public Address Loudspeaker", Unicode: "1F4E2", Alias: []string{"volume", "sound"}}, ":love:": emojiData{Name: ":kissing:", Description: "Kissing Face", Unicode: "1F617", Alias: []string{"love", "like", "face", "3", "valentines", "infatuation", "kiss"}}, ":love_hotel:": emojiData{Name: ":love_hotel:", Description: "Love Hotel", Unicode: "1F3E9", Alias: []string{"like", "affection", "dating"}}, ":love_letter:": emojiData{Name: ":love_letter:", Description: "Love Letter", Unicode: "1F48C", Alias: []string{"email", "like", "affection", "envelope", "valentines"}}, ":low_brightness:": emojiData{Name: ":low_brightness:", Description: "Low Brightness Symbol", Unicode: "1F505", Alias: []string{"sun", "afternoon", "warm", "summer"}}, ":lower_left_ballpoint_pen:": emojiData{Name: ":writing_hand:", Description: "Writing Hand", Unicode: "270D-FE0F", Alias: []string{"lower_left_ballpoint_pen", "stationery", "write", "compose"}}, ":lower_left_crayon:": emojiData{Name: ":lower_left_crayon:", Description: "Lower Left Crayon", Unicode: "1F58D-FE0F", Alias: []string(nil)}, ":lower_left_fountain_pen:": emojiData{Name: ":lower_left_fountain_pen:", Description: "Lower Left Fountain Pen", Unicode: "1F58B-FE0F", Alias: []string(nil)}, ":lower_left_paintbrush:": emojiData{Name: ":lower_left_paintbrush:", Description: "Lower Left Paintbrush", Unicode: "1F58C-FE0F", Alias: []string(nil)}, ":luck:": emojiData{Name: ":racehorse:", Description: "Horse", Unicode: "1F40E", Alias: []string{"animal", "gamble", "luck"}}, ":lucky:": emojiData{Name: ":crossed_fingers:", Description: "Hand with Index and Middle Fingers Crossed", Unicode: "1F91E", Alias: []string{"good", "lucky"}}, ":lying_face:": emojiData{Name: ":lying_face:", Description: "Lying Face", Unicode: "1F925", Alias: []string{"face", "lie", "pinocchio"}}, ":m:": emojiData{Name: ":m:", Description: "Circled Latin Capital Letter M", Unicode: "24C2-FE0F", Alias: []string{"alphabet", "blue-circle", "letter"}}, ":mac:": emojiData{Name: ":apple:", Description: "Red Apple", Unicode: "1F34E", Alias: []string{"fruit", "mac", "school"}}, ":mad:": emojiData{Name: ":anger:", Description: "Anger Symbol", Unicode: "1F4A2", Alias: []string{"angry", "mad"}}, ":mag:": emojiData{Name: ":mag:", Description: "Left-Pointing Magnifying Glass", Unicode: "1F50D", Alias: []string{"search", "zoom", "find", "detective"}}, ":mag_right:": emojiData{Name: ":mag_right:", Description: "Right-Pointing Magnifying Glass", Unicode: "1F50E", Alias: []string{"search", "zoom", "find", "detective"}}, ":mage:": emojiData{Name: ":mage:", Description: "Mage", Unicode: "1F9D9", Alias: []string(nil)}, ":magic:": emojiData{Name: ":spades:", Description: "Black Spade Suit", Unicode: "2660-FE0F", Alias: []string{"poker", "cards", "suits", "magic"}}, ":mahjong:": emojiData{Name: ":mahjong:", Description: "Mahjong Tile Red Dragon", Unicode: "1F004", Alias: []string{"game", "play", "chinese", "kanji"}}, ":mail:": emojiData{Name: ":package:", Description: "Package", Unicode: "1F4E6", Alias: []string{"mail", "gift", "cardboard", "box", "moving"}}, ":mailbox:": emojiData{Name: ":mailbox:", Description: "Closed Mailbox with Raised Flag", Unicode: "1F4EB", Alias: []string{"email", "inbox", "communication"}}, ":mailbox_closed:": emojiData{Name: ":mailbox_closed:", Description: "Closed Mailbox with Lowered Flag", Unicode: "1F4EA", Alias: []string{"email", "communication", "inbox"}}, ":mailbox_with_mail:": emojiData{Name: ":mailbox_with_mail:", Description: "Open Mailbox with Raised Flag", Unicode: "1F4EC", Alias: []string{"email", "inbox", "communication"}}, ":mailbox_with_no_mail:": emojiData{Name: ":mailbox_with_no_mail:", Description: "Open Mailbox with Lowered Flag", Unicode: "1F4ED", Alias: []string{"email", "inbox"}}, ":ainer:": emojiData{Name: ":wrench:", Description: "Wrench", Unicode: "1F527", Alias: []string{"tools", "diy", "ikea", "fix", "ainer"}}, ":male-artist:": emojiData{Name: ":male-artist:", Description: "Male Artist", Unicode: "1F468-200D-1F3A8", Alias: []string(nil)}, ":male-astronaut:": emojiData{Name: ":male-astronaut:", Description: "Male Astronaut", Unicode: "1F468-200D-1F680", Alias: []string(nil)}, ":male-construction-worker:": emojiData{Name: ":male-construction-worker:", Description: "Male Construction Worker", Unicode: "1F477-200D-2642-FE0F", Alias: []string(nil)}, ":male-cook:": emojiData{Name: ":male-cook:", Description: "Male Cook", Unicode: "1F468-200D-1F373", Alias: []string(nil)}, ":male-detective:": emojiData{Name: ":male-detective:", Description: "Male Detective", Unicode: "1F575-FE0F-200D-2642-FE0F", Alias: []string(nil)}, ":male-doctor:": emojiData{Name: ":male-doctor:", Description: "Male Doctor", Unicode: "1F468-200D-2695-FE0F", Alias: []string(nil)}, ":male-factory-worker:": emojiData{Name: ":male-factory-worker:", Description: "Male Factory Worker", Unicode: "1F468-200D-1F3ED", Alias: []string(nil)}, ":male-farmer:": emojiData{Name: ":male-farmer:", Description: "Male Farmer", Unicode: "1F468-200D-1F33E", Alias: []string(nil)}, ":male-firefighter:": emojiData{Name: ":male-firefighter:", Description: "Male Firefighter", Unicode: "1F468-200D-1F692", Alias: []string(nil)}, ":male-guard:": emojiData{Name: ":male-guard:", Description: "Male Guard", Unicode: "1F482-200D-2642-FE0F", Alias: []string(nil)}, ":male-judge:": emojiData{Name: ":male-judge:", Description: "Male Judge", Unicode: "1F468-200D-2696-FE0F", Alias: []string(nil)}, ":male-mechanic:": emojiData{Name: ":male-mechanic:", Description: "Male Mechanic", Unicode: "1F468-200D-1F527", Alias: []string(nil)}, ":male-office-worker:": emojiData{Name: ":male-office-worker:", Description: "Male Office Worker", Unicode: "1F468-200D-1F4BC", Alias: []string(nil)}, ":male-pilot:": emojiData{Name: ":male-pilot:", Description: "Male Pilot", Unicode: "1F468-200D-2708-FE0F", Alias: []string(nil)}, ":male-police-officer:": emojiData{Name: ":male-police-officer:", Description: "Male Police Officer", Unicode: "1F46E-200D-2642-FE0F", Alias: []string(nil)}, ":male-scientist:": emojiData{Name: ":male-scientist:", Description: "Male Scientist", Unicode: "1F468-200D-1F52C", Alias: []string(nil)}, ":male-singer:": emojiData{Name: ":male-singer:", Description: "Male Singer", Unicode: "1F468-200D-1F3A4", Alias: []string(nil)}, ":male-student:": emojiData{Name: ":male-student:", Description: "Male Student", Unicode: "1F468-200D-1F393", Alias: []string(nil)}, ":male-teacher:": emojiData{Name: ":male-teacher:", Description: "Male Teacher", Unicode: "1F468-200D-1F3EB", Alias: []string(nil)}, ":male-technologist:": emojiData{Name: ":male-technologist:", Description: "Male Technologist", Unicode: "1F468-200D-1F4BB", Alias: []string(nil)}, ":male:": emojiData{Name: ":guardsman:", Description: "Guardsman", Unicode: "1F482", Alias: []string{"uk", "gb", "british", "male", "guy", "royal"}}, ":male_elf:": emojiData{Name: ":male_elf:", Description: "Male Elf", Unicode: "1F9DD-200D-2642-FE0F", Alias: []string(nil)}, ":male_fairy:": emojiData{Name: ":male_fairy:", Description: "Male Fairy", Unicode: "1F9DA-200D-2642-FE0F", Alias: []string(nil)}, ":male_genie:": emojiData{Name: ":male_genie:", Description: "Male Genie", Unicode: "1F9DE-200D-2642-FE0F", Alias: []string(nil)}, ":male_mage:": emojiData{Name: ":male_mage:", Description: "Male Mage", Unicode: "1F9D9-200D-2642-FE0F", Alias: []string(nil)}, ":male_sign:": emojiData{Name: ":male_sign:", Description: "Male Sign", Unicode: "2642-FE0F", Alias: []string(nil)}, ":male_vampire:": emojiData{Name: ":male_vampire:", Description: "Male Vampire", Unicode: "1F9DB-200D-2642-FE0F", Alias: []string(nil)}, ":male_zombie:": emojiData{Name: ":male_zombie:", Description: "Male Zombie", Unicode: "1F9DF-200D-2642-FE0F", Alias: []string(nil)}, ":mall:": emojiData{Name: ":department_store:", Description: "Department Store", Unicode: "1F3EC", Alias: []string{"building", "shopping", "mall"}}, ":mallard:": emojiData{Name: ":duck:", Description: "Duck", Unicode: "1F986", Alias: []string{"animal", "nature", "bird", "mallard"}}, ":man-biking:": emojiData{Name: ":man-biking:", Description: "Man Biking", Unicode: "1F6B4-200D-2642-FE0F", Alias: []string(nil)}, ":man-bouncing-ball:": emojiData{Name: ":man-bouncing-ball:", Description: "Man Bouncing Ball", Unicode: "26F9-FE0F-200D-2642-FE0F", Alias: []string(nil)}, ":man-bowing:": emojiData{Name: ":man-bowing:", Description: "Man Bowing", Unicode: "1F647-200D-2642-FE0F", Alias: []string(nil)}, ":man-boy-boy:": emojiData{Name: ":man-boy-boy:", Description: "Man Boy Boy", Unicode: "1F468-200D-1F466-200D-1F466", Alias: []string(nil)}, ":man-boy:": emojiData{Name: ":man-boy:", Description: "Man Boy", Unicode: "1F468-200D-1F466", Alias: []string(nil)}, ":man-cartwheeling:": emojiData{Name: ":man-cartwheeling:", Description: "Man Cartwheeling", Unicode: "1F938-200D-2642-FE0F", Alias: []string(nil)}, ":man-facepalming:": emojiData{Name: ":man-facepalming:", Description: "Man Facepalming", Unicode: "1F926-200D-2642-FE0F", Alias: []string(nil)}, ":man-frowning:": emojiData{Name: ":man-frowning:", Description: "Man Frowning", Unicode: "1F64D-200D-2642-FE0F", Alias: []string(nil)}, ":man-gesturing-no:": emojiData{Name: ":man-gesturing-no:", Description: "Man Gesturing No", Unicode: "1F645-200D-2642-FE0F", Alias: []string(nil)}, ":man-gesturing-ok:": emojiData{Name: ":man-gesturing-ok:", Description: "Man Gesturing Ok", Unicode: "1F646-200D-2642-FE0F", Alias: []string(nil)}, ":man-getting-haircut:": emojiData{Name: ":man-getting-haircut:", Description: "Man Getting Haircut", Unicode: "1F487-200D-2642-FE0F", Alias: []string(nil)}, ":man-getting-massage:": emojiData{Name: ":man-getting-massage:", Description: "Man Getting Massage", Unicode: "1F486-200D-2642-FE0F", Alias: []string(nil)}, ":man-girl-boy:": emojiData{Name: ":man-girl-boy:", Description: "Man Girl Boy", Unicode: "1F468-200D-1F467-200D-1F466", Alias: []string(nil)}, ":man-girl-girl:": emojiData{Name: ":man-girl-girl:", Description: "Man Girl Girl", Unicode: "1F468-200D-1F467-200D-1F467", Alias: []string(nil)}, ":man-girl:": emojiData{Name: ":man-girl:", Description: "Man Girl", Unicode: "1F468-200D-1F467", Alias: []string(nil)}, ":man-golfing:": emojiData{Name: ":man-golfing:", Description: "Man Golfing", Unicode: "1F3CC-FE0F-200D-2642-FE0F", Alias: []string(nil)}, ":man-heart-man:": emojiData{Name: ":man-heart-man:", Description: "Man Heart Man", Unicode: "1F468-200D-2764-FE0F-200D-1F468", Alias: []string(nil)}, ":man-juggling:": emojiData{Name: ":man-juggling:", Description: "Man Juggling", Unicode: "1F939-200D-2642-FE0F", Alias: []string(nil)}, ":man-kiss-man:": emojiData{Name: ":man-kiss-man:", Description: "Man Kiss Man", Unicode: "1F468-200D-2764-FE0F-200D-1F48B-200D-1F468", Alias: []string(nil)}, ":man-lifting-weights:": emojiData{Name: ":man-lifting-weights:", Description: "Man Lifting Weights", Unicode: "1F3CB-FE0F-200D-2642-FE0F", Alias: []string(nil)}, ":man-man-boy-boy:": emojiData{Name: ":man-man-boy-boy:", Description: "Man Man Boy Boy", Unicode: "1F468-200D-1F468-200D-1F466-200D-1F466", Alias: []string(nil)}, ":man-man-boy:": emojiData{Name: ":man-man-boy:", Description: "Man Man Boy", Unicode: "1F468-200D-1F468-200D-1F466", Alias: []string(nil)}, ":man-man-girl-boy:": emojiData{Name: ":man-man-girl-boy:", Description: "Man Man Girl Boy", Unicode: "1F468-200D-1F468-200D-1F467-200D-1F466", Alias: []string(nil)}, ":man-man-girl-girl:": emojiData{Name: ":man-man-girl-girl:", Description: "Man Man Girl Girl", Unicode: "1F468-200D-1F468-200D-1F467-200D-1F467", Alias: []string(nil)}, ":man-man-girl:": emojiData{Name: ":man-man-girl:", Description: "Man Man Girl", Unicode: "1F468-200D-1F468-200D-1F467", Alias: []string(nil)}, ":man-mountain-biking:": emojiData{Name: ":man-mountain-biking:", Description: "Man Mountain Biking", Unicode: "1F6B5-200D-2642-FE0F", Alias: []string(nil)}, ":man-playing-handball:": emojiData{Name: ":man-playing-handball:", Description: "Man Playing Handball", Unicode: "1F93E-200D-2642-FE0F", Alias: []string(nil)}, ":man-playing-water-polo:": emojiData{Name: ":man-playing-water-polo:", Description: "Man Playing Water Polo", Unicode: "1F93D-200D-2642-FE0F", Alias: []string(nil)}, ":man-pouting:": emojiData{Name: ":man-pouting:", Description: "Man Pouting", Unicode: "1F64E-200D-2642-FE0F", Alias: []string(nil)}, ":man-raising-hand:": emojiData{Name: ":man-raising-hand:", Description: "Man Raising Hand", Unicode: "1F64B-200D-2642-FE0F", Alias: []string(nil)}, ":man-rowing-boat:": emojiData{Name: ":man-rowing-boat:", Description: "Man Rowing Boat", Unicode: "1F6A3-200D-2642-FE0F", Alias: []string(nil)}, ":man-running:": emojiData{Name: ":man-running:", Description: "Man Running", Unicode: "1F3C3-200D-2642-FE0F", Alias: []string(nil)}, ":man-shrugging:": emojiData{Name: ":man-shrugging:", Description: "Man Shrugging", Unicode: "1F937-200D-2642-FE0F", Alias: []string(nil)}, ":man-surfing:": emojiData{Name: ":man-surfing:", Description: "Man Surfing", Unicode: "1F3C4-200D-2642-FE0F", Alias: []string(nil)}, ":man-swimming:": emojiData{Name: ":man-swimming:", Description: "Man Swimming", Unicode: "1F3CA-200D-2642-FE0F", Alias: []string(nil)}, ":man-tipping-hand:": emojiData{Name: ":man-tipping-hand:", Description: "Man Tipping Hand", Unicode: "1F481-200D-2642-FE0F", Alias: []string(nil)}, ":man-walking:": emojiData{Name: ":man-walking:", Description: "Man Walking", Unicode: "1F6B6-200D-2642-FE0F", Alias: []string(nil)}, ":man-wearing-turban:": emojiData{Name: ":man-wearing-turban:", Description: "Man Wearing Turban", Unicode: "1F473-200D-2642-FE0F", Alias: []string(nil)}, ":man-with-bunny-ears-partying:": emojiData{Name: ":man-with-bunny-ears-partying:", Description: "Man with Bunny Ears Partying", Unicode: "1F46F-200D-2642-FE0F", Alias: []string(nil)}, ":man-woman-boy-boy:": emojiData{Name: ":man-woman-boy-boy:", Description: "Man Woman Boy Boy", Unicode: "1F468-200D-1F469-200D-1F466-200D-1F466", Alias: []string(nil)}, ":man-woman-boy:": emojiData{Name: ":man-woman-boy:", Description: "Man Woman Boy", Unicode: "1F468-200D-1F469-200D-1F466", Alias: []string(nil)}, ":man-woman-girl-boy:": emojiData{Name: ":man-woman-girl-boy:", Description: "Man Woman Girl Boy", Unicode: "1F468-200D-1F469-200D-1F467-200D-1F466", Alias: []string(nil)}, ":man-woman-girl-girl:": emojiData{Name: ":man-woman-girl-girl:", Description: "Man Woman Girl Girl", Unicode: "1F468-200D-1F469-200D-1F467-200D-1F467", Alias: []string(nil)}, ":man-woman-girl:": emojiData{Name: ":man-woman-girl:", Description: "Man Woman Girl", Unicode: "1F468-200D-1F469-200D-1F467", Alias: []string(nil)}, ":man-wrestling:": emojiData{Name: ":man-wrestling:", Description: "Man Wrestling", Unicode: "1F93C-200D-2642-FE0F", Alias: []string(nil)}, ":man:": emojiData{Name: ":prince:", Description: "Prince", Unicode: "1F934", Alias: []string{"boy", "man", "male", "crown", "royal", "king"}}, ":man_climbing:": emojiData{Name: ":man_climbing:", Description: "Man Climbing", Unicode: "1F9D7-200D-2642-FE0F", Alias: []string(nil)}, ":man_dancing:": emojiData{Name: ":man_dancing:", Description: "Man Dancing", Unicode: "1F57A", Alias: []string{"male", "boy", "fun", "dancer"}}, ":man_in_business_suit_levitating:": emojiData{Name: ":man_in_business_suit_levitating:", Description: "Man in Business Suit Levitating", Unicode: "1F574-FE0F", Alias: []string(nil)}, ":man_in_lotus_position:": emojiData{Name: ":man_in_lotus_position:", Description: "Man in Lotus Position", Unicode: "1F9D8-200D-2642-FE0F", Alias: []string(nil)}, ":man_in_steamy_room:": emojiData{Name: ":man_in_steamy_room:", Description: "Man in Steamy Room", Unicode: "1F9D6-200D-2642-FE0F", Alias: []string(nil)}, ":man_in_tuxedo:": emojiData{Name: ":man_in_tuxedo:", Description: "Man in Tuxedo", Unicode: "1F935", Alias: []string{"couple", "marriage", "wedding", "groom"}}, ":man_with_gua_pi_mao:": emojiData{Name: ":man_with_gua_pi_mao:", Description: "Man with Gua Pi Mao", Unicode: "1F472", Alias: []string{"male", "boy", "chinese"}}, ":man_with_turban:": emojiData{Name: ":man_with_turban:", Description: "Man with Turban", Unicode: "1F473", Alias: []string{"male", "indian", "hinduism", "arabs"}}, ":manicure:": emojiData{Name: ":nail_care:", Description: "Nail Polish", Unicode: "1F485", Alias: []string{"beauty", "manicure", "finger", "fashion", "nail"}}, ":mans_shoe:": emojiData{Name: ":mans_shoe:", Description: "Mans Shoe", Unicode: "1F45E", Alias: []string{"fashion", "male"}}, ":mantelpiece_clock:": emojiData{Name: ":mantelpiece_clock:", Description: "Mantelpiece Clock", Unicode: "1F570-FE0F", Alias: []string{"time"}}, ":map:": emojiData{Name: ":round_pushpin:", Description: "Round Pushpin", Unicode: "1F4CD", Alias: []string{"stationery", "location", "map", "here"}}, ":maple_leaf:": emojiData{Name: ":maple_leaf:", Description: "Maple Leaf", Unicode: "1F341", Alias: []string{"nature", "plant", "vegetable", "ca", "fall"}}, ":mark:": emojiData{Name: ":triangular_flag_on_post:", Description: "Triangular Flag on Post", Unicode: "1F6A9", Alias: []string{"mark", "milestone", "place"}}, ":marriage:": emojiData{Name: ":wedding:", Description: "Wedding", Unicode: "1F492", Alias: []string{"love", "like", "affection", "couple", "marriage", "bride", "groom"}}, ":martial_arts_uniform:": emojiData{Name: ":martial_arts_uniform:", Description: "Martial Arts Uniform", Unicode: "1F94B", Alias: []string{"judo", "karate", "taekwondo"}}, ":mask:": emojiData{Name: ":mask:", Description: "Face with Medical Mask", Unicode: "1F637", Alias: []string{"face", "sick", "ill", "disease"}}, ":massage:": emojiData{Name: ":relaxed:", Description: "White Smiling Face", Unicode: "263A-FE0F", Alias: []string{"face", "blush", "massage", "happiness"}}, ":math:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":mcdonalds:": emojiData{Name: ":hamburger:", Description: "Hamburger", Unicode: "1F354", Alias: []string{"meat", "fast food", "beef", "cheeseburger", "mcdonalds", "burger king"}}, ":mean:": emojiData{Name: ":smirk:", Description: "Smirking Face", Unicode: "1F60F", Alias: []string{"face", "smile", "mean", "prank", "smug", "sarcasm"}}, ":meat:": emojiData{Name: ":dango:", Description: "Dango", Unicode: "1F361", Alias: []string{"food", "dessert", "sweet", "japanese", "barbecue", "meat"}}, ":meat_on_bone:": emojiData{Name: ":meat_on_bone:", Description: "Meat on Bone", Unicode: "1F356", Alias: []string{"good", "food", "drumstick"}}, ":mecca:": emojiData{Name: ":kaaba:", Description: "Kaaba", Unicode: "1F54B", Alias: []string{"mecca", "mosque", "islam"}}, ":medal:": emojiData{Name: ":medal:", Description: "Medal", Unicode: "1F396-FE0F", Alias: []string(nil)}, ":medical_symbol:": emojiData{Name: ":medical_symbol:", Description: "Medical Symbol", Unicode: "2695-FE0F", Alias: []string(nil)}, ":medicine:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":mega:": emojiData{Name: ":mega:", Description: "Cheering Megaphone", Unicode: "1F4E3", Alias: []string{"sound", "speaker", "volume"}}, ":meh:": emojiData{Name: ":expressionless:", Description: "Expressionless Face", Unicode: "1F611", Alias: []string{"face", "indifferent", "-_-", "meh", "deadpan"}}, ":melon:": emojiData{Name: ":melon:", Description: "Melon", Unicode: "1F348", Alias: []string{"fruit", "nature", "food"}}, ":memo:": emojiData{Name: ":memo:", Description: "Memo", Unicode: "1F4DD", Alias: []string{"write", "documents", "stationery", "pencil", "paper", "writing", "legal", "exam", "quiz", "test", "study", "compose"}}, ":men:": emojiData{Name: ":older_man:", Description: "Older Man", Unicode: "1F474", Alias: []string{"human", "male", "men", "old", "elder", "senior"}}, ":menorah_with_nine_branches:": emojiData{Name: ":menorah_with_nine_branches:", Description: "Menorah with Nine Branches", Unicode: "1F54E", Alias: []string(nil)}, ":mens:": emojiData{Name: ":mens:", Description: "Mens Symbol", Unicode: "1F6B9", Alias: []string{"toilet", "restroom", "wc", "blue-square", "gender", "male"}}, ":meow:": emojiData{Name: ":cat2:", Description: "Cat", Unicode: "1F408", Alias: []string{"animal", "meow", "pet", "cats"}}, ":mermaid:": emojiData{Name: ":mermaid:", Description: "Mermaid", Unicode: "1F9DC-200D-2640-FE0F", Alias: []string(nil)}, ":merman:": emojiData{Name: ":merman:", Description: "Merman", Unicode: "1F9DC-200D-2642-FE0F", Alias: []string(nil)}, ":merperson:": emojiData{Name: ":merperson:", Description: "Merperson", Unicode: "1F9DC", Alias: []string(nil)}, ":message:": emojiData{Name: ":speech_balloon:", Description: "Speech Balloon", Unicode: "1F4AC", Alias: []string{"bubble", "words", "message", "talk", "chatting"}}, ":metro:": emojiData{Name: ":metro:", Description: "Metro", Unicode: "1F687", Alias: []string{"transportation", "blue-square", "mrt", "underground", "tube"}}, ":mexican:": emojiData{Name: ":taco:", Description: "Taco", Unicode: "1F32E", Alias: []string{"food", "mexican"}}, ":microphone:": emojiData{Name: ":microphone:", Description: "Microphone", Unicode: "1F3A4", Alias: []string{"sound", "music", "PA", "sing", "talkshow"}}, ":microscope:": emojiData{Name: ":microscope:", Description: "Microscope", Unicode: "1F52C", Alias: []string{"laboratory", "experiment", "zoomin", "science", "study"}}, ":midday:": emojiData{Name: ":clock12:", Description: "Clock Face Twelve Oclock", Unicode: "1F55B", Alias: []string{"time", "noon", "midnight", "midday", "late", "early", "schedule"}}, ":middle_finger:": emojiData{Name: ":middle_finger:", Description: "Reversed Hand with Middle Finger Extended", Unicode: "1F595", Alias: []string(nil)}, ":midnight:": emojiData{Name: ":clock12:", Description: "Clock Face Twelve Oclock", Unicode: "1F55B", Alias: []string{"time", "noon", "midnight", "midday", "late", "early", "schedule"}}, ":milestone:": emojiData{Name: ":triangular_flag_on_post:", Description: "Triangular Flag on Post", Unicode: "1F6A9", Alias: []string{"mark", "milestone", "place"}}, ":military:": emojiData{Name: ":rosette:", Description: "Rosette", Unicode: "1F3F5-FE0F", Alias: []string{"flower", "decoration", "military"}}, ":milk:": emojiData{Name: ":cow:", Description: "Cow Face", Unicode: "1F42E", Alias: []string{"beef", "ox", "animal", "nature", "moo", "milk"}}, ":milky_way:": emojiData{Name: ":milky_way:", Description: "Milky Way", Unicode: "1F30C", Alias: []string{"photo", "space", "stars"}}, ":minaret:": emojiData{Name: ":mosque:", Description: "Mosque", Unicode: "1F54C", Alias: []string{"islam", "worship", "minaret"}}, ":minibus:": emojiData{Name: ":minibus:", Description: "Minibus", Unicode: "1F690", Alias: []string{"vehicle", "car", "transportation"}}, ":minidisc:": emojiData{Name: ":minidisc:", Description: "Minidisc", Unicode: "1F4BD", Alias: []string{"technology", "record", "data", "disk", "90s"}}, ":minor:": emojiData{Name: ":underage:", Description: "No One Under Eighteen Symbol", Unicode: "1F51E", Alias: []string{"18", "drink", "pub", "night", "minor", "circle"}}, ":mischievous:": emojiData{Name: ":stuck_out_tongue_closed_eyes:", Description: "Face with Stuck-out Tongue and Tightly-Closed Eyes", Unicode: "1F61D", Alias: []string{"face", "prank", "playful", "mischievous", "smile", "tongue"}}, ":moai:": emojiData{Name: ":moyai:", Description: "Moyai", Unicode: "1F5FF", Alias: []string{"rock", "easter island", "moai"}}, ":mobile_phone_off:": emojiData{Name: ":mobile_phone_off:", Description: "Mobile Phone off", Unicode: "1F4F4", Alias: []string{"mute", "orange-square", "silence", "quiet"}}, ":mojito:": emojiData{Name: ":tropical_drink:", Description: "Tropical Drink", Unicode: "1F379", Alias: []string{"beverage", "cocktail", "summer", "beach", "alcohol", "booze", "mojito"}}, ":money:": emojiData{Name: ":bank:", Description: "Bank", Unicode: "1F3E6", Alias: []string{"building", "money", "sales", "cash", "business", "enterprise"}}, ":money_mouth_face:": emojiData{Name: ":money_mouth_face:", Description: "Money-Mouth Face", Unicode: "1F911", Alias: []string{"face", "rich", "dollar", "money"}}, ":money_with_wings:": emojiData{Name: ":money_with_wings:", Description: "Money with Wings", Unicode: "1F4B8", Alias: []string{"dollar", "bills", "payment", "sale"}}, ":moneybag:": emojiData{Name: ":moneybag:", Description: "Money Bag", Unicode: "1F4B0", Alias: []string{"dollar", "payment", "coins", "sale"}}, ":monitor:": emojiData{Name: ":computer:", Description: "Personal Computer", Unicode: "1F4BB", Alias: []string{"technology", "laptop", "screen", "display", "monitor"}}, ":monkey:": emojiData{Name: ":monkey:", Description: "Monkey", Unicode: "1F412", Alias: []string{"animal", "nature", "banana", "circus"}}, ":monkey_face:": emojiData{Name: ":monkey_face:", Description: "Monkey Face", Unicode: "1F435", Alias: []string{"animal", "nature", "circus"}}, ":monorail:": emojiData{Name: ":monorail:", Description: "Monorail", Unicode: "1F69D", Alias: []string{"transportation", "vehicle"}}, ":monster:": emojiData{Name: ":japanese_ogre:", Description: "Japanese Ogre", Unicode: "1F479", Alias: []string{"monster", "red", "mask", "halloween", "scary", "creepy", "devil", "demon", "japanese", "ogre"}}, ":month:": emojiData{Name: ":u6708:", Description: "Squared Cjk Unified Ideograph-6708", Unicode: "1F237-FE0F", Alias: []string{"chinese", "month", "moon", "japanese", "orange-square", "kanji"}}, ":moo:": emojiData{Name: ":cow:", Description: "Cow Face", Unicode: "1F42E", Alias: []string{"beef", "ox", "animal", "nature", "moo", "milk"}}, ":moon:": emojiData{Name: ":u6708:", Description: "Squared Cjk Unified Ideograph-6708", Unicode: "1F237-FE0F", Alias: []string{"chinese", "month", "moon", "japanese", "orange-square", "kanji"}}, ":more:": emojiData{Name: ":heavy_plus_sign:", Description: "Heavy Plus Sign", Unicode: "2795", Alias: []string{"math", "calculation", "addition", "more", "increase"}}, ":morning:": emojiData{Name: ":sun_with_face:", Description: "Sun with Face", Unicode: "1F31E", Alias: []string{"nature", "morning", "sky"}}, ":mortar_board:": emojiData{Name: ":mortar_board:", Description: "Graduation Cap", Unicode: "1F393", Alias: []string{"school", "college", "degree", "university", "graduation", "cap", "hat", "legal", "learn", "education"}}, ":mosque:": emojiData{Name: ":mosque:", Description: "Mosque", Unicode: "1F54C", Alias: []string{"islam", "worship", "minaret"}}, ":mostly_sunny:": emojiData{Name: ":mostly_sunny:", Description: "Mostly Sunny", Unicode: "1F324-FE0F", Alias: []string(nil)}, ":mother christmas:": emojiData{Name: ":mrs_claus:", Description: "Mother Christmas", Unicode: "1F936", Alias: []string{"woman", "female", "xmas", "mother christmas"}}, ":motor_boat:": emojiData{Name: ":motor_boat:", Description: "Motor Boat", Unicode: "1F6E5-FE0F", Alias: []string{"ship"}}, ":motor_scooter:": emojiData{Name: ":motor_scooter:", Description: "Motor Scooter", Unicode: "1F6F5", Alias: []string{"vehicle", "vespa", "sasha"}}, ":motorway:": emojiData{Name: ":motorway:", Description: "Motorway", Unicode: "1F6E3-FE0F", Alias: []string{"road", "cupertino", "interstate", "highway"}}, ":mount_fuji:": emojiData{Name: ":mount_fuji:", Description: "Mount Fuji", Unicode: "1F5FB", Alias: []string{"photo", "mountain", "nature", "japanese"}}, ":mountain:": emojiData{Name: ":mountain:", Description: "Mountain", Unicode: "26F0-FE0F", Alias: []string{"photo", "nature", "environment"}}, ":mountain_bicyclist:": emojiData{Name: ":mountain_bicyclist:", Description: "Mountain Bicyclist", Unicode: "1F6B5", Alias: []string(nil)}, ":mountain_cableway:": emojiData{Name: ":mountain_cableway:", Description: "Mountain Cableway", Unicode: "1F6A0", Alias: []string{"transportation", "vehicle", "ski"}}, ":mountain_railway:": emojiData{Name: ":mountain_railway:", Description: "Mountain Railway", Unicode: "1F69E", Alias: []string{"transportation", "vehicle"}}, ":mouse2:": emojiData{Name: ":mouse2:", Description: "Mouse", Unicode: "1F401", Alias: []string{"animal", "nature", "rodent"}}, ":mouse:": emojiData{Name: ":mouse:", Description: "Mouse Face", Unicode: "1F42D", Alias: []string{"animal", "nature", "cheese_wedge", "rodent"}}, ":moustache:": emojiData{Name: ":wavy_dash:", Description: "Wavy Dash", Unicode: "3030-FE0F", Alias: []string{"draw", "line", "moustache", "mustache", "squiggle", "scribble"}}, ":mouth:": emojiData{Name: ":lips:", Description: "Mouth", Unicode: "1F444", Alias: []string{"mouth", "kiss"}}, ":movie theater:": emojiData{Name: ":popcorn:", Description: "Popcorn", Unicode: "1F37F", Alias: []string{"food", "movie theater", "films", "snack"}}, ":movie:": emojiData{Name: ":clapper:", Description: "Clapper Board", Unicode: "1F3AC", Alias: []string{"movie", "film", "record"}}, ":movie_camera:": emojiData{Name: ":movie_camera:", Description: "Movie Camera", Unicode: "1F3A5", Alias: []string{"film", "record"}}, ":moving:": emojiData{Name: ":package:", Description: "Package", Unicode: "1F4E6", Alias: []string{"mail", "gift", "cardboard", "box", "moving"}}, ":moyai:": emojiData{Name: ":moyai:", Description: "Moyai", Unicode: "1F5FF", Alias: []string{"rock", "easter island", "moai"}}, ":mrs_claus:": emojiData{Name: ":mrs_claus:", Description: "Mother Christmas", Unicode: "1F936", Alias: []string{"woman", "female", "xmas", "mother christmas"}}, ":mrt:": emojiData{Name: ":metro:", Description: "Metro", Unicode: "1F687", Alias: []string{"transportation", "blue-square", "mrt", "underground", "tube"}}, ":munch:": emojiData{Name: ":scream:", Description: "Face Screaming in Fear", Unicode: "1F631", Alias: []string{"face", "munch", "scared", "omg"}}, ":muscle:": emojiData{Name: ":muscle:", Description: "Flexed Biceps", Unicode: "1F4AA", Alias: []string{"arm", "flex", "hand", "summer", "strong", "biceps"}}, ":mushroom:": emojiData{Name: ":mushroom:", Description: "Mushroom", Unicode: "1F344", Alias: []string{"plant", "vegetable"}}, ":music:": emojiData{Name: ":notes:", Description: "Multiple Musical Notes", Unicode: "1F3B6", Alias: []string{"music", "score"}}, ":musical_keyboard:": emojiData{Name: ":musical_keyboard:", Description: "Musical Keyboard", Unicode: "1F3B9", Alias: []string{"piano", "instrument", "compose"}}, ":musical_note:": emojiData{Name: ":musical_note:", Description: "Musical Note", Unicode: "1F3B5", Alias: []string{"score", "tone", "sound"}}, ":musical_score:": emojiData{Name: ":musical_score:", Description: "Musical Score", Unicode: "1F3BC", Alias: []string{"treble", "clef", "compose"}}, ":mustache:": emojiData{Name: ":wavy_dash:", Description: "Wavy Dash", Unicode: "3030-FE0F", Alias: []string{"draw", "line", "moustache", "mustache", "squiggle", "scribble"}}, ":mute:": emojiData{Name: ":mobile_phone_off:", Description: "Mobile Phone off", Unicode: "1F4F4", Alias: []string{"mute", "orange-square", "silence", "quiet"}}, ":myth:": emojiData{Name: ":dragon:", Description: "Dragon", Unicode: "1F409", Alias: []string{"animal", "myth", "nature", "chinese", "green"}}, ":nail:": emojiData{Name: ":nail_care:", Description: "Nail Polish", Unicode: "1F485", Alias: []string{"beauty", "manicure", "finger", "fashion", "nail"}}, ":nail_care:": emojiData{Name: ":nail_care:", Description: "Nail Polish", Unicode: "1F485", Alias: []string{"beauty", "manicure", "finger", "fashion", "nail"}}, ":namaste:": emojiData{Name: ":pray:", Description: "Person with Folded Hands", Unicode: "1F64F", Alias: []string{"please", "hope", "wish", "namaste", "highfive"}}, ":name_badge:": emojiData{Name: ":name_badge:", Description: "Name Badge", Unicode: "1F4DB", Alias: []string{"fire", "forbid"}}, ":nap:": emojiData{Name: ":sleepy:", Description: "Sleepy Face", Unicode: "1F62A", Alias: []string{"face", "tired", "rest", "nap"}}, ":narutomaki:": emojiData{Name: ":fish_cake:", Description: "Fish Cake with Swirl Design", Unicode: "1F365", Alias: []string{"food", "japan", "sea", "beach", "narutomaki", "pink", "swirl", "kamaboko", "surimi", "ramen"}}, ":nation:": emojiData{Name: ":us:", Description: "United States Flag", Unicode: "1F1FA-1F1F8", Alias: []string{"united", "states", "america", "flag", "nation", "country", "banner"}}, ":national_park:": emojiData{Name: ":national_park:", Description: "National Park", Unicode: "1F3DE-FE0F", Alias: []string{"photo", "environment", "nature"}}, ":nature:": emojiData{Name: ":national_park:", Description: "National Park", Unicode: "1F3DE-FE0F", Alias: []string{"photo", "environment", "nature"}}, ":nauseated_face:": emojiData{Name: ":nauseated_face:", Description: "Nauseated Face", Unicode: "1F922", Alias: []string{"face", "vomit", "gross", "green", "sick", "throw up", "ill"}}, ":necktie:": emojiData{Name: ":necktie:", Description: "Necktie", Unicode: "1F454", Alias: []string{"shirt", "suitup", "formal", "fashion", "cloth", "business"}}, ":needle:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":negative_squared_cross_mark:": emojiData{Name: ":negative_squared_cross_mark:", Description: "Negative Squared Cross Mark", Unicode: "274E", Alias: []string{"x", "green-square", "no", "deny"}}, ":nemo:": emojiData{Name: ":tropical_fish:", Description: "Tropical Fish", Unicode: "1F420", Alias: []string{"animal", "swim", "ocean", "beach", "nemo"}}, ":nerd_face:": emojiData{Name: ":nerd_face:", Description: "Nerd Face", Unicode: "1F913", Alias: []string{"face", "nerdy", "geek", "dork"}}, ":nerdy:": emojiData{Name: ":nerd_face:", Description: "Nerd Face", Unicode: "1F913", Alias: []string{"face", "nerdy", "geek", "dork"}}, ":nervous:": emojiData{Name: ":worried:", Description: "Worried Face", Unicode: "1F61F", Alias: []string{"face", "concern", "nervous", ":("}}, ":neutral:": emojiData{Name: ":neutral_face:", Description: "Neutral Face", Unicode: "1F610", Alias: []string{"indifference", "meh", ":|", "neutral"}}, ":neutral_face:": emojiData{Name: ":neutral_face:", Description: "Neutral Face", Unicode: "1F610", Alias: []string{"indifference", "meh", ":|", "neutral"}}, ":new:": emojiData{Name: ":new:", Description: "Squared New", Unicode: "1F195", Alias: []string{"blue-square", "words", "start"}}, ":new_moon:": emojiData{Name: ":new_moon:", Description: "New Moon Symbol", Unicode: "1F311", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":new_moon_with_face:": emojiData{Name: ":new_moon_with_face:", Description: "New Moon with Face", Unicode: "1F31A", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":newspaper:": emojiData{Name: ":newspaper:", Description: "Newspaper", Unicode: "1F4F0", Alias: []string{"press", "headline"}}, ":newyork:": emojiData{Name: ":statue_of_liberty:", Description: "Statue of Liberty", Unicode: "1F5FD", Alias: []string{"american", "newyork"}}, ":next:": emojiData{Name: ":arrow_right:", Description: "Black Rightwards Arrow", Unicode: "27A1-FE0F", Alias: []string{"blue-square", "next"}}, ":ng:": emojiData{Name: ":ng:", Description: "Squared Ng", Unicode: "1F196", Alias: []string{"blue-square", "words", "shape", "icon"}}, ":night life:": emojiData{Name: ":cityscape:", Description: "Cityscape", Unicode: "1F3D9-FE0F", Alias: []string{"photo", "night life", "urban"}}, ":night:": emojiData{Name: ":stars:", Description: "Shooting Star", Unicode: "1F320", Alias: []string{"night", "photo"}}, ":night_with_stars:": emojiData{Name: ":night_with_stars:", Description: "Night with Stars", Unicode: "1F303", Alias: []string{"evening", "city", "downtown"}}, ":nike:": emojiData{Name: ":heavy_check_mark:", Description: "Heavy Check Mark", Unicode: "2714-FE0F", Alias: []string{"ok", "nike", "answer", "yes", "tick"}}, ":nine:": emojiData{Name: ":nine:", Description: "Keycap 9", Unicode: "0039-FE0F-20E3", Alias: []string{"blue-square", "numbers", "9"}}, ":no:": emojiData{Name: ":persevere:", Description: "Persevering Face", Unicode: "1F623", Alias: []string{"face", "sick", "no", "upset", "oops"}}, ":no_bell:": emojiData{Name: ":no_bell:", Description: "Bell with Cancellation Stroke", Unicode: "1F515", Alias: []string{"sound", "volume", "mute", "quiet", "silent"}}, ":no_bicycles:": emojiData{Name: ":no_bicycles:", Description: "No Bicycles", Unicode: "1F6B3", Alias: []string{"cyclist", "prohibited", "circle"}}, ":no_entry:": emojiData{Name: ":no_entry:", Description: "No Entry", Unicode: "26D4", Alias: []string{"limit", "security", "privacy", "bad", "denied", "stop", "circle"}}, ":no_entry_sign:": emojiData{Name: ":no_entry_sign:", Description: "No Entry Sign", Unicode: "1F6AB", Alias: []string{"forbid", "stop", "limit", "denied", "disallow", "circle"}}, ":no_good:": emojiData{Name: ":no_good:", Description: "Face with No Good Gesture", Unicode: "1F645", Alias: []string(nil)}, ":no_mobile_phones:": emojiData{Name: ":no_mobile_phones:", Description: "No Mobile Phones", Unicode: "1F4F5", Alias: []string{"iphone", "mute", "circle"}}, ":no_mouth:": emojiData{Name: ":no_mouth:", Description: "Face Without Mouth", Unicode: "1F636", Alias: []string{"face", "hellokitty"}}, ":no_pedestrians:": emojiData{Name: ":no_pedestrians:", Description: "No Pedestrians", Unicode: "1F6B7", Alias: []string{"rules", "crossing", "walking", "circle"}}, ":no_smoking:": emojiData{Name: ":no_smoking:", Description: "No Smoking Symbol", Unicode: "1F6AD", Alias: []string{"cigarette", "blue-square", "smell", "smoke"}}, ":noise:": emojiData{Name: ":loud_sound:", Description: "Speaker with Three Sound Waves", Unicode: "1F50A", Alias: []string{"volume", "noise", "noisy", "speaker", "broadcast"}}, ":noisy:": emojiData{Name: ":loud_sound:", Description: "Speaker with Three Sound Waves", Unicode: "1F50A", Alias: []string{"volume", "noise", "noisy", "speaker", "broadcast"}}, ":nom:": emojiData{Name: ":yum:", Description: "Face Savouring Delicious Food", Unicode: "1F60B", Alias: []string{"happy", "joy", "tongue", "smile", "face", "silly", "yummy", "nom", "delicious", "savouring"}}, ":non-potable_water:": emojiData{Name: ":non-potable_water:", Description: "Non-Potable Water Symbol", Unicode: "1F6B1", Alias: []string{"drink", "faucet", "tap", "circle"}}, ":noodle:": emojiData{Name: ":spaghetti:", Description: "Spaghetti", Unicode: "1F35D", Alias: []string{"food", "italian", "noodle"}}, ":noon:": emojiData{Name: ":clock12:", Description: "Clock Face Twelve Oclock", Unicode: "1F55B", Alias: []string{"time", "noon", "midnight", "midday", "late", "early", "schedule"}}, ":northeast:": emojiData{Name: ":arrow_upper_right:", Description: "North East Arrow", Unicode: "2197-FE0F", Alias: []string{"blue-square", "point", "direction", "diagonal", "northeast"}}, ":northwest:": emojiData{Name: ":arrow_upper_left:", Description: "North West Arrow", Unicode: "2196-FE0F", Alias: []string{"blue-square", "point", "direction", "diagonal", "northwest"}}, ":nose:": emojiData{Name: ":nose:", Description: "Nose", Unicode: "1F443", Alias: []string{"smell", "sniff"}}, ":note:": emojiData{Name: ":symbols:", Description: "Input Symbol for Symbols", Unicode: "1F523", Alias: []string{"blue-square", "music", "note", "ampersand", "percent", "glyphs", "characters"}}, ":notebook:": emojiData{Name: ":notebook:", Description: "Notebook", Unicode: "1F4D3", Alias: []string{"stationery", "record", "notes", "paper", "study"}}, ":notebook_with_decorative_cover:": emojiData{Name: ":notebook_with_decorative_cover:", Description: "Notebook with Decorative Cover", Unicode: "1F4D4", Alias: []string{"classroom", "notes", "record", "paper", "study"}}, ":notes:": emojiData{Name: ":notes:", Description: "Multiple Musical Notes", Unicode: "1F3B6", Alias: []string{"music", "score"}}, ":nothing:": emojiData{Name: ":u7121:", Description: "Squared Cjk Unified Ideograph-7121", Unicode: "1F21A", Alias: []string{"nothing", "chinese", "kanji", "japanese", "orange-square"}}, ":notification:": emojiData{Name: ":bell:", Description: "Bell", Unicode: "1F514", Alias: []string{"sound", "notification", "christmas", "xmas", "chime"}}, ":null:": emojiData{Name: ":zero:", Description: "Keycap 0", Unicode: "0030-FE0F-20E3", Alias: []string{"0", "numbers", "blue-square", "null"}}, ":numbers:": emojiData{Name: ":three:", Description: "Keycap 3", Unicode: "0033-FE0F-20E3", Alias: []string{"3", "numbers", "prime", "blue-square"}}, ":nurse:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":nut:": emojiData{Name: ":peanuts:", Description: "Peanuts", Unicode: "1F95C", Alias: []string{"food", "nut"}}, ":nut_and_bolt:": emojiData{Name: ":nut_and_bolt:", Description: "Nut and Bolt", Unicode: "1F529", Alias: []string{"handy", "tools", "fix"}}, ":o2:": emojiData{Name: ":o2:", Description: "Negative Squared Latin Capital Letter O", Unicode: "1F17E-FE0F", Alias: []string{"alphabet", "red-square", "letter"}}, ":o:": emojiData{Name: ":o:", Description: "Heavy Large Circle", Unicode: "2B55", Alias: []string{"circle", "round"}}, ":obtain:": emojiData{Name: ":ideograph_advantage:", Description: "Circled Ideograph Advantage", Unicode: "1F250", Alias: []string{"chinese", "kanji", "obtain", "get", "circle"}}, ":ocean:": emojiData{Name: ":tropical_fish:", Description: "Tropical Fish", Unicode: "1F420", Alias: []string{"animal", "swim", "ocean", "beach", "nemo"}}, ":octagonal_sign:": emojiData{Name: ":octagonal_sign:", Description: "Octagonal Sign", Unicode: "1F6D1", Alias: []string(nil)}, ":octopus:": emojiData{Name: ":octopus:", Description: "Octopus", Unicode: "1F419", Alias: []string{"animal", "creature", "ocean", "sea", "nature", "beach"}}, ":oden:": emojiData{Name: ":oden:", Description: "Oden", Unicode: "1F362", Alias: []string{"food", "japanese"}}, ":office:": emojiData{Name: ":office:", Description: "Office Building", Unicode: "1F3E2", Alias: []string{"building", "bureau", "work"}}, ":ogre:": emojiData{Name: ":japanese_ogre:", Description: "Japanese Ogre", Unicode: "1F479", Alias: []string{"monster", "red", "mask", "halloween", "scary", "creepy", "devil", "demon", "japanese", "ogre"}}, ":ohyeah:": emojiData{Name: ":v:", Description: "Victory Hand", Unicode: "270C-FE0F", Alias: []string{"fingers", "ohyeah", "hand", "peace", "victory", "two"}}, ":oil_drum:": emojiData{Name: ":oil_drum:", Description: "Oil Drum", Unicode: "1F6E2-FE0F", Alias: []string{"barrell"}}, ":oink:": emojiData{Name: ":pig_nose:", Description: "Pig Nose", Unicode: "1F43D", Alias: []string{"animal", "oink"}}, ":ok:": emojiData{Name: ":heavy_check_mark:", Description: "Heavy Check Mark", Unicode: "2714-FE0F", Alias: []string{"ok", "nike", "answer", "yes", "tick"}}, ":ok_hand:": emojiData{Name: ":ok_hand:", Description: "Ok Hand Sign", Unicode: "1F44C", Alias: []string{"fingers", "limbs", "perfect", "ok", "okay"}}, ":ok_woman:": emojiData{Name: ":ok_woman:", Description: "Face with Ok Gesture", Unicode: "1F646", Alias: []string{"women", "girl", "female", "pink", "human", "woman"}}, ":okay:": emojiData{Name: ":ok_hand:", Description: "Ok Hand Sign", Unicode: "1F44C", Alias: []string{"fingers", "limbs", "perfect", "ok", "okay"}}, ":old:": emojiData{Name: ":older_man:", Description: "Older Man", Unicode: "1F474", Alias: []string{"human", "male", "men", "old", "elder", "senior"}}, ":old_key:": emojiData{Name: ":old_key:", Description: "Old Key", Unicode: "1F5DD-FE0F", Alias: []string{"lock", "door", "password"}}, ":older_adult:": emojiData{Name: ":older_adult:", Description: "Older Adult", Unicode: "1F9D3", Alias: []string(nil)}, ":older_man:": emojiData{Name: ":older_man:", Description: "Older Man", Unicode: "1F474", Alias: []string{"human", "male", "men", "old", "elder", "senior"}}, ":older_woman:": emojiData{Name: ":older_woman:", Description: "Older Woman", Unicode: "1F475", Alias: []string{"human", "female", "women", "lady", "old", "elder", "senior"}}, ":oldschool:": emojiData{Name: ":tv:", Description: "Television", Unicode: "1F4FA", Alias: []string{"technology", "program", "oldschool", "show", "television"}}, ":om_symbol:": emojiData{Name: ":om_symbol:", Description: "Om Symbol", Unicode: "1F549-FE0F", Alias: []string(nil)}, ":omg:": emojiData{Name: ":scream:", Description: "Face Screaming in Fear", Unicode: "1F631", Alias: []string{"face", "munch", "scared", "omg"}}, ":on:": emojiData{Name: ":on:", Description: "On with Exclamation Mark with Left Right Arrow Above", Unicode: "1F51B", Alias: []string{"arrow", "words"}}, ":oncoming_automobile:": emojiData{Name: ":oncoming_automobile:", Description: "Oncoming Automobile", Unicode: "1F698", Alias: []string{"car", "vehicle", "transportation"}}, ":oncoming_bus:": emojiData{Name: ":oncoming_bus:", Description: "Oncoming Bus", Unicode: "1F68D", Alias: []string{"vehicle", "transportation"}}, ":oncoming_police_car:": emojiData{Name: ":oncoming_police_car:", Description: "Oncoming Police Car", Unicode: "1F694", Alias: []string{"vehicle", "law", "legal", "enforcement", "911"}}, ":oncoming_taxi:": emojiData{Name: ":oncoming_taxi:", Description: "Oncoming Taxi", Unicode: "1F696", Alias: []string{"vehicle", "cars", "uber"}}, ":one:": emojiData{Name: ":one:", Description: "Keycap 1", Unicode: "0031-FE0F-20E3", Alias: []string{"blue-square", "numbers", "1"}}, ":oops:": emojiData{Name: ":persevere:", Description: "Persevering Face", Unicode: "1F623", Alias: []string{"face", "sick", "no", "upset", "oops"}}, ":open:": emojiData{Name: ":open_hands:", Description: "Open Hands Sign", Unicode: "1F450", Alias: []string{"fingers", "butterfly", "hands", "open"}}, ":open_file_folder:": emojiData{Name: ":open_file_folder:", Description: "Open File Folder", Unicode: "1F4C2", Alias: []string{"documents", "load"}}, ":open_hands:": emojiData{Name: ":open_hands:", Description: "Open Hands Sign", Unicode: "1F450", Alias: []string{"fingers", "butterfly", "hands", "open"}}, ":open_mouth:": emojiData{Name: ":open_mouth:", Description: "Face with Open Mouth", Unicode: "1F62E", Alias: []string{"face", "surprise", "impressed", "wow", "whoa", ":O"}}, ":opening hours:": emojiData{Name: ":u55b6:", Description: "Squared Cjk Unified Ideograph-55b6", Unicode: "1F23A", Alias: []string{"japanese", "opening hours", "orange-square"}}, ":ophiuchus:": emojiData{Name: ":ophiuchus:", Description: "Ophiuchus", Unicode: "26CE", Alias: []string{"sign", "purple-square", "constellation", "astrology"}}, ":orange-circle:": emojiData{Name: ":accept:", Description: "Circled Ideograph Accept", Unicode: "1F251", Alias: []string{"ok", "good", "chinese", "kanji", "agree", "yes", "orange-circle"}}, ":orange-square:": emojiData{Name: ":baby_symbol:", Description: "Baby Symbol", Unicode: "1F6BC", Alias: []string{"orange-square", "child"}}, ":orange:": emojiData{Name: ":carrot:", Description: "Carrot", Unicode: "1F955", Alias: []string{"vegetable", "food", "orange"}}, ":orange_book:": emojiData{Name: ":orange_book:", Description: "Orange Book", Unicode: "1F4D9", Alias: []string{"read", "library", "knowledge", "textbook", "study"}}, ":orange_heart:": emojiData{Name: ":orange_heart:", Description: "Orange Heart", Unicode: "1F9E1", Alias: []string(nil)}, ":orchestra:": emojiData{Name: ":violin:", Description: "Violin", Unicode: "1F3BB", Alias: []string{"music", "instrument", "orchestra", "symphony"}}, ":order:": emojiData{Name: ":bookmark_tabs:", Description: "Bookmark Tabs", Unicode: "1F4D1", Alias: []string{"favorite", "save", "order", "tidy"}}, ":oreo:": emojiData{Name: ":cookie:", Description: "Cookie", Unicode: "1F36A", Alias: []string{"food", "snack", "oreo", "chocolate", "sweet", "dessert"}}, ":organizing:": emojiData{Name: ":card_index_dividers:", Description: "Card Index Dividers", Unicode: "1F5C2-FE0F", Alias: []string{"organizing", "business", "stationery"}}, ":orthodox_cross:": emojiData{Name: ":orthodox_cross:", Description: "Orthodox Cross", Unicode: "2626-FE0F", Alias: []string{"suppedaneum", "religion"}}, ":outbox_tray:": emojiData{Name: ":outbox_tray:", Description: "Outbox Tray", Unicode: "1F4E4", Alias: []string{"inbox", "email"}}, ":outdoors:": emojiData{Name: ":camping:", Description: "Camping", Unicode: "1F3D5-FE0F", Alias: []string{"photo", "outdoors", "tent"}}, ":outer space:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":outer_space:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":owl:": emojiData{Name: ":owl:", Description: "Owl", Unicode: "1F989", Alias: []string{"animal", "nature", "bird", "hoot"}}, ":ox:": emojiData{Name: ":cow:", Description: "Cow Face", Unicode: "1F42E", Alias: []string{"beef", "ox", "animal", "nature", "moo", "milk"}}, ":package:": emojiData{Name: ":package:", Description: "Package", Unicode: "1F4E6", Alias: []string{"mail", "gift", "cardboard", "box", "moving"}}, ":paddle:": emojiData{Name: ":canoe:", Description: "Canoe", Unicode: "1F6F6", Alias: []string{"boat", "paddle", "water", "ship"}}, ":padlock:": emojiData{Name: ":lock:", Description: "Lock", Unicode: "1F512", Alias: []string{"security", "password", "padlock"}}, ":paella:": emojiData{Name: ":shallow_pan_of_food:", Description: "Shallow Pan of Food", Unicode: "1F958", Alias: []string{"food", "cooking", "casserole", "paella"}}, ":page_facing_up:": emojiData{Name: ":page_facing_up:", Description: "Page Facing Up", Unicode: "1F4C4", Alias: []string{"documents", "office", "paper", "information"}}, ":page_with_curl:": emojiData{Name: ":page_with_curl:", Description: "Page with Curl", Unicode: "1F4C3", Alias: []string{"documents", "office", "paper"}}, ":pageant:": emojiData{Name: ":running_shirt_with_sash:", Description: "Running Shirt with Sash", Unicode: "1F3BD", Alias: []string{"play", "pageant"}}, ":pager:": emojiData{Name: ":pager:", Description: "Pager", Unicode: "1F4DF", Alias: []string{"bbcall", "oldschool", "90s"}}, ":paint:": emojiData{Name: ":art:", Description: "Artist Palette", Unicode: "1F3A8", Alias: []string{"design", "paint", "draw", "colors"}}, ":pair:": emojiData{Name: ":two_men_holding_hands:", Description: "Two Men Holding Hands", Unicode: "1F46C", Alias: []string{"pair", "couple", "love", "like", "bromance", "friendship", "people", "human"}}, ":palm:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":palm_tree:": emojiData{Name: ":palm_tree:", Description: "Palm Tree", Unicode: "1F334", Alias: []string{"plant", "vegetable", "nature", "summer", "beach", "mojito", "tropical"}}, ":palms_up_together:": emojiData{Name: ":palms_up_together:", Description: "Palms Up Together", Unicode: "1F932", Alias: []string(nil)}, ":pancakes:": emojiData{Name: ":pancakes:", Description: "Pancakes", Unicode: "1F95E", Alias: []string{"food", "breakfast", "flapjacks", "hotcakes"}}, ":panda:": emojiData{Name: ":bamboo:", Description: "Pine Decoration", Unicode: "1F38D", Alias: []string{"plant", "nature", "vegetable", "panda", "pine_decoration"}}, ":panda_face:": emojiData{Name: ":panda_face:", Description: "Panda Face", Unicode: "1F43C", Alias: []string{"animal", "nature", "panda"}}, ":paper:": emojiData{Name: ":izakaya_lantern:", Description: "Izakaya Lantern", Unicode: "1F3EE", Alias: []string{"light", "paper", "halloween", "spooky"}}, ":paperclip:": emojiData{Name: ":paperclip:", Description: "Paperclip", Unicode: "1F4CE", Alias: []string{"documents", "stationery"}}, ":parking:": emojiData{Name: ":parking:", Description: "Negative Squared Latin Capital Letter P", Unicode: "1F17F-FE0F", Alias: []string{"cars", "blue-square", "alphabet", "letter"}}, ":part_alternation_mark:": emojiData{Name: ":part_alternation_mark:", Description: "Part Alternation Mark", Unicode: "303D-FE0F", Alias: []string{"graph", "presentation", "stats", "business", "economics", "bad"}}, ":partly_sunny:": emojiData{Name: ":partly_sunny:", Description: "Sun Behind Cloud", Unicode: "26C5", Alias: []string{"weather", "nature", "cloudy", "morning", "fall", "spring"}}, ":partly_sunny_rain:": emojiData{Name: ":partly_sunny_rain:", Description: "Partly Sunny Rain", Unicode: "1F326-FE0F", Alias: []string(nil)}, ":party:": emojiData{Name: ":clinking_glasses:", Description: "Clinking Glasses", Unicode: "1F942", Alias: []string{"beverage", "drink", "party", "alcohol", "celebrate", "cheers"}}, ":pass:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":passenger_ship:": emojiData{Name: ":passenger_ship:", Description: "Passenger Ship", Unicode: "1F6F3-FE0F", Alias: []string{"yacht", "cruise", "ferry"}}, ":passport:": emojiData{Name: ":customs:", Description: "Customs", Unicode: "1F6C3", Alias: []string{"passport", "border", "blue-square"}}, ":passport_control:": emojiData{Name: ":passport_control:", Description: "Passport Control", Unicode: "1F6C2", Alias: []string{"custom", "blue-square"}}, ":password:": emojiData{Name: ":lock:", Description: "Lock", Unicode: "1F512", Alias: []string{"security", "password", "padlock"}}, ":paul:": emojiData{Name: ":alien:", Description: "Extraterrestrial Alien", Unicode: "1F47D", Alias: []string{"UFO", "paul", "weird", "outer_space"}}, ":payment:": emojiData{Name: ":money_with_wings:", Description: "Money with Wings", Unicode: "1F4B8", Alias: []string{"dollar", "bills", "payment", "sale"}}, ":peace:": emojiData{Name: ":v:", Description: "Victory Hand", Unicode: "270C-FE0F", Alias: []string{"fingers", "ohyeah", "hand", "peace", "victory", "two"}}, ":peace_symbol:": emojiData{Name: ":peace_symbol:", Description: "Peace Symbol", Unicode: "262E-FE0F", Alias: []string{"hippie"}}, ":peach:": emojiData{Name: ":peach:", Description: "Peach", Unicode: "1F351", Alias: []string{"fruit", "nature", "food"}}, ":peanuts:": emojiData{Name: ":peanuts:", Description: "Peanuts", Unicode: "1F95C", Alias: []string{"food", "nut"}}, ":pear:": emojiData{Name: ":pear:", Description: "Pear", Unicode: "1F350", Alias: []string{"fruit", "nature", "food"}}, ":peek:": emojiData{Name: ":eyes:", Description: "Eyes", Unicode: "1F440", Alias: []string{"look", "watch", "stalk", "peek", "see"}}, ":pen:": emojiData{Name: ":black_nib:", Description: "Black Nib", Unicode: "2712-FE0F", Alias: []string{"pen", "stationery", "writing", "write"}}, ":pencil2:": emojiData{Name: ":pencil2:", Description: "Pencil", Unicode: "270F-FE0F", Alias: []string{"stationery", "write", "paper", "writing", "school", "study"}}, ":pencil:": emojiData{Name: ":memo:", Description: "Memo", Unicode: "1F4DD", Alias: []string{"write", "documents", "stationery", "pencil", "paper", "writing", "legal", "exam", "quiz", "test", "study", "compose"}}, ":penguin:": emojiData{Name: ":penguin:", Description: "Penguin", Unicode: "1F427", Alias: []string{"animal", "nature"}}, ":pensive:": emojiData{Name: ":pensive:", Description: "Pensive Face", Unicode: "1F614", Alias: []string{"face", "sad", "depressed", "upset"}}, ":people:": emojiData{Name: ":two_men_holding_hands:", Description: "Two Men Holding Hands", Unicode: "1F46C", Alias: []string{"pair", "couple", "love", "like", "bromance", "friendship", "people", "human"}}, ":percent:": emojiData{Name: ":symbols:", Description: "Input Symbol for Symbols", Unicode: "1F523", Alias: []string{"blue-square", "music", "note", "ampersand", "percent", "glyphs", "characters"}}, ":perfect:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":performing_arts:": emojiData{Name: ":performing_arts:", Description: "Performing Arts", Unicode: "1F3AD", Alias: []string{"acting", "theater", "drama"}}, ":persevere:": emojiData{Name: ":persevere:", Description: "Persevering Face", Unicode: "1F623", Alias: []string{"face", "sick", "no", "upset", "oops"}}, ":person:": emojiData{Name: ":bust_in_silhouette:", Description: "Bust in Silhouette", Unicode: "1F464", Alias: []string{"user", "person", "human"}}, ":person_climbing:": emojiData{Name: ":person_climbing:", Description: "Person Climbing", Unicode: "1F9D7", Alias: []string(nil)}, ":person_doing_cartwheel:": emojiData{Name: ":person_doing_cartwheel:", Description: "Person Doing Cartwheel", Unicode: "1F938", Alias: []string(nil)}, ":person_frowning:": emojiData{Name: ":person_frowning:", Description: "Person Frowning", Unicode: "1F64D", Alias: []string(nil)}, ":person_in_lotus_position:": emojiData{Name: ":person_in_lotus_position:", Description: "Person in Lotus Position", Unicode: "1F9D8", Alias: []string(nil)}, ":person_in_steamy_room:": emojiData{Name: ":person_in_steamy_room:", Description: "Person in Steamy Room", Unicode: "1F9D6", Alias: []string(nil)}, ":person_with_ball:": emojiData{Name: ":person_with_ball:", Description: "Person with Ball", Unicode: "26F9-FE0F", Alias: []string(nil)}, ":person_with_blond_hair:": emojiData{Name: ":person_with_blond_hair:", Description: "Person with Blond Hair", Unicode: "1F471", Alias: []string(nil)}, ":person_with_headscarf:": emojiData{Name: ":person_with_headscarf:", Description: "Person with Headscarf", Unicode: "1F9D5", Alias: []string(nil)}, ":person_with_pouting_face:": emojiData{Name: ":person_with_pouting_face:", Description: "Person with Pouting Face", Unicode: "1F64E", Alias: []string(nil)}, ":pet:": emojiData{Name: ":dog:", Description: "Dog Face", Unicode: "1F436", Alias: []string{"animal", "friend", "nature", "woof", "puppy", "pet", "faithful"}}, ":petroleum:": emojiData{Name: ":fuelpump:", Description: "Fuel Pump", Unicode: "26FD", Alias: []string{"gas station", "petroleum"}}, ":pharmacy:": emojiData{Name: ":pill:", Description: "Pill", Unicode: "1F48A", Alias: []string{"health", "medicine", "doctor", "pharmacy", "drug"}}, ":phew:": emojiData{Name: ":disappointed_relieved:", Description: "Disappointed but Relieved Face", Unicode: "1F625", Alias: []string{"face", "phew", "sweat", "nervous"}}, ":phone:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":photo:": emojiData{Name: ":fireworks:", Description: "Fireworks", Unicode: "1F386", Alias: []string{"photo", "festival", "carnival", "congratulations"}}, ":photography:": emojiData{Name: ":camera:", Description: "Camera", Unicode: "1F4F7", Alias: []string{"gadgets", "photography"}}, ":physics:": emojiData{Name: ":atom_symbol:", Description: "Atom Symbol", Unicode: "269B-FE0F", Alias: []string{"science", "physics", "chemistry"}}, ":piano:": emojiData{Name: ":musical_keyboard:", Description: "Musical Keyboard", Unicode: "1F3B9", Alias: []string{"piano", "instrument", "compose"}}, ":pick:": emojiData{Name: ":pick:", Description: "Pick", Unicode: "26CF-FE0F", Alias: []string{"tools", "dig"}}, ":pickle:": emojiData{Name: ":cucumber:", Description: "Cucumber", Unicode: "1F952", Alias: []string{"fruit", "food", "pickle"}}, ":picnic:": emojiData{Name: ":watermelon:", Description: "Watermelon", Unicode: "1F349", Alias: []string{"fruit", "food", "picnic", "summer"}}, ":pie:": emojiData{Name: ":pie:", Description: "Pie", Unicode: "1F967", Alias: []string(nil)}, ":pig2:": emojiData{Name: ":pig2:", Description: "Pig", Unicode: "1F416", Alias: []string{"animal", "nature"}}, ":pig:": emojiData{Name: ":bacon:", Description: "Bacon", Unicode: "1F953", Alias: []string{"food", "breakfast", "pork", "pig", "meat"}}, ":pig_nose:": emojiData{Name: ":pig_nose:", Description: "Pig Nose", Unicode: "1F43D", Alias: []string{"animal", "oink"}}, ":pill:": emojiData{Name: ":pill:", Description: "Pill", Unicode: "1F48A", Alias: []string{"health", "medicine", "doctor", "pharmacy", "drug"}}, ":pine_decoration:": emojiData{Name: ":bamboo:", Description: "Pine Decoration", Unicode: "1F38D", Alias: []string{"plant", "nature", "vegetable", "panda", "pine_decoration"}}, ":pineapple:": emojiData{Name: ":pineapple:", Description: "Pineapple", Unicode: "1F34D", Alias: []string{"fruit", "nature", "food"}}, ":pinged:": emojiData{Name: ":rotating_light:", Description: "Police Cars Revolving Light", Unicode: "1F6A8", Alias: []string{"police", "ambulance", "911", "emergency", "alert", "error", "pinged", "law", "legal"}}, ":pink-square:": emojiData{Name: ":u5272:", Description: "Squared Cjk Unified Ideograph-5272", Unicode: "1F239", Alias: []string{"cut", "divide", "chinese", "kanji", "pink-square"}}, ":pink:": emojiData{Name: ":heartbeat:", Description: "Beating Heart", Unicode: "1F493", Alias: []string{"love", "like", "affection", "valentines", "pink", "heart"}}, ":pinocchio:": emojiData{Name: ":lying_face:", Description: "Lying Face", Unicode: "1F925", Alias: []string{"face", "lie", "pinocchio"}}, ":pirate:": emojiData{Name: ":skull_and_crossbones:", Description: "Skull and Crossbones", Unicode: "2620-FE0F", Alias: []string{"poison", "danger", "deadly", "scary", "death", "pirate", "evil"}}, ":pisces:": emojiData{Name: ":pisces:", Description: "Pisces", Unicode: "2653", Alias: []string{"purple-square", "sign", "zodiac", "astrology"}}, ":pistol:": emojiData{Name: ":gun:", Description: "Pistol", Unicode: "1F52B", Alias: []string{"violence", "weapon", "pistol", "revolver"}}, ":pizza:": emojiData{Name: ":pizza:", Description: "Slice of Pizza", Unicode: "1F355", Alias: []string{"food", "party"}}, ":place:": emojiData{Name: ":triangular_flag_on_post:", Description: "Triangular Flag on Post", Unicode: "1F6A9", Alias: []string{"mark", "milestone", "place"}}, ":place_of_worship:": emojiData{Name: ":place_of_worship:", Description: "Place of Worship", Unicode: "1F6D0", Alias: []string{"religion", "church", "temple", "prayer"}}, ":planet:": emojiData{Name: ":waning_crescent_moon:", Description: "Waning Crescent Moon Symbol", Unicode: "1F318", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":planning:": emojiData{Name: ":calendar:", Description: "Tear-off Calendar", Unicode: "1F4C6", Alias: []string{"schedule", "date", "planning"}}, ":plant:": emojiData{Name: ":cactus:", Description: "Cactus", Unicode: "1F335", Alias: []string{"vegetable", "plant", "nature"}}, ":play:": emojiData{Name: ":dart:", Description: "Direct Hit", Unicode: "1F3AF", Alias: []string{"game", "play", "bar"}}, ":playful:": emojiData{Name: ":stuck_out_tongue_closed_eyes:", Description: "Face with Stuck-out Tongue and Tightly-Closed Eyes", Unicode: "1F61D", Alias: []string{"face", "prank", "playful", "mischievous", "smile", "tongue"}}, ":playground:": emojiData{Name: ":roller_coaster:", Description: "Roller Coaster", Unicode: "1F3A2", Alias: []string{"carnival", "playground", "photo", "fun"}}, ":please:": emojiData{Name: ":pray:", Description: "Person with Folded Hands", Unicode: "1F64F", Alias: []string{"please", "hope", "wish", "namaste", "highfive"}}, ":podcast:": emojiData{Name: ":radio:", Description: "Radio", Unicode: "1F4FB", Alias: []string{"communication", "music", "podcast", "program"}}, ":point:": emojiData{Name: ":arrow_up_small:", Description: "Up-Pointing Small Red Triangle", Unicode: "1F53C", Alias: []string{"blue-square", "triangle", "direction", "point", "forward", "top"}}, ":point_down:": emojiData{Name: ":point_down:", Description: "White Down Pointing Backhand Index", Unicode: "1F447", Alias: []string{"fingers", "hand", "direction", "down"}}, ":point_left:": emojiData{Name: ":point_left:", Description: "White Left Pointing Backhand Index", Unicode: "1F448", Alias: []string{"direction", "fingers", "hand", "left"}}, ":point_right:": emojiData{Name: ":point_right:", Description: "White Right Pointing Backhand Index", Unicode: "1F449", Alias: []string{"fingers", "hand", "direction", "right"}}, ":point_up:": emojiData{Name: ":point_up:", Description: "White Up Pointing Index", Unicode: "261D-FE0F", Alias: []string{"hand", "fingers", "direction", "up"}}, ":point_up_2:": emojiData{Name: ":point_up_2:", Description: "White Up Pointing Backhand Index", Unicode: "1F446", Alias: []string{"fingers", "hand", "direction", "up"}}, ":poison:": emojiData{Name: ":skull_and_crossbones:", Description: "Skull and Crossbones", Unicode: "2620-FE0F", Alias: []string{"poison", "danger", "deadly", "scary", "death", "pirate", "evil"}}, ":poisoned:": emojiData{Name: ":astonished:", Description: "Astonished Face", Unicode: "1F632", Alias: []string{"face", "xox", "surprised", "poisoned"}}, ":poker:": emojiData{Name: ":spades:", Description: "Black Spade Suit", Unicode: "2660-FE0F", Alias: []string{"poker", "cards", "suits", "magic"}}, ":police:": emojiData{Name: ":rotating_light:", Description: "Police Cars Revolving Light", Unicode: "1F6A8", Alias: []string{"police", "ambulance", "911", "emergency", "alert", "error", "pinged", "law", "legal"}}, ":police_car:": emojiData{Name: ":police_car:", Description: "Police Car", Unicode: "1F693", Alias: []string{"vehicle", "cars", "transportation", "law", "legal", "enforcement"}}, ":pollution:": emojiData{Name: ":factory:", Description: "Factory", Unicode: "1F3ED", Alias: []string{"building", "industry", "pollution", "smoke"}}, ":polygon:": emojiData{Name: ":eight_pointed_black_star:", Description: "Eight Pointed Black Star", Unicode: "2734-FE0F", Alias: []string{"orange-square", "shape", "polygon"}}, ":poodle:": emojiData{Name: ":poodle:", Description: "Poodle", Unicode: "1F429", Alias: []string{"dog", "animal", "101", "nature", "pet"}}, ":pool:": emojiData{Name: ":8ball:", Description: "Billiards", Unicode: "1F3B1", Alias: []string{"pool", "hobby", "game", "luck", "magic"}}, ":popcorn:": emojiData{Name: ":popcorn:", Description: "Popcorn", Unicode: "1F37F", Alias: []string{"food", "movie theater", "films", "snack"}}, ":pork:": emojiData{Name: ":bacon:", Description: "Bacon", Unicode: "1F953", Alias: []string{"food", "breakfast", "pork", "pig", "meat"}}, ":post_office:": emojiData{Name: ":post_office:", Description: "Japanese Post Office", Unicode: "1F3E3", Alias: []string{"building", "envelope", "communication"}}, ":postal:": emojiData{Name: ":email:", Description: "Envelope", Unicode: "2709-FE0F", Alias: []string{"letter", "postal", "inbox", "communication"}}, ":postal_horn:": emojiData{Name: ":postal_horn:", Description: "Postal Horn", Unicode: "1F4EF", Alias: []string{"instrument", "music"}}, ":postbox:": emojiData{Name: ":postbox:", Description: "Postbox", Unicode: "1F4EE", Alias: []string{"email", "letter", "envelope"}}, ":potable_water:": emojiData{Name: ":potable_water:", Description: "Potable Water Symbol", Unicode: "1F6B0", Alias: []string{"blue-square", "liquid", "restroom", "cleaning", "faucet"}}, ":potato:": emojiData{Name: ":potato:", Description: "Potato", Unicode: "1F954", Alias: []string{"food", "tuber", "vegatable", "starch"}}, ":potty:": emojiData{Name: ":toilet:", Description: "Toilet", Unicode: "1F6BD", Alias: []string{"restroom", "wc", "washroom", "bathroom", "potty"}}, ":pouch:": emojiData{Name: ":pouch:", Description: "Pouch", Unicode: "1F45D", Alias: []string{"bag", "accessories", "shopping"}}, ":poultry_leg:": emojiData{Name: ":poultry_leg:", Description: "Poultry Leg", Unicode: "1F357", Alias: []string{"food", "meat", "drumstick", "bird", "chicken", "turkey"}}, ":pound:": emojiData{Name: ":pound:", Description: "Banknote with Pound Sign", Unicode: "1F4B7", Alias: []string{"british", "sterling", "money", "sales", "bills", "uk", "england", "currency"}}, ":pouting_cat:": emojiData{Name: ":pouting_cat:", Description: "Pouting Cat Face", Unicode: "1F63E", Alias: []string{"animal", "cats"}}, ":power:": emojiData{Name: ":electric_plug:", Description: "Electric Plug", Unicode: "1F50C", Alias: []string{"charger", "power"}}, ":praise:": emojiData{Name: ":clap:", Description: "Clapping Hands Sign", Unicode: "1F44F", Alias: []string{"hands", "praise", "applause", "congrats", "yay"}}, ":prank:": emojiData{Name: ":stuck_out_tongue_closed_eyes:", Description: "Face with Stuck-out Tongue and Tightly-Closed Eyes", Unicode: "1F61D", Alias: []string{"face", "prank", "playful", "mischievous", "smile", "tongue"}}, ":pray:": emojiData{Name: ":pray:", Description: "Person with Folded Hands", Unicode: "1F64F", Alias: []string{"please", "hope", "wish", "namaste", "highfive"}}, ":prayer:": emojiData{Name: ":place_of_worship:", Description: "Place of Worship", Unicode: "1F6D0", Alias: []string{"religion", "church", "temple", "prayer"}}, ":prayer_beads:": emojiData{Name: ":prayer_beads:", Description: "Prayer Beads", Unicode: "1F4FF", Alias: []string{"dhikr", "religious"}}, ":prc:": emojiData{Name: ":cn:", Description: "China Flag", Unicode: "1F1E8-1F1F3", Alias: []string{"china", "chinese", "prc", "flag", "country", "nation", "banner"}}, ":pregnant_woman:": emojiData{Name: ":pregnant_woman:", Description: "Pregnant Woman", Unicode: "1F930", Alias: []string{"baby"}}, ":present:": emojiData{Name: ":gift:", Description: "Wrapped Present", Unicode: "1F381", Alias: []string{"present", "birthday", "christmas", "xmas"}}, ":presentation:": emojiData{Name: ":part_alternation_mark:", Description: "Part Alternation Mark", Unicode: "303D-FE0F", Alias: []string{"graph", "presentation", "stats", "business", "economics", "bad"}}, ":press:": emojiData{Name: ":newspaper:", Description: "Newspaper", Unicode: "1F4F0", Alias: []string{"press", "headline"}}, ":pretzel:": emojiData{Name: ":pretzel:", Description: "Pretzel", Unicode: "1F968", Alias: []string(nil)}, ":previous:": emojiData{Name: ":arrow_left:", Description: "Leftwards Black Arrow", Unicode: "2B05-FE0F", Alias: []string{"blue-square", "previous", "back"}}, ":pride:": emojiData{Name: ":triumph:", Description: "Face with Look of Triumph", Unicode: "1F624", Alias: []string{"face", "gas", "phew", "proud", "pride"}}, ":prime:": emojiData{Name: ":three:", Description: "Keycap 3", Unicode: "0033-FE0F-20E3", Alias: []string{"3", "numbers", "prime", "blue-square"}}, ":prince:": emojiData{Name: ":prince:", Description: "Prince", Unicode: "1F934", Alias: []string{"boy", "man", "male", "crown", "royal", "king"}}, ":princess:": emojiData{Name: ":princess:", Description: "Princess", Unicode: "1F478", Alias: []string{"girl", "woman", "female", "blond", "crown", "royal", "queen"}}, ":printer:": emojiData{Name: ":printer:", Description: "Printer", Unicode: "1F5A8-FE0F", Alias: []string{"paper", "ink"}}, ":privacy:": emojiData{Name: ":closed_lock_with_key:", Description: "Closed Lock with Key", Unicode: "1F510", Alias: []string{"security", "privacy"}}, ":problem:": emojiData{Name: ":warning:", Description: "Warning Sign", Unicode: "26A0-FE0F", Alias: []string{"exclamation", "wip", "alert", "error", "problem", "issue"}}, ":program:": emojiData{Name: ":tv:", Description: "Television", Unicode: "1F4FA", Alias: []string{"technology", "program", "oldschool", "show", "television"}}, ":progress:": emojiData{Name: ":construction:", Description: "Construction Sign", Unicode: "1F6A7", Alias: []string{"wip", "progress", "caution", "warning"}}, ":prohibited:": emojiData{Name: ":no_bicycles:", Description: "No Bicycles", Unicode: "1F6B3", Alias: []string{"cyclist", "prohibited", "circle"}}, ":propose:": emojiData{Name: ":ring:", Description: "Ring", Unicode: "1F48D", Alias: []string{"wedding", "propose", "marriage", "valentines", "diamond", "fashion", "jewelry", "gem", "engagement"}}, ":protection:": emojiData{Name: ":shield:", Description: "Shield", Unicode: "1F6E1-FE0F", Alias: []string{"protection", "security"}}, ":proud:": emojiData{Name: ":triumph:", Description: "Face with Look of Triumph", Unicode: "1F624", Alias: []string{"face", "gas", "phew", "proud", "pride"}}, ":pub:": emojiData{Name: ":beers:", Description: "Clinking Beer Mugs", Unicode: "1F37B", Alias: []string{"relax", "beverage", "drink", "drunk", "party", "pub", "summer", "alcohol", "booze"}}, ":public:": emojiData{Name: ":train:", Description: "Tram Car", Unicode: "1F68B", Alias: []string{"transportation", "vehicle", "carriage", "public", "travel"}}, ":puff:": emojiData{Name: ":dash:", Description: "Dash Symbol", Unicode: "1F4A8", Alias: []string{"wind", "air", "fast", "shoo", "fart", "smoke", "puff"}}, ":pumpkin:": emojiData{Name: ":jack_o_lantern:", Description: "Jack-O-Lantern", Unicode: "1F383", Alias: []string{"halloween", "light", "pumpkin", "creepy", "fall"}}, ":pumps:": emojiData{Name: ":high_heel:", Description: "High-Heeled Shoe", Unicode: "1F460", Alias: []string{"fashion", "shoes", "female", "pumps", "stiletto"}}, ":punctuation:": emojiData{Name: ":grey_exclamation:", Description: "White Exclamation Mark Ornament", Unicode: "2755", Alias: []string{"surprise", "punctuation", "gray", "wow", "warning"}}, ":puppy:": emojiData{Name: ":dog:", Description: "Dog Face", Unicode: "1F436", Alias: []string{"animal", "friend", "nature", "woof", "puppy", "pet", "faithful"}}, ":purple-square:": emojiData{Name: ":ophiuchus:", Description: "Ophiuchus", Unicode: "26CE", Alias: []string{"sign", "purple-square", "constellation", "astrology"}}, ":purple_heart:": emojiData{Name: ":purple_heart:", Description: "Purple Heart", Unicode: "1F49C", Alias: []string{"love", "like", "affection", "valentines"}}, ":purse:": emojiData{Name: ":purse:", Description: "Purse", Unicode: "1F45B", Alias: []string{"fashion", "accessories", "money", "sales", "shopping"}}, ":pushpin:": emojiData{Name: ":pushpin:", Description: "Pushpin", Unicode: "1F4CC", Alias: []string{"stationery", "mark", "here"}}, ":put_litter_in_its_place:": emojiData{Name: ":put_litter_in_its_place:", Description: "Put Litter in Its Place Symbol", Unicode: "1F6AE", Alias: []string{"blue-square", "sign", "human", "info"}}, ":python:": emojiData{Name: ":snake:", Description: "Snake", Unicode: "1F40D", Alias: []string{"animal", "evil", "nature", "hiss", "python"}}, ":queen:": emojiData{Name: ":princess:", Description: "Princess", Unicode: "1F478", Alias: []string{"girl", "woman", "female", "blond", "crown", "royal", "queen"}}, ":question:": emojiData{Name: ":question:", Description: "Black Question Mark Ornament", Unicode: "2753", Alias: []string{"doubt", "confused"}}, ":quiet:": emojiData{Name: ":mobile_phone_off:", Description: "Mobile Phone off", Unicode: "1F4F4", Alias: []string{"mute", "orange-square", "silence", "quiet"}}, ":quiz:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":rabbit2:": emojiData{Name: ":rabbit2:", Description: "Rabbit", Unicode: "1F407", Alias: []string{"animal", "nature", "pet", "magic", "spring"}}, ":rabbit:": emojiData{Name: ":rabbit:", Description: "Rabbit Face", Unicode: "1F430", Alias: []string{"animal", "nature", "pet", "spring", "magic", "bunny"}}, ":race:": emojiData{Name: ":checkered_flag:", Description: "Chequered Flag", Unicode: "1F3C1", Alias: []string{"contest", "finishline", "race", "gokart"}}, ":racehorse:": emojiData{Name: ":racehorse:", Description: "Horse", Unicode: "1F40E", Alias: []string{"animal", "gamble", "luck"}}, ":racing_car:": emojiData{Name: ":racing_car:", Description: "Racing Car", Unicode: "1F3CE-FE0F", Alias: []string{"sports", "race", "fast", "formula", "f1"}}, ":racing_motorcycle:": emojiData{Name: ":racing_motorcycle:", Description: "Racing Motorcycle", Unicode: "1F3CD-FE0F", Alias: []string(nil)}, ":radio:": emojiData{Name: ":radio:", Description: "Radio", Unicode: "1F4FB", Alias: []string{"communication", "music", "podcast", "program"}}, ":radio_button:": emojiData{Name: ":radio_button:", Description: "Radio Button", Unicode: "1F518", Alias: []string{"input", "old", "music", "circle"}}, ":radioactive_sign:": emojiData{Name: ":radioactive_sign:", Description: "Radioactive Sign", Unicode: "2622-FE0F", Alias: []string(nil)}, ":rage:": emojiData{Name: ":rage:", Description: "Pouting Face", Unicode: "1F621", Alias: []string{"angry", "mad", "hate", "despise"}}, ":railway_car:": emojiData{Name: ":railway_car:", Description: "Railway Car", Unicode: "1F683", Alias: []string{"transportation", "vehicle"}}, ":railway_track:": emojiData{Name: ":railway_track:", Description: "Railway Track", Unicode: "1F6E4-FE0F", Alias: []string{"train", "transportation"}}, ":rain:": emojiData{Name: ":closed_umbrella:", Description: "Closed Umbrella", Unicode: "1F302", Alias: []string{"weather", "rain", "drizzle"}}, ":rain_cloud:": emojiData{Name: ":rain_cloud:", Description: "Rain Cloud", Unicode: "1F327-FE0F", Alias: []string(nil)}, ":rainbow-flag:": emojiData{Name: ":rainbow-flag:", Description: "Rainbow Flag", Unicode: "1F3F3-FE0F-200D-1F308", Alias: []string(nil)}, ":rainbow:": emojiData{Name: ":rainbow:", Description: "Rainbow", Unicode: "1F308", Alias: []string{"nature", "happy", "unicorn_face", "photo", "sky", "spring"}}, ":rainy:": emojiData{Name: ":umbrella:", Description: "Umbrella", Unicode: "2602-FE0F", Alias: []string{"rainy", "weather", "spring"}}, ":raised:": emojiData{Name: ":raised_back_of_hand:", Description: "Raised Back of Hand", Unicode: "1F91A", Alias: []string{"fingers", "raised", "backhand"}}, ":raised_back_of_hand:": emojiData{Name: ":raised_back_of_hand:", Description: "Raised Back of Hand", Unicode: "1F91A", Alias: []string{"fingers", "raised", "backhand"}}, ":raised_hand_with_fingers_splayed:": emojiData{Name: ":raised_hand_with_fingers_splayed:", Description: "Raised Hand with Fingers Splayed", Unicode: "1F590-FE0F", Alias: []string{"hand", "fingers", "palm"}}, ":raised_hands:": emojiData{Name: ":raised_hands:", Description: "Person Raising Both Hands in Celebration", Unicode: "1F64C", Alias: []string{"gesture", "hooray", "yea", "celebration", "hands"}}, ":raising_hand:": emojiData{Name: ":raising_hand:", Description: "Happy Person Raising One Hand", Unicode: "1F64B", Alias: []string(nil)}, ":ram:": emojiData{Name: ":ram:", Description: "Ram", Unicode: "1F40F", Alias: []string{"animal", "sheep", "nature"}}, ":ramen:": emojiData{Name: ":fish_cake:", Description: "Fish Cake with Swirl Design", Unicode: "1F365", Alias: []string{"food", "japan", "sea", "beach", "narutomaki", "pink", "swirl", "kamaboko", "surimi", "ramen"}}, ":random:": emojiData{Name: ":game_die:", Description: "Game Die", Unicode: "1F3B2", Alias: []string{"dice", "random", "tabletop", "play", "luck"}}, ":rat:": emojiData{Name: ":rat:", Description: "Rat", Unicode: "1F400", Alias: []string{"animal", "mouse", "rodent"}}, ":read:": emojiData{Name: ":orange_book:", Description: "Orange Book", Unicode: "1F4D9", Alias: []string{"read", "library", "knowledge", "textbook", "study"}}, ":reception:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":recession:": emojiData{Name: ":chart_with_downwards_trend:", Description: "Chart with Downwards Trend", Unicode: "1F4C9", Alias: []string{"graph", "presentation", "stats", "recession", "business", "economics", "money", "sales", "bad", "failure"}}, ":record:": emojiData{Name: ":minidisc:", Description: "Minidisc", Unicode: "1F4BD", Alias: []string{"technology", "record", "data", "disk", "90s"}}, ":recording:": emojiData{Name: ":studio_microphone:", Description: "Studio Microphone", Unicode: "1F399-FE0F", Alias: []string{"sing", "recording", "artist", "talkshow"}}, ":recovery:": emojiData{Name: ":chart_with_upwards_trend:", Description: "Chart with Upwards Trend", Unicode: "1F4C8", Alias: []string{"graph", "presentation", "stats", "recovery", "business", "economics", "money", "sales", "good", "success"}}, ":recycle:": emojiData{Name: ":recycle:", Description: "Black Universal Recycling Symbol", Unicode: "267B-FE0F", Alias: []string{"arrow", "environment", "garbage", "trash"}}, ":red-circle:": emojiData{Name: ":secret:", Description: "Circled Ideograph Secret", Unicode: "3299-FE0F", Alias: []string{"privacy", "chinese", "sshh", "kanji", "red-circle"}}, ":red-square:": emojiData{Name: ":cl:", Description: "Squared Cl", Unicode: "1F191", Alias: []string{"alphabet", "words", "red-square"}}, ":red:": emojiData{Name: ":flower_playing_cards:", Description: "Flower Playing Cards", Unicode: "1F3B4", Alias: []string{"game", "sunset", "red"}}, ":red_circle:": emojiData{Name: ":red_circle:", Description: "Large Red Circle", Unicode: "1F534", Alias: []string{"shape", "error", "danger"}}, ":refresh:": emojiData{Name: ":restroom:", Description: "Restroom", Unicode: "1F6BB", Alias: []string{"blue-square", "toilet", "refresh", "wc", "gender"}}, ":registered:": emojiData{Name: ":registered:", Description: "Registered Sign", Unicode: "00AE-FE0F", Alias: []string{"alphabet", "circle"}}, ":relax:": emojiData{Name: ":beers:", Description: "Clinking Beer Mugs", Unicode: "1F37B", Alias: []string{"relax", "beverage", "drink", "drunk", "party", "pub", "summer", "alcohol", "booze"}}, ":relaxed:": emojiData{Name: ":relaxed:", Description: "White Smiling Face", Unicode: "263A-FE0F", Alias: []string{"face", "blush", "massage", "happiness"}}, ":relief:": emojiData{Name: ":sweat_smile:", Description: "Smiling Face with Open Mouth and Cold Sweat", Unicode: "1F605", Alias: []string{"face", "hot", "happy", "laugh", "sweat", "smile", "relief"}}, ":relieved:": emojiData{Name: ":relieved:", Description: "Relieved Face", Unicode: "1F60C", Alias: []string{"face", "relaxed", "phew", "massage", "happiness"}}, ":religion:": emojiData{Name: ":orthodox_cross:", Description: "Orthodox Cross", Unicode: "2626-FE0F", Alias: []string{"suppedaneum", "religion"}}, ":religious:": emojiData{Name: ":prayer_beads:", Description: "Prayer Beads", Unicode: "1F4FF", Alias: []string{"dhikr", "religious"}}, ":reminder_ribbon:": emojiData{Name: ":reminder_ribbon:", Description: "Reminder Ribbon", Unicode: "1F397-FE0F", Alias: []string{"sports", "cause", "support", "awareness"}}, ":remove:": emojiData{Name: ":x:", Description: "Cross Mark", Unicode: "274C", Alias: []string{"no", "delete", "remove", "cancel"}}, ":repeat:": emojiData{Name: ":arrows_clockwise:", Description: "Clockwise Downwards and Upwards Open Circle Arrows", Unicode: "1F503", Alias: []string{"sync", "cycle", "round", "repeat"}}, ":repeat_one:": emojiData{Name: ":repeat_one:", Description: "Clockwise Rightwards and Leftwards Open Circle Arrows with Circled One Overlay", Unicode: "1F502", Alias: []string{"blue-square", "loop"}}, ":reptile:": emojiData{Name: ":crocodile:", Description: "Crocodile", Unicode: "1F40A", Alias: []string{"animal", "nature", "reptile", "lizard", "alligator"}}, ":rest:": emojiData{Name: ":bed:", Description: "Bed", Unicode: "1F6CF-FE0F", Alias: []string{"sleep", "rest"}}, ":restricted:": emojiData{Name: ":u7981:", Description: "Squared Cjk Unified Ideograph-7981", Unicode: "1F232", Alias: []string{"kanji", "japanese", "chinese", "forbidden", "limit", "restricted", "red-square"}}, ":restroom:": emojiData{Name: ":wc:", Description: "Water Closet", Unicode: "1F6BE", Alias: []string{"toilet", "restroom", "blue-square"}}, ":return:": emojiData{Name: ":leftwards_arrow_with_hook:", Description: "Leftwards Arrow with Hook", Unicode: "21A9-FE0F", Alias: []string{"back", "return", "blue-square", "undo", "enter"}}, ":revolver:": emojiData{Name: ":gun:", Description: "Pistol", Unicode: "1F52B", Alias: []string{"violence", "weapon", "pistol", "revolver"}}, ":revolving_hearts:": emojiData{Name: ":revolving_hearts:", Description: "Revolving Hearts", Unicode: "1F49E", Alias: []string{"love", "like", "affection", "valentines"}}, ":rewind:": emojiData{Name: ":rewind:", Description: "Black Left-Pointing Double Triangle", Unicode: "23EA", Alias: []string{"play", "blue-square"}}, ":rhinoceros:": emojiData{Name: ":rhinoceros:", Description: "Rhinoceros", Unicode: "1F98F", Alias: []string{"animal", "nature", "horn"}}, ":ribbon:": emojiData{Name: ":ribbon:", Description: "Ribbon", Unicode: "1F380", Alias: []string{"decoration", "pink", "girl", "bowtie"}}, ":rice:": emojiData{Name: ":sushi:", Description: "Sushi", Unicode: "1F363", Alias: []string{"food", "fish", "japanese", "rice"}}, ":rice_ball:": emojiData{Name: ":rice_ball:", Description: "Rice Ball", Unicode: "1F359", Alias: []string{"food", "japanese"}}, ":rice_cracker:": emojiData{Name: ":rice_cracker:", Description: "Rice Cracker", Unicode: "1F358", Alias: []string{"food", "japanese"}}, ":rice_scene:": emojiData{Name: ":rice_scene:", Description: "Moon Viewing Ceremony", Unicode: "1F391", Alias: []string{"photo", "japan", "asia", "tsukimi"}}, ":rich:": emojiData{Name: ":money_mouth_face:", Description: "Money-Mouth Face", Unicode: "1F911", Alias: []string{"face", "rich", "dollar", "money"}}, ":right-facing_fist:": emojiData{Name: ":right-facing_fist:", Description: "Right-Facing Fist", Unicode: "1F91C", Alias: []string(nil)}, ":right:": emojiData{Name: ":arrow_forward:", Description: "Black Right-Pointing Triangle", Unicode: "25B6-FE0F", Alias: []string{"blue-square", "right", "direction", "play"}}, ":right_anger_bubble:": emojiData{Name: ":right_anger_bubble:", Description: "Right Anger Bubble", Unicode: "1F5EF-FE0F", Alias: []string{"caption", "speech", "thinking", "mad"}}, ":ring:": emojiData{Name: ":ring:", Description: "Ring", Unicode: "1F48D", Alias: []string{"wedding", "propose", "marriage", "valentines", "diamond", "fashion", "jewelry", "gem", "engagement"}}, ":rings:": emojiData{Name: ":link:", Description: "Link Symbol", Unicode: "1F517", Alias: []string{"rings", "url"}}, ":rip:": emojiData{Name: ":funeral_urn:", Description: "Funeral Urn", Unicode: "26B1-FE0F", Alias: []string{"dead", "die", "death", "rip", "ashes"}}, ":road:": emojiData{Name: ":motorway:", Description: "Motorway", Unicode: "1F6E3-FE0F", Alias: []string{"road", "cupertino", "interstate", "highway"}}, ":roar:": emojiData{Name: ":tiger2:", Description: "Tiger", Unicode: "1F405", Alias: []string{"animal", "nature", "roar"}}, ":robot_face:": emojiData{Name: ":robot_face:", Description: "Robot Face", Unicode: "1F916", Alias: []string(nil)}, ":rock:": emojiData{Name: ":moyai:", Description: "Moyai", Unicode: "1F5FF", Alias: []string{"rock", "easter island", "moai"}}, ":rocket:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":rodent:": emojiData{Name: ":mouse:", Description: "Mouse Face", Unicode: "1F42D", Alias: []string{"animal", "nature", "cheese_wedge", "rodent"}}, ":rolled_up_newspaper:": emojiData{Name: ":rolled_up_newspaper:", Description: "Rolled Up Newspaper", Unicode: "1F5DE-FE0F", Alias: []string(nil)}, ":roller_coaster:": emojiData{Name: ":roller_coaster:", Description: "Roller Coaster", Unicode: "1F3A2", Alias: []string{"carnival", "playground", "photo", "fun"}}, ":rolling_on_the_floor_laughing:": emojiData{Name: ":rolling_on_the_floor_laughing:", Description: "Rolling on the Floor Laughing", Unicode: "1F923", Alias: []string(nil)}, ":rooster:": emojiData{Name: ":rooster:", Description: "Rooster", Unicode: "1F413", Alias: []string{"animal", "nature", "chicken"}}, ":rose:": emojiData{Name: ":rose:", Description: "Rose", Unicode: "1F339", Alias: []string{"flowers", "valentines", "love", "spring"}}, ":rosette:": emojiData{Name: ":rosette:", Description: "Rosette", Unicode: "1F3F5-FE0F", Alias: []string{"flower", "decoration", "military"}}, ":rotate:": emojiData{Name: ":arrow_right_hook:", Description: "Rightwards Arrow with Hook", Unicode: "21AA-FE0F", Alias: []string{"blue-square", "return", "rotate", "direction"}}, ":rotating_light:": emojiData{Name: ":rotating_light:", Description: "Police Cars Revolving Light", Unicode: "1F6A8", Alias: []string{"police", "ambulance", "911", "emergency", "alert", "error", "pinged", "law", "legal"}}, ":round:": emojiData{Name: ":arrows_clockwise:", Description: "Clockwise Downwards and Upwards Open Circle Arrows", Unicode: "1F503", Alias: []string{"sync", "cycle", "round", "repeat"}}, ":round_pushpin:": emojiData{Name: ":round_pushpin:", Description: "Round Pushpin", Unicode: "1F4CD", Alias: []string{"stationery", "location", "map", "here"}}, ":rowboat:": emojiData{Name: ":rowboat:", Description: "Rowboat", Unicode: "1F6A3", Alias: []string(nil)}, ":royal:": emojiData{Name: ":guardsman:", Description: "Guardsman", Unicode: "1F482", Alias: []string{"uk", "gb", "british", "male", "guy", "royal"}}, ":royalty:": emojiData{Name: ":crown:", Description: "Crown", Unicode: "1F451", Alias: []string{"king", "kod", "leader", "royalty", "lord"}}, ":ru:": emojiData{Name: ":ru:", Description: "Russia Flag", Unicode: "1F1F7-1F1FA", Alias: []string{"russian", "federation", "flag", "nation", "country", "banner"}}, ":rubbish:": emojiData{Name: ":wastebasket:", Description: "Wastebasket", Unicode: "1F5D1-FE0F", Alias: []string{"bin", "trash", "rubbish", "garbage", "toss"}}, ":ruby:": emojiData{Name: ":gem:", Description: "Gem Stone", Unicode: "1F48E", Alias: []string{"blue", "ruby", "diamond", "jewelry"}}, ":rugby_football:": emojiData{Name: ":rugby_football:", Description: "Rugby Football", Unicode: "1F3C9", Alias: []string{"sports", "team"}}, ":rules:": emojiData{Name: ":no_pedestrians:", Description: "No Pedestrians", Unicode: "1F6B7", Alias: []string{"rules", "crossing", "walking", "circle"}}, ":runner:": emojiData{Name: ":runner:", Description: "Runner", Unicode: "1F3C3", Alias: []string(nil)}, ":running_shirt_with_sash:": emojiData{Name: ":running_shirt_with_sash:", Description: "Running Shirt with Sash", Unicode: "1F3BD", Alias: []string{"play", "pageant"}}, ":russian:": emojiData{Name: ":ru:", Description: "Russia Flag", Unicode: "1F1F7-1F1FA", Alias: []string{"russian", "federation", "flag", "nation", "country", "banner"}}, ":sa:": emojiData{Name: ":sa:", Description: "Squared Katakana Sa", Unicode: "1F202-FE0F", Alias: []string{"japanese", "blue-square", "katakana"}}, ":sad:": emojiData{Name: ":sob:", Description: "Loudly Crying Face", Unicode: "1F62D", Alias: []string{"face", "cry", "tears", "sad", "upset", "depressed"}}, ":sagittarius:": emojiData{Name: ":sagittarius:", Description: "Sagittarius", Unicode: "2650", Alias: []string{"sign", "zodiac", "purple-square", "astrology"}}, ":saharah:": emojiData{Name: ":desert:", Description: "Desert", Unicode: "1F3DC-FE0F", Alias: []string{"photo", "warm", "saharah"}}, ":sake:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":sale:": emojiData{Name: ":label:", Description: "Label", Unicode: "1F3F7-FE0F", Alias: []string{"sale", "tag"}}, ":sales:": emojiData{Name: ":bank:", Description: "Bank", Unicode: "1F3E6", Alias: []string{"building", "money", "sales", "cash", "business", "enterprise"}}, ":salon:": emojiData{Name: ":barber:", Description: "Barber Pole", Unicode: "1F488", Alias: []string{"hair", "salon", "style"}}, ":sandal:": emojiData{Name: ":sandal:", Description: "Womans Sandal", Unicode: "1F461", Alias: []string{"shoes", "fashion", "flip flops"}}, ":sandwich:": emojiData{Name: ":sandwich:", Description: "Sandwich", Unicode: "1F96A", Alias: []string(nil)}, ":sanfrancisco:": emojiData{Name: ":bridge_at_night:", Description: "Bridge at Night", Unicode: "1F309", Alias: []string{"photo", "sanfrancisco"}}, ":santa:": emojiData{Name: ":santa:", Description: "Father Christmas", Unicode: "1F385", Alias: []string{"festival", "man", "male", "xmas", "father christmas"}}, ":sarcasm:": emojiData{Name: ":unamused:", Description: "Unamused Face", Unicode: "1F612", Alias: []string{"indifference", "bored", "straight face", "serious", "sarcasm"}}, ":sasha:": emojiData{Name: ":motor_scooter:", Description: "Motor Scooter", Unicode: "1F6F5", Alias: []string{"vehicle", "vespa", "sasha"}}, ":satellite:": emojiData{Name: ":satellite:", Description: "Satellite", Unicode: "1F6F0-FE0F", Alias: []string{"communication", "future", "radio", "space"}}, ":satellite_antenna:": emojiData{Name: ":satellite_antenna:", Description: "Satellite Antenna", Unicode: "1F4E1", Alias: []string(nil)}, ":satisfied:": emojiData{Name: ":laughing:", Description: "Smiling Face with Open Mouth and Tightly-Closed Eyes", Unicode: "1F606", Alias: []string{"happy", "joy", "lol", "satisfied", "haha", "face", "glad", "XD", "laugh"}}, ":sauropod:": emojiData{Name: ":sauropod:", Description: "Sauropod", Unicode: "1F995", Alias: []string(nil)}, ":save:": emojiData{Name: ":bookmark:", Description: "Bookmark", Unicode: "1F516", Alias: []string{"favorite", "label", "save"}}, ":savouring:": emojiData{Name: ":yum:", Description: "Face Savouring Delicious Food", Unicode: "1F60B", Alias: []string{"happy", "joy", "tongue", "smile", "face", "silly", "yummy", "nom", "delicious", "savouring"}}, ":saxophone:": emojiData{Name: ":saxophone:", Description: "Saxophone", Unicode: "1F3B7", Alias: []string{"music", "instrument", "jazz", "blues"}}, ":scale:": emojiData{Name: ":level_slider:", Description: "Level Slider", Unicode: "1F39A-FE0F", Alias: []string{"scale"}}, ":scales:": emojiData{Name: ":scales:", Description: "Scales", Unicode: "2696-FE0F", Alias: []string(nil)}, ":scared:": emojiData{Name: ":scream:", Description: "Face Screaming in Fear", Unicode: "1F631", Alias: []string{"face", "munch", "scared", "omg"}}, ":scarf:": emojiData{Name: ":scarf:", Description: "Scarf", Unicode: "1F9E3", Alias: []string(nil)}, ":scary:": emojiData{Name: ":japanese_ogre:", Description: "Japanese Ogre", Unicode: "1F479", Alias: []string{"monster", "red", "mask", "halloween", "scary", "creepy", "devil", "demon", "japanese", "ogre"}}, ":schedule:": emojiData{Name: ":calendar:", Description: "Tear-off Calendar", Unicode: "1F4C6", Alias: []string{"schedule", "date", "planning"}}, ":school:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":school_satchel:": emojiData{Name: ":school_satchel:", Description: "School Satchel", Unicode: "1F392", Alias: []string{"student", "education", "bag", "backpack"}}, ":science:": emojiData{Name: ":alembic:", Description: "Alembic", Unicode: "2697-FE0F", Alias: []string{"distilling", "science", "experiment", "chemistry"}}, ":scissors:": emojiData{Name: ":scissors:", Description: "Black Scissors", Unicode: "2702-FE0F", Alias: []string{"stationery", "cut"}}, ":scooter:": emojiData{Name: ":scooter:", Description: "Scooter", Unicode: "1F6F4", Alias: []string(nil)}, ":score:": emojiData{Name: ":notes:", Description: "Multiple Musical Notes", Unicode: "1F3B6", Alias: []string{"music", "score"}}, ":scorpio:": emojiData{Name: ":scorpius:", Description: "Scorpius", Unicode: "264F", Alias: []string{"sign", "zodiac", "purple-square", "astrology", "scorpio"}}, ":scorpion:": emojiData{Name: ":scorpion:", Description: "Scorpion", Unicode: "1F982", Alias: []string{"animal", "arachnid"}}, ":scorpius:": emojiData{Name: ":scorpius:", Description: "Scorpius", Unicode: "264F", Alias: []string{"sign", "zodiac", "purple-square", "astrology", "scorpio"}}, ":scotch:": emojiData{Name: ":tumbler_glass:", Description: "Tumbler Glass", Unicode: "1F943", Alias: []string{"drink", "beverage", "drunk", "alcohol", "liquor", "booze", "bourbon", "scotch", "whisky", "glass", "shot"}}, ":scout:": emojiData{Name: ":fleur_de_lis:", Description: "Fleur De Lis", Unicode: "269C-FE0F", Alias: []string{"decorative", "scout"}}, ":scream:": emojiData{Name: ":scream:", Description: "Face Screaming in Fear", Unicode: "1F631", Alias: []string{"face", "munch", "scared", "omg"}}, ":scream_cat:": emojiData{Name: ":scream_cat:", Description: "Weary Cat Face", Unicode: "1F640", Alias: []string{"animal", "cats", "munch", "scared", "scream"}}, ":screen:": emojiData{Name: ":desktop_computer:", Description: "Desktop Computer", Unicode: "1F5A5-FE0F", Alias: []string{"technology", "computing", "screen"}}, ":scribble:": emojiData{Name: ":curly_loop:", Description: "Curly Loop", Unicode: "27B0", Alias: []string{"scribble", "draw", "shape", "squiggle"}}, ":scroll:": emojiData{Name: ":scroll:", Description: "Scroll", Unicode: "1F4DC", Alias: []string{"documents", "ancient", "history", "paper"}}, ":sea:": emojiData{Name: ":shell:", Description: "Spiral Shell", Unicode: "1F41A", Alias: []string{"nature", "sea", "beach"}}, ":seafood:": emojiData{Name: ":shrimp:", Description: "Shrimp", Unicode: "1F990", Alias: []string{"animal", "ocean", "nature", "seafood"}}, ":sealed:": emojiData{Name: ":zipper_mouth_face:", Description: "Zipper-Mouth Face", Unicode: "1F910", Alias: []string{"face", "sealed", "zipper", "secret"}}, ":search:": emojiData{Name: ":mag:", Description: "Left-Pointing Magnifying Glass", Unicode: "1F50D", Alias: []string{"search", "zoom", "find", "detective"}}, ":season:": emojiData{Name: ":snowflake:", Description: "Snowflake", Unicode: "2744-FE0F", Alias: []string{"winter", "season", "cold", "weather", "christmas", "xmas"}}, ":seat:": emojiData{Name: ":seat:", Description: "Seat", Unicode: "1F4BA", Alias: []string{"sit", "airplane", "transport", "bus", "flight", "fly"}}, ":second_place_medal:": emojiData{Name: ":second_place_medal:", Description: "Second Place Medal", Unicode: "1F948", Alias: []string(nil)}, ":secret:": emojiData{Name: ":secret:", Description: "Circled Ideograph Secret", Unicode: "3299-FE0F", Alias: []string{"privacy", "chinese", "sshh", "kanji", "red-circle"}}, ":security:": emojiData{Name: ":closed_lock_with_key:", Description: "Closed Lock with Key", Unicode: "1F510", Alias: []string{"security", "privacy"}}, ":see:": emojiData{Name: ":eyes:", Description: "Eyes", Unicode: "1F440", Alias: []string{"look", "watch", "stalk", "peek", "see"}}, ":see_no_evil:": emojiData{Name: ":see_no_evil:", Description: "See-No-Evil Monkey", Unicode: "1F648", Alias: []string{"monkey", "animal", "nature", "haha"}}, ":seedling:": emojiData{Name: ":seedling:", Description: "Seedling", Unicode: "1F331", Alias: []string{"plant", "nature", "grass", "lawn", "spring"}}, ":selfie:": emojiData{Name: ":selfie:", Description: "Selfie", Unicode: "1F933", Alias: []string{"camera", "phone"}}, ":senior:": emojiData{Name: ":older_man:", Description: "Older Man", Unicode: "1F474", Alias: []string{"human", "male", "men", "old", "elder", "senior"}}, ":serious:": emojiData{Name: ":unamused:", Description: "Unamused Face", Unicode: "1F612", Alias: []string{"indifference", "bored", "straight face", "serious", "sarcasm"}}, ":service:": emojiData{Name: ":bellhop_bell:", Description: "Bellhop Bell", Unicode: "1F6CE-FE0F", Alias: []string{"service"}}, ":seven:": emojiData{Name: ":seven:", Description: "Keycap 7", Unicode: "0037-FE0F-20E3", Alias: []string{"7", "numbers", "blue-square", "prime"}}, ":shake:": emojiData{Name: ":handshake:", Description: "Handshake", Unicode: "1F91D", Alias: []string{"agreement", "shake"}}, ":shallow_pan_of_food:": emojiData{Name: ":shallow_pan_of_food:", Description: "Shallow Pan of Food", Unicode: "1F958", Alias: []string{"food", "cooking", "casserole", "paella"}}, ":shamrock:": emojiData{Name: ":shamrock:", Description: "Shamrock", Unicode: "2618-FE0F", Alias: []string{"vegetable", "plant", "nature", "irish", "clover"}}, ":shape:": emojiData{Name: ":black_small_square:", Description: "Black Small Square", Unicode: "25AA-FE0F", Alias: []string{"shape", "icon"}}, ":shark:": emojiData{Name: ":shark:", Description: "Shark", Unicode: "1F988", Alias: []string{"animal", "nature", "fish", "sea", "ocean", "jaws", "fins", "beach"}}, ":shaved_ice:": emojiData{Name: ":shaved_ice:", Description: "Shaved Ice", Unicode: "1F367", Alias: []string{"hot", "dessert", "summer"}}, ":sheep:": emojiData{Name: ":ram:", Description: "Ram", Unicode: "1F40F", Alias: []string{"animal", "sheep", "nature"}}, ":shell:": emojiData{Name: ":shell:", Description: "Spiral Shell", Unicode: "1F41A", Alias: []string{"nature", "sea", "beach"}}, ":shh:": emojiData{Name: ":hushed:", Description: "Hushed Face", Unicode: "1F62F", Alias: []string{"face", "woo", "shh"}}, ":shield:": emojiData{Name: ":shield:", Description: "Shield", Unicode: "1F6E1-FE0F", Alias: []string{"protection", "security"}}, ":shine:": emojiData{Name: ":sparkles:", Description: "Sparkles", Unicode: "2728", Alias: []string{"stars", "shine", "shiny", "cool", "awesome", "good", "magic"}}, ":shinto_shrine:": emojiData{Name: ":shinto_shrine:", Description: "Shinto Shrine", Unicode: "26E9-FE0F", Alias: []string{"temple", "japan", "kyoto"}}, ":shiny:": emojiData{Name: ":sparkles:", Description: "Sparkles", Unicode: "2728", Alias: []string{"stars", "shine", "shiny", "cool", "awesome", "good", "magic"}}, ":ship:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":shipit:": emojiData{Name: ":sheep:", Description: "Sheep", Unicode: "1F411", Alias: []string{"animal", "nature", "wool", "shipit"}}, ":shirt:": emojiData{Name: ":shirt:", Description: "T-Shirt", Unicode: "1F455", Alias: []string(nil)}, ":shoes:": emojiData{Name: ":sandal:", Description: "Womans Sandal", Unicode: "1F461", Alias: []string{"shoes", "fashion", "flip flops"}}, ":shoo:": emojiData{Name: ":dash:", Description: "Dash Symbol", Unicode: "1F4A8", Alias: []string{"wind", "air", "fast", "shoo", "fart", "smoke", "puff"}}, ":shoot:": emojiData{Name: ":dizzy:", Description: "Dizzy Symbol", Unicode: "1F4AB", Alias: []string{"star", "sparkle", "shoot", "magic"}}, ":shopping:": emojiData{Name: ":dress:", Description: "Dress", Unicode: "1F457", Alias: []string{"clothes", "fashion", "shopping"}}, ":shopping_bags:": emojiData{Name: ":womans_clothes:", Description: "Womans Clothes", Unicode: "1F45A", Alias: []string{"fashion", "shopping_bags", "female"}}, ":shopping_trolley:": emojiData{Name: ":shopping_trolley:", Description: "Shopping Trolley", Unicode: "1F6D2", Alias: []string(nil)}, ":shot:": emojiData{Name: ":tumbler_glass:", Description: "Tumbler Glass", Unicode: "1F943", Alias: []string{"drink", "beverage", "drunk", "alcohol", "liquor", "booze", "bourbon", "scotch", "whisky", "glass", "shot"}}, ":show:": emojiData{Name: ":tv:", Description: "Television", Unicode: "1F4FA", Alias: []string{"technology", "program", "oldschool", "show", "television"}}, ":shower:": emojiData{Name: ":bathtub:", Description: "Bathtub", Unicode: "1F6C1", Alias: []string{"clean", "shower", "bathroom"}}, ":shrimp:": emojiData{Name: ":shrimp:", Description: "Shrimp", Unicode: "1F990", Alias: []string{"animal", "ocean", "nature", "seafood"}}, ":shrug:": emojiData{Name: ":shrug:", Description: "Shrug", Unicode: "1F937", Alias: []string(nil)}, ":shuffle:": emojiData{Name: ":twisted_rightwards_arrows:", Description: "Twisted Rightwards Arrows", Unicode: "1F500", Alias: []string{"blue-square", "shuffle", "music", "random"}}, ":shushing_face:": emojiData{Name: ":shushing_face:", Description: "Face with Finger Covering Closed Lips", Unicode: "1F92B", Alias: []string(nil)}, ":shy:": emojiData{Name: ":blush:", Description: "Smiling Face with Smiling Eyes", Unicode: "1F60A", Alias: []string{"face", "smile", "happy", "flushed", "crush", "embarrassed", "shy", "joy"}}, ":sick:": emojiData{Name: ":sneezing_face:", Description: "Sneezing Face", Unicode: "1F927", Alias: []string{"face", "gesundheit", "sneeze", "sick", "allergy"}}, ":sideways:": emojiData{Name: ":left_right_arrow:", Description: "Left Right Arrow", Unicode: "2194-FE0F", Alias: []string{"shape", "direction", "horizontal", "sideways"}}, ":sight:": emojiData{Name: ":flashlight:", Description: "Electric Torch", Unicode: "1F526", Alias: []string{"dark", "camping", "sight", "night"}}, ":sign:": emojiData{Name: ":ophiuchus:", Description: "Ophiuchus", Unicode: "26CE", Alias: []string{"sign", "purple-square", "constellation", "astrology"}}, ":signal:": emojiData{Name: ":traffic_light:", Description: "Horizontal Traffic Light", Unicode: "1F6A5", Alias: []string{"transportation", "signal"}}, ":signal_strength:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":sikhism:": emojiData{Name: ":wheel_of_dharma:", Description: "Wheel of Dharma", Unicode: "2638-FE0F", Alias: []string{"hinduism", "buddhism", "sikhism", "jainism"}}, ":silence:": emojiData{Name: ":mobile_phone_off:", Description: "Mobile Phone off", Unicode: "1F4F4", Alias: []string{"mute", "orange-square", "silence", "quiet"}}, ":silent:": emojiData{Name: ":no_bell:", Description: "Bell with Cancellation Stroke", Unicode: "1F515", Alias: []string{"sound", "volume", "mute", "quiet", "silent"}}, ":silk:": emojiData{Name: ":spider_web:", Description: "Spider Web", Unicode: "1F578-FE0F", Alias: []string{"animal", "insect", "arachnid", "silk"}}, ":silly:": emojiData{Name: ":yum:", Description: "Face Savouring Delicious Food", Unicode: "1F60B", Alias: []string{"happy", "joy", "tongue", "smile", "face", "silly", "yummy", "nom", "delicious", "savouring"}}, ":sing:": emojiData{Name: ":studio_microphone:", Description: "Studio Microphone", Unicode: "1F399-FE0F", Alias: []string{"sing", "recording", "artist", "talkshow"}}, ":sir:": emojiData{Name: ":man:", Description: "Man", Unicode: "1F468", Alias: []string{"mustache", "father", "dad", "guy", "classy", "sir", "moustache"}}, ":sit:": emojiData{Name: ":seat:", Description: "Seat", Unicode: "1F4BA", Alias: []string{"sit", "airplane", "transport", "bus", "flight", "fly"}}, ":six:": emojiData{Name: ":six:", Description: "Keycap 6", Unicode: "0036-FE0F-20E3", Alias: []string{"6", "numbers", "blue-square"}}, ":six_pointed_star:": emojiData{Name: ":six_pointed_star:", Description: "Six Pointed Star with Middle Dot", Unicode: "1F52F", Alias: []string{"purple-square", "religion", "jewish", "hexagram"}}, ":skeleton:": emojiData{Name: ":skull:", Description: "Skull", Unicode: "1F480", Alias: []string{"dead", "skeleton", "creepy", "death"}}, ":sketch:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":ski:": emojiData{Name: ":ski:", Description: "Ski and Ski Boot", Unicode: "1F3BF", Alias: []string{"sports", "winter", "cold", "snow"}}, ":skier:": emojiData{Name: ":skier:", Description: "Skier", Unicode: "26F7-FE0F", Alias: []string{"sports", "winter", "snow"}}, ":skull:": emojiData{Name: ":skull:", Description: "Skull", Unicode: "1F480", Alias: []string{"dead", "skeleton", "creepy", "death"}}, ":skull_and_crossbones:": emojiData{Name: ":skull_and_crossbones:", Description: "Skull and Crossbones", Unicode: "2620-FE0F", Alias: []string{"poison", "danger", "deadly", "scary", "death", "pirate", "evil"}}, ":sky:": emojiData{Name: ":cloud:", Description: "Cloud", Unicode: "2601-FE0F", Alias: []string{"weather", "sky"}}, ":sled:": emojiData{Name: ":sled:", Description: "Sled", Unicode: "1F6F7", Alias: []string(nil)}, ":sleep:": emojiData{Name: ":bed:", Description: "Bed", Unicode: "1F6CF-FE0F", Alias: []string{"sleep", "rest"}}, ":sleeping:": emojiData{Name: ":sleeping:", Description: "Sleeping Face", Unicode: "1F634", Alias: []string{"face", "tired", "sleepy", "night", "zzz"}}, ":sleeping_accommodation:": emojiData{Name: ":sleeping_accommodation:", Description: "Sleeping Accommodation", Unicode: "1F6CC", Alias: []string(nil)}, ":sleepy:": emojiData{Name: ":sleepy:", Description: "Sleepy Face", Unicode: "1F62A", Alias: []string{"face", "tired", "rest", "nap"}}, ":sleuth_or_spy:": emojiData{Name: ":sleuth_or_spy:", Description: "Sleuth or Spy", Unicode: "1F575-FE0F", Alias: []string(nil)}, ":slightly_frowning_face:": emojiData{Name: ":slightly_frowning_face:", Description: "Slightly Frowning Face", Unicode: "1F641", Alias: []string{"face", "frowning", "disappointed", "sad", "upset"}}, ":slightly_smiling_face:": emojiData{Name: ":slightly_smiling_face:", Description: "Slightly Smiling Face", Unicode: "1F642", Alias: []string{"face", "smile"}}, ":slot_machine:": emojiData{Name: ":slot_machine:", Description: "Slot Machine", Unicode: "1F3B0", Alias: []string{"bet", "gamble", "vegas", "fruit machine", "luck", "casino"}}, ":slow:": emojiData{Name: ":snail:", Description: "Snail", Unicode: "1F40C", Alias: []string{"slow", "animal", "shell"}}, ":small_airplane:": emojiData{Name: ":small_airplane:", Description: "Small Airplane", Unicode: "1F6E9-FE0F", Alias: []string{"flight", "transportation", "fly", "vehicle"}}, ":small_blue_diamond:": emojiData{Name: ":small_blue_diamond:", Description: "Small Blue Diamond", Unicode: "1F539", Alias: []string{"shape", "jewel", "gem"}}, ":small_orange_diamond:": emojiData{Name: ":small_orange_diamond:", Description: "Small Orange Diamond", Unicode: "1F538", Alias: []string{"shape", "jewel", "gem"}}, ":small_red_triangle:": emojiData{Name: ":small_red_triangle:", Description: "Up-Pointing Red Triangle", Unicode: "1F53A", Alias: []string{"shape", "direction", "up", "top"}}, ":small_red_triangle_down:": emojiData{Name: ":small_red_triangle_down:", Description: "Down-Pointing Red Triangle", Unicode: "1F53B", Alias: []string{"shape", "direction", "bottom"}}, ":smell:": emojiData{Name: ":nose:", Description: "Nose", Unicode: "1F443", Alias: []string{"smell", "sniff"}}, ":smile:": emojiData{Name: ":sunglasses:", Description: "Smiling Face with Sunglasses", Unicode: "1F60E", Alias: []string{"face", "cool", "smile", "summer", "beach", "sunglass"}}, ":smile_cat:": emojiData{Name: ":smile_cat:", Description: "Grinning Cat Face with Smiling Eyes", Unicode: "1F638", Alias: []string{"animal", "cats", "smile"}}, ":smiley:": emojiData{Name: ":smiley:", Description: "Smiling Face with Open Mouth", Unicode: "1F603", Alias: []string{"face", "happy", "joy", "haha", ":D", ":)", "smile", "funny"}}, ":smiley_cat:": emojiData{Name: ":smiley_cat:", Description: "Smiling Cat Face with Open Mouth", Unicode: "1F63A", Alias: []string{"animal", "cats", "happy", "smile"}}, ":smiling_imp:": emojiData{Name: ":smiling_imp:", Description: "Smiling Face with Horns", Unicode: "1F608", Alias: []string{"devil", "horns"}}, ":smirk:": emojiData{Name: ":smirk:", Description: "Smirking Face", Unicode: "1F60F", Alias: []string{"face", "smile", "mean", "prank", "smug", "sarcasm"}}, ":smirk_cat:": emojiData{Name: ":smirk_cat:", Description: "Cat Face with Wry Smile", Unicode: "1F63C", Alias: []string{"animal", "cats", "smirk"}}, ":smoke:": emojiData{Name: ":no_smoking:", Description: "No Smoking Symbol", Unicode: "1F6AD", Alias: []string{"cigarette", "blue-square", "smell", "smoke"}}, ":smoking:": emojiData{Name: ":smoking:", Description: "Smoking Symbol", Unicode: "1F6AC", Alias: []string{"kills", "tobacco", "cigarette", "joint", "smoke"}}, ":smug:": emojiData{Name: ":smirk:", Description: "Smirking Face", Unicode: "1F60F", Alias: []string{"face", "smile", "mean", "prank", "smug", "sarcasm"}}, ":snack:": emojiData{Name: ":popcorn:", Description: "Popcorn", Unicode: "1F37F", Alias: []string{"food", "movie theater", "films", "snack"}}, ":snail:": emojiData{Name: ":snail:", Description: "Snail", Unicode: "1F40C", Alias: []string{"slow", "animal", "shell"}}, ":snake:": emojiData{Name: ":snake:", Description: "Snake", Unicode: "1F40D", Alias: []string{"animal", "evil", "nature", "hiss", "python"}}, ":sneakers:": emojiData{Name: ":athletic_shoe:", Description: "Athletic Shoe", Unicode: "1F45F", Alias: []string{"shoes", "sports", "sneakers"}}, ":sneeze:": emojiData{Name: ":sneezing_face:", Description: "Sneezing Face", Unicode: "1F927", Alias: []string{"face", "gesundheit", "sneeze", "sick", "allergy"}}, ":sneezing_face:": emojiData{Name: ":sneezing_face:", Description: "Sneezing Face", Unicode: "1F927", Alias: []string{"face", "gesundheit", "sneeze", "sick", "allergy"}}, ":sniff:": emojiData{Name: ":nose:", Description: "Nose", Unicode: "1F443", Alias: []string{"smell", "sniff"}}, ":snow:": emojiData{Name: ":ski:", Description: "Ski and Ski Boot", Unicode: "1F3BF", Alias: []string{"sports", "winter", "cold", "snow"}}, ":snow_capped_mountain:": emojiData{Name: ":snow_capped_mountain:", Description: "Snow Capped Mountain", Unicode: "1F3D4-FE0F", Alias: []string(nil)}, ":snow_cloud:": emojiData{Name: ":snow_cloud:", Description: "Snow Cloud", Unicode: "1F328-FE0F", Alias: []string(nil)}, ":snowboarder:": emojiData{Name: ":snowboarder:", Description: "Snowboarder", Unicode: "1F3C2", Alias: []string{"sports", "winter"}}, ":snowflake:": emojiData{Name: ":snowflake:", Description: "Snowflake", Unicode: "2744-FE0F", Alias: []string{"winter", "season", "cold", "weather", "christmas", "xmas"}}, ":snowman:": emojiData{Name: ":snowman:", Description: "Snowman", Unicode: "2603-FE0F", Alias: []string{"winter", "season", "cold", "weather", "christmas", "xmas", "frozen", "without_snow"}}, ":snowman_without_snow:": emojiData{Name: ":snowman_without_snow:", Description: "Snowman Without Snow", Unicode: "26C4", Alias: []string(nil)}, ":sob:": emojiData{Name: ":sob:", Description: "Loudly Crying Face", Unicode: "1F62D", Alias: []string{"face", "cry", "tears", "sad", "upset", "depressed"}}, ":soccer:": emojiData{Name: ":soccer:", Description: "Soccer Ball", Unicode: "26BD", Alias: []string{"sports", "football"}}, ":socks:": emojiData{Name: ":socks:", Description: "Socks", Unicode: "1F9E6", Alias: []string(nil)}, ":solong:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":soon:": emojiData{Name: ":soon:", Description: "Soon with Rightwards Arrow Above", Unicode: "1F51C", Alias: []string{"arrow", "words"}}, ":sorry:": emojiData{Name: ":broken_heart:", Description: "Broken Heart", Unicode: "1F494", Alias: []string{"sad", "sorry", "break", "heart", "heartbreak"}}, ":sos:": emojiData{Name: ":sos:", Description: "Squared Sos", Unicode: "1F198", Alias: []string{"help", "red-square", "words", "emergency", "911"}}, ":sound:": emojiData{Name: ":mega:", Description: "Cheering Megaphone", Unicode: "1F4E3", Alias: []string{"sound", "speaker", "volume"}}, ":soup:": emojiData{Name: ":stew:", Description: "Pot of Food", Unicode: "1F372", Alias: []string{"food", "meat", "soup"}}, ":south:": emojiData{Name: ":kr:", Description: "South Korea Flag", Unicode: "1F1F0-1F1F7", Alias: []string{"south", "korea", "nation", "flag", "country", "banner"}}, ":southeast:": emojiData{Name: ":arrow_lower_right:", Description: "South East Arrow", Unicode: "2198-FE0F", Alias: []string{"blue-square", "direction", "diagonal", "southeast"}}, ":southwest:": emojiData{Name: ":arrow_lower_left:", Description: "South West Arrow", Unicode: "2199-FE0F", Alias: []string{"blue-square", "direction", "diagonal", "southwest"}}, ":space:": emojiData{Name: ":waning_crescent_moon:", Description: "Waning Crescent Moon Symbol", Unicode: "1F318", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":space_invader:": emojiData{Name: ":space_invader:", Description: "Alien Monster", Unicode: "1F47E", Alias: []string{"game", "arcade", "play"}}, ":spades:": emojiData{Name: ":spades:", Description: "Black Spade Suit", Unicode: "2660-FE0F", Alias: []string{"poker", "cards", "suits", "magic"}}, ":spaghetti:": emojiData{Name: ":spaghetti:", Description: "Spaghetti", Unicode: "1F35D", Alias: []string{"food", "italian", "noodle"}}, ":spain:": emojiData{Name: ":es:", Description: "Spain Flag", Unicode: "1F1EA-1F1F8", Alias: []string{"spain", "flag", "nation", "country", "banner"}}, ":sparkle:": emojiData{Name: ":star2:", Description: "Glowing Star", Unicode: "1F31F", Alias: []string{"night", "sparkle", "awesome", "good", "magic"}}, ":sparkler:": emojiData{Name: ":sparkler:", Description: "Firework Sparkler", Unicode: "1F387", Alias: []string{"stars", "night", "shine"}}, ":sparkles:": emojiData{Name: ":sparkles:", Description: "Sparkles", Unicode: "2728", Alias: []string{"stars", "shine", "shiny", "cool", "awesome", "good", "magic"}}, ":sparkling_heart:": emojiData{Name: ":sparkling_heart:", Description: "Sparkling Heart", Unicode: "1F496", Alias: []string{"love", "like", "affection", "valentines"}}, ":speak_no_evil:": emojiData{Name: ":speak_no_evil:", Description: "Speak-No-Evil Monkey", Unicode: "1F64A", Alias: []string{"monkey", "animal", "nature", "omg"}}, ":speaker:": emojiData{Name: ":mega:", Description: "Cheering Megaphone", Unicode: "1F4E3", Alias: []string{"sound", "speaker", "volume"}}, ":speaking_head_in_silhouette:": emojiData{Name: ":speaking_head_in_silhouette:", Description: "Speaking Head in Silhouette", Unicode: "1F5E3-FE0F", Alias: []string(nil)}, ":spear:": emojiData{Name: ":trident:", Description: "Trident Emblem", Unicode: "1F531", Alias: []string{"weapon", "spear"}}, ":speech:": emojiData{Name: ":thought_balloon:", Description: "Thought Balloon", Unicode: "1F4AD", Alias: []string{"bubble", "cloud", "speech", "thinking", "dream"}}, ":speech_balloon:": emojiData{Name: ":speech_balloon:", Description: "Speech Balloon", Unicode: "1F4AC", Alias: []string{"bubble", "words", "message", "talk", "chatting"}}, ":speed:": emojiData{Name: ":fast_forward:", Description: "Black Right-Pointing Double Triangle", Unicode: "23E9", Alias: []string{"blue-square", "play", "speed", "continue"}}, ":speedboat:": emojiData{Name: ":speedboat:", Description: "Speedboat", Unicode: "1F6A4", Alias: []string{"ship", "transportation", "vehicle", "summer"}}, ":spent:": emojiData{Name: ":dizzy_face:", Description: "Dizzy Face", Unicode: "1F635", Alias: []string{"spent", "unconscious", "xox", "dizzy"}}, ":spicy:": emojiData{Name: ":curry:", Description: "Curry and Rice", Unicode: "1F35B", Alias: []string{"food", "spicy", "hot", "indian"}}, ":spider:": emojiData{Name: ":spider:", Description: "Spider", Unicode: "1F577-FE0F", Alias: []string{"animal", "arachnid"}}, ":spider_web:": emojiData{Name: ":spider_web:", Description: "Spider Web", Unicode: "1F578-FE0F", Alias: []string{"animal", "insect", "arachnid", "silk"}}, ":spin:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":spiral:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":spiral_calendar_pad:": emojiData{Name: ":spiral_calendar_pad:", Description: "Spiral Calendar Pad", Unicode: "1F5D3-FE0F", Alias: []string(nil)}, ":spiral_note_pad:": emojiData{Name: ":spiral_note_pad:", Description: "Spiral Note Pad", Unicode: "1F5D2-FE0F", Alias: []string(nil)}, ":spock-hand:": emojiData{Name: ":spock-hand:", Description: "Raised Hand with Part Between Middle and Ring Fingers", Unicode: "1F596", Alias: []string(nil)}, ":spooky:": emojiData{Name: ":izakaya_lantern:", Description: "Izakaya Lantern", Unicode: "1F3EE", Alias: []string{"light", "paper", "halloween", "spooky"}}, ":spoon:": emojiData{Name: ":spoon:", Description: "Spoon", Unicode: "1F944", Alias: []string{"cutlery", "kitchen", "tableware"}}, ":sports:": emojiData{Name: ":volleyball:", Description: "Volleyball", Unicode: "1F3D0", Alias: []string{"sports", "balls"}}, ":sports_medal:": emojiData{Name: ":sports_medal:", Description: "Sports Medal", Unicode: "1F3C5", Alias: []string(nil)}, ":spring:": emojiData{Name: ":white_flower:", Description: "White Flower", Unicode: "1F4AE", Alias: []string{"japanese", "spring"}}, ":squid:": emojiData{Name: ":squid:", Description: "Squid", Unicode: "1F991", Alias: []string{"animal", "nature", "ocean", "sea"}}, ":squiggle:": emojiData{Name: ":curly_loop:", Description: "Curly Loop", Unicode: "27B0", Alias: []string{"scribble", "draw", "shape", "squiggle"}}, ":squirrel:": emojiData{Name: ":chestnut:", Description: "Chestnut", Unicode: "1F330", Alias: []string{"food", "squirrel"}}, ":sshh:": emojiData{Name: ":secret:", Description: "Circled Ideograph Secret", Unicode: "3299-FE0F", Alias: []string{"privacy", "chinese", "sshh", "kanji", "red-circle"}}, ":stadium:": emojiData{Name: ":stadium:", Description: "Stadium", Unicode: "1F3DF-FE0F", Alias: []string{"photo", "place", "sports", "concert", "venue"}}, ":staffmode:": emojiData{Name: ":rocket:", Description: "Rocket", Unicode: "1F680", Alias: []string{"launch", "ship", "staffmode", "NASA", "outer space", "outer_space", "fly"}}, ":stage:": emojiData{Name: ":cinema:", Description: "Cinema", Unicode: "1F3A6", Alias: []string{"blue-square", "record", "film", "movie", "curtain", "stage", "theater"}}, ":stalk:": emojiData{Name: ":eyes:", Description: "Eyes", Unicode: "1F440", Alias: []string{"look", "watch", "stalk", "peek", "see"}}, ":star-struck:": emojiData{Name: ":star-struck:", Description: "Grinning Face with Star Eyes", Unicode: "1F929", Alias: []string(nil)}, ":star2:": emojiData{Name: ":star2:", Description: "Glowing Star", Unicode: "1F31F", Alias: []string{"night", "sparkle", "awesome", "good", "magic"}}, ":star:": emojiData{Name: ":star:", Description: "White Medium Star", Unicode: "2B50", Alias: []string{"night", "yellow"}}, ":star_and_crescent:": emojiData{Name: ":star_and_crescent:", Description: "Star and Crescent", Unicode: "262A-FE0F", Alias: []string{"islam"}}, ":star_of_david:": emojiData{Name: ":star_of_david:", Description: "Star of David", Unicode: "2721-FE0F", Alias: []string{"judaism"}}, ":starch:": emojiData{Name: ":potato:", Description: "Potato", Unicode: "1F954", Alias: []string{"food", "tuber", "vegatable", "starch"}}, ":stare:": emojiData{Name: ":eye:", Description: "Eye", Unicode: "1F441-FE0F", Alias: []string{"face", "look", "see", "watch", "stare"}}, ":stars:": emojiData{Name: ":stars:", Description: "Shooting Star", Unicode: "1F320", Alias: []string{"night", "photo"}}, ":start:": emojiData{Name: ":new:", Description: "Squared New", Unicode: "1F195", Alias: []string{"blue-square", "words", "start"}}, ":states:": emojiData{Name: ":us:", Description: "United States Flag", Unicode: "1F1FA-1F1F8", Alias: []string{"united", "states", "america", "flag", "nation", "country", "banner"}}, ":station:": emojiData{Name: ":station:", Description: "Station", Unicode: "1F689", Alias: []string{"transportation", "vehicle", "public"}}, ":stationery:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":stats:": emojiData{Name: ":part_alternation_mark:", Description: "Part Alternation Mark", Unicode: "303D-FE0F", Alias: []string{"graph", "presentation", "stats", "business", "economics", "bad"}}, ":statue_of_liberty:": emojiData{Name: ":statue_of_liberty:", Description: "Statue of Liberty", Unicode: "1F5FD", Alias: []string{"american", "newyork"}}, ":steam_locomotive:": emojiData{Name: ":steam_locomotive:", Description: "Steam Locomotive", Unicode: "1F682", Alias: []string{"transportation", "vehicle", "train"}}, ":sterling:": emojiData{Name: ":pound:", Description: "Banknote with Pound Sign", Unicode: "1F4B7", Alias: []string{"british", "sterling", "money", "sales", "bills", "uk", "england", "currency"}}, ":stew:": emojiData{Name: ":stew:", Description: "Pot of Food", Unicode: "1F372", Alias: []string{"food", "meat", "soup"}}, ":stiletto:": emojiData{Name: ":high_heel:", Description: "High-Heeled Shoe", Unicode: "1F460", Alias: []string{"fashion", "shoes", "female", "pumps", "stiletto"}}, ":stone:": emojiData{Name: ":white_medium_square:", Description: "White Medium Square", Unicode: "25FB-FE0F", Alias: []string{"shape", "stone", "icon"}}, ":stop:": emojiData{Name: ":no_entry_sign:", Description: "No Entry Sign", Unicode: "1F6AB", Alias: []string{"forbid", "stop", "limit", "denied", "disallow", "circle"}}, ":stopwatch:": emojiData{Name: ":stopwatch:", Description: "Stopwatch", Unicode: "23F1-FE0F", Alias: []string{"time", "deadline"}}, ":straight face:": emojiData{Name: ":unamused:", Description: "Unamused Face", Unicode: "1F612", Alias: []string{"indifference", "bored", "straight face", "serious", "sarcasm"}}, ":straight_ruler:": emojiData{Name: ":straight_ruler:", Description: "Straight Ruler", Unicode: "1F4CF", Alias: []string{"stationery", "calculate", "length", "math", "school", "drawing", "architect", "sketch"}}, ":strawberry:": emojiData{Name: ":strawberry:", Description: "Strawberry", Unicode: "1F353", Alias: []string{"fruit", "food", "nature"}}, ":strong:": emojiData{Name: ":muscle:", Description: "Flexed Biceps", Unicode: "1F4AA", Alias: []string{"arm", "flex", "hand", "summer", "strong", "biceps"}}, ":stuck_out_tongue:": emojiData{Name: ":stuck_out_tongue:", Description: "Face with Stuck-out Tongue", Unicode: "1F61B", Alias: []string{"face", "prank", "childish", "playful", "mischievous", "smile", "tongue"}}, ":stuck_out_tongue_closed_eyes:": emojiData{Name: ":stuck_out_tongue_closed_eyes:", Description: "Face with Stuck-out Tongue and Tightly-Closed Eyes", Unicode: "1F61D", Alias: []string{"face", "prank", "playful", "mischievous", "smile", "tongue"}}, ":stuck_out_tongue_winking_eye:": emojiData{Name: ":stuck_out_tongue_winking_eye:", Description: "Face with Stuck-out Tongue and Winking Eye", Unicode: "1F61C", Alias: []string{"face", "prank", "childish", "playful", "mischievous", "smile", "wink", "tongue"}}, ":student:": emojiData{Name: ":school_satchel:", Description: "School Satchel", Unicode: "1F392", Alias: []string{"student", "education", "bag", "backpack"}}, ":studio_microphone:": emojiData{Name: ":studio_microphone:", Description: "Studio Microphone", Unicode: "1F399-FE0F", Alias: []string{"sing", "recording", "artist", "talkshow"}}, ":study:": emojiData{Name: ":microscope:", Description: "Microscope", Unicode: "1F52C", Alias: []string{"laboratory", "experiment", "zoomin", "science", "study"}}, ":stuffed:": emojiData{Name: ":stuffed_flatbread:", Description: "Stuffed Flatbread", Unicode: "1F959", Alias: []string{"food", "flatbread", "stuffed", "gyro"}}, ":stuffed_flatbread:": emojiData{Name: ":stuffed_flatbread:", Description: "Stuffed Flatbread", Unicode: "1F959", Alias: []string{"food", "flatbread", "stuffed", "gyro"}}, ":stunned:": emojiData{Name: ":anguished:", Description: "Anguished Face", Unicode: "1F627", Alias: []string{"face", "stunned", "nervous"}}, ":style:": emojiData{Name: ":barber:", Description: "Barber Pole", Unicode: "1F488", Alias: []string{"hair", "salon", "style"}}, ":subtract:": emojiData{Name: ":heavy_minus_sign:", Description: "Heavy Minus Sign", Unicode: "2796", Alias: []string{"math", "calculation", "subtract", "less"}}, ":success:": emojiData{Name: ":chart_with_upwards_trend:", Description: "Chart with Upwards Trend", Unicode: "1F4C8", Alias: []string{"graph", "presentation", "stats", "recovery", "business", "economics", "money", "sales", "good", "success"}}, ":suits:": emojiData{Name: ":spades:", Description: "Black Spade Suit", Unicode: "2660-FE0F", Alias: []string{"poker", "cards", "suits", "magic"}}, ":suitup:": emojiData{Name: ":necktie:", Description: "Necktie", Unicode: "1F454", Alias: []string{"shirt", "suitup", "formal", "fashion", "cloth", "business"}}, ":summer:": emojiData{Name: ":icecream:", Description: "Soft Ice Cream", Unicode: "1F366", Alias: []string{"food", "hot", "dessert", "summer"}}, ":sun:": emojiData{Name: ":low_brightness:", Description: "Low Brightness Symbol", Unicode: "1F505", Alias: []string{"sun", "afternoon", "warm", "summer"}}, ":sun_with_face:": emojiData{Name: ":sun_with_face:", Description: "Sun with Face", Unicode: "1F31E", Alias: []string{"nature", "morning", "sky"}}, ":sunflower:": emojiData{Name: ":sunflower:", Description: "Sunflower", Unicode: "1F33B", Alias: []string{"nature", "plant", "fall"}}, ":sunglass:": emojiData{Name: ":sunglasses:", Description: "Smiling Face with Sunglasses", Unicode: "1F60E", Alias: []string{"face", "cool", "smile", "summer", "beach", "sunglass"}}, ":sunglasses:": emojiData{Name: ":sunglasses:", Description: "Smiling Face with Sunglasses", Unicode: "1F60E", Alias: []string{"face", "cool", "smile", "summer", "beach", "sunglass"}}, ":sunny:": emojiData{Name: ":sunny:", Description: "Black Sun with Rays", Unicode: "2600-FE0F", Alias: []string{"weather", "nature", "brightness", "summer", "beach", "spring"}}, ":sunrise:": emojiData{Name: ":sunrise:", Description: "Sunrise", Unicode: "1F305", Alias: []string{"morning", "view", "vacation", "photo"}}, ":sunrise_over_mountains:": emojiData{Name: ":sunrise_over_mountains:", Description: "Sunrise over Mountains", Unicode: "1F304", Alias: []string{"view", "vacation", "photo"}}, ":sunset:": emojiData{Name: ":flower_playing_cards:", Description: "Flower Playing Cards", Unicode: "1F3B4", Alias: []string{"game", "sunset", "red"}}, ":suppedaneum:": emojiData{Name: ":orthodox_cross:", Description: "Orthodox Cross", Unicode: "2626-FE0F", Alias: []string{"suppedaneum", "religion"}}, ":support:": emojiData{Name: ":reminder_ribbon:", Description: "Reminder Ribbon", Unicode: "1F397-FE0F", Alias: []string{"sports", "cause", "support", "awareness"}}, ":surfer:": emojiData{Name: ":surfer:", Description: "Surfer", Unicode: "1F3C4", Alias: []string(nil)}, ":surgery:": emojiData{Name: ":hospital:", Description: "Hospital", Unicode: "1F3E5", Alias: []string{"building", "health", "surgery", "doctor"}}, ":surimi:": emojiData{Name: ":fish_cake:", Description: "Fish Cake with Swirl Design", Unicode: "1F365", Alias: []string{"food", "japan", "sea", "beach", "narutomaki", "pink", "swirl", "kamaboko", "surimi", "ramen"}}, ":surprise:": emojiData{Name: ":grey_exclamation:", Description: "White Exclamation Mark Ornament", Unicode: "2755", Alias: []string{"surprise", "punctuation", "gray", "wow", "warning"}}, ":surprised:": emojiData{Name: ":astonished:", Description: "Astonished Face", Unicode: "1F632", Alias: []string{"face", "xox", "surprised", "poisoned"}}, ":sushi:": emojiData{Name: ":sushi:", Description: "Sushi", Unicode: "1F363", Alias: []string{"food", "fish", "japanese", "rice"}}, ":suspension_railway:": emojiData{Name: ":suspension_railway:", Description: "Suspension Railway", Unicode: "1F69F", Alias: []string{"vehicle", "transportation"}}, ":sustain:": emojiData{Name: ":battery:", Description: "Battery", Unicode: "1F50B", Alias: []string{"power", "energy", "sustain"}}, ":sweat:": emojiData{Name: ":disappointed_relieved:", Description: "Disappointed but Relieved Face", Unicode: "1F625", Alias: []string{"face", "phew", "sweat", "nervous"}}, ":sweat_drops:": emojiData{Name: ":sweat_drops:", Description: "Splashing Sweat Symbol", Unicode: "1F4A6", Alias: []string{"water", "drip", "oops"}}, ":sweat_smile:": emojiData{Name: ":sweat_smile:", Description: "Smiling Face with Open Mouth and Cold Sweat", Unicode: "1F605", Alias: []string{"face", "hot", "happy", "laugh", "sweat", "smile", "relief"}}, ":sweet:": emojiData{Name: ":doughnut:", Description: "Doughnut", Unicode: "1F369", Alias: []string{"food", "dessert", "snack", "sweet", "donut"}}, ":sweet_potato:": emojiData{Name: ":sweet_potato:", Description: "Roasted Sweet Potato", Unicode: "1F360", Alias: []string{"food", "nature"}}, ":swim:": emojiData{Name: ":tropical_fish:", Description: "Tropical Fish", Unicode: "1F420", Alias: []string{"animal", "swim", "ocean", "beach", "nemo"}}, ":swimmer:": emojiData{Name: ":swimmer:", Description: "Swimmer", Unicode: "1F3CA", Alias: []string(nil)}, ":swimming:": emojiData{Name: ":bikini:", Description: "Bikini", Unicode: "1F459", Alias: []string{"swimming", "female", "woman", "girl", "fashion", "beach", "summer"}}, ":swirl:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":symbol:": emojiData{Name: ":hash:", Description: "Hash Key", Unicode: "0023-FE0F-20E3", Alias: []string{"symbol", "blue-square", "twitter"}}, ":symbols:": emojiData{Name: ":symbols:", Description: "Input Symbol for Symbols", Unicode: "1F523", Alias: []string{"blue-square", "music", "note", "ampersand", "percent", "glyphs", "characters"}}, ":symphony:": emojiData{Name: ":violin:", Description: "Violin", Unicode: "1F3BB", Alias: []string{"music", "instrument", "orchestra", "symphony"}}, ":synagogue:": emojiData{Name: ":synagogue:", Description: "Synagogue", Unicode: "1F54D", Alias: []string{"judaism", "worship", "temple", "jewish"}}, ":sync:": emojiData{Name: ":arrows_clockwise:", Description: "Clockwise Downwards and Upwards Open Circle Arrows", Unicode: "1F503", Alias: []string{"sync", "cycle", "round", "repeat"}}, ":syringe:": emojiData{Name: ":syringe:", Description: "Syringe", Unicode: "1F489", Alias: []string{"health", "hospital", "drugs", "blood", "medicine", "needle", "doctor", "nurse"}}, ":t-rex:": emojiData{Name: ":t-rex:", Description: "T-Rex", Unicode: "1F996", Alias: []string(nil)}, ":table_tennis_paddle_and_ball:": emojiData{Name: ":table_tennis_paddle_and_ball:", Description: "Table Tennis Paddle and Ball", Unicode: "1F3D3", Alias: []string(nil)}, ":tabletop:": emojiData{Name: ":game_die:", Description: "Game Die", Unicode: "1F3B2", Alias: []string{"dice", "random", "tabletop", "play", "luck"}}, ":tableware:": emojiData{Name: ":spoon:", Description: "Spoon", Unicode: "1F944", Alias: []string{"cutlery", "kitchen", "tableware"}}, ":taco:": emojiData{Name: ":taco:", Description: "Taco", Unicode: "1F32E", Alias: []string{"food", "mexican"}}, ":tada:": emojiData{Name: ":tada:", Description: "Party Popper", Unicode: "1F389", Alias: []string{"party", "congratulations", "birthday", "magic", "circus", "celebration"}}, ":taekwondo:": emojiData{Name: ":martial_arts_uniform:", Description: "Martial Arts Uniform", Unicode: "1F94B", Alias: []string{"judo", "karate", "taekwondo"}}, ":tag:": emojiData{Name: ":label:", Description: "Label", Unicode: "1F3F7-FE0F", Alias: []string{"sale", "tag"}}, ":takeout_box:": emojiData{Name: ":takeout_box:", Description: "Takeout Box", Unicode: "1F961", Alias: []string(nil)}, ":talk:": emojiData{Name: ":speech_balloon:", Description: "Speech Balloon", Unicode: "1F4AC", Alias: []string{"bubble", "words", "message", "talk", "chatting"}}, ":talkshow:": emojiData{Name: ":studio_microphone:", Description: "Studio Microphone", Unicode: "1F399-FE0F", Alias: []string{"sing", "recording", "artist", "talkshow"}}, ":tanabata_tree:": emojiData{Name: ":tanabata_tree:", Description: "Tanabata Tree", Unicode: "1F38B", Alias: []string{"plant", "nature", "branch", "summer"}}, ":tangerine:": emojiData{Name: ":tangerine:", Description: "Tangerine", Unicode: "1F34A", Alias: []string{"food", "fruit", "nature", "orange"}}, ":tap:": emojiData{Name: ":non-potable_water:", Description: "Non-Potable Water Symbol", Unicode: "1F6B1", Alias: []string{"drink", "faucet", "tap", "circle"}}, ":tape:": emojiData{Name: ":loop:", Description: "Double Curly Loop", Unicode: "27BF", Alias: []string{"tape", "cassette"}}, ":taurus:": emojiData{Name: ":taurus:", Description: "Taurus", Unicode: "2649", Alias: []string{"purple-square", "sign", "zodiac", "astrology"}}, ":taxi:": emojiData{Name: ":taxi:", Description: "Taxi", Unicode: "1F695", Alias: []string{"uber", "vehicle", "cars", "transportation"}}, ":tea:": emojiData{Name: ":tea:", Description: "Teacup Without Handle", Unicode: "1F375", Alias: []string{"drink", "bowl", "breakfast", "green", "british"}}, ":teach:": emojiData{Name: ":school:", Description: "School", Unicode: "1F3EB", Alias: []string{"building", "student", "education", "learn", "teach"}}, ":team:": emojiData{Name: ":rugby_football:", Description: "Rugby Football", Unicode: "1F3C9", Alias: []string{"sports", "team"}}, ":tears:": emojiData{Name: ":sob:", Description: "Loudly Crying Face", Unicode: "1F62D", Alias: []string{"face", "cry", "tears", "sad", "upset", "depressed"}}, ":technology:": emojiData{Name: ":tv:", Description: "Television", Unicode: "1F4FA", Alias: []string{"technology", "program", "oldschool", "show", "television"}}, ":teenager:": emojiData{Name: ":girl:", Description: "Girl", Unicode: "1F467", Alias: []string{"female", "woman", "teenager"}}, ":teeth:": emojiData{Name: ":grimacing:", Description: "Grimacing Face", Unicode: "1F62C", Alias: []string{"face", "grimace", "teeth"}}, ":telephone:": emojiData{Name: ":phone:", Description: "Black Telephone", Unicode: "260E-FE0F", Alias: []string{"technology", "communication", "dial", "telephone"}}, ":telephone_receiver:": emojiData{Name: ":telephone_receiver:", Description: "Telephone Receiver", Unicode: "1F4DE", Alias: []string{"technology", "communication", "dial"}}, ":telescope:": emojiData{Name: ":telescope:", Description: "Telescope", Unicode: "1F52D", Alias: []string{"stars", "space", "zoom", "science", "astronomy"}}, ":television:": emojiData{Name: ":tv:", Description: "Television", Unicode: "1F4FA", Alias: []string{"technology", "program", "oldschool", "show", "television"}}, ":temperature:": emojiData{Name: ":face_with_thermometer:", Description: "Face with Thermometer", Unicode: "1F912", Alias: []string{"sick", "temperature", "thermometer", "cold", "fever"}}, ":temple:": emojiData{Name: ":place_of_worship:", Description: "Place of Worship", Unicode: "1F6D0", Alias: []string{"religion", "church", "temple", "prayer"}}, ":tennis:": emojiData{Name: ":tennis:", Description: "Tennis Racquet and Ball", Unicode: "1F3BE", Alias: []string{"sports", "balls", "green"}}, ":tent:": emojiData{Name: ":camping:", Description: "Camping", Unicode: "1F3D5-FE0F", Alias: []string{"photo", "outdoors", "tent"}}, ":terrified:": emojiData{Name: ":fearful:", Description: "Fearful Face", Unicode: "1F628", Alias: []string{"face", "scared", "terrified", "nervous", "oops", "huh"}}, ":terrorism:": emojiData{Name: ":bomb:", Description: "Bomb", Unicode: "1F4A3", Alias: []string{"boom", "explode", "explosion", "terrorism"}}, ":test:": emojiData{Name: ":100:", Description: "Hundred Points Symbol", Unicode: "1F4AF", Alias: []string{"score", "perfect", "numbers", "century", "exam", "quiz", "test", "pass", "hundred"}}, ":text:": emojiData{Name: ":keyboard:", Description: "Keyboard", Unicode: "2328-FE0F", Alias: []string{"technology", "computer", "type", "input", "text"}}, ":textbook:": emojiData{Name: ":orange_book:", Description: "Orange Book", Unicode: "1F4D9", Alias: []string{"read", "library", "knowledge", "textbook", "study"}}, ":th:": emojiData{Name: ":elephant:", Description: "Elephant", Unicode: "1F418", Alias: []string{"animal", "nature", "nose", "th", "circus"}}, ":the_horns:": emojiData{Name: ":the_horns:", Description: "Sign of the Horns", Unicode: "1F918", Alias: []string(nil)}, ":theater:": emojiData{Name: ":cinema:", Description: "Cinema", Unicode: "1F3A6", Alias: []string{"blue-square", "record", "film", "movie", "curtain", "stage", "theater"}}, ":thermometer:": emojiData{Name: ":face_with_thermometer:", Description: "Face with Thermometer", Unicode: "1F912", Alias: []string{"sick", "temperature", "thermometer", "cold", "fever"}}, ":thinking:": emojiData{Name: ":thought_balloon:", Description: "Thought Balloon", Unicode: "1F4AD", Alias: []string{"bubble", "cloud", "speech", "thinking", "dream"}}, ":thinking_face:": emojiData{Name: ":thinking_face:", Description: "Thinking Face", Unicode: "1F914", Alias: []string(nil)}, ":third_place_medal:": emojiData{Name: ":third_place_medal:", Description: "Third Place Medal", Unicode: "1F949", Alias: []string(nil)}, ":thought_balloon:": emojiData{Name: ":thought_balloon:", Description: "Thought Balloon", Unicode: "1F4AD", Alias: []string{"bubble", "cloud", "speech", "thinking", "dream"}}, ":three:": emojiData{Name: ":three:", Description: "Keycap 3", Unicode: "0033-FE0F-20E3", Alias: []string{"3", "numbers", "prime", "blue-square"}}, ":three_button_mouse:": emojiData{Name: ":three_button_mouse:", Description: "Three Button Mouse", Unicode: "1F5B1-FE0F", Alias: []string(nil)}, ":throw up:": emojiData{Name: ":nauseated_face:", Description: "Nauseated Face", Unicode: "1F922", Alias: []string{"face", "vomit", "gross", "green", "sick", "throw up", "ill"}}, ":thumbsdown:": emojiData{Name: ":-1:", Description: "Thumbs Down Sign", Unicode: "1F44E", Alias: []string{"thumbsdown", "no", "dislike", "hand"}}, ":thumbsup:": emojiData{Name: ":+1:", Description: "Thumbs Up Sign", Unicode: "1F44D", Alias: []string{"thumbsup", "yes", "awesome", "good", "agree", "accept", "cool", "hand", "like"}}, ":thunder:": emojiData{Name: ":zap:", Description: "High Voltage Sign", Unicode: "26A1", Alias: []string{"thunder", "weather", "lightning bolt", "fast"}}, ":thunder_cloud_and_rain:": emojiData{Name: ":thunder_cloud_and_rain:", Description: "Thunder Cloud and Rain", Unicode: "26C8-FE0F", Alias: []string(nil)}, ":tick:": emojiData{Name: ":heavy_check_mark:", Description: "Heavy Check Mark", Unicode: "2714-FE0F", Alias: []string{"ok", "nike", "answer", "yes", "tick"}}, ":ticket:": emojiData{Name: ":ticket:", Description: "Ticket", Unicode: "1F3AB", Alias: []string{"event", "concert", "pass"}}, ":tidy:": emojiData{Name: ":bookmark_tabs:", Description: "Bookmark Tabs", Unicode: "1F4D1", Alias: []string{"favorite", "save", "order", "tidy"}}, ":tiger2:": emojiData{Name: ":tiger2:", Description: "Tiger", Unicode: "1F405", Alias: []string{"animal", "nature", "roar"}}, ":tiger:": emojiData{Name: ":tiger:", Description: "Tiger Face", Unicode: "1F42F", Alias: []string{"animal", "cat", "danger", "wild", "nature", "roar"}}, ":time:": emojiData{Name: ":clock12:", Description: "Clock Face Twelve Oclock", Unicode: "1F55B", Alias: []string{"time", "noon", "midnight", "midday", "late", "early", "schedule"}}, ":timer_clock:": emojiData{Name: ":timer_clock:", Description: "Timer Clock", Unicode: "23F2-FE0F", Alias: []string{"alarm"}}, ":tired:": emojiData{Name: ":sleepy:", Description: "Sleepy Face", Unicode: "1F62A", Alias: []string{"face", "tired", "rest", "nap"}}, ":tired_face:": emojiData{Name: ":tired_face:", Description: "Tired Face", Unicode: "1F62B", Alias: []string{"sick", "whine", "upset", "frustrated"}}, ":titanic:": emojiData{Name: ":ship:", Description: "Ship", Unicode: "1F6A2", Alias: []string{"transportation", "titanic", "deploy"}}, ":tm:": emojiData{Name: ":tm:", Description: "Trade Mark Sign", Unicode: "2122-FE0F", Alias: []string{"trademark", "brand", "law", "legal"}}, ":toad:": emojiData{Name: ":frog:", Description: "Frog Face", Unicode: "1F438", Alias: []string{"animal", "nature", "croak", "toad"}}, ":toast:": emojiData{Name: ":bread:", Description: "Bread", Unicode: "1F35E", Alias: []string{"food", "wheat", "breakfast", "toast"}}, ":tobacco:": emojiData{Name: ":smoking:", Description: "Smoking Symbol", Unicode: "1F6AC", Alias: []string{"kills", "tobacco", "cigarette", "joint", "smoke"}}, ":toddler:": emojiData{Name: ":baby:", Description: "Baby", Unicode: "1F476", Alias: []string{"child", "boy", "girl", "toddler"}}, ":toilet:": emojiData{Name: ":wc:", Description: "Water Closet", Unicode: "1F6BE", Alias: []string{"toilet", "restroom", "blue-square"}}, ":tokyo_tower:": emojiData{Name: ":tokyo_tower:", Description: "Tokyo Tower", Unicode: "1F5FC", Alias: []string{"photo", "japanese"}}, ":tomato:": emojiData{Name: ":tomato:", Description: "Tomato", Unicode: "1F345", Alias: []string{"fruit", "vegetable", "nature", "food"}}, ":tone:": emojiData{Name: ":musical_note:", Description: "Musical Note", Unicode: "1F3B5", Alias: []string{"score", "tone", "sound"}}, ":tongue:": emojiData{Name: ":stuck_out_tongue_closed_eyes:", Description: "Face with Stuck-out Tongue and Tightly-Closed Eyes", Unicode: "1F61D", Alias: []string{"face", "prank", "playful", "mischievous", "smile", "tongue"}}, ":tools:": emojiData{Name: ":nut_and_bolt:", Description: "Nut and Bolt", Unicode: "1F529", Alias: []string{"handy", "tools", "fix"}}, ":top:": emojiData{Name: ":arrow_up_small:", Description: "Up-Pointing Small Red Triangle", Unicode: "1F53C", Alias: []string{"blue-square", "triangle", "direction", "point", "forward", "top"}}, ":tophat:": emojiData{Name: ":tophat:", Description: "Top Hat", Unicode: "1F3A9", Alias: []string{"magic", "gentleman", "classy", "circus"}}, ":tornado:": emojiData{Name: ":tornado:", Description: "Tornado", Unicode: "1F32A-FE0F", Alias: []string{"weather", "cyclone", "twister"}}, ":tortoise:": emojiData{Name: ":turtle:", Description: "Turtle", Unicode: "1F422", Alias: []string{"animal", "slow", "nature", "tortoise"}}, ":toss:": emojiData{Name: ":wastebasket:", Description: "Wastebasket", Unicode: "1F5D1-FE0F", Alias: []string{"bin", "trash", "rubbish", "garbage", "toss"}}, ":toy:": emojiData{Name: ":dolls:", Description: "Japanese Dolls", Unicode: "1F38E", Alias: []string{"japanese", "toy", "kimono"}}, ":trackball:": emojiData{Name: ":trackball:", Description: "Trackball", Unicode: "1F5B2-FE0F", Alias: []string{"technology", "trackpad"}}, ":tracking:": emojiData{Name: ":footprints:", Description: "Footprints", Unicode: "1F463", Alias: []string{"feet", "tracking", "walking", "beach"}}, ":trackpad:": emojiData{Name: ":trackball:", Description: "Trackball", Unicode: "1F5B2-FE0F", Alias: []string{"technology", "trackpad"}}, ":tractor:": emojiData{Name: ":tractor:", Description: "Tractor", Unicode: "1F69C", Alias: []string{"vehicle", "car", "farming", "agriculture"}}, ":trademark:": emojiData{Name: ":tm:", Description: "Trade Mark Sign", Unicode: "2122-FE0F", Alias: []string{"trademark", "brand", "law", "legal"}}, ":traffic_light:": emojiData{Name: ":traffic_light:", Description: "Horizontal Traffic Light", Unicode: "1F6A5", Alias: []string{"transportation", "signal"}}, ":train2:": emojiData{Name: ":train2:", Description: "Train", Unicode: "1F686", Alias: []string{"transportation", "vehicle"}}, ":train:": emojiData{Name: ":train:", Description: "Tram Car", Unicode: "1F68B", Alias: []string{"transportation", "vehicle", "carriage", "public", "travel"}}, ":tram:": emojiData{Name: ":tram:", Description: "Tram", Unicode: "1F68A", Alias: []string{"transportation", "vehicle"}}, ":transport:": emojiData{Name: ":seat:", Description: "Seat", Unicode: "1F4BA", Alias: []string{"sit", "airplane", "transport", "bus", "flight", "fly"}}, ":transportation:": emojiData{Name: ":fire_engine:", Description: "Fire Engine", Unicode: "1F692", Alias: []string{"transportation", "cars", "vehicle"}}, ":trash:": emojiData{Name: ":wastebasket:", Description: "Wastebasket", Unicode: "1F5D1-FE0F", Alias: []string{"bin", "trash", "rubbish", "garbage", "toss"}}, ":travel:": emojiData{Name: ":train:", Description: "Tram Car", Unicode: "1F68B", Alias: []string{"transportation", "vehicle", "carriage", "public", "travel"}}, ":treble:": emojiData{Name: ":musical_score:", Description: "Musical Score", Unicode: "1F3BC", Alias: []string{"treble", "clef", "compose"}}, ":tree:": emojiData{Name: ":leaves:", Description: "Leaf Fluttering in Wind", Unicode: "1F343", Alias: []string{"nature", "plant", "tree", "vegetable", "grass", "lawn", "spring"}}, ":triangle:": emojiData{Name: ":arrow_up_small:", Description: "Up-Pointing Small Red Triangle", Unicode: "1F53C", Alias: []string{"blue-square", "triangle", "direction", "point", "forward", "top"}}, ":triangular_flag_on_post:": emojiData{Name: ":triangular_flag_on_post:", Description: "Triangular Flag on Post", Unicode: "1F6A9", Alias: []string{"mark", "milestone", "place"}}, ":triangular_ruler:": emojiData{Name: ":triangular_ruler:", Description: "Triangular Ruler", Unicode: "1F4D0", Alias: []string{"stationery", "math", "architect", "sketch"}}, ":trident:": emojiData{Name: ":trident:", Description: "Trident Emblem", Unicode: "1F531", Alias: []string{"weapon", "spear"}}, ":triumph:": emojiData{Name: ":triumph:", Description: "Face with Look of Triumph", Unicode: "1F624", Alias: []string{"face", "gas", "phew", "proud", "pride"}}, ":trolleybus:": emojiData{Name: ":trolleybus:", Description: "Trolleybus", Unicode: "1F68E", Alias: []string{"bart", "transportation", "vehicle"}}, ":trophy:": emojiData{Name: ":trophy:", Description: "Trophy", Unicode: "1F3C6", Alias: []string{"win", "award", "contest", "place", "ftw", "ceremony"}}, ":tropical:": emojiData{Name: ":desert_island:", Description: "Desert Island", Unicode: "1F3DD-FE0F", Alias: []string{"photo", "tropical", "mojito"}}, ":tropical_drink:": emojiData{Name: ":tropical_drink:", Description: "Tropical Drink", Unicode: "1F379", Alias: []string{"beverage", "cocktail", "summer", "beach", "alcohol", "booze", "mojito"}}, ":tropical_fish:": emojiData{Name: ":tropical_fish:", Description: "Tropical Fish", Unicode: "1F420", Alias: []string{"animal", "swim", "ocean", "beach", "nemo"}}, ":truck:": emojiData{Name: ":truck:", Description: "Delivery Truck", Unicode: "1F69A", Alias: []string{"cars", "transportation"}}, ":trumpet:": emojiData{Name: ":trumpet:", Description: "Trumpet", Unicode: "1F3BA", Alias: []string{"music", "brass"}}, ":tsukimi:": emojiData{Name: ":rice_scene:", Description: "Moon Viewing Ceremony", Unicode: "1F391", Alias: []string{"photo", "japan", "asia", "tsukimi"}}, ":tsunami:": emojiData{Name: ":ocean:", Description: "Water Wave", Unicode: "1F30A", Alias: []string{"sea", "water", "wave", "nature", "tsunami", "disaster"}}, ":tube:": emojiData{Name: ":metro:", Description: "Metro", Unicode: "1F687", Alias: []string{"transportation", "blue-square", "mrt", "underground", "tube"}}, ":tuber:": emojiData{Name: ":potato:", Description: "Potato", Unicode: "1F954", Alias: []string{"food", "tuber", "vegatable", "starch"}}, ":tulip:": emojiData{Name: ":tulip:", Description: "Tulip", Unicode: "1F337", Alias: []string{"flowers", "plant", "nature", "summer", "spring"}}, ":tumbler_glass:": emojiData{Name: ":tumbler_glass:", Description: "Tumbler Glass", Unicode: "1F943", Alias: []string{"drink", "beverage", "drunk", "alcohol", "liquor", "booze", "bourbon", "scotch", "whisky", "glass", "shot"}}, ":turkey:": emojiData{Name: ":turkey:", Description: "Turkey", Unicode: "1F983", Alias: []string{"animal", "bird"}}, ":turtle:": emojiData{Name: ":turtle:", Description: "Turtle", Unicode: "1F422", Alias: []string{"animal", "slow", "nature", "tortoise"}}, ":tv:": emojiData{Name: ":tv:", Description: "Television", Unicode: "1F4FA", Alias: []string{"technology", "program", "oldschool", "show", "television"}}, ":tweet:": emojiData{Name: ":bird:", Description: "Bird", Unicode: "1F426", Alias: []string{"animal", "nature", "fly", "tweet", "spring"}}, ":twilight:": emojiData{Name: ":waning_crescent_moon:", Description: "Waning Crescent Moon Symbol", Unicode: "1F318", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":twisted_rightwards_arrows:": emojiData{Name: ":twisted_rightwards_arrows:", Description: "Twisted Rightwards Arrows", Unicode: "1F500", Alias: []string{"blue-square", "shuffle", "music", "random"}}, ":twister:": emojiData{Name: ":tornado:", Description: "Tornado", Unicode: "1F32A-FE0F", Alias: []string{"weather", "cyclone", "twister"}}, ":twitter:": emojiData{Name: ":hash:", Description: "Hash Key", Unicode: "0023-FE0F-20E3", Alias: []string{"symbol", "blue-square", "twitter"}}, ":two:": emojiData{Name: ":two:", Description: "Keycap 2", Unicode: "0032-FE0F-20E3", Alias: []string{"numbers", "2", "prime", "blue-square"}}, ":two_hearts:": emojiData{Name: ":two_hearts:", Description: "Two Hearts", Unicode: "1F495", Alias: []string{"love", "like", "affection", "valentines", "heart"}}, ":two_men_holding_hands:": emojiData{Name: ":two_men_holding_hands:", Description: "Two Men Holding Hands", Unicode: "1F46C", Alias: []string{"pair", "couple", "love", "like", "bromance", "friendship", "people", "human"}}, ":two_women_holding_hands:": emojiData{Name: ":two_women_holding_hands:", Description: "Two Women Holding Hands", Unicode: "1F46D", Alias: []string{"pair", "friendship", "couple", "love", "like", "female", "people", "human"}}, ":type:": emojiData{Name: ":keyboard:", Description: "Keyboard", Unicode: "2328-FE0F", Alias: []string{"technology", "computer", "type", "input", "text"}}, ":typhoon:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":u5272:": emojiData{Name: ":u5272:", Description: "Squared Cjk Unified Ideograph-5272", Unicode: "1F239", Alias: []string{"cut", "divide", "chinese", "kanji", "pink-square"}}, ":u5408:": emojiData{Name: ":u5408:", Description: "Squared Cjk Unified Ideograph-5408", Unicode: "1F234", Alias: []string{"japanese", "chinese", "join", "kanji", "red-square"}}, ":u55b6:": emojiData{Name: ":u55b6:", Description: "Squared Cjk Unified Ideograph-55b6", Unicode: "1F23A", Alias: []string{"japanese", "opening hours", "orange-square"}}, ":u6307:": emojiData{Name: ":u6307:", Description: "Squared Cjk Unified Ideograph-6307", Unicode: "1F22F", Alias: []string{"chinese", "point", "green-square", "kanji"}}, ":u6708:": emojiData{Name: ":u6708:", Description: "Squared Cjk Unified Ideograph-6708", Unicode: "1F237-FE0F", Alias: []string{"chinese", "month", "moon", "japanese", "orange-square", "kanji"}}, ":u6709:": emojiData{Name: ":u6709:", Description: "Squared Cjk Unified Ideograph-6709", Unicode: "1F236", Alias: []string{"orange-square", "chinese", "have", "kanji"}}, ":u6e80:": emojiData{Name: ":u6e80:", Description: "Squared Cjk Unified Ideograph-6e80", Unicode: "1F235", Alias: []string{"full", "chinese", "japanese", "red-square", "kanji"}}, ":u7121:": emojiData{Name: ":u7121:", Description: "Squared Cjk Unified Ideograph-7121", Unicode: "1F21A", Alias: []string{"nothing", "chinese", "kanji", "japanese", "orange-square"}}, ":u7533:": emojiData{Name: ":u7533:", Description: "Squared Cjk Unified Ideograph-7533", Unicode: "1F238", Alias: []string{"chinese", "japanese", "kanji", "orange-square"}}, ":u7981:": emojiData{Name: ":u7981:", Description: "Squared Cjk Unified Ideograph-7981", Unicode: "1F232", Alias: []string{"kanji", "japanese", "chinese", "forbidden", "limit", "restricted", "red-square"}}, ":u7a7a:": emojiData{Name: ":u7a7a:", Description: "Squared Cjk Unified Ideograph-7a7a", Unicode: "1F233", Alias: []string{"kanji", "japanese", "chinese", "empty", "sky", "blue-square"}}, ":uber:": emojiData{Name: ":oncoming_taxi:", Description: "Oncoming Taxi", Unicode: "1F696", Alias: []string{"vehicle", "cars", "uber"}}, ":uk:": emojiData{Name: ":guardsman:", Description: "Guardsman", Unicode: "1F482", Alias: []string{"uk", "gb", "british", "male", "guy", "royal"}}, ":umbrella:": emojiData{Name: ":umbrella:", Description: "Umbrella", Unicode: "2602-FE0F", Alias: []string{"rainy", "weather", "spring"}}, ":umbrella_on_ground:": emojiData{Name: ":umbrella_on_ground:", Description: "Umbrella on Ground", Unicode: "26F1-FE0F", Alias: []string(nil)}, ":umbrella_with_rain_drops:": emojiData{Name: ":umbrella_with_rain_drops:", Description: "Umbrella with Rain Drops", Unicode: "2614", Alias: []string(nil)}, ":unamused:": emojiData{Name: ":unamused:", Description: "Unamused Face", Unicode: "1F612", Alias: []string{"indifference", "bored", "straight face", "serious", "sarcasm"}}, ":unconscious:": emojiData{Name: ":dizzy_face:", Description: "Dizzy Face", Unicode: "1F635", Alias: []string{"spent", "unconscious", "xox", "dizzy"}}, ":underage:": emojiData{Name: ":underage:", Description: "No One Under Eighteen Symbol", Unicode: "1F51E", Alias: []string{"18", "drink", "pub", "night", "minor", "circle"}}, ":underground:": emojiData{Name: ":metro:", Description: "Metro", Unicode: "1F687", Alias: []string{"transportation", "blue-square", "mrt", "underground", "tube"}}, ":undo:": emojiData{Name: ":leftwards_arrow_with_hook:", Description: "Leftwards Arrow with Hook", Unicode: "21A9-FE0F", Alias: []string{"back", "return", "blue-square", "undo", "enter"}}, ":unicorn_face:": emojiData{Name: ":unicorn_face:", Description: "Unicorn Face", Unicode: "1F984", Alias: []string(nil)}, ":united:": emojiData{Name: ":us:", Description: "United States Flag", Unicode: "1F1FA-1F1F8", Alias: []string{"united", "states", "america", "flag", "nation", "country", "banner"}}, ":university:": emojiData{Name: ":mortar_board:", Description: "Graduation Cap", Unicode: "1F393", Alias: []string{"school", "college", "degree", "university", "graduation", "cap", "hat", "legal", "learn", "education"}}, ":unlock:": emojiData{Name: ":unlock:", Description: "Open Lock", Unicode: "1F513", Alias: []string{"privacy", "security"}}, ":unwell:": emojiData{Name: ":confounded:", Description: "Confounded Face", Unicode: "1F616", Alias: []string{"face", "confused", "sick", "unwell", "oops", ":S"}}, ":up:": emojiData{Name: ":point_up_2:", Description: "White Up Pointing Backhand Index", Unicode: "1F446", Alias: []string{"fingers", "hand", "direction", "up"}}, ":upset:": emojiData{Name: ":sob:", Description: "Loudly Crying Face", Unicode: "1F62D", Alias: []string{"face", "cry", "tears", "sad", "upset", "depressed"}}, ":upside_down_face:": emojiData{Name: ":upside_down_face:", Description: "Upside-Down Face", Unicode: "1F643", Alias: []string{"face", "flipped", "silly", "smile"}}, ":urban:": emojiData{Name: ":cityscape:", Description: "Cityscape", Unicode: "1F3D9-FE0F", Alias: []string{"photo", "night life", "urban"}}, ":url:": emojiData{Name: ":link:", Description: "Link Symbol", Unicode: "1F517", Alias: []string{"rings", "url"}}, ":us:": emojiData{Name: ":us:", Description: "United States Flag", Unicode: "1F1FA-1F1F8", Alias: []string{"united", "states", "america", "flag", "nation", "country", "banner"}}, ":user:": emojiData{Name: ":bust_in_silhouette:", Description: "Bust in Silhouette", Unicode: "1F464", Alias: []string{"user", "person", "human"}}, ":v:": emojiData{Name: ":v:", Description: "Victory Hand", Unicode: "270C-FE0F", Alias: []string{"fingers", "ohyeah", "hand", "peace", "victory", "two"}}, ":vacation:": emojiData{Name: ":sunrise:", Description: "Sunrise", Unicode: "1F305", Alias: []string{"morning", "view", "vacation", "photo"}}, ":valentines:": emojiData{Name: ":kissing:", Description: "Kissing Face", Unicode: "1F617", Alias: []string{"love", "like", "face", "3", "valentines", "infatuation", "kiss"}}, ":vampire:": emojiData{Name: ":vampire:", Description: "Vampire", Unicode: "1F9DB", Alias: []string(nil)}, ":vase:": emojiData{Name: ":amphora:", Description: "Amphora", Unicode: "1F3FA", Alias: []string{"vase", "jar"}}, ":vegas:": emojiData{Name: ":slot_machine:", Description: "Slot Machine", Unicode: "1F3B0", Alias: []string{"bet", "gamble", "vegas", "fruit machine", "luck", "casino"}}, ":vegatable:": emojiData{Name: ":potato:", Description: "Potato", Unicode: "1F954", Alias: []string{"food", "tuber", "vegatable", "starch"}}, ":vegetable:": emojiData{Name: ":cactus:", Description: "Cactus", Unicode: "1F335", Alias: []string{"vegetable", "plant", "nature"}}, ":vehicle:": emojiData{Name: ":fire_engine:", Description: "Fire Engine", Unicode: "1F692", Alias: []string{"transportation", "cars", "vehicle"}}, ":venison:": emojiData{Name: ":deer:", Description: "Deer", Unicode: "1F98C", Alias: []string{"animal", "nature", "horns", "venison"}}, ":venue:": emojiData{Name: ":stadium:", Description: "Stadium", Unicode: "1F3DF-FE0F", Alias: []string{"photo", "place", "sports", "concert", "venue"}}, ":vertical:": emojiData{Name: ":arrow_up_down:", Description: "Up Down Arrow", Unicode: "2195-FE0F", Alias: []string{"blue-square", "direction", "way", "vertical"}}, ":vertical_traffic_light:": emojiData{Name: ":vertical_traffic_light:", Description: "Vertical Traffic Light", Unicode: "1F6A6", Alias: []string{"transportation", "driving"}}, ":vespa:": emojiData{Name: ":motor_scooter:", Description: "Motor Scooter", Unicode: "1F6F5", Alias: []string{"vehicle", "vespa", "sasha"}}, ":vhs:": emojiData{Name: ":vhs:", Description: "Videocassette", Unicode: "1F4FC", Alias: []string{"record", "video", "oldschool", "90s", "80s"}}, ":vibration_mode:": emojiData{Name: ":vibration_mode:", Description: "Vibration Mode", Unicode: "1F4F3", Alias: []string{"orange-square", "phone"}}, ":victory:": emojiData{Name: ":v:", Description: "Victory Hand", Unicode: "270C-FE0F", Alias: []string{"fingers", "ohyeah", "hand", "peace", "victory", "two"}}, ":video:": emojiData{Name: ":vhs:", Description: "Videocassette", Unicode: "1F4FC", Alias: []string{"record", "video", "oldschool", "90s", "80s"}}, ":video_camera:": emojiData{Name: ":video_camera:", Description: "Video Camera", Unicode: "1F4F9", Alias: []string{"film", "record"}}, ":video_game:": emojiData{Name: ":video_game:", Description: "Video Game", Unicode: "1F3AE", Alias: []string{"play", "console", "PS4", "controller"}}, ":view:": emojiData{Name: ":sunrise:", Description: "Sunrise", Unicode: "1F305", Alias: []string{"morning", "view", "vacation", "photo"}}, ":violence:": emojiData{Name: ":gun:", Description: "Pistol", Unicode: "1F52B", Alias: []string{"violence", "weapon", "pistol", "revolver"}}, ":violin:": emojiData{Name: ":violin:", Description: "Violin", Unicode: "1F3BB", Alias: []string{"music", "instrument", "orchestra", "symphony"}}, ":virgo:": emojiData{Name: ":virgo:", Description: "Virgo", Unicode: "264D", Alias: []string{"sign", "zodiac", "purple-square", "astrology"}}, ":volcano:": emojiData{Name: ":volcano:", Description: "Volcano", Unicode: "1F30B", Alias: []string{"photo", "nature", "disaster"}}, ":volleyball:": emojiData{Name: ":volleyball:", Description: "Volleyball", Unicode: "1F3D0", Alias: []string{"sports", "balls"}}, ":volume:": emojiData{Name: ":mega:", Description: "Cheering Megaphone", Unicode: "1F4E3", Alias: []string{"sound", "speaker", "volume"}}, ":vomit:": emojiData{Name: ":nauseated_face:", Description: "Nauseated Face", Unicode: "1F922", Alias: []string{"face", "vomit", "gross", "green", "sick", "throw up", "ill"}}, ":vortex:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":vote:": emojiData{Name: ":white_check_mark:", Description: "White Heavy Check Mark", Unicode: "2705", Alias: []string{"green-square", "ok", "agree", "vote", "election", "answer", "tick"}}, ":vs:": emojiData{Name: ":vs:", Description: "Squared Vs", Unicode: "1F19A", Alias: []string{"words", "orange-square"}}, ":wait:": emojiData{Name: ":busstop:", Description: "Bus Stop", Unicode: "1F68F", Alias: []string{"transportation", "wait"}}, ":wake:": emojiData{Name: ":alarm_clock:", Description: "Alarm Clock", Unicode: "23F0", Alias: []string{"time", "wake"}}, ":walking:": emojiData{Name: ":walking:", Description: "Pedestrian", Unicode: "1F6B6", Alias: []string(nil)}, ":waning_crescent_moon:": emojiData{Name: ":waning_crescent_moon:", Description: "Waning Crescent Moon Symbol", Unicode: "1F318", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":waning_gibbous_moon:": emojiData{Name: ":waning_gibbous_moon:", Description: "Waning Gibbous Moon Symbol", Unicode: "1F316", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep", "waxing_gibbous_moon"}}, ":warm:": emojiData{Name: ":desert:", Description: "Desert", Unicode: "1F3DC-FE0F", Alias: []string{"photo", "warm", "saharah"}}, ":warning:": emojiData{Name: ":warning:", Description: "Warning Sign", Unicode: "26A0-FE0F", Alias: []string{"exclamation", "wip", "alert", "error", "problem", "issue"}}, ":washroom:": emojiData{Name: ":toilet:", Description: "Toilet", Unicode: "1F6BD", Alias: []string{"restroom", "wc", "washroom", "bathroom", "potty"}}, ":wastebasket:": emojiData{Name: ":wastebasket:", Description: "Wastebasket", Unicode: "1F5D1-FE0F", Alias: []string{"bin", "trash", "rubbish", "garbage", "toss"}}, ":wat:": emojiData{Name: ":interrobang:", Description: "Exclamation Question Mark", Unicode: "2049-FE0F", Alias: []string{"wat", "punctuation", "surprise"}}, ":watch:": emojiData{Name: ":eyes:", Description: "Eyes", Unicode: "1F440", Alias: []string{"look", "watch", "stalk", "peek", "see"}}, ":water:": emojiData{Name: ":fountain:", Description: "Fountain", Unicode: "26F2", Alias: []string{"photo", "summer", "water", "fresh"}}, ":water_buffalo:": emojiData{Name: ":water_buffalo:", Description: "Water Buffalo", Unicode: "1F403", Alias: []string{"animal", "nature", "ox", "cow"}}, ":water_polo:": emojiData{Name: ":water_polo:", Description: "Water Polo", Unicode: "1F93D", Alias: []string(nil)}, ":watermelon:": emojiData{Name: ":watermelon:", Description: "Watermelon", Unicode: "1F349", Alias: []string{"fruit", "food", "picnic", "summer"}}, ":wave:": emojiData{Name: ":wave:", Description: "Waving Hand Sign", Unicode: "1F44B", Alias: []string{"hands", "gesture", "goodbye", "solong", "farewell", "hello", "hi", "palm"}}, ":waving_black_flag:": emojiData{Name: ":waving_black_flag:", Description: "Waving Black Flag", Unicode: "1F3F4", Alias: []string(nil)}, ":waving_white_flag:": emojiData{Name: ":waving_white_flag:", Description: "Waving White Flag", Unicode: "1F3F3-FE0F", Alias: []string(nil)}, ":wavy_dash:": emojiData{Name: ":wavy_dash:", Description: "Wavy Dash", Unicode: "3030-FE0F", Alias: []string{"draw", "line", "moustache", "mustache", "squiggle", "scribble"}}, ":wax:": emojiData{Name: ":candle:", Description: "Candle", Unicode: "1F56F-FE0F", Alias: []string{"fire", "wax"}}, ":waxing_crescent_moon:": emojiData{Name: ":waxing_crescent_moon:", Description: "Waxing Crescent Moon Symbol", Unicode: "1F312", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":waxing_gibbous_moon:": emojiData{Name: ":waning_gibbous_moon:", Description: "Waning Gibbous Moon Symbol", Unicode: "1F316", Alias: []string{"nature", "twilight", "planet", "space", "night", "evening", "sleep", "waxing_gibbous_moon"}}, ":way:": emojiData{Name: ":arrow_up_down:", Description: "Up Down Arrow", Unicode: "2195-FE0F", Alias: []string{"blue-square", "direction", "way", "vertical"}}, ":wc:": emojiData{Name: ":wc:", Description: "Water Closet", Unicode: "1F6BE", Alias: []string{"toilet", "restroom", "blue-square"}}, ":weapon:": emojiData{Name: ":gun:", Description: "Pistol", Unicode: "1F52B", Alias: []string{"violence", "weapon", "pistol", "revolver"}}, ":weary:": emojiData{Name: ":weary:", Description: "Weary Face", Unicode: "1F629", Alias: []string{"face", "tired", "sleepy", "sad", "frustrated", "upset"}}, ":weather:": emojiData{Name: ":tornado:", Description: "Tornado", Unicode: "1F32A-FE0F", Alias: []string{"weather", "cyclone", "twister"}}, ":wedding:": emojiData{Name: ":wedding:", Description: "Wedding", Unicode: "1F492", Alias: []string{"love", "like", "affection", "couple", "marriage", "bride", "groom"}}, ":weed:": emojiData{Name: ":herb:", Description: "Herb", Unicode: "1F33F", Alias: []string{"vegetable", "plant", "medicine", "weed", "grass", "lawn"}}, ":weep:": emojiData{Name: ":joy:", Description: "Face with Tears of Joy", Unicode: "1F602", Alias: []string{"face", "cry", "tears", "weep", "happy", "happytears", "haha"}}, ":weight_lifter:": emojiData{Name: ":weight_lifter:", Description: "Weight Lifter", Unicode: "1F3CB-FE0F", Alias: []string(nil)}, ":weird:": emojiData{Name: ":confused:", Description: "Confused Face", Unicode: "1F615", Alias: []string{"face", "indifference", "huh", "weird", "hmmm", ":/"}}, ":whale2:": emojiData{Name: ":whale2:", Description: "Whale", Unicode: "1F40B", Alias: []string{"animal", "nature", "sea", "ocean"}}, ":whale:": emojiData{Name: ":whale:", Description: "Spouting Whale", Unicode: "1F433", Alias: []string{"animal", "nature", "sea", "ocean"}}, ":what:": emojiData{Name: ":frowning:", Description: "Frowning Face with Open Mouth", Unicode: "1F626", Alias: []string{"face", "aw", "what"}}, ":wheat:": emojiData{Name: ":bread:", Description: "Bread", Unicode: "1F35E", Alias: []string{"food", "wheat", "breakfast", "toast"}}, ":wheel_of_dharma:": emojiData{Name: ":wheel_of_dharma:", Description: "Wheel of Dharma", Unicode: "2638-FE0F", Alias: []string{"hinduism", "buddhism", "sikhism", "jainism"}}, ":wheelchair:": emojiData{Name: ":wheelchair:", Description: "Wheelchair Symbol", Unicode: "267F", Alias: []string{"blue-square", "disabled", "a11y", "accessibility"}}, ":whine:": emojiData{Name: ":tired_face:", Description: "Tired Face", Unicode: "1F62B", Alias: []string{"sick", "whine", "upset", "frustrated"}}, ":whirlpool:": emojiData{Name: ":cyclone:", Description: "Cyclone", Unicode: "1F300", Alias: []string{"weather", "swirl", "blue", "cloud", "vortex", "spiral", "whirlpool", "spin", "tornado", "hurricane", "typhoon"}}, ":whisky:": emojiData{Name: ":tumbler_glass:", Description: "Tumbler Glass", Unicode: "1F943", Alias: []string{"drink", "beverage", "drunk", "alcohol", "liquor", "booze", "bourbon", "scotch", "whisky", "glass", "shot"}}, ":white_check_mark:": emojiData{Name: ":white_check_mark:", Description: "White Heavy Check Mark", Unicode: "2705", Alias: []string{"green-square", "ok", "agree", "vote", "election", "answer", "tick"}}, ":white_circle:": emojiData{Name: ":white_circle:", Description: "Medium White Circle", Unicode: "26AA", Alias: []string{"shape", "round"}}, ":white_flower:": emojiData{Name: ":white_flower:", Description: "White Flower", Unicode: "1F4AE", Alias: []string{"japanese", "spring"}}, ":white_frowning_face:": emojiData{Name: ":white_frowning_face:", Description: "White Frowning Face", Unicode: "2639-FE0F", Alias: []string(nil)}, ":white_large_square:": emojiData{Name: ":white_large_square:", Description: "White Large Square", Unicode: "2B1C", Alias: []string{"shape", "icon", "stone", "button"}}, ":white_medium_small_square:": emojiData{Name: ":white_medium_small_square:", Description: "White Medium Small Square", Unicode: "25FD", Alias: []string{"shape", "stone", "icon", "button"}}, ":white_medium_square:": emojiData{Name: ":white_medium_square:", Description: "White Medium Square", Unicode: "25FB-FE0F", Alias: []string{"shape", "stone", "icon"}}, ":white_small_square:": emojiData{Name: ":white_small_square:", Description: "White Small Square", Unicode: "25AB-FE0F", Alias: []string{"shape", "icon"}}, ":white_square_button:": emojiData{Name: ":white_square_button:", Description: "White Square Button", Unicode: "1F533", Alias: []string{"shape", "input"}}, ":whoa:": emojiData{Name: ":open_mouth:", Description: "Face with Open Mouth", Unicode: "1F62E", Alias: []string{"face", "surprise", "impressed", "wow", "whoa", ":O"}}, ":wifi:": emojiData{Name: ":signal_strength:", Description: "Antenna with Bars", Unicode: "1F4F6", Alias: []string{"blue-square", "reception", "phone", "internet", "connection", "wifi", "bluetooth", "bars"}}, ":wild:": emojiData{Name: ":bear:", Description: "Bear Face", Unicode: "1F43B", Alias: []string{"animal", "nature", "wild"}}, ":wilted_flower:": emojiData{Name: ":wilted_flower:", Description: "Wilted Flower", Unicode: "1F940", Alias: []string{"plant", "nature", "flower"}}, ":win:": emojiData{Name: ":trophy:", Description: "Trophy", Unicode: "1F3C6", Alias: []string{"win", "award", "contest", "place", "ftw", "ceremony"}}, ":wind:": emojiData{Name: ":dash:", Description: "Dash Symbol", Unicode: "1F4A8", Alias: []string{"wind", "air", "fast", "shoo", "fart", "smoke", "puff"}}, ":wind_blowing_face:": emojiData{Name: ":wind_blowing_face:", Description: "Wind Blowing Face", Unicode: "1F32C-FE0F", Alias: []string(nil)}, ":wind_chime:": emojiData{Name: ":wind_chime:", Description: "Wind Chime", Unicode: "1F390", Alias: []string{"nature", "ding", "spring", "bell"}}, ":wine:": emojiData{Name: ":sake:", Description: "Sake Bottle and Cup", Unicode: "1F376", Alias: []string{"wine", "drink", "drunk", "beverage", "japanese", "alcohol", "booze"}}, ":wine_glass:": emojiData{Name: ":wine_glass:", Description: "Wine Glass", Unicode: "1F377", Alias: []string{"drink", "beverage", "drunk", "alcohol", "booze"}}, ":wings:": emojiData{Name: ":angel:", Description: "Baby Angel", Unicode: "1F47C", Alias: []string{"heaven", "wings", "halo"}}, ":wink:": emojiData{Name: ":stuck_out_tongue_winking_eye:", Description: "Face with Stuck-out Tongue and Winking Eye", Unicode: "1F61C", Alias: []string{"face", "prank", "childish", "playful", "mischievous", "smile", "wink", "tongue"}}, ":winter:": emojiData{Name: ":ski:", Description: "Ski and Ski Boot", Unicode: "1F3BF", Alias: []string{"sports", "winter", "cold", "snow"}}, ":wip:": emojiData{Name: ":warning:", Description: "Warning Sign", Unicode: "26A0-FE0F", Alias: []string{"exclamation", "wip", "alert", "error", "problem", "issue"}}, ":wish:": emojiData{Name: ":pray:", Description: "Person with Folded Hands", Unicode: "1F64F", Alias: []string{"please", "hope", "wish", "namaste", "highfive"}}, ":without_snow:": emojiData{Name: ":snowman:", Description: "Snowman", Unicode: "2603-FE0F", Alias: []string{"winter", "season", "cold", "weather", "christmas", "xmas", "frozen", "without_snow"}}, ":wolf:": emojiData{Name: ":wolf:", Description: "Wolf Face", Unicode: "1F43A", Alias: []string{"animal", "nature", "wild"}}, ":woman-biking:": emojiData{Name: ":woman-biking:", Description: "Woman Biking", Unicode: "1F6B4-200D-2640-FE0F", Alias: []string(nil)}, ":woman-bouncing-ball:": emojiData{Name: ":woman-bouncing-ball:", Description: "Woman Bouncing Ball", Unicode: "26F9-FE0F-200D-2640-FE0F", Alias: []string(nil)}, ":woman-bowing:": emojiData{Name: ":woman-bowing:", Description: "Woman Bowing", Unicode: "1F647-200D-2640-FE0F", Alias: []string(nil)}, ":woman-boy-boy:": emojiData{Name: ":woman-boy-boy:", Description: "Woman Boy Boy", Unicode: "1F469-200D-1F466-200D-1F466", Alias: []string(nil)}, ":woman-boy:": emojiData{Name: ":woman-boy:", Description: "Woman Boy", Unicode: "1F469-200D-1F466", Alias: []string(nil)}, ":woman-cartwheeling:": emojiData{Name: ":woman-cartwheeling:", Description: "Woman Cartwheeling", Unicode: "1F938-200D-2640-FE0F", Alias: []string(nil)}, ":woman-facepalming:": emojiData{Name: ":woman-facepalming:", Description: "Woman Facepalming", Unicode: "1F926-200D-2640-FE0F", Alias: []string(nil)}, ":woman-frowning:": emojiData{Name: ":woman-frowning:", Description: "Woman Frowning", Unicode: "1F64D-200D-2640-FE0F", Alias: []string(nil)}, ":woman-gesturing-no:": emojiData{Name: ":woman-gesturing-no:", Description: "Woman Gesturing No", Unicode: "1F645-200D-2640-FE0F", Alias: []string(nil)}, ":woman-gesturing-ok:": emojiData{Name: ":woman-gesturing-ok:", Description: "Woman Gesturing Ok", Unicode: "1F646-200D-2640-FE0F", Alias: []string(nil)}, ":woman-getting-haircut:": emojiData{Name: ":woman-getting-haircut:", Description: "Woman Getting Haircut", Unicode: "1F487-200D-2640-FE0F", Alias: []string(nil)}, ":woman-getting-massage:": emojiData{Name: ":woman-getting-massage:", Description: "Woman Getting Massage", Unicode: "1F486-200D-2640-FE0F", Alias: []string(nil)}, ":woman-girl-boy:": emojiData{Name: ":woman-girl-boy:", Description: "Woman Girl Boy", Unicode: "1F469-200D-1F467-200D-1F466", Alias: []string(nil)}, ":woman-girl-girl:": emojiData{Name: ":woman-girl-girl:", Description: "Woman Girl Girl", Unicode: "1F469-200D-1F467-200D-1F467", Alias: []string(nil)}, ":woman-girl:": emojiData{Name: ":woman-girl:", Description: "Woman Girl", Unicode: "1F469-200D-1F467", Alias: []string(nil)}, ":woman-golfing:": emojiData{Name: ":woman-golfing:", Description: "Woman Golfing", Unicode: "1F3CC-FE0F-200D-2640-FE0F", Alias: []string(nil)}, ":woman-heart-man:": emojiData{Name: ":woman-heart-man:", Description: "Woman Heart Man", Unicode: "1F469-200D-2764-FE0F-200D-1F468", Alias: []string(nil)}, ":woman-heart-woman:": emojiData{Name: ":woman-heart-woman:", Description: "Woman Heart Woman", Unicode: "1F469-200D-2764-FE0F-200D-1F469", Alias: []string(nil)}, ":woman-juggling:": emojiData{Name: ":woman-juggling:", Description: "Woman Juggling", Unicode: "1F939-200D-2640-FE0F", Alias: []string(nil)}, ":woman-kiss-man:": emojiData{Name: ":woman-kiss-man:", Description: "Woman Kiss Man", Unicode: "1F469-200D-2764-FE0F-200D-1F48B-200D-1F468", Alias: []string(nil)}, ":woman-kiss-woman:": emojiData{Name: ":woman-kiss-woman:", Description: "Woman Kiss Woman", Unicode: "1F469-200D-2764-FE0F-200D-1F48B-200D-1F469", Alias: []string(nil)}, ":woman-lifting-weights:": emojiData{Name: ":woman-lifting-weights:", Description: "Woman Lifting Weights", Unicode: "1F3CB-FE0F-200D-2640-FE0F", Alias: []string(nil)}, ":woman-mountain-biking:": emojiData{Name: ":woman-mountain-biking:", Description: "Woman Mountain Biking", Unicode: "1F6B5-200D-2640-FE0F", Alias: []string(nil)}, ":woman-playing-handball:": emojiData{Name: ":woman-playing-handball:", Description: "Woman Playing Handball", Unicode: "1F93E-200D-2640-FE0F", Alias: []string(nil)}, ":woman-playing-water-polo:": emojiData{Name: ":woman-playing-water-polo:", Description: "Woman Playing Water Polo", Unicode: "1F93D-200D-2640-FE0F", Alias: []string(nil)}, ":woman-pouting:": emojiData{Name: ":woman-pouting:", Description: "Woman Pouting", Unicode: "1F64E-200D-2640-FE0F", Alias: []string(nil)}, ":woman-raising-hand:": emojiData{Name: ":woman-raising-hand:", Description: "Woman Raising Hand", Unicode: "1F64B-200D-2640-FE0F", Alias: []string(nil)}, ":woman-rowing-boat:": emojiData{Name: ":woman-rowing-boat:", Description: "Woman Rowing Boat", Unicode: "1F6A3-200D-2640-FE0F", Alias: []string(nil)}, ":woman-running:": emojiData{Name: ":woman-running:", Description: "Woman Running", Unicode: "1F3C3-200D-2640-FE0F", Alias: []string(nil)}, ":woman-shrugging:": emojiData{Name: ":woman-shrugging:", Description: "Woman Shrugging", Unicode: "1F937-200D-2640-FE0F", Alias: []string(nil)}, ":woman-surfing:": emojiData{Name: ":woman-surfing:", Description: "Woman Surfing", Unicode: "1F3C4-200D-2640-FE0F", Alias: []string(nil)}, ":woman-swimming:": emojiData{Name: ":woman-swimming:", Description: "Woman Swimming", Unicode: "1F3CA-200D-2640-FE0F", Alias: []string(nil)}, ":woman-tipping-hand:": emojiData{Name: ":woman-tipping-hand:", Description: "Woman Tipping Hand", Unicode: "1F481-200D-2640-FE0F", Alias: []string(nil)}, ":woman-walking:": emojiData{Name: ":woman-walking:", Description: "Woman Walking", Unicode: "1F6B6-200D-2640-FE0F", Alias: []string(nil)}, ":woman-wearing-turban:": emojiData{Name: ":woman-wearing-turban:", Description: "Woman Wearing Turban", Unicode: "1F473-200D-2640-FE0F", Alias: []string(nil)}, ":woman-with-bunny-ears-partying:": emojiData{Name: ":woman-with-bunny-ears-partying:", Description: "Woman with Bunny Ears Partying", Unicode: "1F46F-200D-2640-FE0F", Alias: []string(nil)}, ":woman-woman-boy-boy:": emojiData{Name: ":woman-woman-boy-boy:", Description: "Woman Woman Boy Boy", Unicode: "1F469-200D-1F469-200D-1F466-200D-1F466", Alias: []string(nil)}, ":woman-woman-boy:": emojiData{Name: ":woman-woman-boy:", Description: "Woman Woman Boy", Unicode: "1F469-200D-1F469-200D-1F466", Alias: []string(nil)}, ":woman-woman-girl-boy:": emojiData{Name: ":woman-woman-girl-boy:", Description: "Woman Woman Girl Boy", Unicode: "1F469-200D-1F469-200D-1F467-200D-1F466", Alias: []string(nil)}, ":woman-woman-girl-girl:": emojiData{Name: ":woman-woman-girl-girl:", Description: "Woman Woman Girl Girl", Unicode: "1F469-200D-1F469-200D-1F467-200D-1F467", Alias: []string(nil)}, ":woman-woman-girl:": emojiData{Name: ":woman-woman-girl:", Description: "Woman Woman Girl", Unicode: "1F469-200D-1F469-200D-1F467", Alias: []string(nil)}, ":woman-wrestling:": emojiData{Name: ":woman-wrestling:", Description: "Woman Wrestling", Unicode: "1F93C-200D-2640-FE0F", Alias: []string(nil)}, ":woman:": emojiData{Name: ":girl:", Description: "Girl", Unicode: "1F467", Alias: []string{"female", "woman", "teenager"}}, ":woman_climbing:": emojiData{Name: ":woman_climbing:", Description: "Woman Climbing", Unicode: "1F9D7-200D-2640-FE0F", Alias: []string(nil)}, ":woman_in_lotus_position:": emojiData{Name: ":woman_in_lotus_position:", Description: "Woman in Lotus Position", Unicode: "1F9D8-200D-2640-FE0F", Alias: []string(nil)}, ":woman_in_steamy_room:": emojiData{Name: ":woman_in_steamy_room:", Description: "Woman in Steamy Room", Unicode: "1F9D6-200D-2640-FE0F", Alias: []string(nil)}, ":womans_clothes:": emojiData{Name: ":womans_clothes:", Description: "Womans Clothes", Unicode: "1F45A", Alias: []string{"fashion", "shopping_bags", "female"}}, ":womans_hat:": emojiData{Name: ":womans_hat:", Description: "Womans Hat", Unicode: "1F452", Alias: []string{"fashion", "accessories", "female", "lady", "spring"}}, ":women:": emojiData{Name: ":older_woman:", Description: "Older Woman", Unicode: "1F475", Alias: []string{"human", "female", "women", "lady", "old", "elder", "senior"}}, ":womens:": emojiData{Name: ":womens:", Description: "Womens Symbol", Unicode: "1F6BA", Alias: []string{"purple-square", "woman", "female", "toilet", "loo", "restroom", "gender"}}, ":woo:": emojiData{Name: ":hushed:", Description: "Hushed Face", Unicode: "1F62F", Alias: []string{"face", "woo", "shh"}}, ":woof:": emojiData{Name: ":dog:", Description: "Dog Face", Unicode: "1F436", Alias: []string{"animal", "friend", "nature", "woof", "puppy", "pet", "faithful"}}, ":wool:": emojiData{Name: ":sheep:", Description: "Sheep", Unicode: "1F411", Alias: []string{"animal", "nature", "wool", "shipit"}}, ":words:": emojiData{Name: ":cl:", Description: "Squared Cl", Unicode: "1F191", Alias: []string{"alphabet", "words", "red-square"}}, ":work:": emojiData{Name: ":office:", Description: "Office Building", Unicode: "1F3E2", Alias: []string{"building", "bureau", "work"}}, ":working:": emojiData{Name: ":building_construction:", Description: "Building Construction", Unicode: "1F3D7-FE0F", Alias: []string{"wip", "working", "progress"}}, ":world:": emojiData{Name: ":earth_asia:", Description: "Earth Globe Asia-Australia", Unicode: "1F30F", Alias: []string{"globe", "world", "east", "international"}}, ":world_map:": emojiData{Name: ":world_map:", Description: "World Map", Unicode: "1F5FA-FE0F", Alias: []string{"location", "direction"}}, ":worm:": emojiData{Name: ":bug:", Description: "Bug", Unicode: "1F41B", Alias: []string{"animal", "insect", "nature", "worm"}}, ":worried:": emojiData{Name: ":worried:", Description: "Worried Face", Unicode: "1F61F", Alias: []string{"face", "concern", "nervous", ":("}}, ":worship:": emojiData{Name: ":synagogue:", Description: "Synagogue", Unicode: "1F54D", Alias: []string{"judaism", "worship", "temple", "jewish"}}, ":wow:": emojiData{Name: ":grey_exclamation:", Description: "White Exclamation Mark Ornament", Unicode: "2755", Alias: []string{"surprise", "punctuation", "gray", "wow", "warning"}}, ":wrench:": emojiData{Name: ":wrench:", Description: "Wrench", Unicode: "1F527", Alias: []string{"tools", "diy", "ikea", "fix", "ainer"}}, ":wrestlers:": emojiData{Name: ":wrestlers:", Description: "Wrestlers", Unicode: "1F93C", Alias: []string(nil)}, ":write:": emojiData{Name: ":writing_hand:", Description: "Writing Hand", Unicode: "270D-FE0F", Alias: []string{"lower_left_ballpoint_pen", "stationery", "write", "compose"}}, ":writing:": emojiData{Name: ":memo:", Description: "Memo", Unicode: "1F4DD", Alias: []string{"write", "documents", "stationery", "pencil", "paper", "writing", "legal", "exam", "quiz", "test", "study", "compose"}}, ":writing_hand:": emojiData{Name: ":writing_hand:", Description: "Writing Hand", Unicode: "270D-FE0F", Alias: []string{"lower_left_ballpoint_pen", "stationery", "write", "compose"}}, ":x:": emojiData{Name: ":x:", Description: "Cross Mark", Unicode: "274C", Alias: []string{"no", "delete", "remove", "cancel"}}, ":xmas:": emojiData{Name: ":snowflake:", Description: "Snowflake", Unicode: "2744-FE0F", Alias: []string{"winter", "season", "cold", "weather", "christmas", "xmas"}}, ":xox:": emojiData{Name: ":dizzy_face:", Description: "Dizzy Face", Unicode: "1F635", Alias: []string{"spent", "unconscious", "xox", "dizzy"}}, ":yacht:": emojiData{Name: ":passenger_ship:", Description: "Passenger Ship", Unicode: "1F6F3-FE0F", Alias: []string{"yacht", "cruise", "ferry"}}, ":yay:": emojiData{Name: ":clap:", Description: "Clapping Hands Sign", Unicode: "1F44F", Alias: []string{"hands", "praise", "applause", "congrats", "yay"}}, ":yea:": emojiData{Name: ":raised_hands:", Description: "Person Raising Both Hands in Celebration", Unicode: "1F64C", Alias: []string{"gesture", "hooray", "yea", "celebration", "hands"}}, ":yellow-diamond:": emojiData{Name: ":children_crossing:", Description: "Children Crossing", Unicode: "1F6B8", Alias: []string{"school", "warning", "danger", "sign", "driving", "yellow-diamond"}}, ":yellow:": emojiData{Name: ":full_moon:", Description: "Full Moon Symbol", Unicode: "1F315", Alias: []string{"nature", "yellow", "twilight", "planet", "space", "night", "evening", "sleep"}}, ":yellow_heart:": emojiData{Name: ":yellow_heart:", Description: "Yellow Heart", Unicode: "1F49B", Alias: []string{"love", "like", "affection", "valentines"}}, ":yen:": emojiData{Name: ":yen:", Description: "Banknote with Yen Sign", Unicode: "1F4B4", Alias: []string{"money", "sales", "japanese", "dollar", "currency"}}, ":yes:": emojiData{Name: ":heavy_check_mark:", Description: "Heavy Check Mark", Unicode: "2714-FE0F", Alias: []string{"ok", "nike", "answer", "yes", "tick"}}, ":yin_yang:": emojiData{Name: ":yin_yang:", Description: "Yin Yang", Unicode: "262F-FE0F", Alias: []string{"balance"}}, ":yum:": emojiData{Name: ":yum:", Description: "Face Savouring Delicious Food", Unicode: "1F60B", Alias: []string{"happy", "joy", "tongue", "smile", "face", "silly", "yummy", "nom", "delicious", "savouring"}}, ":yummy:": emojiData{Name: ":yum:", Description: "Face Savouring Delicious Food", Unicode: "1F60B", Alias: []string{"happy", "joy", "tongue", "smile", "face", "silly", "yummy", "nom", "delicious", "savouring"}}, ":zany_face:": emojiData{Name: ":zany_face:", Description: "Grinning Face with One Large and One Small Eye", Unicode: "1F92A", Alias: []string(nil)}, ":zap:": emojiData{Name: ":zap:", Description: "High Voltage Sign", Unicode: "26A1", Alias: []string{"thunder", "weather", "lightning bolt", "fast"}}, ":zebra_face:": emojiData{Name: ":zebra_face:", Description: "Zebra Face", Unicode: "1F993", Alias: []string(nil)}, ":zero:": emojiData{Name: ":zero:", Description: "Keycap 0", Unicode: "0030-FE0F-20E3", Alias: []string{"0", "numbers", "blue-square", "null"}}, ":zipper:": emojiData{Name: ":zipper_mouth_face:", Description: "Zipper-Mouth Face", Unicode: "1F910", Alias: []string{"face", "sealed", "zipper", "secret"}}, ":zipper_mouth_face:": emojiData{Name: ":zipper_mouth_face:", Description: "Zipper-Mouth Face", Unicode: "1F910", Alias: []string{"face", "sealed", "zipper", "secret"}}, ":zodiac:": emojiData{Name: ":aquarius:", Description: "Aquarius", Unicode: "2652", Alias: []string{"sign", "purple-square", "zodiac", "astrology"}}, ":zombie:": emojiData{Name: ":zombie:", Description: "Zombie", Unicode: "1F9DF", Alias: []string(nil)}, ":zoom:": emojiData{Name: ":mag:", Description: "Left-Pointing Magnifying Glass", Unicode: "1F50D", Alias: []string{"search", "zoom", "find", "detective"}}, ":zoomin:": emojiData{Name: ":microscope:", Description: "Microscope", Unicode: "1F52C", Alias: []string{"laboratory", "experiment", "zoomin", "science", "study"}}, ":zzz:": emojiData{Name: ":zzz:", Description: "Sleeping Symbol", Unicode: "1F4A4", Alias: []string{"sleepy", "tired", "dream"}}}
